/*******************************************************************************	

Project:  		KePSIE


Written by:  	Thomas Escande			

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Perform the decomposition analysis on all scenarios and generate a figure comparing them 

CONTENT:		Part 0 - Create globals for directories and files 


INPUTS:     	"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"
					
OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	
	*Dofiles to run
		global decomposition_construction 	"${do_end_fin}/decomposition_construction.do"		
		global decomposition  				"${do_end_fin}/decomposition.do"		
		

	*Options for graphs
	global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid noticks)  legend(region(lc(none) fc(none)))

********************************************************************************
** Part 1: Flagging the different facilities with which there are issues to then change in the simulation
********************************************************************************

use "${inputdata}", clear
drop if hfid == 500119 //to delete once Amy has made the change
*Defining the sample: 
keep if !mi(market_all_expanded) //only keep facilities that are part of a market, meaning they have been randomized
keep if active_bl == 1 | active == 1 //Keeping facilities which are either active at baseline and/or active at endline (66 facilities) as we are looking at changes in baseline versus endline so don't care about facilities which are just in the middle period

*Variables recording wether facility was active both at baseline and endline, or exited or enter.
gen continuing = 0
replace continuing = 1 if active_bl == 1 & active == 1
gen entering = 0
replace entering = 1   if active_bl != 1 & active == 1

gen exiting = 0
replace exiting = 1    if active_bl == 1 & active != 1

*Markets with at least one active facility at endline and one active facility at baseline
bys market_all_expanded  : egen N_bl_consent = sum(bl_consent)
bys market_all_expanded  : egen N_fl_consent = sum(fl_consent)

*Generating flags for facilities with issues
gen 	issue_mkt_change = 0
replace issue_mkt_change = 1 		if N_fl_consent == 0 |  N_bl_consent== 0 //Facilities which belong to a market that either has no facilities at baseline or no facilities at endline
drop if issue_mkt_change == 1 //Need to drop it here, cannot vary it as market has to be stable as we compare entry and exit to average quality at the market level at baseline.  

gen 	issue_exithf_ncons_bl = 0
replace issue_exithf_ncons_bl = 1 	if active != 1 & bl_consent !=1  //Facilities which did not give consent at baseline and were not active at endline

gen 	issue_enterhf_ncons_fl = 0
replace issue_enterhf_ncons_fl = 1 	if active_bl != 1 & fl_consent !=1  //Facilities which were not active at baseline and did not give consent at endline

gen 	issue_hf_ncons_fl = 0
replace issue_hf_ncons_fl = 1 		if  active == 1 & bl_consent ==1 & fl_consent !=1   //Facilities which gave consent at baseline but did not give consent at endline (but active)

gen 	issue_hf_ncons_bl = 0
replace issue_hf_ncons_bl = 1 		if  active_bl == 1 & bl_consent !=1 & fl_consent ==1     //Facilities which did not give consent at baseline (but active) but gave consent at endline 

gen     issue_hf_ncons = 0
replace issue_hf_ncons = 1 			if  active_bl == 1 & bl_consent !=1 & fl_consent !=1  & active == 1   //Facilities which did not give consent at baseline (but active) and no consent at endline (but active)

gen 	issue_mi_outp_bl = 0
replace issue_mi_outp_bl = 1 		if  active_bl == 1 & bl_consent ==1 & mi(outp_as_jan_bl)

bysort market_all_expanded : egen tot_fac 		= sum(active) 
bysort market_all_expanded : egen tot_fac_bl 	= sum(active_bl) 

gen issue_fac 		= issue_enterhf_ncons_fl + issue_hf_ncons_fl + issue_hf_ncons_bl + issue_hf_ncons 
gen issue_fac_bl 	= issue_exithf_ncons_bl + issue_hf_ncons_bl + issue_hf_ncons_fl + issue_hf_ncons + issue_mi_outp_bl


bysort market_all_expanded : egen N_fac_mi 		= sum(issue_fac) 
gen per_fac_mi		= N_fac_mi / tot_fac 							//Percentage of facilities at endline in each market that have an issue and should be dropped impacting the whole market

bysort market_all_expanded : egen N_fac_mi_bl 	= sum(issue_fac_bl) 
gen per_fac_mi_bl     = N_fac_mi_bl / tot_fac_bl 					//Percentage of facilities at baseline in each market that have an issue and should be dropped impacting the whole market

*Assumption here
*Three hfs which belong to issue_exithf_ncons_bl have a missing for level. As the 20 other facilities in the same situation are all level 2, we will impute the missing with level 2
replace level = 2 if mi(level) & issue_exithf_ncons_bl == 1

*Variables for imputations: impute by the mean within similar categories : by level, treatment and ownership
bysort t private level : egen jhic_av 		= mean(jhic_all)
bysort t private level : egen jhic_av_bl 	= mean(jhic_all_bl)
bysort t private level : egen outp_av 		= mean(outp_as_jan)
bysort t private level : egen outp_av_bl 	= mean(outp_as_jan_bl)

********************************************************************************
** Part 2: Running the construction and analysis on the selected sample
********************************************************************************
*Setting up globals for how to run it
/* Taking it out for now
*S1 Dropping markets which do not have facilities at baseline and endline and dropping facilities which have some missing because of consent issues
global scenario 			S1
preserve
drop if issue_exithf_ncons_bl == 1 | issue_enterhf_ncons_fl == 1 | issue_hf_ncons_fl == 1 | issue_hf_ncons_bl == 1 | issue_hf_ncons == 1 | issue_mi_outp_bl == 1
*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) & t == 1
global S1_N_t = r(N)
count if !mi(outp_as_jan) & t == 0
global S1_N_c = r(N)
levelsof market_all_expanded
global S1_M = r(r)
do ${decomposition_construction}
do ${decomposition}
restore */

*S1 Basic scenario : Dropping markets when more than 30% of the outpatients (from the listing) come from facilities that have missings at baseline or endline
global scenario 			S1
preserve
drop if market_all_expanded ==6 | market_all_expanded == 194 | market_all_expanded == 199 | market_all_expanded == 241 | market_all_expanded == 273 ///
						| issue_exithf_ncons_bl == 1 | issue_enterhf_ncons_fl == 1 | issue_hf_ncons_fl == 1 | issue_hf_ncons_bl == 1 | issue_hf_ncons == 1 | issue_mi_outp_bl == 1

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
global reg_${scenario}_1_5_2 = _N /*Using all the facilities in the sample to compute the values at the market level and run the regression*/
do "${decomposition_construction}"
do "${decomposition}"
mat ${scenario} = Res_${scenario}'
clear
svmat ${scenario}
*Order of coeff and for merging after
gen coeff = _n 
tempfile ${scenario}
save `${scenario}'
restore


*S2 Keeping markets which do not have facilities at baseline and endline and dropping facilities which have some missing because of consent issues
global scenario 			S2
preserve
drop if per_fac_mi_bl > 0 | per_fac_mi > 0
*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
*Analyzing best and worst facilities to impute in later best and worst scenario
*Continuing
gen tot_continuing  = tsum_within + tsum_between + tsum_cross
gen delta_outp 		= outp_as_jan - outp_as_jan_bl
gen delta_jhic_all  = jhic_all - jhic_all_bl
sum tot_continuing if t == 0 & tsum_between != 0
list  outp_as_jan jhic_all outp_as_jan_bl jhic_all_bl delta_outp delta_jhic_all tot_continuing if (tot_continuing <= `r(min)'+0.001 | tot_continuing >= `r(max)'-0.001) & !mi(tot_continuing) & t == 0 & tsum_between != 0
/*

     +------------------------------------------------------------------------------+
     | ou~s_jan   jhic_all   outp_a..   jhi~l_bl   delta_~p   delta_j~l   tot_con~g |
     |------------------------------------------------------------------------------|
	 | 55.13044      25.18   49.09091   53.92489   6.039528   -28.74489   -13.55206 |
	 | 36.47826      49.25   19.90909    35.0788   16.56917     14.1712    14.05609 |
     +------------------------------------------------------------------------------+

*/

sum tot_continuing if t == 1  & tsum_between != 0
list  outp_as_jan jhic_all outp_as_jan_bl jhic_all_bl delta_outp delta_jhic_all tot_continuing if (tot_continuing <= `r(min)'+0.001 | tot_continuing >= `r(max)'-0.001) & !mi(tot_continuing) & t == 1 & tsum_between != 0
/*

     +-------------------------------------------------------------------------------+
     | ou~s_jan   jhic_all   outp_a..   jhi~l_bl   delta_o~p   delta_j~l   tot_con~g |
     |-------------------------------------------------------------------------------|
	 | 35.83871      40.71   53.41935   55.63184   -17.58064   -14.92184   -12.54309 |
	 | 40.78261      56.04   5.727273   36.24445    35.05534    19.79556    14.73641 |
     +-------------------------------------------------------------------------------+

*/


*Entry
sum tsum_entry if t == 0 
list  outp_as_jan jhic_all if (tsum_entry <= `r(min)'+0.001 | tsum_entry >= `r(max)'-0.001) & !mi(tsum_entry) & t == 0

/*
     +---------------------+
     | ou~s_jan   jhic_all |
     |---------------------|
	 | 36.47826      46.51 |
	 |    8.375      18.26 |
     +---------------------+*/
sum tsum_entry if t == 1 
list outp_as_jan jhic_all if (tsum_entry <= `r(min)'+0.001 | tsum_entry >= `r(max)' -0.001) & !mi(tsum_entry) & t == 1
/*
     +---------------------+
     | ou~s_jan   jhic_all |
     |---------------------|
	 | 50.21739      28.54 |
	 | 30.90322      38.77 |
     +---------------------+
*/

*Exit
sum tsum_exit if t == 0 
list outp_as_jan_bl jhic_all_bl if (tsum_exit <= `r(min)'+0.001 | tsum_exit >= `r(max)'-0.001) & !mi(tsum_exit) & t == 0
/*
     +---------------------+
     | outp_a..   jhi~l_bl |
     |---------------------|
	 |       10   14.93333 |
	 | 2.592592      43.75 |
     +---------------------+

*/ 
 
sum tsum_exit if t == 1 
list outp_as_jan_bl jhic_all_bl if (tsum_exit <= `r(min)'+0.001 | tsum_exit >= `r(max)'-0.001) & !mi(tsum_exit) & t == 1 
/*
     +---------------------+
     | outp_a..   jhi~l_bl |
     |---------------------|
	 | 21.03704   25.43333 |
	 |       15   29.56944 |
     +---------------------+

*/

do "${decomposition}"
mat ${scenario} = Res_${scenario}'
clear
svmat ${scenario}
*Order of coeff and for merging after
gen coeff = _n 
tempfile ${scenario}
save `${scenario}'
restore


*S3 Imputation with average
global scenario 			S3
preserve

*Imputation with listing for baseline outpatients first
replace outp_as_jan_bl = patients_day if (issue_mi_outp_bl == 1 | issue_hf_ncons == 1 | issue_hf_ncons_bl | issue_exithf_ncons_bl == 1) & mi(outp_as_jan_bl)

*Imputation with average for similar groups 
replace outp_as_jan_bl  = outp_av_bl if mi(outp_as_jan_bl)  & active_bl == 1 
replace outp_as_jan 	= outp_av    if mi(outp_as_jan) 	& active == 1 
replace jhic_all_bl     = jhic_av_bl if mi(jhic_all_bl)   	& active_bl == 1 
replace jhic_all 		= jhic_av   if mi(jhic_all) 		& active == 1 

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
do "${decomposition}"
mat ${scenario} = Res_${scenario}'
clear
svmat ${scenario}
*Order of coeff and for merging after
gen coeff = _n 
tempfile ${scenario}
save `${scenario}'
restore


*S4 Best Scenario (see S2 for the origin of the values: facilities which gave higher number of entry, within between cross and exit
global scenario 			S4
preserve

*Continuing facilities
*No data either at baseline or endline
replace outp_as_jan 	=  36.47826     if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		=  49.25  		 if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  =  19.90909  	 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	=  35.0788 	 if t == 0 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

replace outp_as_jan 	= 40.78261   if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		= 56.04   	  if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  = 5.727273   if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	= 36.24445   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

*Data at baseline only
replace outp_as_jan 	=  outp_as_jan_bl 	+ 16.56917	if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl 	+ 14.1712	if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1
replace outp_as_jan 	=  outp_as_jan_bl  + 35.05534 	if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl  	+ 19.79556	if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1

*Data at endline only
replace outp_as_jan_bl  =  outp_as_jan - 16.56917 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all  - 14.1712    if t == 0 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace outp_as_jan_bl  =  outp_as_jan - 35.05534 if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all  - 19.79556   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)


*Entering facilities
replace outp_as_jan = 36.47826  if t == 0 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 46.51 	 if t == 0 & mi(jhic_all)    & entering == 1

replace outp_as_jan = 30.90322  if t == 1 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 38.77 	 if t == 1 & mi(jhic_all)    & entering == 1

*Exiting facilities 
replace outp_as_jan_bl  = 10  			 if t == 0 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 14.93333 	 if t == 0 & mi(jhic_all_bl)    & exiting == 1

replace outp_as_jan_bl  = 21.03704  	 if t == 1 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 25.43333 	 if t == 1 & mi(jhic_all_bl)    & exiting == 1


*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
do "${decomposition}"
mat ${scenario} = Res_${scenario}'
clear
svmat ${scenario}
*Order of coeff and for merging after
gen coeff = _n 
tempfile ${scenario}
save `${scenario}'
restore



*S5 Worst Scenario
global scenario 			S5
preserve

*No data either at baseline or endline
replace outp_as_jan 	=  55.13044    if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		=  25.18  		 if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  =  49.09091  	 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	=  53.92489 	 if t == 0 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

replace outp_as_jan 	= 35.83871   if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		= 40.71   	  if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  = 53.41935   if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	= 55.63184   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

*Data at baseline only
replace outp_as_jan 	=  outp_as_jan_bl 	+ 6.039528	if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl 	- 28.74489	if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1
replace outp_as_jan 	=  outp_as_jan_bl  - 17.58064 	if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl  	- 14.92184	if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1

*Data at endline only
replace outp_as_jan_bl  =  outp_as_jan - 6.039528 		if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all    + 28.74489    	if t == 0 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace outp_as_jan_bl  =  outp_as_jan + 17.58064 		if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all    + 14.92184   	if t == 1 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)

*Entering facilities
replace outp_as_jan = 8.375   	 if t == 0 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 18.26 	 if t == 0 & mi(jhic_all)    & entering == 1

replace outp_as_jan = 50.21739  if t == 1 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 28.54 	 if t == 1 & mi(jhic_all)    & entering == 1

*Exiting facilities 
replace outp_as_jan_bl  = 2.592592  	 if t == 0 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 43.75  		 if t == 0 & mi(jhic_all_bl)    & exiting == 1

replace outp_as_jan_bl  = 15  			 if t == 1 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 29.56944 	 if t == 1 & mi(jhic_all_bl)    & exiting == 1

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
do "${decomposition}"
mat ${scenario} = Res_${scenario}'
clear
svmat ${scenario}
*Order of coeff and for merging after
gen coeff = _n 
tempfile ${scenario}
save `${scenario}'
restore



********************************************************************************
** Part 3: Graph
********************************************************************************
global S1 "Basic Scenario"
global S2 "Only Complete Markets"
global S3 "Mean Imputation"
global S4 "Highest Contribution Imputation"
global S5 "Lowest Contribution Imputation"

*Merging all temporary files with the values to show all the scenarios on the same graph

use `S1', clear 
merge 1:1 coeff using `S2', nogen assert(3)
merge 1:1 coeff using `S3', nogen assert(3)
merge 1:1 coeff using `S4', nogen assert(3)
merge 1:1 coeff using `S5', nogen assert(3)

gen zero = 0

forvalues i = 1/5 {
rename S`i'1 S`i'_t
rename S`i'6 S`i'_CIl
rename S`i'7 S`i'_CIh
}

*Starting developing the graphs	
*Coefficient as dots and CI, but with a slight lag
gen coeff_2 = coeff + 0.1
gen coeff_3 = coeff + 0.2
gen coeff_4 = coeff + 0.3
gen coeff_5 = coeff + 0.4
gen coeff_6 = coeff 
replace coeff_6 = coeff + 0.4 if coeff == 6

twoway (scatter S1_t coeff,mcolor(edkblue)) ///
		(scatter S2_t coeff_2, mcolor(sienna))  ///
		(scatter S3_t coeff_3, mcolor(dkgreen)) ///
		(scatter S4_t coeff_4, mcolor(dkorange))  ///
		(scatter S5_t coeff_5, mcolor(teal)) ///
		(rcap S1_CIl S1_CIh coeff, lcolor(edkblue))  ///
		(rcap S2_CIl S2_CIh coeff_2, lcolor(sienna))  ///
		(rcap S3_CIl S3_CIh coeff_3, lcolor(dkgreen))  ///
		(rcap S4_CIl S4_CIh coeff_4, lcolor(dkorange))  ///
		(rcap S5_CIl S5_CIh coeff_5, lcolor(teal))  ///
		(line  zero coeff_6, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend( order(1 2 3 4 5) row(3) pos(6) label(1 "${S1}") label(2 "${S2}") label(3 "${S3}") label(4 "${S4}") label(5 "${S5}")) ///
		 xlabel( 1.1 "Total" 2.1 "Within" 3.1 "Between" 4.1 "Cross" 5.1 "Entry"  6.2 "Exit" , noticks labgap(3)) xscale(noline) yscale(noline) ///
		xtitle("") ytitle("Treatment Impact (Percentage Points of JHIC)") yscale(range(-2 7)) ylab(-2(1)7, noticks labgap(2)) scheme(cleanplots)
		
	graph export  "${figure_loc}/figure_A6.png", replace

/*
*Coefficient as bars and CI, but with a slight lag
twoway (bar S1_t coeff,bcolor(edkblue) barw(0.1)) ///
		(bar S2_t coeff_2, bcolor(sienna) barw(0.1))  ///
		(bar S3_t coeff_3, bcolor(dkgreen) barw(0.1)) ///
		(bar S4_t coeff_4, bcolor(dkorange) barw(0.1))  ///
		(bar S5_t coeff_5, bcolor(teal) barw(0.1)) ///
		(rcap S1_CIl S1_CIh coeff, lcolor(edkblue))  ///
		(rcap S2_CIl S2_CIh coeff_2, lcolor(sienna))  ///
		(rcap S3_CIl S3_CIh coeff_3, lcolor(dkgreen))  ///
		(rcap S4_CIl S4_CIh coeff_4, lcolor(dkorange))  ///
		(rcap S5_CIl S5_CIh coeff_5, lcolor(teal))  ///
		(line  zero coeff_6, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend( order(1 2 3 4 5)  label(1 "${S1}") label(2 "${S2}") label(3 "${S3}") label(4 "${S4}") label(5 "${S5}")) ///
		 xlabel( 1.1 "Total" 2.1 "Within" 3.1 "Between" 4.1 "Cross" 5.1 "Entry"  6.2 "Exit" , noticks labgap(3)) xscale(noline) yscale(noline) ///
		xtitle("") ytitle("Treatment Impact (Percentage Points of JHIC)") yscale(range(-2 7)) ylab(-2(1)7, noticks labgap(2))  
		
	graph save    "${figure_stata}/decomp_s_bar_ci", replace
	graph export  "${figure_loc}/decomp_s_bar_ci.pdf", replace as(pdf)
*/
******************************End of do file*********************************
		
