/*******************************************************************************	

Project:  		KePSIE - Kenya


Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Compares QTE results when using dte versus using qreg2 stata written command 

CONTENT:		Part 0 - Create globals for directories and files
				Part 1 - 
INPUTS:     	

OUTPUTS:		

Note: This dofile requires two ado files to run which were taken from the paper "Distributional Impact Analysis", Bedoya et al.   	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

  * Set the environment to make randomization replicable
    version 12.0 	
	
	*Running the adofiles which will be used in the dofile
		do "${program}/bscr.ado" 
		do "${program}/dte.ado"		
		do "${program}/qreg2.ado"			
		
		glo inputdata	 	"${dt_final}/data_for_analysis.dta" 
		glo date = 			word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)
				
	*Options for graphs
	global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid noticks)  legend(region(lc(none) fc(none)))
	
	set seed 33
			
********************************************************************************
** Part 1: Setup 
********************************************************************************
use "${inputdata}", clear

		
	keep if !mi(t)  //Cannot have missing for the ado file so need to drop 
	gen 	zero 	= 0 	
	local 	first 	  1
	local 	bs_rep 	= 1000
	
	*Changing categories of marketsize_rand_expanded_group for this specific analysis:
	* 1-2 HFs, 3-10HFs, 11+ HFs
	ren  	marketsize_rand_expanded_group marketsize_rand_exp_group_o
	gen     marketsize_rand_expanded_group = 1 if marketsize_rand_exp_group_o == 1 | marketsize_rand_exp_group_o == 2
	replace marketsize_rand_expanded_group = 2 if marketsize_rand_exp_group_o == 3 | marketsize_rand_exp_group_o == 4
	replace marketsize_rand_expanded_group = 3 if marketsize_rand_exp_group_o == 5	
	
	*Generate county dummy
		forvalues i = 1/3 {
			gen county_`i' = 0
			replace county_`i' = 1 if county == `i'
		}
		
	
	loc x 3 // toggle based on market size group // update later in loops
	loc q 0.10 0.25 0.50 0.75 0.90 // set quantiles	
	
	*local additional_control `quart_var'_missing_d `quart_var'_quartile_dummy2 `quart_var'_quartile_dummy3 `quart_var'_quartile_dummy4
	*local additional_control  jhic_all_bl_m_mean 
	*local additional_control  jhic_all_bl
	local additional_control 	
	* Switches	
	* ---------


	
foreach var  in    jhic_all  {


	* Setup
	* ---------
local quart_var  jhic_all_bl /*Variable on which we define quartile dummy*/	
			
	* Dummy for Quartile at baseline level including the facility
	egen `quart_var'_quartile1 = pctile(`quart_var'), p(25) 
	egen `quart_var'_quartile2 = pctile(`quart_var'), p(50) 
	egen `quart_var'_quartile3 = pctile(`quart_var'), p(75)  
	
	* Dummy for belonging at each quartile
	gen 	`quart_var'_quartile_dummy1 = 0 if !mi(`quart_var') 
	replace `quart_var'_quartile_dummy1 = 1 if !mi(`quart_var') & `quart_var' <=  `quart_var'_quartile1	
	
	gen 	`quart_var'_quartile_dummy2 = 0 if !mi(`quart_var') 
	replace `quart_var'_quartile_dummy2 = 1 if !mi(`quart_var') & `quart_var' >  `quart_var'_quartile1	& `quart_var' <=  `quart_var'_quartile2 
	
	gen 	`quart_var'_quartile_dummy3 = 0 if !mi(`quart_var') 
	replace `quart_var'_quartile_dummy3 = 1 if !mi(`quart_var') & `quart_var' >  `quart_var'_quartile2	& `quart_var' <=  `quart_var'_quartile3 
	
	gen 	`quart_var'_quartile_dummy4 = 0 if !mi(`quart_var') 
	replace `quart_var'_quartile_dummy4 = 1 if !mi(`quart_var') & `quart_var' >  `quart_var'_quartile3	
	
		forvalues i = 1/4 {
	replace `quart_var'_quartile_dummy`i' = 0 if `quart_var'_missing_d == 1	
		}	
	

	
********************************************************************************
** Part 2: Run the different regressions
********************************************************************************
*Regression with HF controls, county levels, quartile baseline dummy 
foreach sample in All pub priv { 
	
	preserve 
	
if "`sample'" == "pub" {
    keep if private == 0
}
if "`sample'" == "priv" {
    keep if private == 1
}	

	gen x_axis_1   = _n if _n < 6
	gen x_axis_2   = x_axis_1 + 0.1	
	gen x_axis_3   = x_axis_2 + 0.1		
	
    gen coeff_`sample' 	= .
    gen CIl_`sample' 	= .
    gen CIu_`sample' 	= .		
	
	local i = 1 

		foreach j in `q'  {	
*Saving Test as with different command (only once)
if `j' == 0.1 {
		cap	sqreg `var' t level_3 level_4_5 county_2 county_3 `additional_control' , q(`q')  reps(`bs_rep')
		
	*Test 10th Quintile equal to 90th Quintile
		test [q10]t = [q90]t
		local test_10_90_p_`sample' : disp %4.3f round(r(p),0.001)	
	    
	*Test 25th Quintile equal to 75th Quintile
		test [q25]t = [q75]t
		local test_25_75_p_`sample' : disp %4.3f round(r(p),0.001)	    
				}
				
*Now using qreg2 to have more accurate standard errors and t statistics		
		cap	qreg2 `var' t level_3 level_4_5 county_2 county_3 `additional_control', q(`j') cluster(market_all_expanded) 

		replace coeff_`sample'   =  _b[t]	    		if _n == `i'
		replace CIl_`sample'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`sample' 	 =  r(table)[6,1]	    if _n == `i'
	
local i = `i' + 1
			}	
			
	*Saving Tempfile				
	keep coeff_`sample'	CIl_`sample' CIu_`sample' x_axis_1  x_axis_2 x_axis_3
	keep if !mi(x_axis_1)
	tempfile data_`sample'
	save `data_`sample''
	
	restore			
	}
		
		
		

* repeat (1) dummies  with HF controls, county levels, quartile baseline dummy 
foreach sample in All  priv { 
	preserve 
	
if "`sample'" == "priv" {
    keep if private == 1
}

	gen x_axis_1   = _n if _n < 6
	gen x_axis_2   = x_axis_1 + 0.1	
	gen x_axis_3   = x_axis_2 + 0.1	
	
forvalues x = 1/3 {
	
    gen coeff_`sample'_`x' 	= .
    gen CIl_`sample'_`x' 	= .
    gen CIu_`sample'_`x' 	= .	
	
	local i = 1 
	
		foreach j in `q'  {
*Saving Test as with different command (only once)
if `j' == 0.1 {
		cap	sqreg `var' t level_3 level_4_5 county_2 county_3 `additional_control' if inlist(marketsize_rand_expanded_group,`x') , q(`q')  reps(`bs_rep')
		
	*Test 10th Quintile equal to 90th Quintile
		test [q10]t = [q90]t
		local test_10_90_p_`sample'_`x'_mkt_size : disp %4.3f round(r(p),0.001)		
	    
	*Test 25th Quintile equal to 75th Quintile
		test [q25]t = [q75]t
		local test_25_75_p_`sample'_`x'_mkt_size : disp %4.3f round(r(p),0.001)	
				}

*Now using qreg2 to have more accurate standard errors and t statistics						
			lab var `var' "`var' Mkt `x' Quantile `j' baseline control `i' `sample'"
			qui sum `var' if t==0 & inlist(marketsize_rand_expanded_group,`x')
			loc control_mean `r(mean)'
			
		cap	qreg2 `var' t level_3 level_4_5 county_2 county_3 `additional_control' if inlist(marketsize_rand_expanded_group,`x') , q(`j') cluster(market_all_expanded) 
			glo con:  di %4.3f `e(convcode)'
 
 if "`additional_control'" ==  "`jhic_all_bl'" | "`sample'" != "priv" | `x' != 1 {
  		replace coeff_`sample'_`x'   =  _b[t]	    		if _n == `i'
		replace CIl_`sample'_`x'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`sample'_`x' 	 =  r(table)[6,1]	    if _n == `i'    
 }  
 if "`additional_control'" ==  "`jhic_all_bl'" & "`sample'" == "priv" & `x' == 1 {
  		replace coeff_`sample'_`x'   =  .	    if _n == `i'
		replace CIl_`sample'_`x'	 =  .		if _n == `i'
		replace CIu_`sample'_`x' 	 =  .	    if _n == `i'    
 } 
		
	
local i = `i' + 1
disp `i'
disp `x'
disp "`sample'"
			}
				
	}	
	
	*Saving Tempfile		
	keep coeff_`sample'_*	CIl_`sample'_* CIu_`sample'_* x_axis_1  x_axis_2  x_axis_3 
	keep if !mi(x_axis_1)
	tempfile data_`sample'_mkt_size
	save `data_`sample'_mkt_size'		
				
	restore		
		}	
	
	}
				

				
	* Final merge and generate graphs 
	
	use `data_All', clear
	merge 1:1 x_axis_1 using `data_pub', assert(3) nogen
	merge 1:1 x_axis_1 using `data_priv', assert(3) nogen
	
gen zero = 0	

gen 	x_axis_zero = 0.5 	if _n == 1 
replace x_axis_zero = 2 	if _n == 2 
replace x_axis_zero = 3.5 	if _n == 3 
replace x_axis_zero = 4 	if _n == 4
replace x_axis_zero = 5.3 	if _n == 5 
		
twoway  (scatter coeff_All    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_priv   x_axis_2   	,mcolor(edkblue)) ///
	    (scatter coeff_pub    x_axis_3 	, mcolor(sienna))  ///
		(rcap CIl_All 	CIu_All   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_priv 	CIu_priv   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_pub   CIu_pub  x_axis_3 , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(1) pos(6) order(1 2 3) label(1 "All Facilities" " " "Test 10th = 90th : `test_10_90_p_All'" "Test 25th = 75th : `test_25_75_p_All'" ) /// 
		label(2 "Private" " "  "Test 10th = 90th : `test_10_90_p_priv'" "Test 25th = 75th : `test_25_75_p_priv'") label(3 "Public" " "  "Test 10th = 90th : `test_10_90_p_pub'" "Test 25th = 75th : `test_25_75_p_pub'") size(small)) ///
		 xlabel( 1.1 "10th" 2.1 "25th" 3.1 "50th" 4.1 "75th" 5.1 "90th"  , noticks labgap(3)) xscale(noline range(0.5 5.3) titlegap(3) ) yscale(noline) ///
		xtitle("Percentile") ytitle("JHIC Score") yscale(range(-4 12)) ylab(-4(4)12, noticks labgap(2))  title("By Ownership") scheme(cleanplots) name(own)
		
	*graph export  "${out_main}/figure_3_cqte_own.pdf", replace as(pdf)		
	
	
	use `data_All_mkt_size', clear
	
gen zero = 0	

gen 	x_axis_zero = 0.5 	if _n == 1 
replace x_axis_zero = 2 	if _n == 2 
replace x_axis_zero = 3.5 	if _n == 3 
replace x_axis_zero = 4 	if _n == 4
replace x_axis_zero = 5.3 	if _n == 5 
		
twoway  (scatter coeff_All_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_All_2   	x_axis_2   	,mcolor(edkblue)) ///
	    (scatter coeff_All_3    x_axis_3 	, mcolor(sienna))  ///
		(rcap CIl_All_1 	CIu_All_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_All_2 	CIu_All_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_All_3   	CIu_All_3  	x_axis_3 , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(1) pos(6) order(1 2 3) label(1 "1-2 HFs" " " "Test 10th = 90th : `test_10_90_p_All_1_mkt_size'" "Test 25th = 75th : `test_25_75_p_All_1_mkt_size'" ) /// 
		label(2 "3-10 HFs" " "  "Test 10th = 90th : `test_10_90_p_All_2_mkt_size'" "Test 25th = 75th : `test_25_75_p_All_2_mkt_size'") label(3 "11+ HFs" " "  "Test 10th = 90th : `test_10_90_p_All_3_mkt_size'" "Test 25th = 75th : `test_25_75_p_All_3_mkt_size'") size(small)) ///
		 xlabel( 1.1 "10th" 2.1 "25th" 3.1 "50th" 4.1 "75th" 5.1 "90th"  , noticks labgap(3)) xscale(noline range(0.5 5.3) titlegap(3) ) yscale(noline) ///
		xtitle("Percentile") ytitle("JHIC Score") yscale(range(-4 12)) ylab(-4(4)12, noticks labgap(2))  title("By Market Size Group") scheme(cleanplots) name(mk)
		
	*graph export  "${out_main}/figure_3_cqte_mkt.pdf", replace as(pdf)		
		
		
	use `data_priv_mkt_size', clear
	
gen zero = 0	

gen 	x_axis_zero = 0.5 	if _n == 1 
replace x_axis_zero = 2 	if _n == 2 
replace x_axis_zero = 3.5 	if _n == 3 
replace x_axis_zero = 4 	if _n == 4
replace x_axis_zero = 5.3 	if _n == 5 
		
twoway  (scatter coeff_priv_2   	x_axis_2   	,mcolor(edkblue)) ///
	    (scatter coeff_priv_3    	x_axis_3 	, mcolor(sienna))  ///	
		(rcap CIl_priv_2 	CIu_priv_2  	 x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_priv_3   	CIu_priv_3  	x_axis_3 , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(1) pos(6) order(1 2)  /// 
		label(1 "3-10 HFs" " "  "Test 10th = 90th : `test_10_90_p_priv_2_mkt_size'" "Test 25th = 75th : `test_25_75_p_priv_2_mkt_size'") label(2 "11+ HFs" " "  "Test 10th = 90th : `test_10_90_p_priv_3_mkt_size'" "Test 25th = 75th : `test_25_75_p_priv_3_mkt_size'") size(small)) ///
		 xlabel( 1.1 "10th" 2.1 "25th" 3.1 "50th" 4.1 "75th" 5.1 "90th"  , noticks labgap(3)) xscale(noline range(0.5 5.3) titlegap(3) ) yscale(noline) ///
		xtitle("Percentile") ytitle("JHIC Score") yscale(range(-4 12)) ylab(-4(4)12, noticks labgap(2))  title("By Market Size Group (Private Only)") scheme(cleanplots) name(mk_pri)
		
	*graph export  "${out_main}/figure_3_cqte_mkt_pri.pdf", replace as(pdf)	
	
graph combine own mk mk_pri, row(3) iscale(.5) ysize(8) graphregion(color(white))	
	
graph export "${out_main}/figure_3.png", as(png)  replace
	
