/*******************************************************************************	

Project:  		KePSIE
Created on:  	August 2, 2017
Last udpate on: Oct 17, 2017

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
				  with select code lines from: Benjamin Daniels

Revision: 		Lupe Bedoya
					General structue - August 8, 14 2017

********************************************************************************			

THIS DO FILE: 	Cleans the Patient Exit database for upload in the WB microdata catalog


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
				Part 2 - Complete variables
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionnary					
		
INPUTS:     	* Raw data
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PatientExit_final.dta"
				
				* eQuestionnaire
				"$KePSIE_DB/Data Collection/Baseline/Questionnaires/Electronic/PE/PE_eQuestionnaire2_Baseline_corrected.xls"
				
				* Spotchecker list
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/spotcheckers.xlsx"
				
				* HF Baseline profile data
				"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta"

OUTPUTS:     	* Anonymized data for microdata catalog
				"${bl_dt}/Final/PE_clean_nopii.dta"
				
				* Non-anonymized data for further analysis
				"${bl_dt}/Final/PE_clean_pii.dta"
				
				* Quality checks 
				"${bl_dt}/Intermediate/PE_quality_checks.dta"
				
				* Dictionary
				"${bl_out}/Final/PE_clean_nopii_dictionary.xls"
				
				* Response rate table
				"${bl_out}/Final/PE_response_rate.xls"

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo pe_bl_raw		"${volume}/pe_bl_raw.dta"
		glo pe_bl_q 		"${doc_bl}/codebooks/pe_bl_equestionnaire.xlsx"
		glo spotcheckers 	"${volume}/supplemental/spotcheckers.xlsx"
		glo profile_bl		"${dt_mast}/profile_bl.dta"
		
	* Output files
		glo pe_bl			"${dt_bl_clean}/pe_bl.dta"
		glo qchecks  		"${dt_bl_clean}/pe_bl_qchecks.dta"
					
********************************************************************************
	** Part 1: Complete database
********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	
	cls
	clear all
	use "${pe_bl_raw}"
	
	* Drop unnecessary variables
	drop submissiondate deviceid subscriberid simid devicephonenum audio1 ///
		 audio2 audio1_s audio2_s time_startinteraction2 diff1 ///
		 b3_v c11_v1 c11_v2 c11_v3 c11_v4   time_endinteraction_s2 ///
		 time_endinteraction_e2 b3_v_s c11_v* diff2 time_endinteraction_e1 time_endinteraction_s1 ///
		 speedviolcount speedviollist formdef_version audio b3_c b8_c b8_v1* ///
		 b8_v2* b8_v3* b8_v4* c4_c1 c4_v c11_c a4* a7 k11_c k11_v a2_1_v a2_1 ///
		 facilitycode pri_string a10 a9 time_formopen b3_c_s b8_c_s c4_c1_s ///
		 c4_v_s c11_c_s a6_c starttime endtime a2_2 time_endinteraction2

	*-----------------*		 
	* Drop duplicates *
	*-----------------*	
	
	* Drop duplicates in terms of Patients. The duplicates are spotchecks done as 
	* part of the quality checks, usually by a supervisor or higher-quality enumerator.
	* We drop the spotcheks using the spotchecker list.
	
		duplicates list a5 a11_1
		duplicates tag  a5 a11_1 if a11_1 ! = ., gen(dup)

	* Prepare spotchecker list to merge
		preserve
		import excel "${spotcheckers}", sheet("Sheet1") firstrow clear
		rename level spotchecker_level
		tempfile spotcheckers
		save 	`spotcheckers'
		
	* Merge spotchecker list
		restore
		rename a8 spotchecker_id
		merge m:1 spotchecker_id using `spotcheckers'
		assert _merge != 2
	
	* Generate dummy for spotcheckers
		sort a5 a11_1 
		gen 	spotchecker = .
		replace spotchecker = 1 if _merge == 3
		replace spotchecker = 0 if _merge != 3
		drop 	_merge
	
	* See how many spotcheckers are there for duplicated survey
		bys a5 a11_1: egen spotcheck = sum(spotchecker) if a11_1 ! = . & dup > 0
	
	* We have three situations for duplicated surveys:
		* 1. One FO is a spotchecker and the other one is not 
		*	 --> we keep the survey made by the FO that is NOT a spotchecker

		gen	 	drop_dup = .
		replace drop_dup = 1 if spotcheck == 1 & spotchecker == 1
		
		* 2. No FO is a spotchecker
		*	 --> This happens because of a typo in patient's ID. We keep both surveys.
		
		replace drop_dup = 0 if spotcheck == 0 & spotchecker == 0
		
		* 3. Both FO are spotcheckers: We use the spotchecker's level. If he/she 
		* is level 2, then he/she is a spotchecker. Hence, we check whether or 
		* not one spotchecker is level 1, and the other one is level 2.
	
		bys a5 a11_1: egen check = sum(spotchecker_level) if a11_1 ! = . & dup > 0 & spotcheck == 2
		
			* A. When one FO is a spotchecker (level 2) and the other one is not (i.e. check = 3)
			* 	--> We keep the survey from the FO that is level 1.
			replace drop_dup = 1 if spotcheck == 2 & spotchecker_level == 2

			* B. When both FO are level 1 (i.e. check = 2)
			* 	--> We keep one survey, randomly selected
			set seed 339266 //random number created with random.org
			bys a5 a11_1: gen random = uniform() if check == 2
			bys a5 a11_1 (random): replace drop_dup = 1 if _n == 1 & check == 2
	
	rename spotchecker_id a8
	
	* Observations with weird FO's IDs (only one survey)
		drop if a8 == 83
		drop if a8 == 17287
		drop if a8 == 11839
		drop if a8 == 18492
	
	* Save spotchecks
		preserve
		* Keep duplicated surveys
		keep if dup > 0 & a11_1 ! = .
		* Drop surveys that we decided are typos
		drop if drop_dup == 0
		* Save quality checks output
		drop dup spotcheck check random spotchecker_name spotchecker_level spotchecker
		rename drop_dup spotcheck
		lab var spotcheck "This is a spotcheck"
		*save "${qchecks}", replace
		restore
		
	* Drop duplicates
	drop if drop_dup == 1
	drop dup drop_dup spotcheck check random spotchecker_name spotchecker_level spotchecker

	
	*--------------------------*
	* Calculate response rates *
	*--------------------------*
	
	* Generate only one variable for consent and able to proceed
		foreach var in a12 a14 {
			rename `var' `var'_e
			gen 	`var' = `var'_e 
			replace `var' = `var'_s if `var'_s != . & `var'_e == .
			drop `var'_e `var'_s
		}
		
	* Attempted
		mat T = J(4,1,.)
		count
		scalar 	attemp = r(N)
		display attemp
		mat T[1,1] = attemp
	* Consent
		count if a12 == 1
		scalar 	consent = r(N)
		display consent
		mat T[2,1] = consent
	* Able to proceed
		count if a14 == 1
		scalar 	proceed = r(N)
		display proceed
		mat T[3,1] = proceed	
	* Response rate
		scalar resp_rate = proceed/attemp*100
		display resp_rate
		mat T[4,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "Consent" "Able to proceed" "Response rate"
		matlist T
		
	/* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify sheet("Patient Exit")
		putexcel A2 = ("Attempted") A3 = ("Consent") A4 = ("Able to proceed") A5 = ("Response rate") ///
		B2 = matrix(T)
		*/
	
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
	
	* Those who gave consent
		keep if a12 == 1
	* Those who were able to proceed
		keep if a14 == 1
		
	
********************************************************************************
	** Part 2: Complete variables
********************************************************************************

	*-------------------------------------*
	* Separates select_multiple questions * 
	*-------------------------------------*
	
	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
			replace `theName' = " "+`theName' +" "
			
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace
					cap gen `theName'_ch_`j' = 1 if regexm(`theName'," `theNextValue' ")
						cap replace `theName'_ch_`j' = 0 if `theName' != "  " & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace
					
			}			
		end
		}
		
		tempfile split
		save `split'

		* Split the multiple-choice questions
			splitmult `split' using "$pe_bl_q"

			save `split', replace
			drop e1 f4 g2 g6b g7b e1_s f4_s g2_s g6b_s g7b_s k3
			
		* Rename of splitted variables in Swahili
			rename *_s_ch_* *_ch_*_s
		
		* Fix k3 variable to let one variable per language
			drop k3_ch_4 k3_ch_8 k3_ch_12 k3_ch_15 k3_ch_5 k3_ch_9 k3_ch_13 k3_ch_16 ///
				 k3_ch_11 k3_ch_14 k3_ch_17
		
	*----------------------------------------*
	* Merge questions in English and Swahili *
	*----------------------------------------*
	
	* Destring numeric variables
	foreach var in level pri {
		destring `var', replace
	}

		* For numeric variables
		local vars		a13 			b1 		b3_1 b3_2	b4 b5 b6 	b7 c2		///
						c3 c4_1		c4_2 c5 	c6 c7 c8 	c9 c10  	e1_ch_1 	///
						e1_ch_2		e1_ch_3		e2a	e2b		e2c	e2d 	e3 e4 e5    ///
						e6a e6b 	e6c e6d		e6e e6f		e6g e6h 	e6i e6j		///
						e6k e6l  	e6m	e6n 	e6o f1 f2	f3 f4_ch_1 	f4_ch_2 	///
						f4_ch_3 	f4_ch_4 	f4_ch_5		f4_ch_6 	f4_ch_7 	///
						f4_ch_8 	f4_ch_9 	f4_ch_10 	f5 g1 		g2_ch_1   	///
						g2_ch_2 	g2_ch_3 	g2_ch_4		g2_ch_5 	g2_ch_6 	///
						g2_ch_7 	g2_ch_8 	g2_ch_9 	g2_ch_10 	g2_ch_11 	///
						g2_ch_12 	g2_ch_13 	g2_ch_14    g2_ch_15	g2_ch_16	///
						g2_ch_17	g2_ch_18 	g3 g4 g5	g6a			g6b_ch_1 	///
						g6b_ch_2	g6b_ch_3 	g6b_ch_4	g6b_ch_5	g6b_ch_6	///
						g6b_ch_7	g6b_ch_8 	g6b_ch_9	g6b_ch_10	g6b_ch_11	///
						g6b_ch_12	g6b_ch_13 	g6b_ch_14	g6b_ch_15	g6b_ch_16	///
						g6b_ch_17	g6b_ch_18 	g7a			g7b_ch_1 	g7b_ch_2	///
						g7b_ch_3	g7b_ch_4 	g7b_ch_5	g7b_ch_6	g7b_ch_7	///
						g7b_ch_8	g7b_ch_9 	g7b_ch_10	g7b_ch_11	g7b_ch_12	///
						g7b_ch_13	g7b_ch_14 	g7b_ch_15	g7b_ch_16	g7b_ch_17	///
						g7b_ch_18	g8a	g8b 	g8c	h1 		h1a h1b 	h2 h2a 		///
						h2b h3 h3a 	h3b h4a 	h4b h4c 	h4d h4e 	h4f h4g 	///
						h4h h4i		h4j	h4k 	h4l	h4m		i1a	i1b		i1c	i1d		///
						i1e	i1f		i1g	i2 		j1 j2 j3 	j4 d1 d2 	d3a d3b 	///
						d3c d3d 	d3e d3f 	d3g d3h 	d3i d3j 	d3k d3l 	///
						d3m d3n 	d3o d3p 	d3q	d3r		d3s	d3t		d3u	d3v		///
						d3w	d3x		d3y	d3z		

		foreach var in `vars' {
			capture confirm string var `var'
			rename `var' `var'_e
			
				if _rc != 0 {
					gen 	`var' =  `var'_e 
					replace `var' = `var'_s if `var'_s != . & `var'_e == .	
			}
			else { 
				gen 	`var' = `var'_e 
				replace `var' = `var'_s if `var'_s != "" & `var'_e == ""
			}		
		* Drop questions in English and in Swahili
			drop `var'_e `var'_s
			}
			
		* Formatting date
		gen date1 = date(date,"DMY")
		format date1 %td
		drop date
		rename date1 date
	
		
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************

	*------------------------------------*
	* 3.1. Label define and label values *
	*------------------------------------*	

	* Yes/No

		lab define yesno_l 1 "Yes" 0 "No"
		local yesno_var "a11_v a12	a13	a14	b3_v b5	b8_v1 b8_v2	b8_v3 b8_v4	c3 c4_v	c8 f4_ch e6a	e6b	e6c	e6d	e6e	e6f	e6g	e6h	e6i	e6j	e6k	e6l	e6m	e6n	e6o	g4	g5	h1	h2	h2b	h3	h3b	d3a	d3b	d3c	d3d	d3e	d3f	d3g	d3h	d3i	d3j	d3k	d3l	d3m	d3n	d3o	d3p	d3q	d3r	d3y e1_ch_1 e1_ch_1 e1_ch_2 e1_ch_3 f4_ch_1 f4_ch_2 f4_ch_3 f4_ch_4 f4_ch_5 f4_ch_6 f4_ch_7 f4_ch_8 f4_ch_9 f4_ch_10 g2_ch_1 g2_ch_2 g2_ch_3 g2_ch_4 g2_ch_5 g2_ch_6 g2_ch_7 g2_ch_8 g2_ch_9 g2_ch_10 g2_ch_11 g2_ch_12 g2_ch_13 g2_ch_14 g2_ch_15 g2_ch_16 g2_ch_17 g2_ch_18 g6b_ch_1 g6b_ch_2 g6b_ch_3 g6b_ch_4 g6b_ch_5 g6b_ch_6 g6b_ch_7 g6b_ch_8 g6b_ch_9 g6b_ch_10 g6b_ch_11 g6b_ch_12 g6b_ch_13 g6b_ch_14 g6b_ch_15 g6b_ch_16 g6b_ch_17 g6b_ch_18 g7b_ch_1 g7b_ch_2 g7b_ch_3 g7b_ch_4 g7b_ch_5 g7b_ch_6 g7b_ch_7 g7b_ch_8 g7b_ch_9 g7b_ch_10 g7b_ch_11 g7b_ch_12 g7b_ch_13 g7b_ch_14 g7b_ch_15 g7b_ch_16 g7b_ch_17 g7b_ch_18"

		foreach var in `yesno_var' {
			cap lab values `var' yesno_l
		}
	
	* Ownership
		lab def ownership 1 "Private" 0 "Public"
		lab val pri ownership

	* Yes/No/Don't know

		lab define yesnodk_l 1 "Yes" 0 "No" -99 "-99: Don't know"
		local yesnodk_var "h4a	h4b	h4c	h4d	h4e	h4f	h4g	h4h	h4i	h4j	h4k	h4l	h4m	h4m"
		foreach var in `yesnodk_var' {
			lab values `var' yesnodk_l
		}
		
	* Relationship
		lab def relationship_l  1 "Father/Mother" 2 "Son/Daughter" 3 "Brother/Sister" /// 
								4 "Husband/Wife" 5 "Grandparent" 6 "Uncle/Aunt"  ///
								7 "Cousin" 8 "Niece/Nephew" 9 "House helper" 10 "Friend" ///
								0 "Other"
	lab val b1 relationship_l					
		
	* Male/Female
		lab def male_l	1 "Male" ///
						0 "Female"
		local male_var "b4 c2 d2 k2_3 k2_4"
		foreach var in `male_var' {
			lab values `var' male_l
		}
	
	* Education
		lab def educ_l	1 "In primary school" 2 "In secondary school" 3 "In college (studying for certificate)"  ///
						4 "In college (studying for diploma)" 5 "In Bachelors program"  ///
						6 "In Masters program" 7 "In PhD/Doctoral program"
		lab val b6 educ_l
		lab val c9 educ_l
										
	* Highest level of education				
		lab def highesteduc_l 	0 "No school" 1 "Completed primary school (Finished Standard 8)"  ///
								2 "Completed secondary school (Finished Form 4)"  ///
								3 "College certificate completed" 4 "College diploma completed"  ///
								5 "Bachelors" 6 "Masters" 7 "PhD / Doctoral"
		lab val b7  highesteduc_l
		lab val c10 highesteduc_l
						
	* Age under two					
		lab def ageundertwo_l	1 "Newborn" 2 "3 months" 3 "6 months" 4 "9 months"  ///
								5 "1 year" 6 "1 year, 6 months"
		lab val c6 ageundertwo_l
		
	* Month
		lab def month_l 	1 "January" ///
							2 "February" ///
							3 "March" ///
							4 "April" ///
							5 "May" ///
							6 "June" ///
							7 "July" ///
							8 "August" ///
							9 "September" ///
							10 "October" ///
							11 "November" ///
							12 "December"
		lab val c7 month_l
		
	* Comfort				
		lab def comfort_l	1 "Can do very comfortably" ///
							2 "Can do but with help" ///
							3 "Absolutely cannot do" ///
							0 "Don't know"
		lab val e2a comfort_l
		lab val e2b comfort_l
		lab val e2c comfort_l
		lab val e2d comfort_l

	* units				
		lab def units_l	1 "Days" ///
						2 "Weeks" ///
						3 "Months"  ///
						4 "Years"
		lab val e4 units_l
		
	* Overall health
		lab def overallhealth_l	1 "Very good" ///
								2 "Good" ///
								3 "Average" ///
								4 "Bad" ///
								5 "Very bad"
		lab val e5 overallhealth_l					
	
	* Units vtc
		lab def units_vtc_l	1 "Village" ///
							2 "Town" ///
							3 "City"
		lab val f2 units_vtc_l

	* Distance
		lab def dist_l	1 "2km or less (10 minutes or less)" ///
						2 "2.1km - 4km (between 11 and 20 minutes)" ///
						3 "4.1km - 6km (between 21 and 40 minutes)" ///
						4 "More than 6km (more than 40 minutes)" ///
						0 "Don't know"
		lab val f3 dist_l				
		
	* Time
		lab def time_l	15 " 15 Minutes or less" ///
						30 " 30 Minutes" ///
						45 " 45 Minutes" ///
						60 " 1 Hour" ///
						75 " 1 Hour 15 Minutes" ///
						90 " 1.5 Hours" ///
						105 " 1 Hour 45 Minutes" ///
						120 " 2 Hours" ///
						150 " 2.5 Hours" ///
						180 " 3 Hours" ///
						210 " 3.5 Hours" ///
						240 " 4 Hours or more"
		lab val f5 time_l								

	* Alternative why private
	
		lab def alternativewhy_pri_l	1 "Better services" ///
										2 "Wider variety of serices" ///
										3 "Higher quality" ///
										4 "Shorter waiting time" ///
										5 "Shorter distance/more convenient to travel" ///
										6 "Cheaper" ///
										7 "My insurance is accepted here" ///
										8 "Better staff" ///
										9 "Bigger facility" ///
										10 "Older facility" ///
										11 "Better results" ///
										12 "I always come to this private health facility" ///
										13 "The public facility was closed" ///
										14 "Recommended by someone" ///
										15 "Trying this facility for the first time" ///
										16 "No reason" ///
										17 "Better availability of essential medicines" ///
										0 "Other"
		lab val g6a alternativewhy_pri_l						

	* Alternative why public
	
		lab def alternativewhy_pub_l	1 "Better services" ///
										2 "Wider variety of serices" ///
										3 "Higher quality" ///
										4 "Shorter waiting time" ///
										5 "Shorter distance/more convenient to travel" ///
										6 "Cheaper" ///
										7 "My insurance is accepted here" ///
										8 "Better staff" ///
										9 "Bigger facility" ///
										10 "Older facility" ///
										11 "Better results" ///
										12 "I always come to this public health facility" ///
										13 "The private facility was closed" ///
										14 "Recommended by someone" ///
										15 "Trying this facility for the first time" ///
										16 "No reason" ///
										17 "Better availability of essential medicines" ///
										0 "Other"
		lab val g7a alternativewhy_pub_l						

	* Care type
		lab def caretype_l	1 "I would not seek care for this" ///
							2 "Pharmacy/Self-medicate" ///
							3 "Traditional Doctor or Herbalist" ///
							4 "Public Clinic" ///
							5 "Private Clinic" ///
							6 "Public Hospital" ///
							7 "Private Hospital"
		lab val g8a caretype_l
		lab val g8b caretype_l
		lab val g8c caretype_l

	* Problem
		lab def problem_l	1 "No problem" ///
							2 "Minor problem" ///
							3 "Major problem" ///
							4 "Don't know"

		local prob_var "i1a i1b i1c i1d i1e i1f i1g"
		foreach var in `prob_var' {
			lab values `var' problem_l
		}
			
		lab def  sat_l	1 "Very satisfied" ///
						2 "Satisfied" ///
						3 "Neither satisfied nor dissatisfied" ///
						4 "Dissatisfied" ///
						5 "Very dissatisfied"
		lab val i2 sat_l				
						
	* Level
		lab define levell 2 "Level 2" 3 "Level 3" 4 "Level 4" 5 "Level 5"
		lab val level levell
	
	* Toilet
		lab def yesnotoilet_l 1 "Yes" 0 "No" 2 "No toilet"
		lab val d3z yesnotoilet_l
	
	*-----------------------------------------------------------------------*
	* 3.2. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
	
	* Preloaded data
		rename a5			 		 hfid
		rename facilityname 		 hfname
		rename pri 					 ownership
		rename time_startinteraction time_start
		rename time_endinteraction 	 time_end
	
	* Cover and consent
		rename a8 enumeratorid
		rename a8_c enumeratorname
		rename a11_v a3
		rename a11_1 a4
		rename a11_3 a5
		rename a6 a_6
		rename a12 a6
		rename a13 a7
		rename a14 a8
		
	* Respondent's details
		rename b3_1 b2
		rename b3_2 b3
	
	* Patient's details
		rename c2 	c1
		rename c3 	c2
		rename c4_1 c3a
		rename c4_2 c3b
		rename c5 	c4a
		rename c6 	c4b
		rename c7 	c5
		rename c8 	c6
		rename c9 	c6a
		rename c10	c6b
	
	* Patient's health details
		rename d* d_*
		rename e1_ch_1 d1_1
		rename e1_ch_2 d1_2
		rename e1_ch_3 d1_3
		rename e5 d2
		rename e2a d3a
		rename e2b d3b
		rename e2c d3c
		rename e2d d3d
		rename e3 d4a
		rename e4 d4b
		rename e6a d5a
		rename e6b d5b
		rename e6e d5c
		rename e6f d5d
		rename e6g d5e
		rename e6h d5f
		rename e6k d5g
		rename e6n d5h
		rename e6c d5i
		rename e6d d5j
		rename e6i d5k
		rename e6j d5l
		rename e6l d5m
		rename e6m d5n
		rename e6o d5o
		
	* Patient's travel details
		rename f1 e1a
		rename f2 e1b
		rename f3 e2
		rename f4_ch_1 e3a
		rename f4_ch_2 e3b
		rename f4_ch_3 e3c
		rename f4_ch_4 e3d
		rename f4_ch_5 e3e
		rename f4_ch_6 e3f
		rename f4_ch_7 e3g
		rename f4_ch_8 e3h
		rename f4_ch_9 e3i
		rename f4_ch_10 e3j
		rename f5 e4
	
	* Alternative details
		rename g3 f1
		rename g1 f2
		rename g2_ch_1 f3_1
		rename g2_ch_2 f3_2
		rename g2_ch_3 f3_3
		rename g2_ch_4 f3_4
		rename g2_ch_5 f3_5
		rename g2_ch_6 f3_6
		rename g2_ch_7 f3_7
		rename g2_ch_8 f3_8
		rename g2_ch_9 f3_9
		rename g2_ch_10 f3_10
		rename g2_ch_11 f3_11
		rename g2_ch_12 f3_12
		rename g2_ch_13 f3_13
		rename g2_ch_14 f3_14
		rename g2_ch_15 f3_15
		rename g2_ch_16 f3_16
		rename g2_ch_17 f3_17
		rename g2_ch_18 f3_18
		rename g4 f4
		rename g5 f5
		rename g6a f4a
		rename g6b_ch_1 f4b_1
		rename g6b_ch_2 f4b_2
		rename g6b_ch_3 f4b_3
		rename g6b_ch_4 f4b_4
		rename g6b_ch_5 f4b_5
		rename g6b_ch_6 f4b_6
		rename g6b_ch_7 f4b_7
		rename g6b_ch_8 f4b_8
		rename g6b_ch_9 f4b_9
		rename g6b_ch_10 f4b_10
		rename g6b_ch_11 f4b_11
		rename g6b_ch_12 f4b_12
		rename g6b_ch_13 f4b_13
		rename g6b_ch_14 f4b_14
		rename g6b_ch_15 f4b_15
		rename g6b_ch_16 f4b_16
		rename g6b_ch_17 f4b_17
		rename g6b_ch_18 f4b_18
		rename g7a f5a
		rename g7b_ch_1 f5b_1
		rename g7b_ch_2 f5b_2
		rename g7b_ch_3 f5b_3
		rename g7b_ch_4 f5b_4
		rename g7b_ch_5 f5b_5
		rename g7b_ch_6 f5b_6
		rename g7b_ch_7 f5b_7
		rename g7b_ch_8 f5b_8
		rename g7b_ch_9 f5b_9
		rename g7b_ch_10 f5b_10
		rename g7b_ch_11 f5b_11
		rename g7b_ch_12 f5b_12
		rename g7b_ch_13 f5b_13
		rename g7b_ch_14 f5b_14
		rename g7b_ch_15 f5b_15
		rename g7b_ch_16 f5b_16
		rename g7b_ch_17 f5b_17
		rename g7b_ch_18 f5b_18
		rename g8a f6a
		rename g8b f6b
		rename g8c f6c
		
	* Service details
		rename h1 g1
		rename h1a g1a
		rename h1b g1b
		rename h2 g2
		rename h2a g2a
		rename h2b g2b
		rename h3 g3
		rename h3a g3a
		rename h3b g4
		rename h4a g5a
		rename h4b g5b
		rename h4c g5c
		rename h4d g5d
		rename h4e g5e
		rename h4f g5f
		rename h4g g5g
		rename h4h g5h
		rename h4i g5i
		rename h4j g5j
		rename h4k g5k
		rename h4l g5l
		rename h4m g5m
	
	* Service satisfaction details
		rename i1a h1a
		rename i1b h1b
		rename i1c h1c
		rename i1d h1d
		rename i1e h1e
		rename i1f h1f
		rename i1g h1g
		rename i2 h2
		
	* Payment details
		rename j1 i1
		rename j2 i2 
		rename j3 i3
		rename j4 i4
	
	* Patient's household details
		rename d_1 j1
		rename d_2 j2
		rename d_3a j3a
		rename d_3b j3b
		rename d_3c j3c
		rename d_3d j3d
		rename d_3e j3e
		rename d_3f j3f
		rename d_3g j3g
		rename d_3h j3h
		rename d_3i j3i
		rename d_3j j3j
		rename d_3k j3k
		rename d_3l j3l
		rename d_3m j3m
		rename d_3n j3n
		rename d_3o j3o
		rename d_3p j3p
		rename d_3q j3q
		rename d_3r j3r
		rename d_3s j3s
		rename d_3t j3t
		rename d_3u j3u
		rename d_3v j3v
		rename d_3w j3w
		rename d_3x j3x
		rename d_3y j3y
		rename d_3z j3z
		
	* Final details
		rename k1_1	k2
		rename k1_2	k3
		rename k1_3 k4
		rename k2_1 k5
		rename k6 k_6
		rename k2_2 k6
		rename k2_3 k7
		rename k2_4 k8
		rename k3_ch_1 k9_1
		rename k3_ch_2 k9_2
		rename k3_ch_3 k9_3
		rename k3_ch_6 k9_4
		rename k3_ch_10 k9_5
		rename k3_ch_7 k9_6	
		rename k5_1 k10_1
		rename k5_2 k10_2
		rename k5_3 k10_3
		rename k5_4 k10_4
		rename k5_5 k10_5
		rename k5_6 k10_6	
		rename k11* k13*
		rename k_6 k11
		rename a_6 k12
		rename d_ate date
		
	*----------------------*
	* 3.3. Label variables *
	*----------------------*
	
	* Preloaded data
		lab var date			"Survey date"
		lab var time			"Survey time"
		lab var hfid 			"Facility ID"
		lab var hfname 			"Health Facility name"
		lab var county 			"County"
		lab var location 		"Location"
		lab var sublocation 	"Sublocation"
		lab var ownership 		"Ownership"		
		lab var level 			"Level"		
		lab var key 			"Survey CTO ID"
		lab var time_end 		"Time after last question"
		lab var time_start 		"Time before consent"
				
	* Cover and consent
		lab var enumeratorid	"Enumerator ID"
		lab var enumeratorname	"Enumerator Name"
		lab var a3 				"Patient has and ID number"
		lab var a4 				"Patient ID"
		lab var a5 				"Which language you will be conducting this survey in?"
		lab var a6 				"Patient's consent"
		lab var a7 				"Someone else is speaking for the patient"
		lab var a8 				"Are you able to proceed with the survey?"
	
	* Respondent's details
		lab var b1 "Respondent: Relationship with the patient (if a8 = 1 and a9 = 1)"
		lab var b2 "Respondent: Year of birth (if a8 = 1 and a9 = 1)"
		lab var b3 "Respondent: Age (if a8 = 1 and a9 = 1)"
		lab var b4 "Respondent: Gender (if a8 = 1 and a9 = 1)"
		lab var b5 "Respondent: Are you in school right now? (if a8 = 1 and a9 = 1)"
		lab var b6 "Respondent: What level of education are you at? (if b5 = 1)"
		lab var b7 "Respondent: Highest completed education level (if b5 = 0)"
	
	* Patient's details	
		lab var c1  "Patient: Gender"
		lab var c2  "Patient: Is under two years old?"
		lab var c3a "Patient: Year of birth (if c2 = 0)"
		lab var c3b "Patient: Year of birth (if c2 = 1)"
		lab var c4a "Patient: Age (if c2 = 0)"
		lab var c4b "Patient: Age (if c2 = 1)"
		lab var c5  "Patient: Month of birth (if c2 = 1)"
		lab var c6  "Patient: Is still in school? (if c4a >= 6)"	
		lab var c6a "Patient: Where is going to for school? (if c6 = 1 and c4a >= 6)"
		lab var c6b "Patient: Highest qualification (if c6 = 0 and c4a >= 6)"
	
	* Patient's health details
		lab var d1_1 "Reasons to come includes: Preventive visit such as ANC or vaccination"
		lab var d1_2 "Reasons to come includes: Ongoing monitoring or medication for an ongoing illness"
		lab var d1_3 "Reasons to come includes: Diagnosis and treatment"
		lab var d2	"Overall health state"
		lab var d3a "Comfortable when putting on clothes (if c4a > 6 and d1_3 = 1)"
		lab var d3b "Comfortable when doing light work around house (if c4a > 6 and d1_3 = 1)"
		lab var d3c "Comfortable when lifting a bag (5kg) & walking (100 m) (if c4a > 6 and d1_3 = 1)"
		lab var d3d "Comfortable when walking 200-300 m (if c4a > 6 and d1_3 = 1)"
		lab var d4a "How long have you been sick? (if d1_2 = 1 or d1_3 = 1)"
		lab var d4b "Units (if d1_2 = 1 or d1_3 = 1)"
		lab var d5a "Are you experiencing: Cough/cold (if d1_2 = 1 or d1_3 = 1)"
		lab var d5b "Are you experiencing: Fever (if d1_2 = 1 or d1_3 = 1)"
		lab var d5c "Are you experiencing: Sweats (if d1_2 = 1 or d1_3 = 1)"
		lab var d5d "Are you experiencing: Diarrhea (if d1_2 = 1 or d1_3 = 1)"
		lab var d5e "Are you experiencing: Vomiting (if d1_2 = 1 or d1_3 = 1)"
		lab var d5f "Are you experiencing: Chills (if d1_2 = 1 or d1_3 = 1)"
		lab var d5g "Are you experiencing: Skin problems (if d1_2 = 1 or d1_3 = 1)"
		lab var d5h "Are you experiencing: Shaking (if d1_2 = 1 or d1_3 = 1)"
		lab var d5i "Are you experiencing: Weakness (if d1_2 = 1 or d1_3 = 1)"
		lab var d5j "Are you experiencing: Fatigue (if d1_2 = 1 or d1_3 = 1)"
		lab var d5k "Are you experiencing: Stomach pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5l "Are you experiencing: Head pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5m "Are you experiencing: Chest pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5n "Are you experiencing: Limbs pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5o "Are you experiencing: Other (if d1_2 = 1 or d1_3 = 1)"
		
	* Patient's travel details
		lab var e1a "Patient's village/town/city name"
		lab var e1b "Settlement type"
		lab var e2  "Distance from home"
		lab var e3a "Mode of transport includes: Own vehicle"
		lab var e3b "Mode of transport includes: Bicycle"
		lab var e3c "Mode of transport includes: Taxi"
		lab var e3d "Mode of transport includes: By foot"
		lab var e3e "Mode of transport includes: Boat or ferry"
		lab var e3f "Mode of transport includes: Bus"
		lab var e3g "Mode of transport includes: Motorbike"
		lab var e3h "Mode of transport includes: Matatu"
		lab var e3i "Mode of transport includes: Train"
		lab var e3j "Mode of transport includes: Other Private Vehicle"
		lab var e4  "Total time from home to HF"
	
	* Alternative details	
		lab var f1 "In which year did you start coming to this facility?"
		lab var f2 "How many other facilities could you have gone to for this condition today?"
		lab var f3_1 "Reasons to choose the HF: Better services (if f2 != 0)"
		lab var f3_2 "Reasons to choose the HF: Wider variety of serices (if f2 != 0)"
		lab var f3_3 "Reasons to choose the HF: Higher quality (if f2 != 0)"
		lab var f3_4 "Reasons to choose the HF: Shorter waiting time (if f2 != 0)"
		lab var f3_5 "Reasons to choose the HF: Shorter distance/more convenient to travel (if f2 != 0)"
		lab var f3_6 "Reasons to choose the HF: Cheaper (if f2 != 0)"
		lab var f3_7 "Reasons to choose the HF: My insurance is accepted here (if f2 != 0)"
		lab var f3_8 "Reasons to choose the HF: Better staff (if f2 != 0)"
		lab var f3_9 "Reasons to choose the HF: Bigger facility (if f2 != 0)"
		lab var f3_10 "Reasons to choose the HF: Older facility (if f2 != 0)"
		lab var f3_11 "Reasons to choose the HF: Better results (if f2 != 0)"
		lab var f3_12 "Reasons to choose the HF: I always come to this health facility (if f2 != 0)"
		lab var f3_13 "Reasons to choose the HF: The facility I usually go to was closed (if f2 != 0)"
		lab var f3_14 "Reasons to choose the HF: Recommended by someone (if f2 != 0)"
		lab var f3_15 "Reasons to choose the HF: Trying this facility for the first time (if f2 != 0)"
		lab var f3_16 "Reasons to choose the HF: Better availability of essential medicines (if f2 != 0)"
		lab var f3_17 "Reasons to choose the HF: No reason (if f2 != 0)"
		lab var f3_18 "Reasons to choose the HF: Other (if f2 != 0)"
		lab var f4 "Public HF available to treat patient's condition if private HF & another HF available"
		lab var f5 "Private HF available to treat patient's condition if public HF & another HF available"
		lab var f4a "Reason choose private HF"
		lab var f4b_1 "Additional reasons: Better services if private & another HF available"
		lab var f4b_2 "Additional reasons: Wider variety of serices if private & another HF available"
		lab var f4b_3 "Additional reasons: Higher quality if private & another HF available"
		lab var f4b_4 "Additional reasons: Shorter waiting time if private & another HF available"
		lab var f4b_5 "Additional reasons: Shorter distance/more convenient to travel if private & another HF available"
		lab var f4b_6 "Additional reasons: Cheaper if private & another HF available"
		lab var f4b_7 "Additional reasons: My insurance is accepted here if private & another HF available"
		lab var f4b_8 "Additional reasons: Better staff if private & another HF available"
		lab var f4b_9 "Additional reasons: Bigger facility if private & another HF available"
		lab var f4b_10 "Additional reasons: Older facility if private & another HF available"
		lab var f4b_11 "Additional reasons: Better results if private & another HF available"
		lab var f4b_12 "Additional reasons: I always come to this private health facility if private & another HF available"
		lab var f4b_13 "Additional reasons: The public facility was closed if private & another HF available"
		lab var f4b_14 "Additional reasons: Recommended by someone if private & another HF available"
		lab var f4b_15 "Additional reasons: Trying this facility for the first time if private & another HF available"
		lab var f4b_16 "Additional reasons: Better availability of essential medicines if private & another HF available"
		lab var f4b_17 "Additional reasons: No other reason if private & another HF available"
		lab var f4b_18 "Additional reasons: Other if private & another HF available"
		lab var f5a "Reason choose public HF"
		lab var f5b_1 "Additional reasons: Better services  if public & another HF available"
		lab var f5b_2 "Additional reasons: Wider variety of serices  if public & another HF available"
		lab var f5b_3 "Additional reasons: Higher quality  if public & another HF available"
		lab var f5b_4 "Additional reasons: Shorter waiting time  if public & another HF available"
		lab var f5b_5 "Additional reasons: Shorter distance/more convenient to travel  if public & another HF available"
		lab var f5b_6 "Additional reasons: Cheaper  if public & another HF available"
		lab var f5b_7 "Additional reasons: My insurance is accepted here  if public & another HF available"
		lab var f5b_8 "Additional reasons: Better staff  if public & another HF available"
		lab var f5b_9 "Additional reasons: Bigger facility  if public & another HF available"
		lab var f5b_10 "Additional reasons: Older facility  if public & another HF available"
		lab var f5b_11 "Additional reasons: Better results  if public & another HF available"
		lab var f5b_12 "Additional reasons: I always come to this public health facility  if public & another HF available"
		lab var f5b_13 "Additional reasons: The private facility was closed  if public & another HF available"
		lab var f5b_14 "Additional reasons: Recommended by someone  if public & another HF available"
		lab var f5b_15 "Additional reasons: Trying this facility for the first time  if public & another HF available"
		lab var f5b_16 "Additional reasons: Better availability of essential medicines  if public & another HF available"
		lab var f5b_17 "Additional reasons: No other reason  if public & another HF available"
		lab var f5b_18 "Additional reasons: Other  if public & another HF available"
		lab var f6a "Type of care if chest pain/anxiety morning"
		lab var f6b "Type of care if a child of 8 months old has diarrhea for 2 days"
		lab var f6c "Type of care if high fevers, shaking chills, fatigue"
	
	* Service details
		lab var g1  "Examination from a health care worker recieved"
		lab var g1a "Minutes waited before examination (if g1 = 1)"
		lab var g1b "Minutes spent with the health care worker (if g1 = 1)"
		lab var g2  "Laboratory services received"
		lab var g2a "Minutes waited in line to run the tests (if g2 = 1)"
		lab var g2b "Blood test (if g2 = 1)"
		lab var g3  "Medicines from  pharmacy recived"
		lab var g3a "Minutes waited in line to receive the medicines (if g3 = 1)"
		lab var g4  "Injection with medicine for treatment recieved"
		lab var g5a "Did the provider: take your pulse (if g1 = 1)"
		lab var g5b "Did the provider: check your blood pressure (if g1 = 1)"
		lab var g5c "Did the provider: listen, either directly or through a stethoscope, to the front of your body (if g1 = 1)"
		lab var g5d "Did the provider: listen, either directly or through a stethoscope, to the back of your body (if g1 = 1)"
		lab var g5e "Did the provider: perform a throat exam (if g1 = 1)"
		lab var g5f "Did the provider: take your temperature with a thermometer (if g1 = 1)"
		lab var g5g "Did the provider: take your temperature by touch (if g1 = 1)"
		lab var g5h "Did the provider: conduct other tests e.g., malaria, stool (if g1 = 1)"
		lab var g5i "Did the provider: do a basic check e.g., weight, height (if g1 = 1)"
		lab var g5j "Did the provider: conduct other exams e.g., eye examination (if g1 = 1)"
		lab var g5k "Did the provider: do a follow-up check on you from a previous visit (if g1 = 1)"
		lab var g5l "Did the provider: refer you to another health facility for other services (if g1 = 1)"
		lab var g5m "Did the provider: give you medicines (or prescription) (if g1 = 1)"
	
	* Service satisfaction details
		lab var h1a "Problem discussing condition with HCW (if g1 = 1)"
		lab var h1b "Problem with explanations about problem or treatment (if g1 = 1)"
		lab var h1c "Problem quality exami. & treatment provided (if g1 = 1)"
		lab var h1d "Problem availability medicines/methods (if g1 = 1 or g3 = 1)"
		lab var h1e "Problem with cleanliness of HF"
		lab var h1f "Problem with how the staff treated you"
		lab var h1g "Problem with waiting time"
		lab var h2  "Satisfaction with HF"
	
	* Payment details
		lab var i1 "Total amount paid out of pocket for the visit"
		lab var i2 "Total amount paid for the examination (if g1 = 1 and i1 > 0)"
		lab var i3 "Total amount paid for laboratory services (if g2 = 1 and i1 > 0)"
		lab var i4 "Total amount paid for medicines (if g3 = 1 and i1 > 0)"
	
	* Patient's household details
		lab var j1 "Total number of people who live in the household"
		lab var j2 "Gender of the household breadwinner"
		lab var j3a "Household has: Electricity from the grid"
		lab var j3b "Household has: Running water in the house"
		lab var j3c "Household has: Clock"
		lab var j3d "Household has: Radio"
		lab var j3e "Household has: Television"
		lab var j3f "Household has: Mobile telephone"
		lab var j3g "Household has: Landline"
		lab var j3h "Household has: Refrigerator"
		lab var j3i "Household has: Solar Panel"
		lab var j3j "Household has: Bicycle"
		lab var j3k "Household has: Boat"
		lab var j3l "Household has: Car or truck"
		lab var j3m "Household has: Motorbike"
		lab var j3n "Household has: Animal drawn cart"
		lab var j3o "Household has: Ownership of the dwelling"
		lab var j3p "Household has: Ownership of the land the dwelling is built on"
		lab var j3q "Household has: Ownership of agricultural land (anywhere)"
		lab var j3r "Household has: Ownership of farm animals (anywhere)"
		lab var j3s "Household has: Number of milk cows or bulls (if j3r = 1)"
		lab var j3t "Household has: Number of horses, donkeys or mules (if j3r = 1)"
		lab var j3u "Household has: Number of goats (if j3r = 1)"
		lab var j3v "Household has: Number of sheep (if j3r = 1)"
		lab var j3w "Household has: Number of chicken (if j3r = 1)"
		lab var j3x "Household has: Number of rooms in your house that are used for sleeping"
		lab var j3y "Household has: Separate room that is used as a kitchen"
		lab var j3z "Household has: Toilet shared with other households"
	
	* Final details
		lab var k1  "Result of the survey (if a6 = 0 or a8 = 0)"
		lab var k2  "Why was it partially completed? (if k1 = 2)"
		lab var k3  "Why was it not started? (if k1 = 3)"
		lab var k4  "Why dis respondent refuse? (if k2 == 1 or k3 == 1)"
		lab var k5  "Estimate the age group of the respondent"
		lab var k6  "Estimate the age group of the patient"
		lab var k7  "Enter the gender of the respondent"
		lab var k8  "Enter the gender of the patient"
		lab var k9_1 "Languages used: English"
		lab var k9_2 "Languages used: Swahili"
		lab var k9_3 "Languages used: Mijikenda (if Kilifi)"
		lab var k9_4 "Languages used: Kimeru (if Meru)"
		lab var k9_5 "Languages used: Luhya if (Kakamega)"
		lab var k9_6 "Languages used: Other languages"
		lab var k10_1 "How much of the survey did you conduct in English? (if k5_1 = 1)"
		lab var k10_2 "How much of the survey did you conduct in Swahili? (if k5_2 = 1)"
		lab var k10_3 "How much of the survey did you conduct in Mijikenda? (if k5_3 = 1)"
		lab var k10_4 "How much of the survey did you conduct in Kimeru? (if k5_4 = 1)"
		lab var k10_5 "How much of the survey did you conduct in Luhya? (if k5_5 = 1)"
		lab var k10_6 "How much of the survey did you conduct in another language? (if k5_6 = 1)"
		lab var k11 "Was a translator used?"
	
	*---------------------*
	* 3.4. Order database *
	*---------------------*
				
		global preload		date time hfid hfname county location sublocation level ownership key time_start time_end
		
		global basics 		enumeratorid enumeratorname a3 a4 a5 a6 a7 a8 
							
		global respondent 	b1 b2 b3 b4 b5 b6 b7
							
		global charac_p		c1 c2 c3a c3b c4a c4b c5 c6 c6a c6b
							
		global health_p		d1_1 d1_2 d1_3 d2 d3a d3b d3c d3d d4a d4b d5a d5b d5c d5d d5e d5f ///
							d5g	d5h	d5i	d5j d5k	d5l	d5m	d5n	d5o
							
		global travel_p		e1a	e1b e2 e3a	e3b	e3c e3d	e3e	e3f	e3g	e3h	e3i e3j	e4	     
												
		global altern_p		f1	f2 f3_1	f3_2 f3_3 f3_4 f3_5 f3_6 f3_7 f3_8 f3_9 f3_10 f3_11  ///	
							f3_12 f3_13 f3_14 f3_15 f3_16 f3_17	f3_18 f4 f4a f4b_1 f4b_2 f4b_3	 ///
							f4b_4	f4b_5 f4b_6	f4b_7	f4b_8	f4b_9	f4b_10	f4b_11 ///
							f4b_12	f4b_13 	f4b_14 f4b_15	f4b_16	f4b_17	f4b_18	///
							f5	f5a	f5b_1	f5b_2	f5b_3	f5b_4	f5b_5	f5b_6	///
							f5b_7 f5b_8	f5b_9	f5b_10	f5b_11	f5b_12	f5b_13	f5b_14	///
							f5b_15	f5b_16	f5b_17 f5b_18 f6a f6b f6c
							
		global service		g1	g1a	g1b	g2	g2a	g2b	g3	g3a	g4	g5a	g5b	g5c	g5d	g5e	///
							g5f	g5g	g5h	g5i	g5j	g5k	g5l	g5m		
							
		global satisfac		h1a h1b h1c h1d h1e h1f h1g h2
	 
		global payment		i1	i2	i3	i4	j1
		
		global household	j2	j3a	j3b	j3c	j3d	j3e	j3f	j3g	j3h	j3i	j3j	j3k	j3l	j3m	///
							j3n	j3o	j3p	j3q	j3r	j3s	j3t	j3u	j3v	j3w	j3x	j3y	j3z
													
		global finald		k1 k2 k3 k4 k5 k6 k7 k8 k9_1 k9_2 k9_3 k9_4 k9_5 k9_6 ///
							k10* k11 k12 
							
		global gps			k13*
			
		order $preload $basics $respondent $charac_p $health_p $travel_p $altern_p $service $satisfac $payment $household $finald $gps	 
  
* Years of education
clonevar educ_p	= c6b
replace  educ_p = c6a if mi(educ_p)
clonevar educ_r = b7
replace  educ_r = b6 if mi(educ_r)

foreach x in educ_p educ_r {
	recode `x' (1=8) (2=12) (3=14) (4=15) (5=16) (6=18) (7=20), gen(`x'_yrs)
	}
	
clonevar educp = educ_p_yrs
replace  educp = educ_r_yrs if mi(educp)
lab var  educp "Years of education (patient is priority)"

clonevar educr = educ_r_yrs
replace  educr = educ_p_yrs if mi(educr)
lab var  educr "Years of education (respondent is priority)"

clonevar educ_bl = educr
lab var educ_bl "Years of education"
drop educ_p educ_r educ_p_yrs educ_r_yrs educp educr
	
* Overall health
recode d2 (4/5=1) (1/3=0), gen(health_status_bl)
lab def health_status_bl 1 "Bad or very bad" 0 "Average, good, or very good", modify
lab val health_status_bl health_status_bl
lab var health_status_bl "Overall health status"

* Distance
clonevar distance_bl=e2
replace distance_bl=. if distance_bl==0
ren distance_bl distance_bl_group
recode distance_bl_group (2=3) (3=5) (4=8), gen(distance_bl)
drop distance_bl_group
 
********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 4.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Drop old profile information
		drop hfname county location sublocation level ownership k13*
	
	* Merge profile information
		local prof_vars "latitude longitude hfid hfid_m hfname county subcounty location sublocation level ownership inchargename inchargenumber"

		merge m:1 hfid using "${profile_bl}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
	
	* Order dataset
		order `prof_vars', after(key)
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
		
	*-------------------------------------*
	* 4.2. Save database for construction *
	*-------------------------------------*

	*save "$PE_clean_pii", replace 	
	
	*----------------*
	* 4.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude hfname location sublocation inchargename inchargenumber enumeratorname // hfid

	*--------------------------------------------*
	* 4.4. Save database for microdata catalogue *
	*--------------------------------------------*A
	
	save "${pe_bl}", replace 
	/*
	preserve
	
	*------------------------*
	* 4.5. Build dictionnary *
	*------------------------*

	tempfile dictionarydta
	descsave, list(name varlab, clean noobs) saving(`dictionarydta', replace)
	
	use `dictionarydta', clear
	drop vallab
	*putexcel set Dictionary_PE, replace
	*export excel using "${dictionary}", firstrow(variables) replace
	
	* Restore clean dataset
	restore
	*/
	* Dismount
	veracrypt, dismount drive("${mount}") 

