/*******************************************************************************	

Project:  		KePSIE
Created on:  	August 25, 2017
Last udpate on: Sep 3, 2017

Written by:  	Garima Sharma
				Maria Camila Ayala (mayalaguerrero@worldbank.org)
				  with select code lines from: Benjamin Daniels

Revision: 		Guadalupe Bedoya
Date: 			May 17-20, 2016

********************************************************************************			

THIS DO FILE: 	Cleans the HCW-Patient observation checklist for upload in the WB microdata catalog


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
					 	 1.1 - Fixing/Completing variables
						 1.2 - Drop duplicates
						 1.3 - Correcting issues with facility_id and HCW_id
						 1.4 - Calculate response rates
				Part 2 - Basic cleaning
						 2.1 - Rename variables to coincide with printer-friendly questionnaire
						 2.2 - Inputations
						 2.3 - Label variables
						 2.4 - Additional fix
						 2.5 - Order database	
				Part 3 - Save different files and anonymize 
						 3.1 - Upload HF’s information with profile information corrected
						 3.2 - Save database for construction
						 3.3 - Anonymize
						 3.4 - Save database for microdata catalogue
						 3.5 - Build dictionnary					
						 
INPUTS:     	* Raw data
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/final_reconciliation.dta"
			
				* Spotchecker list
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/spotcheckers.xlsx"
				
				* Input IR
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PPS_DO_IR_Fix_24May2016.csv"
				
				* Input Corrected IDs
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PPS_Merge_CorrectedIDs_30May2016.csv"
				
				* HF Baseline profile data
				"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta"

OUTPUTS:     	* Anonymized data for microdata catalog
				"${bl_dt}/Final/PPS_DO_clean_nopii.dta"
				
				* Non-anonymized data for further analysis
				"${bl_dt}/Final/PPS_DO_clean_pii.dta"

				* Quality checks 
				"${bl_dt}/Intermediate/PPS_DO_quality_checks.dta"
				
				* Dictionary
				"${bl_out}/Final/PPS_DO_clean_nopii_dictionary.xls"
				
				* Response rate table
				"${bl_out}/Final/PPS_DO_response_rate.xls"
				
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	* Input files	
		glo pps_do_bl_raw 		"${volume}/pps_do_bl_raw.dta"
		glo spotcheckers 		"${volume}/supplemental/spotcheckers.xlsx"
		glo input_ir 			"${volume}/supplemental/pps_do_ir_manual.csv"
		glo input_IDs1 			"${volume}/supplemental/pps_merge_correctedids.csv"
		glo profile_bl			"${dt_mast}/profile_bl.dta"
		
	* Output files
		glo pps_do_clean		"${dt_bl_clean}/pps_do_bl.dta"
		glo qchecks				"${dt_bl_clean}/pps_do_bl_qchecks.dta"
		
********************************************************************************
	** Part 1: Complete database
********************************************************************************
* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")


	use "${pps_do_bl_raw}", clear
		
	*----------------------------------*
	* 1.1. Fixing/Completing variables *
	*----------------------------------*
	
	* Renames of variables
		rename aa4_fo_id enuid
		rename aa3_facility_id facilityid
		rename aa10_patient_id patientid
		rename aa9_hcw_id hcwid
		rename aa8_a_site aa8_a
		rename aa8_b_site aa8_b
		rename aa8_c_site aa8_c
	
	* Date
		split aa5_date, p("/", ".", "-")
		replace aa5_date3 = "2015" if aa5_date3 == "2014"
		replace aa5_date3 = "2015" if aa5_date3 == "15"
		replace aa5_date = aa5_date1 + "-" + aa5_date2 + "-" + aa5_date3

	* Fixing facilityid: We look at HCWID and see which facility they belong to
		recode facilityid . = 15833 if hcwid==1569 
		recode facilityid . = 16762 if hcwid==1573
		recode facilityid . = 15874 if hcwid==1409
		recode facilityid . = 16101 if hcwid==1491
		recode facilityid . = 15841 if hcwid==1516
		recode facilityid . = 900350 if hcwid==5920
		recode facilityid 90035 = 900350 if hcwid==5920
		recode facilityid . = 15966 if hcwid==1522
		recode facilityid . = 16105 if hcwid==1431
		recode facilityid . = 16122 if hcwid==1653
		recode facilityid . = 15820 if hcwid==1535
		recode facilityid . = 15916 if hcwid==1584
		recode facilityid . = 15859 if hcwid==1664
		recode facilityid . = 18361 if hcwid==5620
		recode facilityid . = 12447 if hcwid==1134
		recode facilityid . = 12036 if hcwid==569
		recode facilityid . = 901121 if hcwid==1209
		recode facilityid . = 15940 if enuid==46
		recode facilityid 16122 = 16112 if survey_id == 19154
		recode facilityid 11477 = 11474 if survey_id == 5902
		recode facilityid 11477 = 11474 if survey_id == 5903
		recode facilityid 11477 = 11474 if survey_id == 5904
		recode facilityid 900266 = 900226 if survey_id == 10520
		recode facilityid 900266 = 900226 if survey_id == 10519
		recode facilityid 16 = 16046 if survey_id == 16148
		recode facilityid 1793 = 17931 if survey_id == 19788
		recode facilityid 90164 = 901624 if survey_id == 1318
		recode facilityid 12784 = 12748 if survey_id == 5615
		recode facilityid 12916 = 12116 if survey_id == 248
		recode facilityid 12916 = 12116 if survey_id == 247
		recode facilityid . = 16112 if survey_id == 15991
		
		replace facilityid = 900710 if facilityid== 900170
		replace facilityid = 900966 if facilityid== 90096
		replace facilityid = 17825 if facilityid== 17826
		replace facilityid = 11553 if facilityid== 11533
		replace facilityid = 16005 if facilityid== 1600
		replace facilityid = 11883 if facilityid== 10723
		replace facilityid = 11444 if facilityid== 1144
		replace facilityid = 18939 if facilityid== 18959
		replace facilityid = 17298 if facilityid== 46
		replace facilityid = 901138 if facilityid== 101138
		replace facilityid = 901138 if facilityid== 901136
		replace facilityid = 16121 if facilityid== 1621
		replace facilityid = 18711 if facilityid== 8711
		replace facilityid = 15882 if facilityid== 15887
		replace facilityid = 11912 if facilityid== 11922
		replace facilityid = 11719 if facilityid== 11718
		replace facilityid = 15999 if facilityid== 1599
		replace facilityid = 15874 if facilityid== 15
		replace facilityid = 15945 if facilityid== 15495
		replace facilityid = 15964 if facilityid== 15764
		replace facilityid = 15964 if facilityid== 15994
		replace facilityid = 900244 if facilityid== 90024
		replace facilityid = 12535 if facilityid== 12856
		replace facilityid = 12031 if facilityid== 12037
		replace facilityid = 12557 if facilityid== 12257
		replace facilityid = 12233 if facilityid== 1233
		replace facilityid = 15970 if facilityid== 159
		replace facilityid = 900409 if facilityid== 900406
		replace facilityid = 17287 if facilityid== 17278
		replace facilityid = 18482 if facilityid== 18842
		replace facilityid = 11392 if facilityid== 11932
		replace facilityid = 16105 if facilityid== 16155
		replace facilityid = 17226 if facilityid== 17266
		replace facilityid = 15996 if facilityid== 15966
		replace facilityid = 900600 if facilityid== 1615
		replace facilityid = 11738 if facilityid== 11735
		replace facilityid = 11738 if facilityid== 11736
		replace facilityid = 11394 if facilityid== 11398
		replace facilityid = 16109 if facilityid== 16901
		replace facilityid = 16109 if facilityid== 77
		replace facilityid = 11652 if facilityid== 11652
		replace facilityid = 18779 if facilityid== 18799
		replace facilityid = 20320 if facilityid== 203200
		replace facilityid = 15983 if facilityid== 5983
		replace facilityid = 800051 if facilityid== 500051
		replace facilityid = 16078 if facilityid== 5
		replace facilityid = 11360 if facilityid== 11630
		replace facilityid = 18501 if facilityid== 18507
		replace facilityid = 15938 if facilityid== 15958
		replace facilityid = 16607 if facilityid== 16670
		replace facilityid = 20043 if facilityid== 1911
		replace facilityid = 901624 if facilityid== 90164
		replace facilityid = 18361 if facilityid== 18360
		replace facilityid = 17408 if facilityid== 17048
		replace facilityid = 12116 if facilityid== 12916
		replace facilityid = 15859 if facilityid== 16859
		replace facilityid = 18802 if facilityid== 18806
		replace facilityid = 18802 if facilityid== 18809
		replace facilityid = 17597 if facilityid== 17595
		replace facilityid = 901792 if facilityid== 9017
		replace facilityid = 17596 if facilityid== 11714
		replace facilityid = 16526 if facilityid== 16
		replace facilityid = 16122 if facilityid== 166122
		replace facilityid = 900054 if facilityid== 90054
		replace facilityid = 11402 if facilityid== 11406
		replace facilityid = 17660 if facilityid== 17600
		replace facilityid = 901341 if facilityid== 90134
		replace facilityid = 800053 if facilityid== 80053
		replace facilityid = 901571 if facilityid== 90151
		replace facilityid = 12296 if facilityid== 12576
		replace facilityid = 901630 if facilityid== 901360
		replace facilityid = 11529 if facilityid== 1529
		replace facilityid = 901080 if facilityid== 901020
		replace facilityid = 11748 if facilityid== 61
		replace facilityid = 16037 if facilityid== 1603
		replace facilityid = 16037 if facilityid== 16034
		replace facilityid = 16182 if facilityid== 1680
		replace facilityid = 16070 if facilityid== 16870
		replace facilityid = 16229 if facilityid== 16299
		replace facilityid = 901331 if facilityid== 701331
		replace facilityid = 901331 if facilityid== 901334
		replace facilityid = 11474 if facilityid== 11477
		replace facilityid = 16031 if facilityid== 16013
		replace facilityid = 11383 if facilityid== 11385
		replace facilityid = 900966 if facilityid== 4212
		replace facilityid = 901600 if facilityid== 76
		replace facilityid = 16046 if facilityid== 15401
		replace facilityid = 17931 if facilityid== 1793
		replace facilityid = 12516 if facilityid== 12156
		replace facilityid = 16764 if facilityid== 1674
		replace facilityid = 15888 if facilityid== 1585
		replace facilityid = 15888 if facilityid== 1588
		replace facilityid = 16059 if facilityid== 160
		replace facilityid =11532 if facilityid == 11523 & enuid==95
		replace facilityid =11532 if facilityid == 11553 & enuid==62
		replace facilityid =11562 if facilityid == 11652 & enuid==61
		replace facilityid =11659 if facilityid == 11657 & enuid==19
		replace facilityid =11748 if facilityid == 11758 & enuid==61

	* Fixing HCWID: Look at which hcw observed by the same enumerator at that facility around that time
		recode hcwid .=5904 if enuid==46
		recode hcwid .=1712 if facilityid==16102 & enuid==31
		recode hcwid .=1487 if facilityid==900216 & enuid==17
		recode hcwid .=1551 if facilityid==900054 & enuid==31
		recode hcwid .=1632 if facilityid==18779 & enuid==42
		recode hcwid .=1632 if facilityid==18779 & enuid==92
		recode hcwid . = 1515 if enuid==17 & facilityid==15898
		recode hcwid . = 1911 if enuid==77 & facilityid==20043
		recode hcwid . = 1567 if enuid==42 & facilityid==17178
		recode hcwid . = 1396 if enuid==42 & facilityid==15812
		recode hcwid . = 1428 if enuid==31 & facilityid==19991
		recode hcwid . = 5785 if enuid==46 & facilityid==17298
		recode hcwid . = 5708 if enuid==17 & facilityid==15906
		recode hcwid . = 5788 if enuid==17 & facilityid==15999
		recode hcwid . = 5803 if enuid==31 & facilityid==16121
		recode hcwid 23977 = 5803 if enuid==31 & facilityid==16121
		recode hcwid . = 1471 if enuid==46 & facilityid==15881
		recode hcwid . = 1712 if enuid==31 & facilityid==16102
		recode hcwid . = 1487 if enuid==17 & facilityid==900216
		recode hcwid . = 1897 if enuid==17 & facilityid==900187
		recode hcwid . = 1670 if enuid==17 & facilityid==15850
		recode hcwid . = 5784 if enuid==17 & facilityid==16715
		recode hcwid . = 1483 if enuid==17 & facilityid==901593
		recode hcwid . = 1584 if enuid==17 & facilityid==15916
		recode hcwid . = 1659 if enuid==17 & facilityid==16005
		recode hcwid . = 5664 if enuid==17 & facilityid==15991
		recode hcwid . = 1432 if enuid==17 & facilityid==16164
		recode hcwid . = 1717 if enuid==17 & facilityid==16139
		recode hcwid . = 1663 if enuid==17 & facilityid==18815
		recode hcwid . = 1415 if enuid==17 & facilityid==15892
		recode hcwid . = 1525 if enuid==17 & facilityid==17597
		recode hcwid . = 5652 if enuid==17 & facilityid==15873
		recode hcwid . = 1470 if enuid==25 & facilityid==16006
		recode hcwid . = 1483 if enuid==25 & facilityid==901593
		recode hcwid . = 1681 if enuid==25 & facilityid==15969
		recode hcwid . = 1462 if enuid==25 & facilityid==19960
		recode hcwid . = 1510 if enuid==31 & facilityid==15832
		recode hcwid . = 5729 if enuid==31 & facilityid==15931
		recode hcwid . = 1459 if enuid==31 & facilityid==16145
		recode hcwid . = 5676 if enuid==31 & facilityid==20194
		recode hcwid . = 1551 if enuid==31 & facilityid==900054
		recode hcwid . = 1673 if enuid==42 & facilityid==16064
		recode hcwid . = 1632 if enuid==42 & facilityid==18779
		recode hcwid . = 1437 if enuid==42 & facilityid==900303
		recode hcwid . = 1693 if enuid==46 & facilityid==15851
		recode hcwid . = 1701 if enuid==46 & facilityid==15988
		recode hcwid . = 9365 if enuid==93 & facilityid==12471
		recode hcwid . = 1486 if survey_id == 15991
		recode hcwid . = 1901 if survey_id == 18225
		recode hcwid 1177 = 945 if survey_id == 2263
		recode hcwid 558 = 748 if survey_id == 2741
		recode hcwid 13272 = 7016 if survey_id == 281
		recode hcwid 2201 = 2204 if survey_id == 7487
		recode hcwid . = 1440 if survey_id == 11727
		recode hcwid 1394 = 1894 if survey_id == 18122
		recode hcwid . = 1896 if survey_id == 15524
		recode hcwid 1486 = 1486 if survey_id == 14063
		recode hcwid . = 1486 if survey_id == 15989
		recode hcwid . = 1637 if survey_id == 11733
		recode hcwid . = 1433 if survey_id == 17124
		recode hcwid . = 1516 if survey_id == 15293
		recode hcwid . = 1720 if survey_id == 11595
		recode hcwid 1702 = 1720 if survey_id == 11597
		recode hcwid . = 5803 if survey_id == 14944
		recode hcwid 72 = 725 if survey_id == 4064
		recode hcwid 796 = 815 if survey_id == 2966
		recode hcwid 573 = 5731 if survey_id == 19962
		recode hcwid 2042 = 2242 if survey_id == 8462
		recode hcwid 2232 = 2233 if survey_id == 6985
		
		replace hcwid = 5397 if hcwid==5497 & facilityid==900066
		replace hcwid = 6997 if hcwid ==  6991 & facilityid ==100005 & enuid ==29
		replace hcwid = 1986 if hcwid ==  1936 & facilityid ==11196 & enuid ==44
		replace hcwid = 2175 if hcwid ==  . & facilityid ==11282 & enuid ==76
		replace hcwid = 2061 if hcwid ==  5108 & facilityid ==11297 & enuid ==19
		replace hcwid = 2436 if hcwid ==  2430 & facilityid ==11305 & enuid ==30
		replace hcwid = 2370 if hcwid ==  2375 & facilityid ==11360 & enuid ==61
		replace hcwid = 1993 if hcwid ==  1996 & facilityid ==11379 & enuid ==19
		replace hcwid = 2381 if hcwid ==  . & facilityid ==11383 & enuid ==76
		replace hcwid = 2038 if hcwid ==  2036 & facilityid ==11394 & enuid ==1
		replace hcwid = 2034 if hcwid ==  2035 & facilityid ==11401 & enuid ==18
		replace hcwid = 2035 if hcwid ==  2034 & facilityid ==11402 & enuid ==18
		replace hcwid = 2341 if hcwid ==  231 & facilityid ==11444 & enuid ==61
		replace hcwid = 2341 if hcwid ==  234 & facilityid ==11444 & enuid ==61
		replace hcwid = 5525 if hcwid ==  5520 & facilityid ==11497 & enuid ==76
		replace hcwid = 2387 if hcwid ==  . & facilityid ==11498 & enuid ==76
		replace hcwid = 2387 if hcwid ==  2385 & facilityid ==11498 & enuid ==76
		replace hcwid = 2102 if hcwid ==  2101 & facilityid ==11514 & enuid ==62
		replace hcwid = 2273 if hcwid ==  2276 & facilityid ==11529 & enuid ==76
		replace hcwid = 2268 if hcwid ==  2266 & facilityid ==11532 & enuid ==62
		replace hcwid = 1938 if hcwid ==  1939 & facilityid ==11555 & enuid ==1
		replace hcwid = 1991 if hcwid ==  1994 & facilityid ==11562 & enuid ==76
		replace hcwid = 2098 if hcwid ==  2099 & facilityid ==11562 & enuid ==61
		replace hcwid = 2900 if hcwid ==  2100 & facilityid ==11562 & enuid ==61
		replace hcwid = 2363 if hcwid ==  . & facilityid ==11566 & enuid ==44
		replace hcwid = 2282 if hcwid ==  2280 & facilityid ==11653 & enuid ==61
		replace hcwid = 1979 if hcwid ==  . & facilityid ==11666 & enuid ==19
		replace hcwid = 2354 if hcwid ==  . & facilityid ==11673 & enuid ==76
		replace hcwid = 2167 if hcwid ==  2169 & facilityid ==11696 & enuid ==30
		replace hcwid = 2266 if hcwid ==  . & facilityid ==11730 & enuid ==62
		replace hcwid = 2266 if hcwid ==  1266 & facilityid ==11730 & enuid ==62
		replace hcwid = 2266 if hcwid ==  2262 & facilityid ==11730 & enuid ==62
		replace hcwid = 2191 if hcwid ==  . & facilityid ==11748 & enuid ==30
		replace hcwid = 2191 if hcwid ==  219 & facilityid ==11748 & enuid ==30
		replace hcwid = 2191 if hcwid ==  2291 & facilityid ==11748 & enuid ==30
		replace hcwid = 2142 if hcwid ==  2145 & facilityid ==11758 & enuid ==30
		replace hcwid = 2383 if hcwid ==  . & facilityid ==11802 & enuid ==76
		replace hcwid = 2426 if hcwid ==  2401 & facilityid ==11805 & enuid ==61
		replace hcwid = 2047 if hcwid ==  2407 & facilityid ==11805 & enuid ==62
		replace hcwid = 2426 if hcwid ==  61 & facilityid ==11805 & enuid ==61
		replace hcwid = 2426 if hcwid ==  8420 & facilityid ==11805 & enuid ==61
		replace hcwid = 2112 if hcwid ==  7118 & facilityid ==11820 & enuid ==19
		replace hcwid = 2226 if hcwid ==  2225 & facilityid ==11859 & enuid ==44
		replace hcwid = 569 if hcwid ==  558 & facilityid ==12036 & enuid ==56
		replace hcwid = 663 if hcwid ==  633 & facilityid ==12041 & enuid ==12
		replace hcwid = 1031 if hcwid ==  5469 & facilityid ==12042 & enuid ==75
		replace hcwid = 676 if hcwid ==  676 & facilityid ==12070 & enuid ==24
		replace hcwid = 927 if hcwid ==  925 & facilityid ==12181 & enuid ==8
		replace hcwid = 1289 if hcwid ==  1259 & facilityid ==12292 & enuid ==29
		replace hcwid = 699 if hcwid ==  1134 & facilityid ==12296 & enuid ==22
		replace hcwid = 699 if hcwid ==  669 & facilityid ==12296 & enuid ==22
		replace hcwid = 517 if hcwid ==  715 & facilityid ==12302 & enuid ==72
		replace hcwid = 1042 if hcwid ==  1046 & facilityid ==12336 & enuid ==67
		replace hcwid = 778 if hcwid ==  538 & facilityid ==12354 & enuid ==22
		replace hcwid = 1067 if hcwid ==  1607 & facilityid ==12423 & enuid ==22
		replace hcwid = 1134 if hcwid ==  5292 & facilityid ==12447 & enuid ==8
		replace hcwid = 1051 if hcwid ==  921 & facilityid ==12500 & enuid ==75
		replace hcwid = 1250 if hcwid ==  12 & facilityid ==12525 & enuid ==22
		replace hcwid = 662 if hcwid ==  725 & facilityid ==12534 & enuid ==37
		replace hcwid = 684 if hcwid ==  . & facilityid ==12535 & enuid ==10
		replace hcwid = 1237 if hcwid ==  1137 & facilityid ==12625 & enuid ==8
		replace hcwid = 921 if hcwid ==  721 & facilityid ==12671 & enuid ==8
		replace hcwid = 1373 if hcwid ==  1377 & facilityid ==15804 & enuid ==42
		replace hcwid = 1534 if hcwid ==  15 & facilityid ==15810 & enuid ==60
		replace hcwid = 1536 if hcwid ==  153 & facilityid ==15810 & enuid ==46
		replace hcwid = 1396 if hcwid ==  1394 & facilityid ==15812 & enuid ==42
		replace hcwid = 1439 if hcwid ==  . & facilityid ==15820 & enuid ==52
		replace hcwid = 1535 if hcwid ==  15 & facilityid ==15820 & enuid ==47
		replace hcwid = 1535 if hcwid ==  1534 & facilityid ==15820 & enuid ==47
		replace hcwid = 1511 if hcwid ==  1510 & facilityid ==15832 & enuid ==42
		replace hcwid = 5805 if hcwid ==  5803 & facilityid ==15836 & enuid ==31
		replace hcwid = 1516 if hcwid ==  1561 & facilityid ==15841 & enuid ==42
		replace hcwid = 1675 if hcwid ==  1671 & facilityid ==15851 & enuid ==42
		replace hcwid = 1435 if hcwid ==  1434 & facilityid ==15857 & enuid ==52
		replace hcwid = 1662 if hcwid ==  . & facilityid ==15859 & enuid ==5
		replace hcwid = 1575 if hcwid ==  1572 & facilityid ==15872 & enuid ==42
		replace hcwid = 1723 if hcwid ==  172 & facilityid ==15873 & enuid ==47
		replace hcwid = 1572 if hcwid ==  1372 & facilityid ==15874 & enuid ==5

	* Adding site var for easier replace
		gen 	site = 1 if aa8_a == 1
		replace site = 2 if aa8_c == 1
		replace site = 3 if aa8_b == 1
		replace site =2 if site == 3 & facilityid==11677 & enuid==30
		replace site =2 if site == 1 & facilityid==11756 & enuid==19
		replace site =1 if site == 2 & facilityid==11759 & enuid==44
		replace site =1 if site == 2 & facilityid==11759 & enuid==44
		replace site =2 if site == 3 & facilityid==11891 & enuid==76
		replace site =1 if site == 2 & facilityid==11894 & enuid==62
		replace site =3 if site == 1 & facilityid==11976 & enuid==68
		replace site =1 if site == 2 & facilityid==12290 & enuid==29
		replace site =2 if site == 1 & facilityid==12293 & enuid==39
		replace site =2 if site == 1 & facilityid==12525 & enuid==49
		replace site =2 if site == . & facilityid==12598 & enuid==10
		replace site =1 if site == 3 & facilityid==12684 & enuid==29
		replace site =1 if site == . & facilityid==12717 & enuid==29
		replace site =3 if site == . & facilityid==15810 & enuid==46
		replace site =3 if site == . & facilityid==15812 & enuid==42
		replace site =2 if site == . & facilityid==15836 & enuid==52
		replace site =3 if site == 2 & facilityid==15851 & enuid==46		

	* Other
		replace patientid=5247 if survey_id==9092
		replace patientid=6785 if survey_id==3086
		replace patientid=17212 if survey_id==11327
		replace patientid=17214 if survey_id==11332
		replace patientid=16086 if survey_id==11604
		replace enuid=29 if survey_id==1797
		
		replace county = "KI" if survey_id == 6131
		replace county = "KI" if survey_id == 6132
		recode enuid . = 46 if survey_id == 18233
		recode enuid 4 = 2 if survey_id == 3217
		recode enuid 76 = 68 if survey_id == 381
		recode enuid . = 46 if survey_id == 18426
	
		recode patientid 23845 = 23843 if survey_id == 13414
		recode patientid 5849 = 6246 if survey_id == 2971
		recode patientid 18501 = 16544 if survey_id == 1985
		recode patientid 13035 = 9121 if survey_id == 2664
		recode patientid 9972 = 7972 if survey_id == 8384
		recode enuid . = 92 if survey_id == 15991
	
	*----------------------*
	* 1.2. Drop duplicates *
	*----------------------*
	
	* 1. Duplicate observations. Where enuid & start time are the same.

		duplicates tag facilityid hcwid patientid enuid aa5_date aa6_start_time, gen (tag3)
		* There are 30 duplicates
		
		* Confirm duplicate
			egen nonmiss_total2 = rownonmiss(survey_id	operator	de_date	start_hours	start_minutes	start_seconds	time	end_hours	end_minutes	end_seconds	desecs	county	ir	aa1_hcw_consent	aa2_patient_consent	aa5_date	aa6_start_time	aa7_end_time	aa8_a	aa8_b	aa8_c	aa11_a_male	aa11_b_female	aa12_a_u5	aa12_b_child	aa12_c_young	aa12_d_middle	aa12_e_old	aa13_a_done	aa13_b_partially	aa13_c_refused	aa14_a_provider	aa14_b_patient	aa14_c_surveyor	aa14_d_other	aa14_e_specify	ab_a_results	ab_b_lab	ab_c_sent	ba1_a_ring	ba1_b_bracelet	ba1_c_nails	ba2_gloves	ba2_1a_new	ba2_1b_reused	ba2_1c_notassessed	ba2_2a_hr	ba2_2b_wsoap	ba2_2c_wosoap	ba2_2d_missed	ba2_2e_notassessed	ba2_3a_hr	ba2_3b_wsoap	ba2_3c_wosoap	ba2_3d_missed	ba2_3e_notassessed	bb1_contact	bb1_a_invasive	bb1_b_non_invasive	bb1_1a_hr	bb1_1b_wsoap	bb1_1c_wosoap	bb1_1d_missed	bb1_1e_notassessed	bb1_2a_hr	bb1_2b_wsoap	bb1_2c_wosoap	bb1_2d_missed	bb1_2e_notassessed	bb2_procedure	bb2_1a_hr	bb2_1b_wsoap	bb2_1c_wosoap	bb2_1d_missed	bb2_1e_notassessed	bb3_fluids	bb3_1a_hr	bb3_1b_wsoap	bb3_1c_wosoap	bb3_1d_missed	bb3_1e_notassessed	bb4_surrcontact	bb4_1a_hr	bb4_1b_wsoap	bb4_1c_wosoap	bb4_1d_missed	bb4_1e_notassessed	bb5_a_hr	bb5_b_wsoap	bb5_c_wosoap	bb5_d_missed	bb5_e_notassessed	bc1_hw_sec	bc2_hr_sec	bc3_tookplace	bc4_reused_towel	c1_thermometer	c1_1_standard	c1_2_infrared	c1_a_disinfected	c1_b_cleaned	c1_c_notcleaned	c1_d_in_disinfectant	c1_e_notassessed	c2_stethoscope	c2_a_disinfected	c2_b_cleaned	c2_c_notcleaned	c2_d_notassessed	c3_tongue_depressor	c3_1_plastic	c3_2_wooden	c3_3_metalic	c3_a_segregated	c3_a1_black_bin	c3_a2_yellow_bin	c3_a3_red_bin	c3_a4_othercoloured_bin	c3_b_disinfected	c3_c_cleaned	c3_d_notcleaned	c3_e_notassessed	c4_gloves	c4_a_segregated	c4_a1_black_bin	c4_a2_yellow_bin	c4_a3_red_bin	c4_a4_othercoloured_bin	c4_b_left_on	c4_c_left_outside	c4_d_notassessed	c5_swabs_gauze	c5_a_segregated	c5_a1_black_bin	c5_a2_yellow_bin	c5_a3_red_bin	c5_a4_othercoloured_bin	c5_b_left_outside	c5_c_notassessed	coments_pg1	da_injection_n_1	da_injection_n_2	da_a_vacation_n_1	da_a_vacation_n_2	da_b_family_n_1	da_b_family_n_2	da_c_curative_n_1	da_c_curative_n_2	da_d_notassesed_n_1	da_d_notassesed_n_2	db_blooddraw_n_1	db_blooddraw_n_2	db_a_phlebotomy_n_1	db_a_phlebotomy_n_2	db_b_lancet_n_1	db_b_lancet_n_2	dc1_a_hr_n_1	dc1_a_hr_n_2	dc1_b_wsoap_n_1	dc1_b_wsoap_n_2	dc1_c_wosoap_n_1	dc1_c_wosoap_n_2	dc1_d_missed_n_1	dc1_d_missed_n_2	dc1_e_notassessed_n_1	dc1_e_notassessed_n_2	dc2_a_clean_n_1	dc2_a_clean_n_2	dc2_b_blood_n_1	dc2_b_blood_n_2	dc2_c_syringes_n_1	dc2_c_syringes_n_2	dc2_d_swaps_n_1	dc2_d_swaps_n_2	dc2_e_infectius_n_1	dc2_e_infectius_n_2	dc3_1_syringe_n_1	dc3_1_syringe_n_2	dc3_2_slide_n_1	dc3_2_slide_n_2	dc3_3_vacutainer_n_1	dc3_3_vacutainer_n_2	dc3_123_a_new_n_1	dc3_123_a_new_n_2	dc3_123_b_reused_n_1	dc3_123_b_reused_n_2	dc3_123_c_notassessed_n_1	dc3_123_c_notassessed_n_2	dc3_4_rdt_set_n_1	dc3_4_rdt_set_n_2	dc3_5_glucometer_n_1	dc3_5_glucometer_n_2	dc3_45_a_new_n_1	dc3_45_a_new_n_2	dc3_45_b_reused_n_1	dc3_45_b_reused_n_2	dc3_45_c_notassessed_n_1	dc3_45_c_notassessed_n_2	dc4_a_new_n_1	dc4_a_new_n_2	dc4_b_reused_n_1	dc4_b_reused_n_2	dc4_c_notassessed_n_1	dc4_c_notassessed_n_2	dc5_a_cleanswab_n_1	dc5_a_cleanswab_n_2	dc5_a1_dispenser_n_1	dc5_a1_dispenser_n_2	dc5_a2_bottle_n_1	dc5_a2_bottle_n_2	dc5_a3_wet_prep_n_1	dc5_a3_wet_prep_n_2	dc5_a4_alcoholswab_n_1	dc5_a4_alcoholswab_n_2	dc5_b_dirtyswab_n_1	dc5_b_dirtyswab_n_2	dc5_c_missed_n_1	dc5_c_missed_n_2	dc6_medication_type_n_1	dc6_medication_type_n_2	dc6_a_vial_n_1	dc6_a_vial_n_2	dc6_b_glasstop_n_1	dc6_b_glasstop_n_2	dc6_c_popopen_n_1	dc6_c_popopen_n_2	dd1_1_syringe_n_1	dd1_1_syringe_n_2	dd1_2_slide_n_1	dd1_2_slide_n_2	dd1_3_vacutainer_n_1	dd1_3_vacutainer_n_2	dd1_123_a_sharpcontainer_n_1	dd1_123_a_sharpcontainer_n_2	dd1_123_a1_safetybox_n_1	dd1_123_a1_safetybox_n_2	dd1_123_a2_improvised_n_1	dd1_123_a2_improvised_n_2	dd1_123_b_opencont_n_1	dd1_123_b_opencont_n_2	dd1_123_c_redyellow_n_1	dd1_123_c_redyellow_n_2	dd1_123_d_black_n_1	dd1_123_d_black_n_2	dd1_123_e_outside_n_1	dd1_123_e_outside_n_2	dd1_123_f_notassessed_n_1	dd1_123_f_notassessed_n_2	dd1_4_rdtset_n_1	dd1_4_rdtset_n_2	dd1_5_glucometer_n_1	dd1_5_glucometer_n_2	dd1_45_a_sharpcontainer_n_1	dd1_45_a_sharpcontainer_n_2	dd1_45_a1_safetybox_n_1	dd1_45_a1_safetybox_n_2	dd1_45_a2_improvised_n_1	dd1_45_a2_improvised_n_2	dd1_45_b_opencont_n_1	dd1_45_b_opencont_n_2	dd1_45_c_redyellow_n_1	dd1_45_c_redyellow_n_2	dd1_45_d_black_n_1	dd1_45_d_black_n_2	dd1_45_e_outside_n_1	dd1_45_e_outside_n_2	dd1_45_f_notassessed_n_1	dd1_45_f_notassessed_n_2	dd2_a_sharpcontainer_n_1	dd2_a_sharpcontainer_n_2	dd2_a1_safetybox_n_1	dd2_a1_safetybox_n_2	dd2_a2_improvised_n_1	dd2_a2_improvised_n_2	dd2_b_opencont_n_1	dd2_b_opencont_n_2	dd2_c_sterilization_n_1	dd2_c_sterilization_n_2	dd2_d_outside_n_1	dd2_d_outside_n_2	dd2_e_notassessed_n_1	dd2_e_notassessed_n_2	dd3_leftmedicine_n_1	dd3_leftmedicine_n_2	dd3_a_redyellsharp_n_1	dd3_a_redyellsharp_n_2	dd3_b_othercolor_n_1	dd3_b_othercolor_n_2	dd3_c_not_patientzone_n_1	dd3_c_not_patientzone_n_2	dd3_d_patientzone_n_1	dd3_d_patientzone_n_2	dd3_e_needleinserted_n_1	dd3_e_needleinserted_n_2	dd3_f_outside_n_1	dd3_f_outside_n_2	dd3_g_notassessed_n_1	dd3_g_notassessed_n_2	dd4_swabsgauze_n_1	dd4_swabsgauze_n_2	dd4_a_segregated_n_1	dd4_a_segregated_n_2	dd4_a1_black_bin_n_1	dd4_a1_black_bin_n_2	dd4_a2_yellow_bin_n_1	dd4_a2_yellow_bin_n_2	dd4_a3_red_bin_n_1	dd4_a3_red_bin_n_2	dd4_a4_othercoloured_bin_n_1	dd4_a4_othercoloured_bin_n_2	dd4_b_left_outside_n_1	dd4_b_left_outside_n_2	dd4_c_notassessed_n_1	dd4_c_notassessed_n_2	dd5_gloves_n_1	dd5_gloves_n_2	dd5_a_segregated_n_1	dd5_a_segregated_n_2	dd5_a1_black_bin_n_1	dd5_a1_black_bin_n_2	dd5_a2_yellow_bin_n_1	dd5_a2_yellow_bin_n_2	dd5_a3_red_bin_n_1	dd5_a3_red_bin_n_2	dd5_a4_othercoloured_bin_n_1	dd5_a4_othercoloured_bin_n_2	dd5_b_lefton_n_1	dd5_b_lefton_n_2	dd5_c_left_outside_n_1	dd5_c_left_outside_n_2	dd5_d_notassessed_n_1	dd5_d_notassessed_n_2	dd6_a_hr_n_1	dd6_a_hr_n_2	dd6_b_wsoap_n_1	dd6_b_wsoap_n_2	dd6_c_wosoap_n_1	dd6_c_wosoap_n_2	dd6_d_missed_n_1	dd6_d_missed_n_2	dd6_e_notassessed_n_1	dd6_e_notassessed_n_2	dd8_needle_recap_n_1	dd8_needle_recap_n_2	dd8_a1_onehand_n_1	dd8_a1_onehand_n_2	dd8_a2_bothands_n_1	dd8_a2_bothands_n_2	dd8_b1_removaldevice_n_1	dd8_b1_removaldevice_n_2	dd8_b2_sephands_n_1	dd8_b2_sephands_n_2	dd9_hcw_needle_n_1	dd9_hcw_needle_n_2	de1_hw_sec	de2_hr_sec	de3_hw_gloves	de4_drying_hw	df_total_inject	dg_total_phlebotom	dh_total_pricks	survey_id2), strok
			*br facilityid hcwid patientid enuid aa5_date aa6_start_time aa7_end_time nonmiss_total2 if tag3 == 1
			sort facilityid hcwid
			
		* Drop duplicate with fewer observations
			drop if hcwid==515 & facilityid==17223 & patientid==8891 & nonmiss_total2==28
			drop if hcwid==1470 & facilityid==16006 & patientid==4812 & nonmiss_total2==23
			drop if hcwid==1486 & facilityid==16112 & patientid==11585 & nonmiss_total2==45
			drop if hcwid==1571 & facilityid==15833 & patientid==3214 & nonmiss_total2==40
			drop if hcwid==5756 & facilityid==15931 & patientid==23179 & nonmiss_total2==43
			drop if hcwid==1419 & facilityid==16006 & patientid==4796 & nonmiss_total2==34

		* For those with same number of nonmissings, we drop one randomly
			duplicates tag facilityid hcwid patientid enuid aa5_date aa6_start_time nonmiss_total2, gen (tag4)
			*br facilityid hcwid patientid enuid aa5_date aa6_start_time aa7_end_time nonmiss_total2 if tag4 == 1

			set seed 461144 //random number created with random.org
			bys aa6_start_time aa5_date hcwid patientid enuid: gen random = uniform() if tag4 == 1
			bys aa6_start_time aa5_date hcwid patientid enuid (random): gen serial_dup = _n if tag4 == 1
			drop if serial_dup == 1
			
	* 2. Check 2: Maybe interrater (match on facilityid hcwid patientid and date but not marked ir); check if time is the same:
			duplicates tag facilityid hcwid patientid aa5_date aa6_start_time if ir==. & tag3 != 1, gen(interrater_probably)
			tab interrater_probably
			*br ir patientid hcwid aa6_start_time if interrater_probably==1

			replace ir = 1 if interrater_probably == 1			
			
	* 3. Check 3: Interrater for sure if ir == 1. 
			
		*One ir observation is repeated twice, i.e. is a duplicate as described above: patientid 2037. 
			duplicates tag facilityid hcwid patientid aa5_date if ir==1, gen(interrater_certain)
			tab interrater_certain ir, m
					
		* Strangely, some cases say it is an interrater observation, but doesn't match on 
		* facilityid hcwid patientid aa5(date)
			duplicates tag facilityid hcwid patientid if interrater_certain==0, gen(tag5)
			sort facilityid hcwid patientid
			*br facilityid hcwid patientid enuid aa5_date aa6_start_time ir tag5 if tag5==1

		* These are all interrater observations
			replace aa5_date = "28-05-2015" if aa6_start_time == "1049" & tag5==1
			replace aa5_date = "02-03-2015" if aa6_start_time == "1100" & tag5==1
			replace aa5_date = "08-07-2015" if aa6_start_time == "1149" & tag5==1
			replace aa5_date = "13-04-2015" if aa6_start_time == "1056" & tag5==1
			replace aa5_date = "28-05-2015" if aa6_start_time == "1022" & tag5==1
			replace aa5_date = "11-05-2015" if aa6_start_time == "1205" & tag5==1
			replace aa5_date = "08-04-2015" if aa6_start_time == "1245" & tag5==1
			replace aa5_date = "08-04-2015" if aa6_start_time == "1252" & tag5==1
			replace aa5_date = "19-05-2015" if aa6_start_time == "1528" & tag5==1
			replace aa5_date = "08-04-2015" if aa6_start_time == "1304" & tag5==1
			replace aa5_date = "30-06-2015" if aa6_start_time == ""	    & tag5==1
			replace aa5_date = "22-05-2015" if aa6_start_time == "1130" & tag5==1
			replace aa5_date = "02-07-2015" if aa6_start_time == "1218" & tag5==1
				
			replace interrater_certain = 1 if tag5==1
			* 16 March 2016: some cases still remain. Not doing anything about these for now.
		
		* Cases where there are 3 interrater observations that match on facilityid hcwid patientid aa5(date)
		* We physically observe to see which are interrater
			*br facilityid hcwid patientid enuid aa5_date aa6_start_time ir if interrater_certain == 2
			sort facilityid hcwid patientid enuid
			recode ir 1 = 0 if enuid==77 & aa6_start_time=="1130" & interrater_certain==2
			recode ir 1 = 0 if enuid==60 & aa6_start_time=="1030" & interrater_certain==2
			recode ir 1 = 0 if enuid==47 & aa6_start_time=="1140" & interrater_certain==2
			recode ir 1 = 0 if enuid==31 & aa6_start_time=="1139" & interrater_certain==2
				
			recode interrater_certain 2 = 1
				
			bysort facilityid hcwid patientid interrater_certain: gen serial_ir=_n if interrater_certain == 1
			order aa5_date facilityid hcwid patientid serial_ir interrater_certain
			*br if interrater_certain==1
			drop serial_ir interrater_certain interrater_probably
			
		*-------------------------------------*
		* Match the IRs based on the checkers *
		*-------------------------------------*
		
		/* Let's try to match the IRs based on the checkers

			Key pieces of information

			- There are people who are only checkers. Those observations are IR by default
			- There are people who are checkers and suveryors at other moments. If an observation is duplicate in those cases, then they are checkers
			- Very important not to confuse some observations that may seem duplicates but are not... 
				for instance when looking at hfid hcwid enuid patientid aa8_a aa8_b aa8_c (last three-->observation site)
				   - Some patients are treated by the same hcw in the consultation room 
					(they are checked go for lab tests and come back) - DO NOT DISMISS ONLY BASED ON THESE VARIABLES, 
					LOOK AT ab_a ab_b ab_c (PATIENT SENT/COMING FROM ANOTHER PART OF THE HF), ALSO CHECK ANOTHER FEW OBSERVATIONS IF IN DOUBT
		*/

		* Prepare spotchecker list to merge
			preserve
			import excel "${spotcheckers}", sheet("Sheet1") firstrow clear
			rename level spotchecker_level
			tempfile spotcheckers
			save 	`spotcheckers'
			
		* Merge spotchecker list
			restore
			rename enuid spotchecker_id
			merge m:1 spotchecker_id using `spotcheckers'
			drop if _merge == 2
			rename spotchecker_id enuid
			
		* Generate dummy for spotcheckers
			gen 	spotchecker = .
			replace spotchecker = 1 if _merge == 3
			replace spotchecker = 0 if _merge != 3
			drop 	_merge


		* generate ir type of enumerators based on what we know
			gen 	ir_enu = 0  
			replace ir_enu = 1 if spotchecker_level == 1 
			replace ir_enu = 2 if spotchecker_level == 2 
			
			lab var ir_enu "IR enumerator status"
			lab define ir_enu 0 "Only Surveyor" 1 "Surveyor/checker" 2 "Only Checker", replace
			lab values ir_enu ir_enu

			tab ir ir_enu, m
				
		* Replace ir=1 if only checker, except some that Salome did as a surveyor
			replace ir=1 if ir_enu==2
			replace ir=. if enuid==95 & facilityid==11453
			replace ir=. if enuid==95 & facilityid==11829
				
		* replace ir=1 if only checker, except some that Salome did as a surveyor

			duplicates tag facilityid hcwid patientid, gen(temp1)

			tab temp1
			tab temp1 ir_enu
			tab temp1 ir

			duplicates tag patientid, gen(temp2)

			tab temp2
			tab temp2 ir_enu
			tab temp2 ir
				
		* identify the pairs
			duplicates tag facilityid hcwid patientid aa5_date if ir==1, gen(repeated_r1)

			bysort facilityid hcwid patientid aa5_date repeated_r1, sort: gen repeated=_n if repeated_r1
				
			gen 	ir_serial=1 if ir==1 & ir_enu==2
			replace ir_serial=0 if ir==1 & ir_enu==0

			lab def ir_serial 0 "Original" 1 "Check"
			lab values ir_serial ir_serial
				
			drop temp1 temp2 repeated_r1 repeated 
						
		* Merging with a file checked manually
				
				preserve
				tempfile ir_clean
					insheet using "${input_ir}", clear	
					save `ir_clean', replace
				restore
					
				merge m:1 survey_id using `ir_clean'
				drop if _merge == 2
				
				replace  ir_serial_man="0" if ir_serial_man=="Original"
				replace  ir_serial_man="1" if ir_serial_man=="Check"
				destring  ir_serial_man, replace	
				lab values ir_serial_man ir_serial
		
			* ir was replaced completely 
				
				drop ir ir_serial
				replace ir_man=. if ir_man==0
				gen ir=1 if ir_serial_man<=1
				rename ir_serial_man ir_serial
				
				drop *_man _merge 
				tab ir_serial ir
			
			* Save 
				preserve
				keep if ir == 1
				*save "${qchecks}", replace
				restore
			
			* Drop duplicates
				drop if ir_serial==1

	*----------------------------------------------------*
	* 1.3. Correcting issues with facility_id and HCW_id *
	*----------------------------------------------------*

		preserve
			tempfile ids_correct
				insheet using "${input_IDs1}", clear	
				save `ids_correct', replace
		restore
				
			merge m:1 survey_id using `ids_correct'
		
 
			replace facilityid=facilityid_c if facilityid_c!=.
			replace hcwid=hcwid_c if hcwid_c!=.
 
			tab _merge
			
			drop hcwid_c facilityid_c _merge
							 		 
	/*-------------------------------*
	* 1.4. Calculate response rates *
	*-------------------------------*
		
	* Attempted
		mat T = J(5,1,.)
		count
		scalar 	attemp = r(N)
		mat T[1,1] = attemp
	* HCW consent
		count if aa1_hcw_consent == 1
		scalar 	HCW_consent = r(N)
		mat T[2,1] = HCW_consent	
	* Patient consent
		count if aa2_patient_consent == 1
		scalar 	patient_consent = r(N)
		mat T[3,1] = patient_consent
	* HCW & patient consent
		count if aa1_hcw_consent == 1 & aa2_patient_consent == 1
		scalar 	both_consent = r(N)
		mat T[4,1] = both_consent	
	* Response rate
		scalar resp_rate = both_consent/attemp*100
		mat T[5,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "HCW consent" "Patient consent" "HCW & patient consent" "Response rate"
		matlist T
		
	* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify 
		putexcel A2 = ("Attempted") A3 = ("HCW consent") A4 = ("Patient consent") A5 = ("HCW & patient consent") A6 = ("Response rate") ///
		B2 = matrix(T) 	
		*/
	*------------------------------------------------------------*
	* 1.5. Keep only those who consented and finished the survey *
	*------------------------------------------------------------*
	
	* Those with HCW consent 	
		keep if aa1_hcw_consent == 1
	* Those with patient consent
		keep if aa2_patient_consent == 1
		
********************************************************************************
	** Part 2: Basic cleaning
********************************************************************************
		
	*-----------------------------------------------------------------------*
	* 2.1. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
	
	* AA. General details
		rename aa1_hcw_consent aa1
		rename aa2_patient_consent aa2
		rename aa5_date aa5
		rename aa6_start_time aa6
		rename aa7_end_time aa7
		rename aa11_a_male aa11_a
		rename aa11_b_female aa11_b
		rename aa12_a_u5 aa12_a
		rename aa12_b_child aa12_b
		rename aa12_c_young aa12_c
		rename aa12_d_middle aa12_d
		rename aa12_e_old aa12_e
		rename aa13_a_done aa13_a
		rename aa13_b_partially aa13_b
		rename aa13_c_refused aa13_c
		rename aa14_a_provider aa14_a
		rename aa14_b_patient aa14_b
		rename aa14_c_surveyor aa14_c
		rename aa14_d_other aa14_d
		rename aa14_e_specify aa14_e
	
	* AB. BEFORE/AFTER INTERVENTION
		rename ab_a_results ab_a
		rename ab_b_lab ab_b
		rename ab_c_sent ab_c
		
	* BA. HAND HYGIENE - HCW PREPARATION IN ALL SITES
		rename ba1_a_ring ba1_a
		rename ba1_b_bracelet ba1_b
		rename ba1_c_nails ba1_c
		rename ba2_gloves ba2
		rename ba2_1a_new ba2_1a
		rename ba2_1b_reused ba2_1b
		rename ba2_1c_notassessed ba2_1c
		rename ba2_2a_hr ba2_2a
		rename ba2_2b_wsoap ba2_2b
		rename ba2_2c_wosoap ba2_2c
		rename ba2_2d_missed ba2_2d
		rename ba2_2e_notassessed ba2_2e
		rename ba2_3a_hr ba2_3a
		rename ba2_3b_wsoap ba2_3b
		rename ba2_3c_wosoap ba2_3c
		rename ba2_3d_missed ba2_3d
		rename ba2_3e_notassessed ba2_3e
	
	* BB. HAND HYGIENE (except for injections/blood draws)
		rename bb1_contact bb1
		rename bb1_a_invasive bb1_a
		rename bb1_b_non_invasive bb1_b
		rename bb1_1a_hr bb1_1a
		rename bb1_1b_wsoap bb1_1b
		rename bb1_1c_wosoap bb1_1c
		rename bb1_1d_missed bb1_1d
		rename bb1_1e_notassessed bb1_1e
		rename bb1_2a_hr bb1_2a
		rename bb1_2b_wsoap bb1_2b
		rename bb1_2c_wosoap bb1_2c
		rename bb1_2d_missed bb1_2d
		rename bb1_2e_notassessed bb1_2e
		rename bb2_procedure bb2
		rename bb2_1a_hr bb2_1a
		rename bb2_1b_wsoap bb2_1b
		rename bb2_1c_wosoap bb2_1c
		rename bb2_1d_missed bb2_1d
		rename bb2_1e_notassessed bb2_1e
		rename bb3_fluids bb3
		rename bb3_1a_hr bb3_1a
		rename bb3_1b_wsoap bb3_1b
		rename bb3_1c_wosoap bb3_1c
		rename bb3_1d_missed bb3_1d
		rename bb3_1e_notassessed bb3_1e
		rename bb4_surrcontact bb4
		rename bb4_1a_hr bb4_1a
		rename bb4_1b_wsoap bb4_1b
		rename bb4_1c_wosoap bb4_1c
		rename bb4_1d_missed bb4_1d
		rename bb4_1e_notassessed bb4_1e
		rename bb5_a_hr bb5_a
		rename bb5_b_wsoap bb5_b
		rename bb5_c_wosoap bb5_c
		rename bb5_d_missed bb5_d
		rename bb5_e_notassessed bb5_e
		
	* BC. Hand Hygiene Characteristics (except for injections/blood draws)
		rename bc1_hw_sec bc1_hw
		rename bc2_hr_sec bc2_hr
		rename bc3_tookplace bc3
		rename bc4_reused_towel bc4
	
	* C. Waste segregation & disinfection (except for injections/blood draws)
		rename c1_thermometer c1
		rename c1_1_standard c1_1
		rename c1_2_infrared c1_2
		rename c1_a_disinfected c1_a
		rename c1_b_cleaned c1_b
		rename c1_c_notcleaned c1_c
		rename c1_d_in_disinfectant c1_d
		rename c1_e_notassessed c1_e
		rename c2_stethoscope c2
		rename c2_a_disinfected c2_a
		rename c2_b_cleaned c2_b
		rename c2_c_notcleaned c2_c
		rename c2_d_notassessed c2_d
		rename c3_tongue_depressor c3
		rename c3_1_plastic c3_1
		rename c3_2_wooden c3_2
		rename c3_3_metalic c3_3
		rename c3_a_segregated c3_a
		rename c3_a1_black_bin c3_a1
		rename c3_a2_yellow_bin c3_a2
		rename c3_a3_red_bin c3_a3
		rename c3_a4_othercoloured_bin c3_a4
		rename c3_b_disinfected c3_b
		rename c3_c_cleaned c3_c
		rename c3_d_notcleaned c3_d
		rename c3_e_notassessed c3_e
		rename c4_gloves c4
		rename c4_a_segregated c4_a
		rename c4_a1_black_bin c4_a1
		rename c4_a2_yellow_bin c4_a2
		rename c4_a3_red_bin c4_a3
		rename c4_a4_othercoloured_bin c4_a4
		rename c4_b_left_on c4_b
		rename c4_c_left_outside c4_c
		rename c4_d_notassessed c4_d
		rename c5_swabs_gauze c5
		rename c5_a_segregated c5_a
		rename c5_a1_black_bin c5_a1
		rename c5_a2_yellow_bin c5_a2
		rename c5_a3_red_bin c5_a3
		rename c5_a4_othercoloured_bin c5_a4
		rename c5_b_left_outside c5_b
		rename c5_c_notassessed c5_c
		rename coments_pg1 coments
	
	* D. INJECTION/BLOOD TEST
		rename da_injection_n_1 da_n1
		rename da_injection_n_2 da_n2
		rename da_a_vacation_n_1 da_a_n1
		rename da_a_vacation_n_2 da_a_n2
		rename da_b_family_n_1 da_b_n1
		rename da_b_family_n_2 da_b_n2
		rename da_c_curative_n_1 da_c_n1
		rename da_c_curative_n_2 da_c_n2
		rename da_d_notassesed_n_1 da_d_n1
		rename da_d_notassesed_n_2 da_d_n2
		rename db_blooddraw_n_1 db_n1
		rename db_blooddraw_n_2 db_n2
		rename db_a_phlebotomy_n_1 db_a_n1
		rename db_a_phlebotomy_n_2 db_a_n2
		rename db_b_lancet_n_1 db_b_n1
		rename db_b_lancet_n_2 db_b_n2
		rename dc1_a_hr_n_1 dc1_a_n1
		rename dc1_a_hr_n_2 dc1_a_n2
		rename dc1_b_wsoap_n_1 dc1_b_n1
		rename dc1_b_wsoap_n_2 dc1_b_n2
		rename dc1_c_wosoap_n_1 dc1_c_n1
		rename dc1_c_wosoap_n_2 dc1_c_n2
		rename dc1_d_missed_n_1 dc1_d_n1
		rename dc1_d_missed_n_2 dc1_d_n2
		rename dc1_e_notassessed_n_1 dc1_e_n1
		rename dc1_e_notassessed_n_2 dc1_e_n2
		rename dc2_a_clean_n_1 dc2_a_n1
		rename dc2_a_clean_n_2 dc2_a_n2
		rename dc2_b_blood_n_1 dc2_b_n1
		rename dc2_b_blood_n_2 dc2_b_n2
		rename dc2_c_syringes_n_1 dc2_c_n1
		rename dc2_c_syringes_n_2 dc2_c_n2
		rename dc2_d_swaps_n_1 dc2_d_n1
		rename dc2_d_swaps_n_2 dc2_d_n2
		rename dc2_e_infectius_n_1 dc2_e_n1
		rename dc2_e_infectius_n_2 dc2_e_n2
		rename dc3_1_syringe_n_1 dc3_1_n1
		rename dc3_1_syringe_n_2 dc3_1_n2
		rename dc3_2_slide_n_1 dc3_2_n1
		rename dc3_2_slide_n_2 dc3_2_n2
		rename dc3_3_vacutainer_n_1 dc3_3_n1
		rename dc3_3_vacutainer_n_2 dc3_3_n2
		rename dc3_123_a_new_n_1 dc3_123_a_n1
		rename dc3_123_a_new_n_2 dc3_123_a_n2
		rename dc3_123_b_reused_n_1 dc3_123_b_n1
		rename dc3_123_b_reused_n_2 dc3_123_b_n2
		rename dc3_123_c_notassessed_n_1 dc3_123_c_n1
		rename dc3_123_c_notassessed_n_2 dc3_123_c_n2
		rename dc3_4_rdt_set_n_1 dc3_4_n1
		rename dc3_4_rdt_set_n_2 dc3_4_n2
		rename dc3_5_glucometer_n_1 dc3_5_n1
		rename dc3_5_glucometer_n_2 dc3_5_n2
		rename dc3_45_a_new_n_1 dc3_45_a_n1
		rename dc3_45_a_new_n_2 dc3_45_a_n2
		rename dc3_45_b_reused_n_1 dc3_45_b_n1
		rename dc3_45_b_reused_n_2 dc3_45_b_n2
		rename dc3_45_c_notassessed_n_1 dc3_45_c_n1
		rename dc3_45_c_notassessed_n_2 dc3_45_c_n2
		rename dc4_a_new_n_1 dc4_a_n1
		rename dc4_a_new_n_2 dc4_a_n2
		rename dc4_b_reused_n_1 dc4_b_n1
		rename dc4_b_reused_n_2 dc4_b_n2
		rename dc4_c_notassessed_n_1 dc4_c_n1
		rename dc4_c_notassessed_n_2 dc4_c_n2
		rename dc5_a_cleanswab_n_1 dc5_a_n1
		rename dc5_a_cleanswab_n_2 dc5_a_n2
		rename dc5_a1_dispenser_n_1 dc5_a1_n1
		rename dc5_a1_dispenser_n_2 dc5_a1_n2
		rename dc5_a2_bottle_n_1 dc5_a2_n1
		rename dc5_a2_bottle_n_2 dc5_a2_n2
		rename dc5_a3_wet_prep_n_1 dc5_a3_n1
		rename dc5_a3_wet_prep_n_2 dc5_a3_n2
		rename dc5_a4_alcoholswab_n_1 dc5_a4_n1
		rename dc5_a4_alcoholswab_n_2 dc5_a4_n2
		rename dc5_b_dirtyswab_n_1 dc5_b_n1
		rename dc5_b_dirtyswab_n_2 dc5_b_n2
		rename dc5_c_missed_n_1 dc5_c_n1
		rename dc5_c_missed_n_2 dc5_c_n2
		rename dc6_medication_type_n_1 dc6_n1
		rename dc6_medication_type_n_2 dc6_n2
		rename dc6_a_vial_n_1 dc6_a_n1
		rename dc6_a_vial_n_2 dc6_a_n2
		rename dc6_b_glasstop_n_1 dc6_b_n1
		rename dc6_b_glasstop_n_2 dc6_b_n2
		rename dc6_c_popopen_n_1 dc6_c_n1
		rename dc6_c_popopen_n_2 dc6_c_n2
		rename dd1_1_syringe_n_1 dd1_1_n1
		rename dd1_1_syringe_n_2 dd1_1_n2
		rename dd1_2_slide_n_1 dd1_2_n1
		rename dd1_2_slide_n_2 dd1_2_n2
		rename dd1_3_vacutainer_n_1 dd1_3_n1
		rename dd1_3_vacutainer_n_2 dd1_3_n2
		rename dd1_123_a_sharpcontainer_n_1 dd1_123_a_n1
		rename dd1_123_a_sharpcontainer_n_2 dd1_123_a_n2
		rename dd1_123_a1_safetybox_n_1 dd1_123_a1_n1
		rename dd1_123_a1_safetybox_n_2 dd1_123_a1_n2
		rename dd1_123_a2_improvised_n_1 dd1_123_a2_n1
		rename dd1_123_a2_improvised_n_2 dd1_123_a2_n2
		rename dd1_123_b_opencont_n_1 dd1_123_b_n1
		rename dd1_123_b_opencont_n_2 dd1_123_b_n2
		rename dd1_123_c_redyellow_n_1 dd1_123_c_n1
		rename dd1_123_c_redyellow_n_2 dd1_123_c_n2
		rename dd1_123_d_black_n_1 dd1_123_d_n1
		rename dd1_123_d_black_n_2 dd1_123_d_n2
		rename dd1_123_e_outside_n_1 dd1_123_e_n1
		rename dd1_123_e_outside_n_2 dd1_123_e_n2
		rename dd1_123_f_notassessed_n_1 dd1_123_f_n1
		rename dd1_123_f_notassessed_n_2 dd1_123_f_n2
		rename dd1_4_rdtset_n_1 dd1_4_n1
		rename dd1_4_rdtset_n_2 dd1_4_n2
		rename dd1_5_glucometer_n_1 dd1_5_n1
		rename dd1_5_glucometer_n_2 dd1_5_n2
		rename dd1_45_a_sharpcontainer_n_1 dd1_45_a_n1
		rename dd1_45_a_sharpcontainer_n_2 dd1_45_a_n2
		rename dd1_45_a1_safetybox_n_1 dd1_45_a1_n1
		rename dd1_45_a1_safetybox_n_2 dd1_45_a1_n2
		rename dd1_45_a2_improvised_n_1 dd1_45_a2_n1
		rename dd1_45_a2_improvised_n_2 dd1_45_a2_n2
		rename dd1_45_b_opencont_n_1 dd1_45_b_n1
		rename dd1_45_b_opencont_n_2 dd1_45_b_n2
		rename dd1_45_c_redyellow_n_1 dd1_45_c_n1
		rename dd1_45_c_redyellow_n_2 dd1_45_c_n2
		rename dd1_45_d_black_n_1 dd1_45_d_n1
		rename dd1_45_d_black_n_2 dd1_45_d_n2
		rename dd1_45_e_outside_n_1 dd1_45_e_n1
		rename dd1_45_e_outside_n_2 dd1_45_e_n2
		rename dd1_45_f_notassessed_n_1 dd1_45_f_n1
		rename dd1_45_f_notassessed_n_2 dd1_45_f_n2
		rename dd2_a_sharpcontainer_n_1 dd2_a_n1
		rename dd2_a_sharpcontainer_n_2 dd2_a_n2
		rename dd2_a1_safetybox_n_1 dd2_a1_n1
		rename dd2_a1_safetybox_n_2 dd2_a1_n2
		rename dd2_a2_improvised_n_1 dd2_a2_n1
		rename dd2_a2_improvised_n_2 dd2_a2_n2
		rename dd2_b_opencont_n_1 dd2_b_n1
		rename dd2_b_opencont_n_2 dd2_b_n2
		rename dd2_c_sterilization_n_1 dd2_c_n1
		rename dd2_c_sterilization_n_2 dd2_c_n2
		rename dd2_d_outside_n_1 dd2_d_n1
		rename dd2_d_outside_n_2 dd2_d_n2
		rename dd2_e_notassessed_n_1 dd2_e_n1
		rename dd2_e_notassessed_n_2 dd2_e_n2
		rename dd3_leftmedicine_n_1 dd3_n1
		rename dd3_leftmedicine_n_2 dd3_n2
		rename dd3_a_redyellsharp_n_1 dd3_a_n1
		rename dd3_a_redyellsharp_n_2 dd3_a_n2
		rename dd3_b_othercolor_n_1 dd3_b_n1
		rename dd3_b_othercolor_n_2 dd3_b_n2
		rename dd3_c_not_patientzone_n_1 dd3_c_n1
		rename dd3_c_not_patientzone_n_2 dd3_c_n2
		rename dd3_d_patientzone_n_1 dd3_d_n1
		rename dd3_d_patientzone_n_2 dd3_d_n2
		rename dd3_e_needleinserted_n_1 dd3_e_n1
		rename dd3_e_needleinserted_n_2 dd3_e_n2
		rename dd3_f_outside_n_1 dd3_f_n1
		rename dd3_f_outside_n_2 dd3_f_n2
		rename dd3_g_notassessed_n_1 dd3_g_n1
		rename dd3_g_notassessed_n_2 dd3_g_n2
		rename dd4_swabsgauze_n_1 dd4_n1
		rename dd4_swabsgauze_n_2 dd4_n2
		rename dd4_a_segregated_n_1 dd4_a_n1
		rename dd4_a_segregated_n_2 dd4_a_n2
		rename dd4_a1_black_bin_n_1 dd4_a1_n1
		rename dd4_a1_black_bin_n_2 dd4_a1_n2
		rename dd4_a2_yellow_bin_n_1 dd4_a2_n1
		rename dd4_a2_yellow_bin_n_2 dd4_a2_n2
		rename dd4_a3_red_bin_n_1 dd4_a3_n1
		rename dd4_a3_red_bin_n_2 dd4_a3_n2
		rename dd4_a4_othercoloured_bin_n_1 dd4_a4_n1
		rename dd4_a4_othercoloured_bin_n_2 dd4_a4_n2
		rename dd4_b_left_outside_n_1 dd4_b_n1
		rename dd4_b_left_outside_n_2 dd4_b_n2
		rename dd4_c_notassessed_n_1 dd4_c_n1
		rename dd4_c_notassessed_n_2 dd4_c_n2
		rename dd5_gloves_n_1 dd5_n1
		rename dd5_gloves_n_2 dd5_n2
		rename dd5_a_segregated_n_1 dd5_a_n1
		rename dd5_a_segregated_n_2 dd5_a_n2
		rename dd5_a1_black_bin_n_1 dd5_a1_n1
		rename dd5_a1_black_bin_n_2 dd5_a1_n2
		rename dd5_a2_yellow_bin_n_1 dd5_a2_n1
		rename dd5_a2_yellow_bin_n_2 dd5_a2_n2
		rename dd5_a3_red_bin_n_1 dd5_a3_n1
		rename dd5_a3_red_bin_n_2 dd5_a3_n2
		rename dd5_a4_othercoloured_bin_n_1 dd5_a4_n1
		rename dd5_a4_othercoloured_bin_n_2 dd5_a4_n2
		rename dd5_b_lefton_n_1 dd5_b_n1
		rename dd5_b_lefton_n_2 dd5_b_n2
		rename dd5_c_left_outside_n_1 dd5_c_n1
		rename dd5_c_left_outside_n_2 dd5_c_n2
		rename dd5_d_notassessed_n_1 dd5_d_n1
		rename dd5_d_notassessed_n_2 dd5_d_n2
		rename dd6_a_hr_n_1 dd6_a_n1
		rename dd6_a_hr_n_2 dd6_a_n2
		rename dd6_b_wsoap_n_1 dd6_b_n1
		rename dd6_b_wsoap_n_2 dd6_b_n2
		rename dd6_c_wosoap_n_1 dd6_c_n1
		rename dd6_c_wosoap_n_2 dd6_c_n2
		rename dd6_d_missed_n_1 dd6_d_n1
		rename dd6_d_missed_n_2 dd6_d_n2
		rename dd6_e_notassessed_n_1 dd6_e_n1
		rename dd6_e_notassessed_n_2 dd6_e_n2
		rename dd8_needle_recap_n_1 dd8_n1
		rename dd8_needle_recap_n_2 dd8_n2
		rename dd8_a1_onehand_n_1 dd8_a1_n1
		rename dd8_a1_onehand_n_2 dd8_a1_n2
		rename dd8_a2_bothands_n_1 dd8_a2_n1
		rename dd8_a2_bothands_n_2 dd8_a2_n2
		rename dd8_b1_removaldevice_n_1 dd8_b1_n1
		rename dd8_b1_removaldevice_n_2 dd8_b1_n2
		rename dd8_b2_sephands_n_1 dd8_b2_n1
		rename dd8_b2_sephands_n_2 dd8_b2_n2
		rename dd9_hcw_needle_n_1 dd9_n1
		rename dd9_hcw_needle_n_2 dd9_n2
		rename de1_hw_sec de1_hw
		rename de2_hr_sec de2_hr
		rename de3_hw_gloves de3_hw
		rename de4_drying_hw de4
		rename df_total_inject df
		rename dg_total_phlebotom dg
		rename dh_total_pricks dh
		rename survey_id2 survey_id2			
	
	*------------------*
	* 2.2. Inputations *
	*------------------*
	
	* AA. General details
	*--------------------

		* Of all the options, only one must be selected
		global aa8 aa8_a aa8_b aa8_c 
		global aa11 aa11_a aa11_b
		global aa12 aa12_a aa12_b aa12_c aa12_d aa12_e
		global aa13 aa13_a aa13_b aa13_c 
		global aa14 aa14_a aa14_b aa14_c aa14_d	
			
		* If both complete and partially complete observation are checked, the observation is complete **
			replace aa13_b = . if aa13_a == 1 & aa13_b == 1
	
			foreach x in aa8 aa11 aa12 aa13 aa14 {
				egen `x'_v=rownonmiss($`x')
				tab `x'_v
					*ds `x'*
					*local count_`x' : word count `r(varlist)'
					*local alphabet = cond(`count'_`x' == 5, e, cond(`count'_`x'==4, d, cond(`count'_`x'==3, c, cond(`count'_`x'==2, b, a))))
					*replace `x'_`alphabet'
					*if `x'_count_`x' 
					
				}

					*29 obs say in two sites.
					*32 obs don't have a site
					
					*201 obs don't have HCW gender
					* First, see if same hcw observed again, impute if so
					* 8 observations mark both genders
					
					*110 obs don't have age
					* check to see if same patient id
					*18 check two ages
					
					*213 don't give status of obs
					*9 give to statuses
		
		* For the questions where there is at least one non-missing variable, change the others to 0
			foreach x in aa8 aa11 aa12 aa13 {
				foreach y of global `x' {
					replace `y' = 0 if `y' != 1 & `x'_v >= 1
				}
			}
					
		* Inputing appropriate zeros
		
			* Consent- abd result-related variables
			global consent aa1 aa2
			global result aa14_a aa14_b aa14_c aa14_d
			global partial aa13_a aa13_b aa13_c
		
			foreach x in consent result partial {
				foreach y of global `x' {
				replace `y'=0 if `y' != 1	
				}
			}
			
	* AB. Before/After Interaction
	*----------------------------

		foreach x in ab_a ab_b ab_c  {
			replace `x'=0 if `x'!=1 
			tab `x'
		}
	
	* BA. Hand Hygiene - HCW preparation in all sites
	*--------------------------------------------------
	
		global ba2_1 ba2_1a ba2_1b
		global ba2_2 ba2_2a ba2_2b ba2_2c ba2_2d
		global ba2_3 ba2_3a ba2_3b ba2_3c ba2_3d
		
		* Assume they are not wearing rings, bracelets, long/artificial nails if none is checked *
		foreach x in ba1_a ba1_b ba1_c  {
			replace `x'=0 if `x'!=1 
			tab `x'
		}		
		
		replace ba2_3d=1 if ba2_3e==1  & dd5_b_n1==1
		replace ba2_3e=. if ba2_3e==1  & dd5_b_n1==1
			
		foreach x in ba2_1 ba2_2 ba2_3 {
			egen `x'_v = rownonmiss(`x'*)
			tab `x'_v
		}
		
		* Giving precedence cba (cannot be assessed) 
		foreach x in ba2_1 ba2_2 ba2_3 {
			foreach y of global `x' {
				replace `y' = .a if `x'_v >= 2
			}
		}
		
		

		* Replace gloves = 1 if:
			* (i) It is missing but 1 in ba2_1 or ba2_2
			replace ba2=1 if (ba2_1_v>=1) | (ba2_2_v>=1) 
		
			* (ii) It has been indicated in any other question relating to gloves. 
			replace ba2=1 if bc3 == 1 

			foreach x in c4 dd5_n1 dd5_n2 {
				egen `x'_v=rownonmiss(`x'*)
				tab  `x'_v
			}
			replace ba2=1 if c4_v!=0 | dd5_n1_v!=0 | dd5_n2_v!=0
			
			drop c4_v dd5_n1_v dd5_n2_v
		
		* Change all other gloves to 0
			replace ba2 = 0 if ba2!= 1
		
	*** Inputting appropriate zeroes ***
		* Note that all observations in ba2_1 & _2 are inputted as missing if selected option is "cannot be assessed".
		
			foreach x in ba2  {
				replace `x'=0 if `x'!=1
			}	
				
			foreach y of global ba2_1 {
				replace `y' = 0 if `y' !=1 & ba2_1_v >= 1 & ba2_1c != 1
				replace `y' = .a if ba2_1_v >= 1 & ba2_1c == 1 
			}
			
			foreach y of global ba2_2 {
				replace `y' = 0 if `y' !=1 & ba2_2_v >= 1 & ba2_2e != 1
				replace `y' = .a if ba2_2_v >= 1 & ba2_2e == 1
			}
			
			foreach y of global ba2_3 {
				replace `y' = 0 if `y' !=1 & ba2_3_v >= 1 & ba2_3e != 1
				replace `y' = .a if ba2_3_v >= 1 & ba2_3e == 1
			}
			
			
		* Note that it may be the case that the number of observations in ba2 is > in ba2_1 or ba2_2, as we are not inputting anything if 
		* observations are missing in ba2_1 & _2.

	* BB. Hand Hygiene - Except for injections/blood draws
	*------------------------------------------------------

		** bb1: patient contact		
			global bb1_1 bb1_1a bb1_1b bb1_1c bb1_1d 
			global bb1_2 bb1_2a bb1_2b bb1_2c bb1_2d 

		* Check non-missing values for hh before/after touching patient *
			foreach x in bb1_1 bb1_2{
				egen `x'_v=rownonmiss(`x'*)
				tab `x'_v
			}

		* Check non-missing values for invasive/non-invasive contact *
			egen bb1_nonmiss = rownonmiss(bb1_a bb1_b)
			tab bb1_nonmiss
			
		* Replace patient contact = 1 if any of the above values are non-missing *
			replace bb1 = 1 if bb1 != 1 & bb1_nonmiss >= 1
			replace bb1 = 1 if bb1 != 1 & bb1_1_v >= 1
			replace bb1 = 1 if bb1 != 1 & bb1_2_v >= 1
				
		* Change all other patient contact to 0 * (relevant basis is consultation aa8==1)
			replace bb1 = 0 if bb1 == . & aa8_a==1
		
		* Change invasive/non-invasive to 0 if patient contact and not selected * (relevant basis is bb1==1)
			replace bb1_a = 0 if bb1_b == 1
			replace bb1_b = 0 if bb1_a == 1 
			replace bb1_a = .a if (bb1_a >1) & bb1 == 1
			replace bb1_b = .a if (bb1_b >1) & bb1 == 1

		** Checks invasive vs. non-invasive... (around 1.2% were not classified at this level)
			tab bb1_b if bb1_b<=1 | bb1_b==.a, m
			tab bb1_a if bb1_a<=1 | bb1_a==.a, m


		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"
			foreach x in bb1_1 bb1_2 {
				foreach y of global `x' {
					replace `y' = 0 if `y' != 1 & `x'_v >= 1 &`x'e != 1
					replace `y' = .a if `x'_v >= 1 &`x'e == 1
					tab `y' if `y'<=1 | `y'==.a, m
				}
			}

			
		** bb2: clean/aseptic procedure
		
			global bb2_1 bb2_1a bb2_1b bb2_1c bb2_1d
		
			foreach x in bb2_1 {
				egen `x'_v = rownonmiss(`x'*)
				tab `x'_v
			}
			replace bb2 = 1 if bb2 != 1 & bb2_1_v >=1
				
		* Change all other clean/aseptic procedure to 0 * (basis consultation)
			replace bb2 = 0 if bb2 != 1 &  aa8_a==1
			
		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"
			foreach x in bb2_1 {
				foreach y of global `x' {
					replace `y' = 0 if `y' != 1 & `x'_v >= 1 & `x'e != 1
					replace `y' = .a if `x'_v >= 1 & `x'e == 1
					tab `y' if `y'<=1 | `y'==.a, m
				}
			}		
			
		** bb3: body fluids exposure
			global bb3_1 bb3_1a bb3_1b bb3_1c bb3_1d 
				
			foreach x in bb3_1 {
				egen `x'_v = rownonmiss(`x'*)
				tab `x'_v
			}
			replace bb3 = 1 if bb3 != 1 & bb3_1_v >=1
				
		* Change all other body fluids exposure to 0 *
			replace bb3 = 0 if bb3 != 1 &  aa8_a==1
			
		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"
			foreach x in bb3_1 {
				foreach y of global `x' {
					replace `y' = 0 if `y' != 1 & `x'_v >= 1 & `x'e != 1
					replace `y' = .a if `x'_v >= 1 & `x'e == 1
					tab `y' if `y'<=1 | `y'==.a, m
				}
			}
			
		** bb4: patient surroundings contact
			global bb4_1 bb4_1a bb4_1b bb4_1c bb4_1d 
		
				foreach x in bb4_1 {
					egen `x'_v = rownonmiss(`x'*)
					tab `x'_v
				}

				replace bb4 = 1 if bb4 == . & bb4_1_v >=1
					
		* Change all other body fluids exposure to 0 *				
				replace bb4 = 0 if bb4 == . &  aa8_a==1
				
		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"					
				foreach x in bb4_1 {
					foreach y of global `x' {
						replace `y' = 0 if `y' != 1 & `x'_v >= 1 & `x'e != 1
						replace `y' = .a if `x'_v >= 1 & `x'e == 1
						tab `y' if `y'<=1 | `y'==.a, m
					}
				}

		** bb5: after patient left	
			global bb5 bb5_a bb5_b bb5_c bb5_d
		
				foreach x in bb5 {
					egen `x'_v = rownonmiss(`x'*)
					tab `x'_v
				}

				foreach x in bb5 {
					foreach y of global `x' {
						replace `y' = 0 if `y' != 1 & `x'_v >= 1 & `x'_e != 1
						replace `y' = .a if `x'_v >= 1 & `x'_e == 1
						tab `y' if `y'<=1 | `y'==.a, m
					}
				}
	
	* BC. Hand Hygiene Characteristics- Except for injections/blood draws
	*---------------------------------------------------------------

		* This section is quantitative information. Does not correspond to all observations.
		* surveyors where instructed to fill it if they observed at least one HH action.
			destring bc1_hw bc2_hr bc3 bc4, replace

	* C. Waste Disposal and Disinfection
	*-----------------------------------

		**c1: thermometer			
			global c1_all c1_a c1_b c1_c c1_d
			
			egen c1_u = rownonmiss(c1_1 c1_2)
			tab c1_u
			replace c1 = 1 if c1 != 1 & c1_u >=1
			
			egen c1_v = rownonmiss(c1_a c1_b c1_c c1_d c1_e)
			tab c1_v
			replace c1 = 1 if c1 != 1 & c1_v >= 1

		* Change all other thermometer to 0 * (basis is consultation)		
			replace c1 = 0 if c1 != 1 &  aa8_a==1
			
		* Change standard/infra-red to 0 if thermometer selected and option not selected *
			replace c1_1 = 0 if c1_2 == 1 
			replace c1_2 = 0 if c1_1 == 1 
			
			replace c1_1 = .a if (c1_1 >1) & c1 == 1
			replace c1_2 = .a if (c1_2 >1) & c1 == 1
			
		** Checks standard vs. infra-red... (around 1.2% were not classified at this level)
			foreach x in c1_1 c1_2 {
				tab `x' if `x'<=1 | `x'==.a, m
			}

			
		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"			
			foreach x of global c1_all {
				replace `x' = 0 if `x' != 1 & c1_v >= 1 & c1_e != 1
				replace `x' = .a if c1_v >= 1 & c1_e == 1
				tab `x' if `x'<=1 | `x'==.a, m
			}


		**c2: stethoscope
			global c2_all c2_a c2_b c2_c
			
			egen c2_v = rownonmiss(c2_a c2_b c2_c c2_d)
			tab c2_v
			replace c2 = 1 if c2 != 1 & c2_v >= 1

			* Change all other stethoscope to 0 *
			
			replace c2 = 0 if c2 != 1 &  aa8_a==1
			
			* Inputting appropriate zeroes *
			* Set to missing if "cannot be assessed"		
			foreach x of global c2_all {
				replace `x' = 0 if `x' != 1 & c2_v == 1 & c2_d != 1
				replace `x' = .a if c2_v == 1 & c2_d == 1
				tab `x' if `x'<=1 | `x'==.a, m

			}
			
		**c3: tongue depressor
			global c3_all c3_a c3_b c3_c c3_d
			
			egen c3_u = rownonmiss(c3_1 c3_2 c3_3)
			tab c3_u
			
			replace c3 = 1 if c3!= 1 & c3_u >= 1
			
			egen c3_a_v = rownonmiss(c3_a*)
			tab c3_a_v
			
			replace c3_a = 1 if c3_a!=1 & c3_a_v >= 1
	
			egen c3_v = rownonmiss(c3_a c3_b c3_c c3_d c3_e)
			tab c3_v
		
			replace c3 = 1 if c3!= 1 & c3_v >= 1
			
		* Change all other tongue depressor to 0 *		
			replace c3 = 0 if c3 != 1 &  aa8_a==1
						
		* Change plastic/wooden/metallic to 0 if not selected & c3 = 1 *		
				replace c3_1 = 0 if (c3_2 == 1 | c3_3==1)
				replace c3_2 = 0 if (c3_1 == 1 | c3_3==1) 
				replace c3_3 = 0 if (c3_1 == 1 | c3_2==1)

				foreach x in c3_1 c3_2 c3_3 {
				replace `x' = .a if (`x' >1) & c3 == 1
				}
		
		* Checks 
				foreach x in c3_1 c3_2 c3_3 {
				tab `x' if `x'<=1 | `x'==.a, m
				}
			
		
			* Inputting appropriate zeroes *
			* Set to missing if "cannot be assessed"		
			foreach x of global c3_all {
				replace `x' = 0 if `x' != 1 & c3_v >= 1 & c3_e != 1
				replace `x' = .a if c3_v >= 1 & c3_e == 1
				tab `x' if `x'<=1 | `x'==.a, m
			}
			
			foreach x in c3_a1 c3_a2 c3_a3 c3_a4 {
				replace `x' = 0 if `x' != 1 & c3_a_v >=1
				replace `x' = .a if c3_v >= 1 & c3_e == 1
				tab `x' if `x'<=1 | `x'==.a, m
			}
			
			
				foreach x in c3_1 c3_2 c3_3 c3_a c3_b c3_c c3_d c3_e  {
				tab `x' if `x'<=1 | `x'==.a, m
				}
				
		**c4: gloves	
				/** About gloves (without cleaning for completed and IRs)
				total observations with gloves  ~4,144
				segregation in the consultation part ~380
				segregation in the IBD section ~ 3,640
				so, adding them up they are around  4020    */

			* First fix the internal inconsistencies				
				global c4_all c4_a c4_a1 c4_a2 c4_a3 c4_a4 c4_b c4_c
				global c4_a c4_a1 c4_a2 c4_a3 c4_a4
			
			* non-missing for subgroup	
				egen c4_a_v = rownonmiss(c4_a1 c4_a2 c4_a3 c4_a4)
				tab c4_a_v
			
			* replace by 1 if missed something inside		
				replace c4_a = 1 if c4_a!=1 & c4_a_v >= 1
				
			* replace by missing if nothing inside	
				replace c4_a = . if  c4_a_v == 0

			* Now, understand whether there are non-missing in relevant cells
				egen c4_v = rownonmiss(c4_a1 c4_a2 c4_a3 c4_a4 c4_b c4_c c4_d)
				tab c4_v
			
			*	Now, replace c4 by 1 if something inside of the whole group 
				replace c4 = 1 if c4!= 1 & c4_v >= 1
			
			* Change all other gloves to 0 *			
				replace c4 = 0 if c4 != 1 &  aa8_a==1
			
			* Inputting appropriate zeroes *
			* Set to missing if "cannot be assessed"				
				foreach x of global c4_all {
					replace `x' = 0 if `x' != 1 & c4_v >= 1 & c4_d != 1
					replace `x' = .a if c4_v >= 1 & c4_d == 1
					tab `x' if `x'<=1 | `x'==.a, m

				}

		**c5: swabs/gauze
				
		* First fix the internal inconsistencies	
				global c5_all c5_a c5_a1 c5_a2 c5_a3 c5_a4 c5_b 
				global c5_a	c5_a1 c5_a2 c5_a3 c5_a4
				
		* non-missing for subgroup		
				egen c5_a_v = rownonmiss(c5_a1 c5_a2 c5_a3 c5_a4)
				tab c5_a_v

		* replace by 1 if missed something inside		
				replace c5_a = 1 if c5_a!=1 & c5_a_v >= 1				
				
		* replace by missing if nothing inside	
				replace c5_a = . if  c5_a_v == 0

		* Now, understand whether there are non-missing in relevant cells			
				egen c5_v = rownonmiss(c5_a c5_b c5_c)
				tab c5_v
					
				replace c5 = 1 if c5!= 1 & c5_v >= 1
			
		* Change all other swabs/gauze to 0 *			
				replace c5 = 0 if c5 != 1 &  aa8_a==1
			
		* Inputting appropriate zeroes *
		* Set to missing if "cannot be assessed"
			
				foreach x of global c5_all {
					replace `x' = 0 if `x' != 1 & c5_v >= 1 & c5_c != 1
					replace `x' = .a if c5_v >= 1 & c5_c == 1
					tab `x' if `x'<=1 | `x'==.a, m

				}
	
	* DA (INJECTION) & DB (BLOOD DRAW)
	*----------------------------------
	
		foreach k in n1 n2 {
		* correcting a label
			lab var da_a_`k' "DA_A. Vaccination (a)"
		
		* Creating a general var for IBD - Interactions that include IBD
			gen d_`k'=1 if da_`k'==1 | db_`k'==1 
			replace d_`k'=0 if d_`k'!=1
			lab var d_`k' "Interactions that include IBD"
			tab d_`k'
			
		}
			
		* Injections and Blod Draws by Type and obvious inputations
			foreach k in n1 n2 {

			global da_all_`k' da_a_`k' da_b_`k' da_c_`k'
			global db_all_`k' db_a_`k' db_b_`k'
			
			egen da_v_`k' = rownonmiss(da_a_`k' da_b_`k' da_c_`k' da_d_`k')
			tab da_v_`k'
			replace da_`k' = 1 if da_`k' != 1 & da_v_`k' >= 1
			
			egen db_v_`k' = rownonmiss(db_a_`k' db_b_`k')
			tab db_v_`k'
		
			replace db_`k' = 1 if db_`k' != 1 & db_v_`k' >= 1
			
		** Inputting appropriate zeroes **	
			foreach x of global da_all_`k' {
				replace `x' = 0 if `x' != 1 & da_v_`k' >= 1 & da_d_`k' != 1
				replace `x' = .a if da_v_`k' >= 1 & da_d_`k' == 1
				tab `x' if `x'<=1 | `x'==.a, m

			}
			
			foreach x of global db_all_`k' {
				replace `x' = 0 if `x' != 1 & db_v_`k' >= 1
				tab `x' if `x'<=1 | `x'==.a, m

			}
			
		}
			
		* Changing to 0 all other injections/blood draw *
			foreach k in n1 n2 {
			replace da_`k' = 0 if da_`k' != 1 & d_`k'==1
			replace db_`k' = 0 if db_`k' != 1 & d_`k'==1
			}
				
	* DC DISINFECTION AND PREPARATION
	*--------------------------------
	
		**dc1: HH before procedure

			foreach k in n1 n2 {
				
				global dc1_all_`k' dc1_a_`k' dc1_b_`k' dc1_c_`k' dc1_d_`k'
			
				egen dc1_v_`k' = rownonmiss(dc1_a_`k' dc1_b_`k' dc1_c_`k' dc1_d_`k' dc1_e_`k')
				tab dc1_v_`k'
					
					
			** Inputting appropriate zeroes **
			* Set to missing if "cannot be assessed"			
			foreach x of global dc1_all_`k' {
				replace `x' = 0 if `x' != 1 & dc1_v_`k' >= 1 & dc1_e_`k' != 1
				replace `x' = .a if dc1_v_`k' >= 1 & dc1_e_`k' == 1
				tab `x' if `x'<=1 | `x'==.a, m
				}
			}

				
		**dc2: Work surfaces preparation
			foreach k in n1 n2 {
					
				global dc2_all_`k' dc2_a_`k' dc2_b_`k' dc2_c_`k' dc2_d_`k' dc2_e_`k'
					
				egen dc2_v_`k' = rownonmiss(dc2_a_`k' dc2_b_`k' dc2_c_`k' dc2_d_`k' dc2_e_`k')
				tab dc2_v_`k'
					
				** Inputting appropriate zeroes **
				* Note this question does not have a cannot be assessed option
					foreach x of global dc2_all_`k' {
						replace `x' = 0 if `x' != 1 & dc2_v_`k' >= 1
						tab `x' if `x'<=1 | `x'==.a, m
						
					}

				}

		**dc3: Syringe/slide/vacutainer 
			
			*** NOTE: here  "cannot be assessed" is different. For Vacuntainer in particular
			* they are taking it for lab test so "cannot be assessed is not bad." We won't be analyzing
			* what happens with the vacutainer or the slide probably. Note that most of the cannot be assessed is for slides and all vacutainer
			* We'll focus on syringe and let the slide and the vacuntainer be appart. 
				foreach k in n1 n2 {
				
					global dc3_`k' dc3_1_`k' dc3_2_`k' dc3_3_`k' dc3_4_`k' dc3_5_`k'

			* There are very few cases in which these overalap, so I'll separate them
				
			* First replace with missing when they overalap (only for syringe that is the one that we care for now)
			* keep original renaiming it and then keep one in which there is no overlaps (all go to missing)
				
					foreach y in 1 2 3 4 5 {
						
					rename dc3_`y'_`k' dc3_`y'_`k'_original
					gen dc3_`y'_`k'=dc3_`y'_`k'_original
					
					}
					
					lab var dc3_1_`k' "DC3.1 Syringe"
					lab var dc3_2_`k' "DC3.2 Slide"
					lab var dc3_3_`k' "DC3.3 Vacutainer"
					lab var dc3_4_`k' "DC3.4 RDT set"
					lab var dc3_5_`k' "DC3.5 Glucometer Strip"

					replace dc3_1_`k'=. if (dc3_1_`k'_original==1 & dc3_2_`k'_original==1) | (dc3_1_`k'_original==1 & dc3_3_`k'_original==1)
					replace dc3_2_`k'=. if (dc3_1_`k'_original==1 & dc3_2_`k'_original==1) | (dc3_2_`k'_original==1 & dc3_3_`k'_original==1)
					replace dc3_3_`k'=. if (dc3_1_`k'_original==1 & dc3_3_`k'_original==1) | (dc3_3_`k'_original==1 & dc3_2_`k'_original==1)
					
					* after checking the segregation, there is a few additional that can be coded as syringes
					replace dc3_1_`k'=1 if dd1_1_`k'==1 & (dd1_2_`k'!=1) & ( dd1_3_`k'!=1)
				
			* check			
				foreach y in 1 2 3 {
					tab dc3_`y'_`k' dc3_`y'_`k'_original, m
				}
					
			* Now assign all the responses
				foreach y in 1 2 3 {
					foreach w in a b c {
						gen dc3_`y'_`w'_`k'= dc3_123_`w'_`k' if dc3_`y'_`k'==1							
						}
						lab var dc3_`y'_a_`k' "DC3_`y'_A.New (original package) (a)"
						lab var dc3_`y'_b_`k' "DC3_`y'_B.Reused (not riginal package)  (b)"
						lab var dc3_`y'_c_`k' "DC3_`y'_C.Cannot be assessed (c)"
				}
					
				foreach y in 4 5 {
						foreach w in a b c {
							gen dc3_`y'_`w'_`k'= dc3_45_`w'_`k' if dc3_`y'_`k'==1
						}
					lab var dc3_`y'_a_`k' "DC3_`y'_A.New (original package) (a)"
					lab var dc3_`y'_b_`k' "DC3_`y'_B.Reused (not riginal package)  (b)"
					lab var dc3_`y'_c_`k' "DC3_`y'_C.Cannot be assessed (c)"								
				}
					
				foreach y in 1 2 3 4 5 {
					global dc3_`y'_all_`k' dc3_`y'_a_`k' dc3_`y'_b_`k'
					egen dc3_`y'_v_`k' = rownonmiss(dc3_`y'_a_`k' dc3_`y'_b_`k' dc3_`y'_c_`k')
					tab dc3_`y'_v_`k'
	
					* checking the total for each: syringe, slide, vacutainer, RDT set, Glucometer strip (where blood stays)
					* we can only check with a good confidence on practic of syringe, RDG and needle/lancet (have to be open from individual
					* packages and segregated right away).
	
					** Inputting appropriate zeroes **
					foreach x of global dc3_`y'_all_`k' {
						replace `x' = 0 if `x' != 1 & dc3_`y'_v_`k' >= 1 & dc3_`y'_c_`k'!= 1
						replace `x' = .a if dc3_`y'_v_`k' >= 1 & dc3_`y'_c_`k'== 1
						tab `x' if `x'<=1 | `x'==.a, m	
					}		
				}				
			}
	
		* checking the data and appropriate denominators
				drop dc3_123* dc3_45*
				

		**dc4: Needle/Lancet
			foreach k in n1 n2 {
				global dc4_all_`k' dc4_a_`k' dc4_b_`k'
						
				egen dc4_v_`k' = rownonmiss(dc4_a_`k' dc4_b_`k' dc4_c_`k')
				tab dc4_v_`k'
						
				** Inputting appropriate zeroes **
				* Set to missing if "cannot be assessed"	
					foreach x of global dc4_all_`k' {
						replace `x' = 0 if `x' != 1 & dc4_v_`k' >= 1 & dc4_c_`k'!= 1
						replace `x' = .a if dc4_v_`k' >= 1 & dc4_c_`k'== 1
						tab `x' if `x'<=1 | `x'==.a, m	
					}
				}

				
		**dc5: Patient skin preparation
		
			* First fix the internal inconsistencies	
			foreach k in n1 n2 {	
				
				global dc5_all_`k' dc5_a_`k' dc5_a1_`k' dc5_a2_`k' dc5_a3_`k' dc5_a4_`k' dc5_b_`k' dc5_c_`k'
					
			* non-missing for subgroup		
				egen dc5_a_v_`k' = rownonmiss(dc5_a1_`k' dc5_a2_`k' dc5_a3_`k' dc5_a4_`k')
				tab dc5_a_v_`k'
						
			* replace by 1 if missed something inside		
				replace dc5_a_`k' = 1 if dc5_a_`k'!= 1 & dc5_a_v_`k' >= 1

			* replace by missing if nothing inside	
				replace dc5_a_`k' = . if  dc5_a_v_`k' == 0
								
			* Understand whether there are non-missing in relevant cells
				egen dc5_v_`k' = rownonmiss(dc5_a1_`k' dc5_a2_`k' dc5_a3_`k' dc5_a4_`k' dc5_b_`k' dc5_c_`k')
				tab dc5_v_`k'

			* Fix all according to all the information
			* Inputting appropriate zeroes **	
				foreach x of global dc5_all_`k' {
						replace `x' = 0 if `x' != 1 & dc5_v_`k' >= 1 
						tab `x' if `x'<=1 | `x'==.a, m	
					}
				}
				
			**dc6: Medication
			
			** Many of the dc6_1 observations have more than one tick. 
			
				foreach k in n1 n2 {
					
					global dc6_all_`k' dc6_a_`k' dc6_b_`k' dc6_c_`k'
					
					egen dc6_v_`k' = rownonmiss(dc6_a_`k' dc6_b_`k' dc6_c_`k')
					tab dc6_v_`k'
					replace dc6_`k' = 1 if dc6_`k' != 1 & dc6_v_`k'>= 1
					
					** Inputting appropriate zeroes **
					* Note there is no cannot be assessed option

					foreach x of global dc6_all_`k' {
						replace `x' = 0 if `x' != 1 & dc6_v_`k' >= 1
						tab `x' if `x'<=1 | `x'==.a, m	

					}

				}
	
	* DD: Segregation/Storage
	*------------------------
	
		**dd1: syringe/slide

		* Replicate the separation from before
			* keep original with another name to check... kept only obs without overlaps (all overalps go to missing)
			foreach k in n1 n2 {
				foreach y in 1 2 3 4 5 {
						
					rename dd1_`y'_`k' dd1_`y'_`k'_original
					gen dd1_`y'_`k'=dd1_`y'_`k'_original			
				}		
					lab var dd1_1_`k' "DD1.1 Syringe"
					lab var dd1_2_`k' "DD1.2 Slide"
					lab var dd1_3_`k' "DD1.3 Vacutainer"
					lab var dd1_4_`k' "DD1.4 RDT set"
					lab var dd1_5_`k' "DD1.5 Glucometer Strip"

					replace dd1_1_`k'=. if (dd1_1_`k'_original==1 & dd1_2_`k'_original==1) | (dd1_1_`k'_original==1 & dd1_3_`k'_original==1)
					replace dd1_2_`k'=. if (dd1_1_`k'_original==1 & dd1_2_`k'_original==1) | (dd1_2_`k'_original==1 & dd1_3_`k'_original==1)
					replace dd1_3_`k'=. if (dd1_1_`k'_original==1 & dd1_3_`k'_original==1) | (dd1_3_`k'_original==1 & dd1_2_`k'_original==1)
	
	
					* check // very minor differences	
		
					foreach y in 1 2 3 4 5 {
					tab dd1_`y'_`k' dd1_`y'_`k'_original, m
					}
					
					foreach y in 1 2 3 4 5 {
					tab dd1_`y'_`k' dc3_`y'_`k', m
					}
					
	
			* Now assign all the responses
				    foreach y in 1 2 3 {
						foreach w in a a1 a2 b c d e f {
							gen dd1_`y'_`w'_`k'= dd1_123_`w'_`k' if dd1_`y'_`k'==1
					}
			
					lab var dd1_`y'_a_`k'  "DD1_`y'_A.Segregated in sharps container (a)"
					lab var dd1_`y'_a1_`k' "DD1_`y'_A1.Safety box (leak- puncture-proof) (a1)"
					lab var dd1_`y'_a2_`k' "DD1_`y'_A2.Improvised (jerry can, others) (a2)"
					lab var dd1_`y'_b_`k'  "DD1_`y'_B. Segregated in open container (b)"
					lab var dd1_`y'_c_`k'  "DD1_`y'_C. Segregated in red/yellow bin (c)"
					lab var dd1_`y'_d_`k'  "DD1_`y'_D. Segregated black bin (d)"
					lab var dd1_`y'_e_`k'  "DD1_`y'_E.Left outside (e)"
					lab var dd1_`y'_f_`k'  "DD1_`y'_F.Cannot be assessed (f)"							
				}
					
					foreach y in 4 5 {
						foreach w in a a1 a2 b c d e f  {
							gen dd1_`y'_`w'_`k'= dd1_45_`w'_`k' if dd1_`y'_`k'==1						
					}
				
					lab var dd1_`y'_a_`k'  "DD1_`y'_A.Segregated in sharps container (a)"
					lab var dd1_`y'_a1_`k'  "DD1_`y'_A1.Safety box (leak- puncture-proof) (a1)"
					lab var dd1_`y'_a2_`k'  "DD1_`y'_A2.Improvised (jerry can, others) (a2)"
					lab var dd1_`y'_b_`k'  "DD1_`y'_B. Segregated in open container (b)"
					lab var dd1_`y'_c_`k'  "DD1_`y'_C. Segregated in red/yellow bin (c)"
					lab var dd1_`y'_d_`k'  "DD1_`y'_D. Segregated black bin (d)"
					lab var dd1_`y'_e_`k'  "DD1_`y'_E.Left outside (e)"
					lab var dd1_`y'_f_`k'  "DD1_`y'_F.Cannot be assessed (f)"

					}
	
				
			* Fix the internal inconsistencies
				foreach y in 1 2 3 4 5 {
					global dd1_`y'_all_`k' dd1_`y'_a_`k' dd1_`y'_a1_`k' dd1_`y'_a2_`k' dd1_`y'_b_`k' dd1_`y'_c_`k' dd1_`y'_d_`k' dd1_`y'_e_`k'
			
					* non-missing for subgroup		
					egen dd1_`y'_a_v_`k' = rownonmiss(dd1_`y'_a1_`k' dd1_`y'_a2_`k')
					
					* replace by 1 if missed something inside
					replace dd1_`y'_a_`k' = 1 if dd1_`y'_a_`k'!= 1 & dd1_`y'_a_v_`k' >= 1

					* replace by . if nothing something inside
					replace dd1_`y'_a_`k' = . if dd1_`y'_a_`k'== 1 & dd1_`y'_a_v_`k' == 0
							
					* Now, understand whether there are non-missing in relevant cells
					egen dd1_`y'_v_`k' = rownonmiss(dd1_`y'_a1_`k' dd1_`y'_a2_`k' dd1_`y'_b_`k' dd1_`y'_c_`k' dd1_`y'_d_`k' dd1_`y'_e_`k' dd1_`y'_f_`k')
					tab dd1_`y'_v_`k'
				
				** Inputting appropriate zeroes **
					foreach x of global dd1_`y'_all_`k' {
					replace `x' = 0 if `x' != 1 & dd1_`y'_v_`k' >= 1 & dd1_`y'_f_`k'!= 1
					replace `x' = .a if dd1_`y'_v_`k' >= 1 & dd1_`y'_f_`k'== 1
					tab `x' if `x'<=1 | `x'==.a, m	
					}			
				}
			}
		
			drop dd1_123* 
			drop dd1_45*		
			
		**dd2: needle
			
			foreach k in n1 n2 {
		
			* First fix the internal inconsistencies
				global dd2_all_`k' dd2_a_`k' dd2_a1_`k' dd2_a2_`k' dd2_b_`k' dd2_c_`k' dd2_d_`k'
				global dd2_a_m_`k' dd2_a1_`k' dd2_a2_`k'				
				
			* non-missing for subgroup		
				egen dd2_a_v_`k' = rownonmiss(dd2_a1_`k' dd2_a2_`k')
				tab dd2_a_v_`k'
			* replace by 1 if missed something inside		
				replace dd2_a_`k' = 1 if dd2_a_`k' != 1 & dd2_a_v_`k' >= 1
		
			* replace by missing if nothing inside	
				replace dd2_a_`k' = . if  dd2_a_v_`k' == 0
		
			* Understand whether there are non-missing in relevant cells
				egen dd2_v_`k' = rownonmiss(dd2_a1_`k' dd2_a2_`k' dd2_b_`k' dd2_c_`k' dd2_d_`k' dd2_e_`k')
				tab dd2_v_`k'				
	
			* Fix all according to all the information
			* Inputting appropriate zeroes **
			* Set to missing if "cannot be assessed"				
				foreach x of global dd2_all_`k' {
					replace `x' = 0 if `x' != 1 & dd2_v_`k' >= 1 & dd2_e_`k' != 1
					replace `x' = .a if dd2_v_`k' >= 1 & dd2_e_`k' == 1
					tab `x' if `x'<=1 | `x'==.a, m	
				}
			}
			
			
		** dd3: leftover medicine			
			foreach k in n1 n2 {
				
				global dd3_all_`k' dd3_a_`k' dd3_b_`k' dd3_c_`k' dd3_d_`k' dd3_e_`k'  dd3_f_`k'
				
				egen dd3_v_`k' = rownonmiss(dd3_a_`k' dd3_b_`k' dd3_c_`k' dd3_d_`k' dd3_e_`k' dd3_f_`k' dd3_g_`k')
				tab dd3_v_`k'
				
				replace dd3_`k' = 1 if dd3_`k' != 1 & dd3_v_`k' >= 1
				
				* Changing all other leftover medicine to 0 * /// CHECK THIS. SHOULD IT BE BASED ON DC6 OR INJECTIONS				
				replace dd3_`k' = 0 if dd3_`k' != 1 & dc6_`k' == 1
				
				** Inputting appropriate zeroes **
				* Set to missing if "cannot be assessed"		
				foreach x of global dd3_all_`k' {
					replace `x' = 0 if `x' != 1 & dd3_v_`k' >= 1 & dd3_g_`k' != 1 
					replace `x' = .a if dd3_v_`k' >= 1 & dd3_g_`k' == 1
					tab `x' if `x'<=1 | `x'==.a, m	
				}
			}
			
		**dd4: swabs/gauze	
			foreach k in n1 n2 {

			* First fix the internal inconsistencies
				global dd4_all_`k' dd4_a_`k' dd4_a1_`k' dd4_a2_`k' dd4_a3_`k' dd4_a4_`k' dd4_b_`k'
				global dd4_a_m_`k' dd4_a1_`k' dd4_a2_`k' dd4_a3_`k' dd4_a4_`k'
				
			* non-missing for subgroup		
				egen dd4_a_v_`k' = rownonmiss(dd4_a1_`k' dd4_a2_`k' dd4_a3_`k' dd4_a4_`k')
				tab dd4_a_v_`k'
			* replace by 1 if missed something inside				
				replace dd4_a_`k' =  1 if dd4_a_`k' != 1 & dd4_a_v_`k' >= 1
				
			* replace by missing if nothing inside	
				replace dd4_a_`k' = . if  dd4_a_v_`k' == 0
					
			* Understand whether there are non-missing in relevant cells
				egen dd4_v_`k' = rownonmiss(dd4_a1_`k' dd4_a2_`k' dd4_a3_`k' dd4_a4_`k' dd4_b_`k' dd4_c_`k')
				tab dd4_v_`k'
				
				replace dd4_`k' = 1 if dd4_`k' != 1 & dd4_v_`k' >= 1	
				replace dd4_`k' = . if dd4_v_`k' ==0	
				
			* Changing all other swabs/gauze to 0 *				
				replace dd4_`k' = 0 if dd4_`k' != 1 & dd4_v_`k' >= 1	
				
				** Inputting appropriate zeroes **
				* Set to missing if "cannot be assessed"
				
				foreach x of global dd4_all_`k' {
					replace `x' = 0 if `x' != 1 & dd4_v_`k' >= 1 & dd4_c_`k' != 1
					replace `x' = .a if dd4_v_`k' >= 1 & dd4_c_`k' == 1
					tab `x' if `x'<=1 | `x'==.a, m						
				}
			}
		
		**dd5: gloves
		
			foreach k in n1 n2 {
		
			* First fix the internal inconsistencies
				global dd5_all_`k' dd5_a_`k' dd5_a1_`k' dd5_a2_`k' dd5_a3_`k' dd5_a4_`k' dd5_b_`k' dd5_c_`k'
				global dd5_a_m_`k' dd5_a1_`k' dd5_a2_`k' dd5_a3_`k' dd5_a4_`k'
				
			* non-missing for subgroup		
				egen dd5_a_v_`k' = rownonmiss(dd5_a1_`k' dd5_a2_`k' dd5_a3_`k' dd5_a4_`k')
				tab dd5_a_v_`k'
				
			* replace by 1 if missed something inside				
				replace dd5_a_`k' =  1 if dd5_a_`k' != 1 & dd5_a_v_`k' >= 1

			* replace by missing if nothing inside	
				replace dd5_a_`k' = . if  dd5_a_v_`k' == 0
				
			* Understand whether there are non-missing in relevant cells
				egen dd5_v_`k' = rownonmiss(dd5_a1_`k' dd5_a2_`k' dd5_a3_`k' dd5_a4_`k' dd5_b_`k' dd5_c_`k' dd5_d_`k')
				tab dd5_v_`k'
								
				** Inputting appropriate zeroes **
				* Set to missing if "cannot be assessed"
				
				foreach x of global dd5_all_`k' {
					replace `x' = 0 if `x' != 1 & dd5_v_`k' >= 1 & dd5_d_`k' != 1
					replace `x' = .a if dd5_v_`k' >= 1 & dd5_d_`k' == 1
					tab `x' if `x'<=1 | `x'==.a, m	
					}			
				}
		
		**dd6: hh after procedure
			
				foreach k in n1 n2 {

					global dd6_all_`k' dd6_a_`k' dd6_b_`k' dd6_c_`k' dd6_d_`k'
					
					egen dd6_v_`k' = rownonmiss(dd6_a_`k' dd6_b_`k' dd6_c_`k' dd6_d_`k' dd6_e_`k')
					tab dd6_v_`k'
					
					gen dd6_total_obs_`k' = 1 if dd2_v_`k' >= 1
					label var dd6_total_obs_`k' "Total observations recorded in dd6 before updating zeroes/missing"
					
					** Inputting appropriate zeroes **
					* Set to missing if "cannot be assessed"
					
					foreach x of global dd6_all_`k' {
						replace `x' = 0 if `x' != 1 & dd6_v_`k' >= 1 & dd6_e_`k' != 1
						replace `x' = .a if `x' != 1 & dd6_v_`k' >= 1 & dd6_e_`k' == 1
						tab `x' if `x'<=1 | `x'==.a, m	
					}
				}
				
			**dd8: needle recapped/separated
			
				* Q. What is the appropriate protocol for entering zeroes here?		
				foreach k in n1 n2 {
				
					global dd8_all_`k' dd8_a1_`k' dd8_a2_`k' dd8_b1_`k' dd8_b2_`k'
				
					egen dd8_v_`k' = rownonmiss(dd8_a1_`k' dd8_a2_`k' dd8_b1_`k' dd8_b2_`k')
					tab dd8_v_`k'
					tab dd8_`k'
				
				* relevant denominator for zeros is whether a needle was used (best proxy)
					replace dd8_`k' = 1 if dd8_`k' != 1 & dd8_v_`k' == 1
					replace dd8_`k' = 0 if dd8_`k' != 1 &  dc4_v_`k'>=1
					
					 tab dc4_v_`k'
				
					foreach x of global dd8_all_`k' {
						replace `x' = 0 if `x' != 1  & dc4_v_`k'>=1
						tab `x' if `x'<=1 | `x'==.a, m	
				}			
				}
				
		**dd9: HCW had a needle-prick				
			foreach k in n1 n2 {
					replace dd9_`k' = 0 if dd9_`k' != 1 &  dc4_v_`k'>=1		
			}		
		
		
	*----------------------*
	* 2.3. Label variables *
	*----------------------*

	* Final renames
		rename aa5 date
		rename facilityid hfid
		rename enuid enumeratorid
		rename site aa8
		rename hcwid aa9
		rename patientid aa10
		rename bc1_hw bc1
		rename bc2_hr bc2
		rename (de1_hw de2_hr de3_hw) (de1 de2 de3)
		rename survey_id key
		
	* AA
		lab var aa8 "8. Observation site"
		lab def site 1 "Consultation Room" 2 "Laboratory" 3 "Injection"
		lab val aa8 site
		lab var key "Survey ID"
		
	* Yes/No
		ds *
		local all_vars `r(varlist)'
		lab def yesno 1 "Yes" 0 "No"
		foreach var of varlist * {
			capture confirm string var `var'
			if _rc != 0 {
				egen max = max(`var')
				egen min = min(`var')
					if max == 1 & min == 0 {
						lab val `var' yesno
					}
			drop max min
			}
		}
		
	* Drop intermadiate variables
		drop aa8 *_v *_original operator de_date start_hours start_minutes start_seconds end_hours end_minutes end_seconds desecs survey_id2  county aa5_date1 aa5_date2 aa5_date3 tag3 nonmiss_total2 tag4 random serial_dup tag5 spotchecker_name spotchecker_level spotchecker ir_enu ir_serial ir site_c bb1_nonmiss c1_u c3_u d_n1 d_n2 da_v_n1 db_v_n1 da_v_n2 db_v_n2 dc1_v_n1 dc1_v_n2 dc2_v_n1 dc2_v_n2 dc3_1_v_n1 dc3_2_v_n1 dc3_3_v_n1 dc3_4_v_n1 dc3_5_v_n1 dc3_1_v_n2 dc3_2_v_n2 dc3_3_v_n2 dc3_4_v_n2 dc3_5_v_n2 dc4_v_n1 dc4_v_n2 dc5_a_v_n1 dc5_v_n1 dc5_a_v_n2 dc5_v_n2 dc6_v_n1 dc6_v_n2 dd1_1_a_v_n1 dd1_1_v_n1 dd1_2_a_v_n1 dd1_2_v_n1 dd1_3_a_v_n1 dd1_3_v_n1 dd1_4_a_v_n1 dd1_4_v_n1 dd1_5_a_v_n1 dd1_5_v_n1 dd1_1_a_v_n2 dd1_1_v_n2 dd1_2_a_v_n2 dd1_2_v_n2 dd1_3_a_v_n2 dd1_3_v_n2 dd1_4_a_v_n2 dd1_4_v_n2 dd1_5_a_v_n2 dd1_5_v_n2 dd2_a_v_n1 dd2_v_n1 dd2_a_v_n2 dd2_v_n2 dd3_v_n1 dd3_v_n2 dd4_a_v_n1 dd4_v_n1 dd4_a_v_n2 dd4_v_n2 dd5_a_v_n1 dd5_v_n1 dd5_a_v_n2 dd5_v_n2 dd6_v_n1 dd6_v_n2 dd8_v_n1 dd8_v_n2 dd6_total_obs_n1 dd6_total_obs_n2
		
	* Drop "Cannot be assessed" variables since they don't give additional information
		drop ba2_1c ba2_2e ba2_3e bb1_1e bb1_2e bb2_1e bb3_1e bb4_1e bb5_e c1_e c2_d c3_e c4_d c5_c da_d_n1 dc1_e_n1 dc3_1_c_n1 dc3_2_c_n1 dc3_3_c_n1 dc3_4_c_n1 dc3_5_c_n1 dc4_c_n1 	dd1_1_f_n1 dd1_2_f_n1 dd1_3_f_n1 dd1_4_f_n1 dd1_5_f_n1 dd2_e_n1 dd3_g_n1 dd4_c_n1 dd5_d_n1 dd6_e_n1 da_d_n2 dc1_e_n2 dc3_1_c_n2 dc3_2_c_n2 dc3_3_c_n2 dc3_4_c_n2 dc3_5_c_n2 dc4_c_n2 dd1_1_f_n2 dd1_2_f_n2 dd1_3_f_n2 dd1_4_f_n2 dd1_5_f_n2 dd2_e_n2 dd3_g_n2 dd4_c_n2 dd5_d_n2 dd6_e_n2

	*---------------------*
	* 2.4. Additional fix *
	*---------------------*
		
		* Correct denominator for some variables	
		
		* c3_a c4_a and c5_a
			foreach var in c3_a c4_a c5_a {
				foreach x in 1 2 3 4 {
					replace `var'`x' = . if `var' != 1
				}
			}		
		
		* dd4_a dd5_a dc5_a
			foreach var in dd4_a dd5_a dc5_a {
				foreach obs in n1 n2 {
					foreach x in 1 2 3 4 {
						replace `var'`x'_`obs' = . if `var'_`obs' != 1
					}
				}
			}
		
		* dd1_1_a dd1_2_a dd1_3_a dd1_4_a dd1_5_a and dd2_a
			foreach var in dd1_1_a dd1_2_a dd1_3_a dd1_4_a dd1_5_a dd2_a {
				foreach obs in n1 n2 {
					foreach x in 1 2 {
						replace `var'`x'_`obs' = . if `var'_`obs' != 1
					}
				}
			}
		
	*---------------------*
	* 2.5. Order database *
	*---------------------*
				
		global AA			key time aa1 aa2 hfid enumeratorid date aa6 aa7 aa8_a aa8_b aa8_c aa9 aa10 aa11_* aa12_* aa13_* aa14_*
		
		global AB 			ab_a ab_b ab_c
		
		global BA 			ba1_a ba1_b ba1_c ba2 ba2 ba2_1a ba2_1b ba2_2a ba2_2b ba2_2c ba2_2d ba2_3a ba2_3b ba2_3c ba2_3d
		
		global BB 			bb1 bb1_a bb1_b bb1_1a bb1_1b bb1_1c bb1_1d bb1_2a bb1_2b bb1_2c bb1_2d bb2 bb2_1a bb2_1b bb2_1c bb2_1d bb3 bb3_1a bb3_1b bb3_1c bb3_1d bb4 bb4_1a bb4_1b bb4_1c bb4_1d bb5_a bb5_b bb5_c bb5_d
		
		global BC 			bc1 bc2 bc3 bc4
		
		global C 			c1 c1_1 c1_2 c1_a c1_b c1_c c1_d c2 c2_a c2_b c2_c c3 c3_1 c3_2 c3_3 c3_a c3_a1 c3_a2 c3_a3 c3_a4 c3_b c3_c c3_d c4 c4_a c4_a1 c4_a2 c4_a3 c4_a4 c4_b c4_c c5 c5_a c5_a1 c5_a2 c5_a3 c5_a4 c5_b coments
		
		global DA_DB_n1 	da_n1 da_a_n1 da_b_n1 da_c_n1 db_n1 db_a_n1 db_b_n1

		global DC_n1 		dc1_a_n1 dc1_b_n1 dc1_c_n1 dc1_d_n1 dc2_a_n1 dc2_b_n1 dc2_c_n1 dc2_d_n1 dc2_e_n1 dc3_1_n1 dc3_1_n1 dc3_1_a_n1 dc3_1_b_n1 dc3_2_n1 dc3_2_a_n1 dc3_2_b_n1 dc3_3_n1 dc3_3_a_n1 dc3_3_b_n1 dc3_4_n1 dc3_4_a_n1 dc3_4_b_n1 dc3_5_n1 dc3_5_a_n1 dc3_5_b_n1 dc4_a_n1 dc4_b_n1 dc5_a_n1 dc5_a1_n1 dc5_a2_n1 dc5_a3_n1 dc5_a4_n1 dc5_b_n1 dc5_c_n1 dc6_n1 dc6_a_n1 dc6_b_n1 dc6_c_n1
		
		global DD_n1 		dd1_1_n1 dd1_1_a_n1 dd1_1_a1_n1 dd1_1_a2_n1 dd1_1_b_n1 dd1_1_c_n1 dd1_1_d_n1 dd1_1_e_n1 dd1_2_n1 dd1_2_a_n1 dd1_2_a1_n1 dd1_2_a2_n1 dd1_2_b_n1 dd1_2_c_n1 dd1_2_d_n1 dd1_2_e_n1 dd1_3_n1 dd1_3_a_n1 dd1_3_a1_n1 dd1_3_a2_n1 dd1_3_b_n1 dd1_3_c_n1 dd1_3_d_n1 dd1_3_e_n1 dd1_4_n1 dd1_4_a_n1 dd1_4_a1_n1 dd1_4_a2_n1 dd1_4_b_n1 dd1_4_c_n1 dd1_4_d_n1 dd1_4_e_n1 dd1_5_n1 dd1_5_a_n1 dd1_5_a1_n1 dd1_5_a2_n1 dd1_5_b_n1 dd1_5_c_n1 dd1_5_d_n1 dd1_5_e_n1 dd2_a_n1 dd2_a1_n1 dd2_a2_n1 dd2_b_n1 dd2_c_n1 dd2_d_n1 dd3_n1 dd3_a_n1 dd3_b_n1 dd3_c_n1 dd3_d_n1 dd3_e_n1 dd3_f_n1 dd4_n1 dd4_a_n1 dd4_a1_n1 dd4_a2_n1 dd4_a3_n1 dd4_a4_n1 dd4_b_n1 dd5_n1 dd5_a_n1 dd5_a1_n1 dd5_a2_n1 dd5_a3_n1 dd5_a4_n1 dd5_b_n1 dd5_c_n1 dd6_a_n1 dd6_b_n1 dd6_c_n1 dd6_d_n1 dd8_n1 dd8_a1_n1 dd8_a2_n1 dd8_b1_n1 dd8_b2_n1 dd9_n1
		
		global DA_DB_n2 	da_n2 da_a_n2 da_b_n2 da_c_n2 db_n2 db_a_n2 db_b_n2

		global DC_n2 		dc1_a_n2 dc1_b_n2 dc1_c_n2 dc1_d_n2 dc2_a_n2 dc2_b_n2 dc2_c_n2 dc2_d_n2 dc2_e_n2 dc3_1_n2 dc3_1_n2 dc3_1_a_n2 dc3_1_b_n2 dc3_2_n2 dc3_2_a_n2 dc3_2_b_n2 dc3_3_n2 dc3_3_a_n2 dc3_3_b_n2 dc3_4_n2 dc3_4_a_n2 dc3_4_b_n2 dc3_5_n2 dc3_5_a_n2 dc3_5_b_n2 dc4_a_n2 dc4_b_n2 dc5_a_n2 dc5_a1_n2 dc5_a2_n2 dc5_a3_n2 dc5_a4_n2 dc5_b_n2 dc5_c_n2 dc6_n2 dc6_a_n2 dc6_b_n2 dc6_c_n2
		
		global DD_n2 		dd1_1_n2 dd1_1_a_n2 dd1_1_a1_n2 dd1_1_a2_n2 dd1_1_b_n2 dd1_1_c_n2 dd1_1_d_n2 dd1_1_e_n2 dd1_2_n2 dd1_2_a_n2 dd1_2_a1_n2 dd1_2_a2_n2 dd1_2_b_n2 dd1_2_c_n2 dd1_2_d_n2 dd1_2_e_n2 dd1_3_n2 dd1_3_a_n2 dd1_3_a1_n2 dd1_3_a2_n2 dd1_3_b_n2 dd1_3_c_n2 dd1_3_d_n2 dd1_3_e_n2 dd1_4_n2 dd1_4_a_n2 dd1_4_a1_n2 dd1_4_a2_n2 dd1_4_b_n2 dd1_4_c_n2 dd1_4_d_n2 dd1_4_e_n2 dd1_5_n2 dd1_5_a_n2 dd1_5_a1_n2 dd1_5_a2_n2 dd1_5_b_n2 dd1_5_c_n2 dd1_5_d_n2 dd1_5_e_n2 dd2_a_n2 dd2_a1_n2 dd2_a2_n2 dd2_b_n2 dd2_c_n2 dd2_d_n2 dd3_n2 dd3_a_n2 dd3_b_n2 dd3_c_n2 dd3_d_n2 dd3_e_n2 dd3_f_n2 dd4_n2 dd4_a_n2 dd4_a1_n2 dd4_a2_n2 dd4_a3_n2 dd4_a4_n2 dd4_b_n2 dd5_n2 dd5_a_n2 dd5_a1_n2 dd5_a2_n2 dd5_a3_n2 dd5_a4_n2 dd5_b_n2 dd5_c_n2 dd6_a_n2 dd6_b_n2 dd6_c_n2 dd6_d_n2 dd8_n2 dd8_a1_n2 dd8_a2_n2 dd8_b1_n2 dd8_b2_n2 dd9_n2
		
		
		global DE 			de1 de2 de3 de4 df dg dh
		
		order $AA $AB $BA $BB $BC $C $DA_DB_n1 $DC_n1 $DD_n1 $DA_DB_n2 $DC_n2 $DD_n2 $DE

		
********************************************************************************
	** Part 3: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 3.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Merge profile information
		local prof_vars "latitude longitude hfid hfid_m hfname county subcounty location sublocation level ownership inchargename inchargenumber"

		merge m:1 hfid using "${profile_bl}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
	
	* Order dataset
		order `prof_vars', after(key)	
		 
	*-------------------------------------*
	* 3.2. Save database for construction *
	*-------------------------------------*

	*save "${PPS_DO_clean_pii}", replace 	
	
	*----------------*
	* 3.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude hfid hfname location sublocation inchargename inchargenumber 
	
	*--------------------------------------------*
	* 3.4. Save database for microdata catalogue *
	*--------------------------------------------*
	
	save "${pps_do_clean}", replace 
	
	
	/*preserve
	
	*------------------------*
	* 3.5. Build dictionnary *
	*------------------------*

	tempfile dictionarydta
	descsave, list(name varlab, clean noobs) saving(`dictionarydta', replace)
	
	use `dictionarydta', clear
	drop vallab
	putexcel set Dictionary_PPS_DO, replace
	export excel using "${dictionary}", firstrow(variables) replace
	
	* Restore clean dataset
	restore
	*/
	* Dismount
	veracrypt, dismount drive("${mount}") 
