/*******************************************************************************	

Project:  		KePSIE
Created on:  	August 14, 2017
Last udpate on: Aug 16, 2017

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
				  with select code lines from: Benjamin Daniels

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Health Care Worker database for upload in the WB microdata catalog


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
				Part 2 - Complete variables
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionnary					
		
INPUTS:     	* Raw data
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PPS_HCW_combined.dta"
				
				* eQuestionnaire
				"$KePSIE_DB/Data Collection/Baseline/Questionnaires/Electronic/HCW/HCW_eQuestionnaire_Baseline_2.xlsx"
				
				* Spotchecker list
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/spotcheckers.xlsx"

				* HF Baseline profile data
				"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta"
				
OUTPUTS:     	* Anonymized data for microdata catalog
				"${bl_dt}/Final/PPS_HCW_clean_nopii.dta"
				
				* Non-anonymized data for further analysis
				"${bl_dt}/Final/PPS_HCW_clean_pii.dta"

				* Quality checks 
				"${bl_dt}/Intermediate/PPS_HCW_quality_checks.dta"
				
				* Dictionary
				"${bl_out}/Final/PPS_HCW_clean_nopii_dictionary.xls"
				
				* Response rate table
				"${bl_out}/Final/PPS_HCW_response_rate.xls"
				
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo pps_hcw 			"${volume}/pps_hcw_bl_raw.dta"
		glo pps_hcw_q 			"${doc_bl}/codebooks/pps_hcw_bl_equestionnaire.xlsx"
		glo spotcheckers 		"${volume}/supplemental/spotcheckers.xlsx"
		glo profile_bl			"${dt_mast}/profile_bl.dta"
		
	* Output files
		glo pps_hcw_clean		"${dt_bl_clean}/pps_hcw_bl.dta"
		glo qchecks				"${dt_bl_clean}/pps_hcw_bl_qchecks.dta"
			
********************************************************************************
	** Part 1: Complete database
********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	
	use "${pps_hcw}", clear

	* Dropping empty observation		
		drop if a4 == .

	* Drop unnecessary variables		
		drop submissiondate deviceid subscriberid simid devicephonenum audio1 ///
			 audio2 formdef_version audio pri_string a1_c_v a3_v a2_v	///
			 facilitycode date1 time_endinteraction2 starttime endtime

	*-----------------*
	* Drop duplicates *
	*-----------------*
	
	* Drop duplicates in terms of HCW-HF-date. The duplicates are spotchecks done as 
	* part of the quality checks, usually by a supervisor or higher-quality enumerator.
	* We drop the spotcheks using the spotchecker list.
	
		duplicates list a1 a4 date
		duplicates tag 	a1 a4 date, gen(dup)
			 	 
	* Prepare spotchecker list to merge
		preserve
		import excel "$spotcheckers", sheet("Sheet1") firstrow clear
		rename level spotchecker_level
		tempfile spotcheckers
		save 	`spotcheckers'
		
	* Merge spotchecker list
		restore
		rename a2 spotchecker_id
		merge m:1 spotchecker_id using `spotcheckers'
		drop if _merge == 2

	* Generate dummy for spotcheckers
		sort a1 a4
		gen 	spotchecker = .
		replace spotchecker = 1 if _merge == 3
		replace spotchecker = 0 if _merge != 3
		drop 	_merge
	
	* See how many spotcheckers are there for duplicated survey
		bys a1 a4 date: egen spotcheck = sum(spotchecker) if dup > 0
	
	* We have three situations for duplicated surveys:
		* 1. One FO is a spotchecker and the other one is not 
		*	 --> we keep the survey made by the FO that is NOT a spotchecker
			gen	 	drop_dup = .
			replace drop_dup = 1 if spotcheck == 1 & spotchecker == 1
					 
		* 2. No FO is a spotchecker
		*	 --> This happens because of a typo. We keep both surveys.
			replace drop_dup = 0 if spotcheck == 0 & spotchecker == 0
		
		* 3. Both FO are spotcheckers: We use the spotchecker's level. If he/she 
		* is level 2, then he/she is a spotchecker. Hence, we check whether or 
		* not one spotchecker is level 1, and the other one is level 2.
			bys a1 a4 date: egen check = sum(spotchecker_level) if dup > 0 & spotcheck == 2
		
			* A. When one FO is a spotchecker (level 2) and the other one is not (i.e. check = 3)
			* 	--> We keep the survey from the FO that is level 1.
			replace drop_dup = 1 if spotcheck == 2 & spotchecker_level == 2

			* B. When both FO are level 1 (i.e. check = 2)
			* 	--> We keep one survey, randomly selected
			set seed 217493 //random number created with random.org
			bys a1 a4 date: gen random = uniform() if check == 2
			bys a1 a4 date (random): replace drop_dup = 1 if _n == 1 & check == 2			 
			
	rename spotchecker_id a2
	
	* Save spotchecks
		preserve
		* Keep duplicated surveys
		keep if dup > 0
		* Drop surveys that we decided are typos
		drop if drop_dup == 0
		* Save quality checks output
		drop dup spotcheck check random spotchecker_name spotchecker_level spotchecker
		rename drop_dup spotcheck
		lab var spotcheck "This is a spotcheck"
		*save "${qchecks}", replace
		restore
		
	* Drop duplicates
	drop if drop_dup == 1
	drop dup drop_dup spotcheck check random spotchecker_name spotchecker_level spotchecker
							 		 
	/*--------------------------*
	* Calculate response rates *
	*--------------------------*
		
	* Attempted
		mat T = J(3,1,.)
		count
		scalar 	attemp = r(N)
		mat T[1,1] = attemp
	* Able to proceed
		count if b2_v == 1
		scalar 	proceed = r(N)
		mat T[2,1] = proceed	
	* Response rate
		scalar resp_rate = proceed/attemp*100
		mat T[3,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "Able to proceed" "Response rate"
		matlist T
		
	* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify sheet("Patient Exit")
		putexcel A2 = ("Attempted") A3 = ("Able to proceed") A4 = ("Response rate") ///
		B2 = matrix(T) 	
	*/
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
	
	* Able to proceed
	keep if b2_v == 1
		
********************************************************************************
	** Part 2: Complete variables
********************************************************************************

	*-------------------------------------*
	* Separates select_multiple questions * 
	*-------------------------------------*
	
		qui {
		cap prog drop splitmult
		prog def splitmult

		syntax anything using
			import excel `using', clear first
			keep if regexm(type,"^select_multiple")
			count
			local nQuestions = `r(N)'
			forvalues i = 1/`nQuestions' {

				import excel `using', clear first
					keep if regexm(type,"^select_multiple")

					local theName = name[`i']
					local theChoices = type[`i']
						local theChoices = regexr("`theChoices'","select_multiple ","")
					
				import excel `using', clear first sheet("choices")
					keep if list_name == "`theChoices'"
					
					count
					local nChoices = `r(N)'
					
					forvalues j = 1/`nChoices' {
					
						local theNextLabel = label[`j']
						local theNextValue  = name[`j']
					
						local `theName'L `" ``theName'L' "`theNextLabel'" "'
						local `theName'V ``theName'V' `theNextValue'
						
						}
						
				use `anything', clear
				replace `theName' = " "+`theName' +" "
				
					forvalues j = 1/`nChoices' {
						
						local theNextLabel : word `j' of ``theName'L'
						local theNextValue : word `j' of ``theName'V'
						
						cap tostring `theName', replace
						cap gen `theName'_ch_`j' = 1 if regexm(`theName'," `theNextValue' ")
							cap replace `theName'_ch_`j' = 0 if `theName' != "  " & `theName'_ch_`j' != 1
							cap label var `theName'_ch_`j' "`theNextLabel'"
							
						}
						
					save `anything', replace
						
				}			
			end
			}
			
			tempfile split
			save `split'

			* Split the multiple-choice questions
				splitmult `split' using "$pps_hcw_q"

				save `split', replace
				
			* Drop variables
				drop a7 c4 c9 d2 d6 d7 d8 e1_1 e1_2 e1_3 e3 e4 f2
			
			* Fix f2 variable to let one variable per language
				drop f2_ch_4 f2_ch_8 f2_ch_12 f2_ch_15 f2_ch_5 f2_ch_9 f2_ch_13 f2_ch_16 ///
					 f2_ch_11 f2_ch_14 f2_ch_17
			
	*--------------------*
	* Destring variables * 
	*--------------------*
		
		* Cadre
			rename  b6 b6_string
			gen 	b6 = 1   if b6_string == "clinicalofficer"
			replace b6 = 2   if b6_string == "chw"
			replace b6 = 3   if b6_string == "dentist"
			replace b6 = 4	 if b6_string == "doctormo"
			replace b6 = 5   if b6_string == "intern"
			replace b6 = 6   if b6_string == "labtech"
			replace b6 = 7   if b6_string == "labsci"
			replace b6 = 8   if b6_string == "midwife"
			replace b6 = 9   if b6_string == "nurse"
			replace b6 = 10  if b6_string == "nurseaide"
			replace b6 = 11  if b6_string == "nutritionist"
			replace b6 = 12  if b6_string == "pharm"
			replace b6 = 13  if b6_string == "pho"
			replace b6 = 14  if b6_string == "specialist"
			replace b6 = 15  if b6_string == "therapist"
			replace b6 = 16  if b6_string == "otherclinical"
			replace b6 = 100 if b6_string == "other"
			drop b6_string
			
		* Nurse type
			rename b7 b7_string
			gen 	b7 = 1 if b7_string == "nurse_bsc"
			replace b7 = 2 if b7_string == "nurse_r"
			replace b7 = 3 if b7_string == "nurse_e"	
			drop b7_string
			
		* Private
			destring pri, replace
		
		* Merge variable
			replace b4_2 = b4_1 if b4_2 == . & b4_1 != .
			drop b4_1

		* Formatting date
			gen date1 = date(date,"DMY")
			format date1 %td
			drop date
			rename date1 date
		
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************

	*------------------------------------*
	* 3.1. Label define and label values *
	*------------------------------------*	

	* Ownership
		lab def ownership 1 "Private" 0 "Public"
		lab val pri ownership

	* Cadre
		lab def cadre 	1 "Clinical officer" ///
						2 "Community health worker" ///
						3 "Dentist" ///
						4 "Doctor or medical officer" ///
						5 "Intern/Student" ///
						6 "Lab technologist/lab technician" ///
						7 "Laboratory scientist" ///
						8 "Midwife" ///
						9 "Nurse" ///
						10 "Nurse Aides" ///
						11 "Nutritionist" ///
						12 "Pharmacist/pharmacy technologist/dispenser" ///
						13 "Public health officer (PHO)" ///
						14 "Specialists (e.g., haemotologists, radiographers)" ///
						15 "Therapist/counselor" ///
						16 "Other clinical staff" ///
						100 "Other"
		lab val b6 cadre
		
	* Nurse 
		lab def nurse 	1 "Nurse (BSc)" ///
						2 "Nurse (Registered Community Health Nurse (KRHCN))" ///
						3 "Nurse (Enrolled Community Health Nurse (EHCN))"
		lab val b7 nurse
	
	* Yes/No
		lab define yesno_l 1 "Yes" 0 "No"

		foreach var in *_ch_* pri {
			lab values `var' yesno_l
		}	
		
	*-----------------------------------------------------------------------*
	* 3.2. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
		
		
	* Preloaded
		rename a1			 		 hfid
		rename facilityname 		 hfname
		rename pri 					 ownership
		rename time_startinteraction time_start
		rename time_endinteraction1  time_end
		
	* Cover
		rename a1_v 	 a1
		rename a1_1 	 a1a
		rename a1_pri 	 a1b
		rename a1_level	 a1c
		rename a1_county a1d
		rename a3		 supervisorid
		rename a3_c		 supervisorname
		rename a2 		 enumeratorid
		rename a2_c		 enumeratorname
		rename a6		 a5
		rename a7_ch_*	 a6_*
			
	* HCW General Information
		rename b3 	b4
		rename b7 	b8
		rename b6 	b7
		rename b5 	b6
		rename b4_2 b5
		rename b2_v b3
	
	* Hang Hygiene and PPE
		rename c1_1 	c1a
		rename c1_2 	c1b
		rename c2 		c2a
		rename c3 		c2b
		rename c4_ch_* 	c3_*
		rename c5 		c4a
		rename c6 		c4b
		rename c7 		c4c
		rename c8 		c4d
		rename c9_ch_*	c5_*

	* Injections and Blood Draws
		rename d1 		d1a
		rename d2_ch_*	d2_*
		rename d3 		d3a
		rename d4 		d3b
		rename d5 		d3c
		rename d6_ch_* 	d4_*
		rename d7_ch_*	d5_*
		rename d8_ch_* 	d6_*
		rename d9 		d7
		rename d10		d8
		rename d11		d9
	
	* Waste segregation and Disinfection of medical devices
		rename e1_1_ch_*	e1_*
		rename e1_2_ch_*	e2_*
		rename e1_3_ch_*	e3_*
		rename e2			e4
		rename e3_ch_*		e5_*
		rename e4_ch_*		e6_*
	
	* End
		rename f1_1 	f2
		rename f3 		f5
		rename f1_2 	f3
		rename f2_ch_1 	f4_1
		rename f2_ch_2 	f4_2
		rename f2_ch_3 	f4_3
		rename f2_ch_6 	f4_4
		rename f2_ch_10 f4_5
		rename f2_ch_7 	f4_6	
  		rename f2_* 	f4a_*
		
	*----------------------*
	* 3.3. Label variables *
	*----------------------*

	* Preloaded data
		lab var date			"Survey date"
		lab var time			"Survey time"
		lab var hfid 			"Facility ID"
		lab var hfname 			"Health Facility name"
		lab var county 			"County"
		lab var location 		"Location"
		lab var sublocation 	"Sublocation"
		lab var ownership 		"Ownership"		
		lab var level 			"Level"		
		lab var key 			"Survey CTO ID"
		lab var time_end 		"Time after last question"
		lab var time_start 		"Time after consent"
	
	* Cover
		lab var supervisorid	"Supervisor ID"
		lab var supervisorname	"Supervisor Name"
		lab var enumeratorid	"Enumerator ID"
		lab var enumeratorname	"Enumerator Name"
		lab var a6_1 "Procedures observed includes: Consultation"
		lab var a6_2 "Procedures observed includes: Injections"
		lab var a6_3 "Procedures observed includes: Blood test"
		lab var a6_4 "Procedures observed includes: None"
		
	* HCW General Information
		lab var b1 "Enter HCW's gender"
		lab var b7 "What is your cadre?"
		lab var b8 "What kind of nurse are you?"
		
	* Drop unnecesary variables
		drop a1 a1a a1b a1c a1d		
	
	*---------------------*
	* 3.4. Order database *
	*---------------------*
				
		global preload		date time hfid hfname county location sublocation level ownership key time_start time_end
		
		global cover		supervisorid supervisorname enumeratorid enumeratorname a4 a5 a6_1 a6_2 a6_3 a6_4
		
		global HCW_info 	b1 b2 b3 b4 b5 b6 b7 b8	
							
		global hand_hyg 	c1 c1a c1b c2a c2b c3_1 c3_2 c3_3 c3_4 c3_5 c3_6 c4a ///
							c4b c4c c4d c5_1 c5_1 c5_2 c5_3 c5_4 c5_5 c5_6 c5_7 ///
							c5_8 c5_9 c5_10
							
		global injection	d1a d2_1 d2_2 d2_3 d2_4 d2_5 d2_6 d3a d3b d3c d4_1 ///
							d4_2 d4_3 d4_4 d4_5 d5_1 d5_2 d5_3 d5_4 d5_5 d6_1 ///
							d6_2 d6_3 d6_4 d6_5 d6_6 d7 d8 d9 
							
		global waste		e1_1 e1_2 e1_3 e1_4 e2_1 e2_2 e2_3 e2_4 e3_1 e3_2 ///
							e3_3 e3_4 e4 e5_1 e5_2 e5_3 e5_4 e5_5 e5_6 e5_7   ///
							e6_1 e6_2 e6_3 e6_4 e6_5 e6_6 e6_7
							
		global sv_end		f1 f2 f3 f4_1 f4_2 f4_3 f4_4 f4_5 f4_6 f4a_1 f4a_2 ///
							f4a_3 f4a_4 f4a_5 f4a_6 f5
												
		order $preload $cover $HCW_info $hand_hyg $injection $waste $sv_end	 

********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 4.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Drop old profile information
		drop hfname county location sublocation level ownership
	
	* Merge profile information
		local prof_vars "latitude longitude hfid hfid_m hfname county subcounty location sublocation level ownership inchargename inchargenumber"

		merge m:1 hfid using "${profile_bl}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
	
	* Order dataset
		order `prof_vars', after(key)
		
	*-------------------------------------*
	* 4.2. Save database for construction *
	*-------------------------------------*

	*save "${PPS_HCW_clean_pii}", replace 	
	
	*----------------*
	* 4.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude hfid hfname location sublocation inchargename inchargenumber
	
	*--------------------------------------------*
	* 4.4. Save database for microdata catalogue *
	*--------------------------------------------*A
	
	save "${pps_hcw_clean}", replace 
	/*
	preserve
	
	*------------------------*
	* 4.5. Build dictionnary *
	*------------------------*

	tempfile dictionarydta
	descsave , list(name varlab, clean noobs) saving(`dictionarydta', replace)
	
	use `dictionarydta', clear
	drop vallab
	putexcel set Dictionary_PPS_HCW, replace
	export excel using "${dictionary}", firstrow(variables) replace
	
	* Restore clean dataset
	restore
	*/
	* Dismount
	veracrypt, dismount drive("${mount}") 
	