/*******************************************************************************	

Project:  		KePSIE
Created on:  	August 18, 2017
Last udpate on: Aug 24, 2017

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
				  with select code lines from: Benjamin Daniels

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Patient Exit database for upload in the WB microdata catalog


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
				Part 2 - Complete variables
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionnary					
		
INPUTS:     	* Raw data
				"$path_raw/PPS_SO_Baseline-HCW.csv"
				"$path_raw/PPS_SO_Baseline_2-HCW.csv"
				"$path_raw/PPS_SO_Baseline-hhroster.csv"
				"$path_raw/PPS_SO_Baseline_2-hhroster.csv"
				"$path_raw/PPS_SO_Baseline-proceed-c-binsroster.csv"
				"$path_raw/PPS_SO_Baseline_2-proceed-c-binsroster.csv"
				"$path_raw/PPS_SO_Baseline-proceed-b-b_g1.csv"
				"$path_raw/PPS_SO_Baseline_2-proceed-b-b_g1.csv"
				"$path_raw/PPS_SO_combined.dta"
				
				* eQuestionnaire
				"$KePSIE_DB/Data Collection/Baseline/Questionnaires/Electronic/SO/SO_eQuestionnaire_Baseline_2.xlsx"
				
				* Spotchecker list
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/spotcheckers.xlsx"

				* HF Baseline profile data
				"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta"
				
OUTPUTS:     	* Anonymized data for microdata catalog
				"${bl_dt}/Final/PPS_SO_clean_nopii.dta"
				
				* Non-anonymized data for further analysis
				"${bl_dt}/Final/PPS_SO_clean_pii.dta"

				* Quality checks 
				"${bl_dt}/Intermediate/PPS_SO_quality_checks.dta"
				
				* Dictionary
				"${bl_out}/Final/PPS_SO_clean_nopii_dictionary.xls"
				
				* Response rate table
				"${bl_out}/Final/PPS_SO_response_rate.xls"
				
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo input_so 		"${volume}/pps_so_bl_raw.dta"
		glo so_q 			"${doc_bl}/codebooks/pps_so_bl_equestionnaire.xlsx"
		glo hcw_1 			"${volume}/supplemental/pps_so_bl-hcw.csv"
		glo hcw_2 			"${volume}/supplemental/pps_so_bl_2-hcw.csv"
		glo hhroster_1		"${volume}/supplemental/pps_so_bl-hhroster.csv"
		glo hhroster_2 		"${volume}/supplemental/pps_so_bl_2-hhroster.csv"
		glo binroster_1 	"${volume}/supplemental/pps_so_bl-proceed-c-binsroster.csv"
		glo binroster_2 	"${volume}/supplemental/pps_so_bl_2-proceed-c-binsroster.csv"
		glo b_b1_1 			"${volume}/supplemental/pps_so_bl-proceed-b-b_g1.csv"
		glo b_b1_2 			"${volume}/supplemental/pps_so_bl_2-proceed-b-b_g1.csv"
		glo spotcheckers 	"${volume}/supplemental/spotcheckers.xlsx"
		glo profile_bl		"${dt_mast}/profile_bl.dta"
		
	* Output files
		glo pps_so_clean	"${dt_bl_clean}/pps_so_bl.dta"
		glo qchecks			"${dt_bl_clean}/pps_so_bl_qchecks.dta"
	
********************************************************************************
	** Part 1: Complete database
********************************************************************************
	
	*----------------------------------------------------------*
	* Append the two versions of the questionnaire and reshape *
	*----------------------------------------------------------*
	
* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	

	* Each loop/roster is exported in a separate data set
	* We reshape each data set to get a data set at the respondent level
	
	* HCW
		import delimited "${hcw_2}", clear
		tempfile hcw_2
		save 	`hcw_2', replace
				
		import delimited "${hcw_1}", clear
		append using `hcw_2'
		drop key setofhcw
		
		* Reshape
		rename a5 a5_
		reshape wide a5_, i(parent_key) j(hcwidnumber)
		
		tempfile hcw
		save 	`hcw', replace
				
	* Bin roster	
		import delimited "${binroster_2}", clear
		tempfile binroster_2
		save 	`binroster_2', replace
				
		import delimited "${binroster_1}", clear
		append using `binroster_2'
		drop key setofbinsroster
		
	* Reshape
		rename (c2 c2type c3) (c2_ c2type_ c3_)
		reshape wide c2_ c2type_ c3_, i(parent_key) j(binsrosternumber)
		
		tempfile binroster
		save 	`binroster', replace

	* Hand Hygiene (HH)roster: 
		import delimited "${hhroster_2}", clear
		tempfile hhroster_2
		save 	`hhroster_2', replace
				
		import delimited "${hhroster_1}", clear
		append using `hhroster_2'
		
		* Generate hh number
		gen hhnumber = substr(key, -2, 1)
		destring hhnumber, replace
		drop key setofhhroster
		
		* Reshape
		rename (b3) (b3_)
		reshape wide b3_, i(parent_key) j(hhnumber)
		rename parent_key key_b_b1 // have to merge it with B_B1
		
		tempfile hhroster
		save 	`hhroster', replace
		
	* B_B1 	
		import delimited "${b_b1_2}", clear
		tempfile b_b1_2
		save 	`b_b1_2', replace
				
		import delimited "${b_b1_1}", clear
		append using `b_b1_2'
		
		* Merge HH roster
		rename key key_b_b1
		merge m:1 key_b_b1 using `hhroster'
	
		* Generate hcw number (should be the same as in HCW database)
		gen hcwnumber = substr(key_b_b1, -2, 1)
		destring hcwnumber, replace
		drop key_b_b1 setofb_g1 setofhhroster hhroster_count _merge

		* Reshape
		rename (hcwidnumber2 b1 b2 b3_1 b3_2 b3_3 b3_4 b3_5) (hcwidnumber2_ b1_ b2_ b3_1_ b3_2_ b3_3_ b3_4_ b3_5_)
		reshape wide hcwidnumber2_ b1_ b2_ b3_1_ b3_2_ b3_3_ b3_4_ b3_5_, i(parent_key) j(hcwnumber)

		tempfile b_b1
		save 	`b_b1', replace
	
	*---------------------------------------------*
	* Merge of all data downloaded from SurveyCTO *
	*---------------------------------------------*
	
	use "${input_so}", clear
	rename key parent_key
	
	* HCW 
		merge 1:1 parent_key using `hcw', nogen
	
	* Bin roster
		merge 1:1 parent_key using `binroster', nogen
	
	* b_b1 + HH roster
		merge 1:1 parent_key using `b_b1', nogen	
		
	*-----------------*
	* Drop duplicates *
	*-----------------*

	* There should be no duplicates. We look duplicates at HF, SO, DATE, HCW IDs
	* br a1 a7 date
	sort a1 a7 date
	duplicates report a1 a7 date a4 hcwidnumber2_1 hcwidnumber2_2 hcwidnumber2_3 hcwidnumber2_4 // 76 duplicates
	*duplicates tag	  a1 a2 a7 date, gen(dup)
	duplicates tag	   a1 a7 date a4 hcwidnumber2_1 hcwidnumber2_2 hcwidnumber2_3 hcwidnumber2_4, gen(dup)
	* br  a1 a7 date a4 hcwidnumber2_1 hcwidnumber2_2 hcwidnumber2_3 hcwidnumber2_4 if dup > 0
	sort  a1 a7 date a4 hcwidnumber2_1 hcwidnumber2_2 hcwidnumber2_3 hcwidnumber2_4

	* Drop unnecesary variables
	drop deviceid facilitycode dup subscriberid simid devicephonenum pri_string a1_c_v a3_v a2_v setofhcw setofb_g1 setofbinsroster time_end2 formdef_version submissiondate starttime endtime date1 audio hcwidnumber2_* c2type_*
	
	/*--------------------------*
	* Calculate response rates *
	*--------------------------*
		
	* Attempted
		mat T = J(3,1,.)
		count
		scalar 	attemp = r(N)
		mat T[1,1] = attemp
	* Able to proceed
		count if a9 == 1
		scalar 	proceed = r(N)
		mat T[2,1] = proceed	
	* Response rate
		scalar resp_rate = proceed/attemp*100
		mat T[3,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "Able to proceed" "Response rate"
		matlist T
		
	* Export to excel
		putexcel clear
		putexcel set "$resp_rate", modify sheet("Patient Exit")
		putexcel A2 = ("Attempted") A3 = ("Able to proceed") A4 = ("Response rate") ///
		B2 = matrix(T) 	
		*/
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
	
	* Able to proceed
		keep if  a9 == 1
	
********************************************************************************
	** Part 2: Complete variables
********************************************************************************

	*-------------------------------------*
	* Separates select_multiple questions * 
	*-------------------------------------*
	
	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
			replace `theName' = " "+`theName' +" "
			
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace
					cap gen `theName'_ch_`j' = 1 if regexm(`theName'," `theNextValue' ")
						cap replace `theName'_ch_`j' = 0 if `theName' != "  " & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace
					
			}			
		end
		}
		
		tempfile split
		save `split'

		* Split the multiple-choice questions
			splitmult `split' using "${so_q}"

	
		* Drop variables
			drop a8 c8 c9 c10 c12
		
	*--------------------*
	* Destring variables * 
	*--------------------*

		* Private
			destring pri, replace
		
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************

	*------------------------------------*
	* 3.1. Label define and label values *
	*------------------------------------*	

	* Formatting date
		gen date1 = date(date,"DMY")
		format date1 %td
		drop date
		rename date1 date

	* Ownership
		lab def ownership 1 "Private" 0 "Public"
		lab val pri ownership

	* Yes/No
		lab define yesno_l 1 "Yes" 0 "No"

		foreach var in *_ch_* {
			lab values `var' yesno_l
		}	
			
			
	* Yes/No/
		lab define yesnoc_l 1 "Yes" 0 "No" -99 "-99: Cannot be assessed"

		foreach var in b1_* {
			lab values `var' yesnoc_l
		}
	
	* Trigger activity
		lab def hhtrigger	1 "Before eating or drinking" 2	"After eating or drinking" ///
							3 "Before using the wash room" 4 "After using the wash room" ///
							5 "After lab test analysis" 6 "None in particular" 0 "Other"
		foreach var in b3_*_1 b3_*_2 b3_*_3 b3_*_4 {
			lab values `var' hhtrigger
		}
	
		
	* Color of bag in bin
		lab define color 1 "Black" 2 "Red" 3 "Yellow" 4 "Other color" 5	"No bag"
		
		foreach var in c3_* {
			lab values `var' color
		}
			
	*-----------------------------------------------------------------------*
	* 3.2. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
		
	* Preloaded
   		rename a1			 		 hfid
		rename facilityname 		 hfname
		rename pri 					 ownership
		rename time_end1   			 time_end
		rename parent_key 			 key
			
	* Cover
		rename a1_v 	 a1
		rename a1_1 	 a1a
		rename a1_pri 	 a1b
		rename a1_level	 a1c
		rename a1_county a1d
		rename a3		 supervisorid
		rename a3_c		 supervisorname
		rename a2 		 enumeratorid
		rename a2_c		 enumeratorname
		rename a5_*		 a4a_*
		rename a7		 a5
		rename a8_ch_*	 a6_*
		rename a9		 a7
		
	* Hand Hygiene Outside of Patient Interaction
		rename b2_*   b1a_*
		rename b3_*_1 b1b_1_*
		rename b3_*_2 b1b_2_*
		rename b3_*_3 b1b_3_*
		rename b3_*_4 b1b_4_*
			
	* Availability of Supplies and Infrastructure
		rename c2_* 	c1a_*
		rename c3_* 	c1b_*
		rename c4		c2
		rename c5		c3
		rename c6		c4
		rename c7		c5
		rename c8_ch_*	c6_*
		rename c9_ch_*	c7_*
		rename c10_ch_*	c8_*
		rename c11		c9
		rename c12_ch_*	c10_*
		rename c13		c11		
	
	* End
		rename f1 	d1
		rename f1_1 d2
		rename f1_2 d3

	*----------------------*
	* 3.3. Label variables *
	*----------------------*
	
	* Preloaded data
		lab var date			"Survey date"
		lab var time			"Survey time"
		lab var hfid 			"Facility ID"
		lab var hfname 			"Health Facility name"
		lab var location 		"Location"
		lab var sublocation 	"Sublocation"
		lab var ownership 		"Ownership"		
		lab var level 			"Level"		
		lab var key 			"Survey CTO ID"
		lab var time_end 		"Time after last question"
		lab var time_start 		"Time after consent"

	* Cover
		lab var supervisorid	"Supervisor ID"
		lab var supervisorname	"Supervisor Name"
		lab var enumeratorid	"Enumerator ID"
		lab var enumeratorname	"Enumerator Name"
		lab var a6_1 "Procedures observed includes: Consultation"
		lab var a6_2 "Procedures observed includes: Injections"
		lab var a6_3 "Procedures observed includes: Blood test"
		lab var a6_4 "Procedures observed includes: None of above"
		
		foreach i of numlist 1(1)4 {
			lab var a4a_`i' "Enter HCW ID [HCW `i']"
		}
		
	* Hand Hygiene Outside of Patient Interaction
		foreach hcwnum of numlist 1(1)4 {
			lab var b1_`hcwnum' 	"Did [HCW `hcwnum'] perform hand hygiene outside of the time of the forms you filled?"
			lab var b1a_`hcwnum'	"How many times [HCW `hcwnum'] perform hand hygiene?"
			
			foreach hhnumber of numlist 1(1)5 {
				lab var b1b_`hcwnum'_`hhnumber' "Activity that triggered [HCW `hcwnum'] to perform hand hygiene `hhnumber'"
			}
		}
		
	* Availability of Supplies and Infrastructure
		foreach bin of numlist 1(1)7 {
			lab var c1a_`bin' 	"Color of bin `bin' available in the room"
			lab var c1b_`bin' 	"Color of the bag in the bin `bin'"
		}

	* Drop other vars that are not needed that will be consolidated by the updated profile characteristics
		drop a1 a1a a1b a1c a1d d1 d2 d3
		
	*---------------------*
	* 3.4. Order database *
	*---------------------*
				
		global preload		date time hfid hfname location sublocation level ownership key time_start time_end
		
		global cover 		supervisorid supervisorname enumeratorid enumeratorname a4 a4a_* a5 a6_* a7
							
		global handhyg	 	b1_* b1a_* b1b_*
							
		global supplies		c1 c1a_* c1b_* c2 c3 c4 c5 c6_* c7_* c8_* c9 c10_* c11
			
		order $preload $cover $handhyg $supplies

********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************

	*-----------------------------------------------------------------*
	* 4.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Drop old profile information
		drop hfname location sublocation level ownership
	
	* Merge profile information
		local prof_vars "latitude longitude hfid hfid_m hfname county subcounty location sublocation level ownership inchargename inchargenumber"

		merge m:1 hfid using "${profile_bl}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
	
	* Order dataset
		order `prof_vars', after(key)	
	
	*-------------------------------------*
	* 4.2. Save database for construction *
	*-------------------------------------*
  
	*save "${PPS_SO_clean_pii}", replace 	
	
	*----------------*
	* 4.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	 
	  drop latitude longitude hfid hfname location sublocation inchargename inchargenumber supervisorname enumeratorname 

	*--------------------------------------------*
	* 4.4. Save database for microdata catalogue *
	*--------------------------------------------*
	
	save "${pps_so_clean}", replace 
	/*
	preserve
	
	*------------------------*
	* 4.5. Build dictionnary *
	*------------------------*

	tempfile dictionarydta
	descsave, list(name varlab, clean noobs) saving(`dictionarydta', replace)
	
	use `dictionarydta', clear
	drop vallab
	putexcel set Dictionary_PPS_HCW, replace
	export excel using "${dictionary}", firstrow(variables) replace
	
	* Restore clean dataset
	restore
	*/
	* Dismount
	veracrypt, dismount drive("${mount}") 
