	/*****************************************************************
	PROJECT: 		KePSIE, Kenya Patient Safety Impact Evaluation
					
	TITLE:			Clean_QPS1_microdata_catalog.do
				
	AUTHOR: 		Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com)
					selected code lines from Ben Daniels and Tatiana Zarate
				
	DATE CREATED:	Aug 21, 2017

	LAST EDITED:	Sep 2, 2017, by Seungmin Lee (slee31@worldbank.org)
					Sep 4, 2017, Lupe Bedoya
					Oct 16, 2017, by Seungmin Lee
					Dec 11, 2018, by Thomas Escande (tescande@worldbank.org)

	DESCRIPTION: 	Clean QPS1 survey to be published on WB Microdata Catalog and analyzed later on
		
	ORGANIZATION:	0 -	Preamble
					1 -	Basic cleaning
					2 - Merge with the Listing and Staff Roster Helper databases
					3 -	Renames & drop variables to follow the paper based form
					X - Save and Exit 

	INPUTS: 		* Raw QPS1 data
						${KePSIE_DB}/DataAnalysis/Baseline/RawData/QPS1_final.dta
					
					* QPS1 questionnaire (electronic)
						${KePSIE_DB}/Data Collection/Baseline/Questionnaires/Electronic/QPS1/QPS1_eQuestionnaire2_103_Baseline.xlsx
					
					* HF Baseline profile data (as of Oct 13, 2017)
						${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta

	OUTPUTS: 		* Cleaned QPS1 data
						${bl_dt}/Final/QPS1_clean_pii.dta
						
					* Cleaned anonymized QPS1 data, to be pulished to the micro data catalog
						${bl_dt}/Final/QPS1_clean_nopii.dta
						
					* Dictionary of anonymized data
						${bl_out}/Final/QPS1_clean_nopii_dictionary.xlsx

	NOTE:			This do-file is based on "Prepare_QP1.do" file written by Tatiana Zarate in May 2016, with the necessary changes for microdata catalog.
					
					
					
	******************************************************************/
 
 
	/****************************************************************
		SECTION 0: Preamble			 									
	****************************************************************/		 
	/*	
	/* 0.1 - Environment setup */
	
	* Clear all stored values in memory from previous projects
	clear		all
	drop		_all
	cap	log		close

	* Filename and log
	loc	name_do	Clean_QPS1_microdata_catalog
	
	* Display current branch and commit
	cd	"${bl}"
	stgit9
	di "Made using `name_do'.do on `c(current_date)' by `c(username)'."
	di "Git branch `r(branch)'; commit `r(sha)'." 
	*/
	* Input files
		* Raw QPS1 data
			glo	qps1_bl_raw			"${volume}/qps1_bl_raw.dta"
			glo qps1_bl_backcheck	"${volume}/supplemental/respondents_baseline.xls"
		
		* QPS1 questionnaire (electronic)
			glo	qps1_bl_q			"${doc_bl}/codebooks/qps1_bl_equestionnaire.xlsx" /*Replace with version _103_ later on with Stata 15*/
		
		* HF Baseline profile data (as of Oct 13, 2017)
			glo profile_bl			"${dt_mast}/profile_bl.dta"
			
	* Output files
		* Cleaned QPS1 data
		glo qps1_bl				"${dt_bl_clean}/qps1_bl.dta"

********************************************************************************

	** Part 1: Basic cleaning 

********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")


	cls
	clear all
	use "${qps1_bl_raw}"
	
	* For the first draft, we will also keep non-completed responses to analyze response rate
	* Keep	only completed survey
	keep if a12 ==1 // Keeping only those that finished QPS1

	* Manual change: Dropping HFs that did not complete both QPS1 and QPS2
	drop if inlist(a5,16622,18700,800028,900478,901253)
	
		
	** Drop misscoded hf: 900899
	drop if a5 == 900899

	** Manual change: HF's survey with code 800004 was coded as 800020, so we need to change those values
	preserve 
		keep if a5 == 800020
		keep submissiondate	deviceid date a2 a2_1 time a4 a5 a6 a6_c a7 a8 a8_c a9 a11 - c18_47
		replace a5 = 800004
		tempfile temp1
		save `temp1'
	restore

	append using `temp1'
	drop if a5 == 800020
	drop if inlist(key,"uuid:b643e997-ff66-4879-91c9-fb7117350f9f","uuid:4289e290-bfcb-4388-8bd2-9361f8b8322a","uuid:3b802bdb-b149-4a74-87d7-906e581cd3d0") // drop backcheck surveys

	** Drop staff roster questions from database
	drop time_start_staffroster roster_repeat-time_end_staffroster c61-c18_478
		
	** Separates select_multiple questions 

	/*** SL, 2017-9-3: The split code is the old one (NOT the new one Camila corrected) since the raw QPS2 is modified and the new code cannot be applied to the modified data
					I checked all the multiple-selection variables and no errors found	*/
	
	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
				
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace					
					cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
						cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace
					
			}			
		end
	}

	tempfile split
	save `split'

	* Split the multiple-choice questions
	splitmult `split' using "${qps1_bl_q}"
	save `split', replace

	** droping splitted variables 
	drop 	b4 d9 d13 f10 f38 f44 e16_v
	
	** Construct missing profile variables and label them
	clonevar	supervisorid	=	a6
	clonevar	supervisorname	=	a6_c
	clonevar	enumeratorid	=	a8
	clonevar	enumeratorname	=	a8_c
	
	lab	var	supervisorid	"Supervisor ID"
	lab	var	supervisorname	"Supervisor Name"
	lab	var	enumeratorid	"Enumerator ID"
	lab	var	enumeratorname	"Enumerator Name"
	

	* Destring variables 
	destring facilitycode level pri b1 f36_s_total patients labtest e16 d16 c2_c, replace

	* Formatting date
	gen date1 = date(date,"DMY")
	format date1 %td
	drop date
	rename date1 date
			
	* Formating time
	foreach var in time time_start_d time_end_d time_start_e time_end_e time_start_f time_end_f time_start_g time_end_g	time_startinteraction	{
		gen double `var'_1 = clock(`var', "hm")
		format `var'_1 %tcHH:MM
		drop `var' 
		rename `var'_1 `var'
		tostring	`var', replace usedisplayformat force
	}
		
	* Facilityname: Update the listing's HF name
	replace facilityname = d1_v if d1_v != ""

	* Generate county as numerical value
	encode county, gen(county_n)
	drop county
	rename county_n county
		
	* Language used for survey
	gen	i5_1	=	1	if	regexm(g9, "English")
	gen	i5_2	=	1	if	regexm(g9, "Swahili")
	gen	i5_3	=	1	if	regexm(g9, "Mijikenda")
	gen	i5_4	=	1	if	regexm(g9, "Kimeru")
	gen	i5_5	=	1	if	regexm(g9, "Luhya")
	gen	i5_6	=	1	if	regexm(g9, "0")
	
	forval	langnum=1/6	{
		replace	i5_`langnum'=0	if	mi(i5_`langnum')
	}

********************************************************************************

	** Part 2: Merge with the Listing and Respondent data

********************************************************************************

	* Drop variables which will be imported from the listing data
	drop	county	location	sublocation	level	a1latitude	a1longitude	a1latitude	facilityname county	a1accuracy    pri	pri_string
	
	preserve 
		use "${profile_bl}", clear
		keep latitude	longitude	hfid	hfname	county	subcounty	location	sublocation	level	ownership	 inchargename d17_1	d17_2	d17_3	d17_4	d17_5	d17_6	d17_7	d17_8	d17_9	d17_10	d17_11	d17_12	d17_13	d17_14	d17_15	d17_16	d17_17	d17_18 d22_1 d22_2	d22_3	d22_4	d22_5	d22_6	d22_7	d22_8	d22_9	d22_10	d22_11	d22_12	d22_13	d22_14	d22_15	d22_16	d22_17	d22_18

		replace	subcounty	=	proper(subcounty)
		replace	location	=	proper(location)
		replace	sublocation	=	proper(sublocation)
		
		rename hfid a5
		tempfile HF_profile 
		save `HF_profile'
	restore
	
	merge	1:1	a5	using	`HF_profile',	assert(2 3) nogen keep(3)
	replace	facilitycode=a5	if	mi(facilitycode)
	

	** Create new variables that combine the in-charge information from profile and from respondents in QPS1. It is required to merge job title variables later		
		preserve
			import excel using "${qps1_bl_backcheck}", sheet("respondents_baseline") firstrow clear
			rename facilityid a5
			rename respondentid b1
			tempfile respondents
			save `respondents'
		restore 		

		merge	m:1	b1 using	`respondents', keep(1 3)  nogen
		
		** Create a variable that combines the respondent name in one variable
		gen b2_n = b2 if b1 == 0 
		replace b2_n = respondentname if b1!= 0 & b1 != . 
		
		drop b2
		rename b2_n b2
		
		replace b2 = upper(b2)
		replace inchargename = upper(inchargename)
			
		** Use reclink to check if there are typos in the in-charge name reported in variable b2
		preserve 
			keep a5 inchargename
			gen id1 = _n
			rename inchargename b2
			sort a5 id1 b2
			tempfile qps1
			save `qps1'
		restore
		
		gen id2 = _n
		sort a5 id2 b2
		reclink a5 b2 using `qps1', gen(myscore) idm(id2) idu(id1)
		sort myscore
		
		** Change manually the typos in the in-charge name according to "myscore": I checked when myscore is less than 1 (41 obs)
		replace b2 = inchargename if a5 == 16041
		replace b2 = inchargename if a5 == 18017
		replace b2 = inchargename if a5 == 16825
		replace b2 = inchargename if a5 == 11387
		replace b2 = inchargename if a5 == 800048
		replace b2 = inchargename if a5 == 100005
		replace b2 = inchargename if a5 == 20536
		replace b2 = inchargename if a5 == 900317
		replace b2 = inchargename if a5 ==  901463
		replace b2 = inchargename if a5 ==  900846
		replace b2 = inchargename if a5 ==  16618
		replace b2 = inchargename if a5 ==  900090
		replace b2 = inchargename if a5 ==  901856
		replace b2 = inchargename if a5 ==  16055
		replace b2 = inchargename if a5 ==  800009
		replace b2 = inchargename if a5 ==  11453
		replace b2 = inchargename if a5 ==  901431
		replace b2 = inchargename if a5 ==  15977
		replace b2 = inchargename if a5 ==  800065
		replace b2 = inchargename if a5 ==  16847
		
		** drop reclink variables 
		drop myscore Ua5 Ub2 _merge id1 id2		

*** Merge job title variables from QPS1 and from listing data
		
	** Create a variable to identify if the respondent is the person in-charge of the HF
	gen incharge = 1 if b2 == inchargename
	replace incharge = 0 if b2 != inchargename & b2 != ""

	** Respondent's job title: the respondent could be the same person reported in the listing (as in-charge or as contact) or could be another person
	** there are some cases in which the respondent has 3 different job titles because in the listing survey they could choose 3 different options at the same time
		
	* CONSTRUCT NEW JOB VARIABLES WHICH ARE MERGED FROM QPS1 AND FROM LISTING SURVEY
	
		* Clinical officer, Community health worker, Dentist, Doctor or medical officer, and Hospital administrator/executive director/superintendent
		forvalues i=1(1)5 {
			gen		b1c_`i' = 1 if b1 == 0 & b4_ch_`i' == 1
			replace b1c_`i' = 1 if b1!= 0 & incharge == 1 & d17_`i' == 1
			replace b1c_`i' = 1 if b1!= 0 & incharge == 0 & d22_`i' == 1
			
			replace b1c_`i' = 0 if b1 == 0 & b4_ch_`i' == 0
			replace b1c_`i' = 0 if b1 != 0 &  incharge == 1 & d17_`i' == 0 
			replace b1c_`i' = 0 if b1 != 0 &  incharge == 0 & d22_`i' == 0		
		}
				
		* Intern/Student(6)
		gen     b1c_6 = 1 if b1 == 0 & b4_ch_6 == 1
		replace b1c_6 = 0 if b1 == 0 & b4_ch_6 == 0
		replace b1c_6 = 0 if b1 != 0 & incharge != .		 	 
		
		* Lab technologist/lab technician

		gen 	b1c_7 = 1 if b1 == 0 & b4_ch_7  == 1
		replace b1c_7 = 1 if b1 != 0 & incharge == 1 & d17_6 == 1
		replace b1c_7 = 1 if b1 != 0 & incharge == 0 & d22_6 == 1
		
		replace b1c_7 = 0 if b1 == 0 & b4_ch_7 	== 0
		replace b1c_7 = 0 if b1 != 0 & incharge == 1 & d17_6 == 0
		replace b1c_7 = 0 if b1 != 0 & incharge == 0 & d22_6 == 0

		* Laboratory scientist
		gen 	b1c_8 = 1 if b1 == 0 & b4_ch_8  == 1
		replace b1c_8 = 1 if b1	!= 0 & incharge == 1 & d17_7 == 1
		replace b1c_8 = 1 if b1	!= 0 & incharge == 0 & d22_7 == 1 
		
		replace b1c_8 = 0 if b1 == 0 & b4_ch_8 == 0
		replace b1c_8 = 0 if b1 != 0 & incharge == 1 & d17_7 == 0
		replace b1c_8 = 0 if b1 != 0 & incharge == 0 & d22_7 == 0
		
		* Midwife
		gen 	b1c_9 = 1 if b1 == 0 & b4_ch_9  == 1
		replace b1c_9 = 1 if b1 != 0 & incharge == 1 & d17_8 == 1
		replace b1c_9 = 1 if b1 != 0 & incharge == 0 & d22_8 == 1 
		
		replace b1c_9 = 0 if b1 == 0 & b4_ch_9 == 0
		replace b1c_9 = 0 if b1 != 0 & incharge == 1 & d17_8 == 0
		replace b1c_9 = 0 if b1 != 0 & incharge == 0 & d22_8 == 0	
		
		* Nurses	
		gen 	b1c_10 = 1 if b1 == 0 & (b4_ch_10 == 1 | b4_ch_11 == 1 | b4_ch_12 == 1)
		replace b1c_10 = 1 if b1 != 0 & incharge  == 1 & d17_9 == 1
		replace b1c_10 = 1 if b1 != 0 & incharge  == 0 & d22_9 == 1 
		
		replace b1c_10 = 0 if b1 == 0 & (b4_ch_10 == 0 & b4_ch_11 == 0 & b4_ch_12 == 0)
		replace b1c_10 = 0 if b1 != 0 & incharge  == 1 & d17_9 == 0
		replace b1c_10 = 0 if b1 != 0 & incharge  == 0 & d22_9 == 0
		
		** Nurse aide
		gen 	b1c_11 = 1 if b1 == 0 & b4_ch_13 == 1
		replace b1c_11 = 1 if b1 != 0 & incharge == 1 & d17_10 == 1
		replace b1c_11 = 1 if b1 != 0 & incharge == 0 & d22_10 == 1 
		
		replace b1c_11 = 0 if b1 == 0 & b4_ch_13 == 0
		replace b1c_11 = 0 if b1 != 0 & incharge == 1 & d17_10 == 0
		replace b1c_11 = 0 if b1 != 0 & incharge == 0 & d22_10 == 0
		
		* Nutritionist
		gen  	b1c_12 = 1 if b1 == 0 & b4_ch_14 == 1
		replace b1c_12 = 1 if b1 != 0 & incharge == 1 & d17_11 == 1
		replace b1c_12 = 1 if b1 != 0 & incharge == 0 & d22_11 == 1 
		
		replace b1c_12 = 0 if b1 == 0 & b4_ch_14 == 0
		replace b1c_12 = 0 if b1 != 0 & incharge == 1 & d17_11 == 0
		replace b1c_12 = 0 if b1 != 0 & incharge == 0 & d22_11 == 0

		* Pharmacist
		gen 	b1c_13 = 1 if b1 == 0 & b4_ch_15 == 1
		replace b1c_13 = 1 if b1 != 0 & incharge == 1 & (d17_12 == 1 |d17_13 == 1)
		replace b1c_13 = 1 if b1 != 0 & incharge == 0 & (d22_12 == 1 | d22_13 == 1) 
		
		replace b1c_13 = 0 if b1 == 0 & b4_ch_15 == 0
		replace b1c_13 = 0 if b1 != 0 & incharge == 1 & (d17_12 == 0 & d17_13 == 0)
		replace b1c_13 = 0 if b1 != 0 & incharge == 0 & (d22_12 == 0 & d22_13 == 0)
		
		* PHO
		gen 	b1c_14 = 1 if b1 == 0 & b4_ch_16 == 1
		replace b1c_14 = 1 if b1 != 0 & incharge == 1 & d17_14 == 1
		replace b1c_14 = 1 if b1 != 0 & incharge == 0 & d22_14 == 1 
		
		replace b1c_14 = 0 if b1 == 0 & b4_ch_16 == 0
		replace b1c_14 = 0 if b1 != 0 & incharge == 1 & d17_14 == 0
		replace b1c_14 = 0 if b1 != 0 & incharge == 0 & d22_14 == 0
		
		* Specialist
		gen 	b1c_15 = 1 if b1 == 0 & b4_ch_17 == 1
		replace b1c_15 = 1 if b1 != 0 & incharge == 1 & d17_16 == 1
		replace b1c_15 = 1 if b1 != 0 & incharge == 0 & d22_16 == 1 
		
		replace b1c_15 = 0 if b1 == 0 & b4_ch_17 == 0
		replace b1c_15 = 0 if b1 != 0 & incharge == 1 & d17_16 == 0
		replace b1c_15 = 0 if b1 != 0 & incharge == 0 & d22_16 == 0
		
		* Therapist
		gen 	b1c_16 = 1 if b1 == 0 & b4_ch_18 == 1
		replace b1c_16 = 1 if b1 != 0 & incharge == 1 & d17_17 == 1
		replace b1c_16 = 1 if b1 != 0 & incharge == 0 & d22_17 == 1 
		
		replace b1c_16 = 0 if b1 == 0 & b4_ch_18 == 0
		replace b1c_16 = 0 if b1 != 0 & incharge == 1 & d17_17 == 0
		replace b1c_16 = 0 if b1 != 0 & incharge == 0 & d22_17 == 0
	
		* Don't know
		gen 	b1c_17 = d17_18 if b1 != 0 & incharge == 1
		replace b1c_17 = d22_18 if b1 != 0 & incharge == 0
		replace b1c_17 = 0 		if b1 == 0	
		
		* Receptionist 
		gen 	b1c_18 = d17_15 if b1 != 0 & incharge == 1
		replace b1c_18 = d22_15 if b1 != 0 & incharge == 0
		replace b1c_18 = 0 		if b1 == 0

	* Drop variables no longer needed
		
		* Job title variables from QPS survey
		drop 	b4_ch_1 b4_ch_2 b4_ch_3 b4_ch_4 b4_ch_5 b4_ch_6 b4_ch_7 b4_ch_8 b4_ch_9 b4_ch_13 b4_ch_14 b4_ch_15 ///
				b4_ch_16 b4_ch_17 b4_ch_18 inchargename
		
		* Job title variables from listing survey
		drop	d17_1 d17_2 d17_3 d17_4 d17_5 d17_6 d17_7 d17_8 d17_9 d17_10 d17_11 d17_12	d17_13 d17_14 d17_15 d17_16 ///
				d17_17	d17_18 d22_1 d22_2 d22_3 d22_4 d22_5 d22_6 d22_7 d22_8 d22_9 d22_10	d22_11 d22_12 d22_13 d22_14	 ///
				d22_15 d22_16 d22_17 d22_18
		
		* Drop temporarily constructed variable
		drop	incharge
		
	
********************************************************************************

	** Part 3: Drop unnecessary variables, and rename & re-label variables to follow the paper-based form

********************************************************************************
	
	* Drop unnecessary variables
	
		drop	submissiondate	deviceid	a1altitude	subscriberid	simid	devicephonenum	audio	formdef_version	///
				a1_cal	a1_v a2 a2_1 a6_c 	a7	a8_c	a9	a10	b4_ch_10 b4_ch_11 b4_ch_12	///
				h2_1latitude h2_1longitude h2_1altitude h2_1accuracy	h1_1	h1_2	h2_2	h2_3	e11_v
	
	
	* Rename variables to follow the paper questionnaire
	
	rename	facilitycode	hfid
	rename	(time_startinteraction time_endinteraction)	(time_start	time_end)
		tostring time time_start,replace force usedisplayformat
	
	rename	(g1	g2)	(i1 i1a)
	rename	(g3 g4)	(i2	i2a)
	rename	(g5 g6)	(i3	i3a)
	rename	(g7	g8)	(i4	i4a)

	rename c1 h1
	rename c2_1  h2a
	rename c2_2  h2b
	rename c2_c h2_total
	
	rename	a4	a2
	rename	a4_1	a2a
	rename	a4_pri	a2b
	rename	a4_level	a2c
	rename	a4_county	a2d
	rename	a5	a3
	rename	a6	a4
	rename	a8	a5
	rename a11 a6
	rename a12 a7
	
	rename b2 b1a
	rename b3 b1b
	rename d2 c2
	
	rename d1 c1
	rename d1_v	c1a
	rename d3  c3
	rename d4 c4
	rename d5 c5
	rename d6 c5a
	rename d7 c6
	rename d8 c6a	
	rename d9_ch_1 c7_1
	rename d9_ch_2 c7_2
	rename d9_ch_3 c7_3
	rename d9_ch_4 c7_4
	rename d9_ch_5 c7_5
	rename d9_ch_6 c7_6
	rename d10 c8
	rename d11 c9a
	rename d12 c9b
	rename d13_ch_1 c10_1
	rename d13_ch_2 c10_2
	rename d13_ch_3 c10_3
	rename d13_ch_4 c10_4
	rename d14 c10a
	rename d15 c10b
	rename d16 c11
	rename d17 c12
	rename d18 c12a
	rename d18_1 c12b
	
	rename e1_1  d1_x
	rename e1_2  d2_x
	rename e1  d3_x
	rename e2  d4_x	
	rename e21  d5_x
	rename e21_ch_1 d5_1
	rename e21_ch_2 d5_2
	rename e21_ch_3 d5_3
	rename e21_ch_4 d5_4
	rename e21_ch_5 d5_5
	rename e21_ch_6 d5_6
	rename e21_ch_7 d5_7
	rename e21_ch_8 d5_8
	rename e21_ch_9 d5_9
	rename e21_ch_10 d5_10
	
	rename	(e3_1 e3_1_1)	(d5a_1	d5a_2)
	rename e4_1  d5a_3
	rename e4_1_1  d5a_4
	rename e5_1  d5a_5	
	rename	(e3_2 e3_2_1)	(d5b_1	d5b_2)
	rename e4_2  d5b_3
	rename e4_2_1  d5b_4
	rename e5_2  d5b_5
	rename	(e3_3 e3_3_1)	(d5c_1	d5c_2)
	rename e4_3  d5c_3
	rename e4_3_1  d5c_4
	rename e5_3  d5c_5
	order	d5a_? d5b_? d5c_?, after(d5_x)
	
	rename e6  d6_x
	rename e6_1  d6a
	rename e7_1  d6b_1
	rename e8_1  d6c_1
	rename e9_1  d6c1_1
	rename e10_1  d6c2_1
	rename e4_4  d6f_1
	rename e4_4_1  d6g_1
	rename e5_4  d6h_1
	rename e7_2  d6b_2
	rename e8_2  d6c_2
	rename e9_2  d6c1_2
	rename e10_2  d6c2_2
	rename e4_5  d6f_2
	rename e4_5_1  d6g_2
	rename e5_5  d6h_2
	rename e7_3  d6b_3
	rename e8_3  d6c_3
	rename e9_3  d6c1_3
	rename e10_3  d6c2_3
	rename e4_6  d6f_3
	rename e4_6_1  d6g_3
	rename e5_6  d6h_3
	rename e7_4  d6b_4
	rename e8_4  d6c_4
	rename e9_4  d6c1_4
	rename e10_4  d6c2_4
	rename e4_14  d6f_4
	rename e4_14_1  d6g_4
	rename e5_14  d6h_4
	rename e7_5  d6b_5
	rename e8_5  d6c_5
	rename e9_5  d6c1_5
	rename e10_5  d6c2_5
	rename e4_11  d6f_5
	rename e4_11_1  d6g_5
	rename e5_11  d6h_5
	rename e7_6  d6b_6
	rename e8_6  d6c_6
	rename e9_6  d6c1_6
	rename e10_6  d6c2_6
	rename e4_7  d6f_6
	rename e4_7_1  d6g_6
	rename e5_7  d6h_6
	
	rename	(e3_4 e3_4_1)	(d6d_1	d6e_1)
	rename	(e3_5 e3_5_1)	(d6d_2	d6e_2)
	rename	(e3_6 e3_6_1)	(d6d_3	d6e_3)
	rename	(e3_14 e3_14_1)	(d6d_4	d6e_4)
	rename	(e3_11 e3_11_1)	(d6d_5	d6e_5)
	rename	(e3_7 e3_7_1)	(d6d_6	d6e_6)
	
	rename e11  d7_x
		rename e11_ch_1 d7_1
		rename e11_ch_2 d7_2
		rename e11_ch_3 d7_3
		rename e11_ch_4 d7_4
	rename e11_1  d7a
	rename e12_1  d7b_1
	rename e13_1  d7c_1
	rename e14_1  d7d_1
	rename e15_1  d7e_1
	rename e4_8  d7h_1
	rename e4_8_1  d7i_1
	rename e5_8  d7j_1
	rename e12_2  d7b_2
	rename e13_2  d7c_2
	rename e14_2  d7d_2
	rename e15_2  d7e_2
	rename e4_9  d7h_2
	rename e4_9_1  d7i_2
	rename e5_9  d7j_2
	rename e12_3  d7b_3
	rename e13_3  d7c_3
	rename e14_3  d7d_3
	rename e15_3  d7e_3
	rename e4_10  d7h_3
	rename e4_10_1  d7i_3
	rename e5_10  d7j_3
	
	rename	(e3_8 e3_8_1)	(d7f_1	d7g_1)
	rename	(e3_9 e3_9_1)	(d7f_2	d7g_2)
	rename	(e3_10 e3_10_1)	(d7f_3	d7g_3)
	
	rename	e16	d8
	rename e16_1  d8a
		rename e16_ch_1 d8_1
		rename e16_ch_2 d8_2
		rename e16_ch_3 d8_3
	rename e17_1  d8b_1
	rename e18_1  d8c_1
	rename e19_1  d8d_1
	rename e20_1  d8e_1
	rename e4_12  d8h_1
	rename e4_12_1  d8i_1
	rename e5_12  d8j_1
	rename e17_2  d8b_2
	rename e18_2  d8c_2
	rename e19_2  d8d_2
	rename e20_2  d8e_2
	rename e4_13  d8h_2
	rename e4_13_1  d8i_2
	rename e5_13  d8j_2
	
	rename	(e3_12 e3_12_1)	(d8f_1	d8g_1)
	rename	(e3_13 e3_13_1)	(d8f_2	d8g_2)

	rename f1  e1_x
	rename f2  e2_x
	rename f3  e3_x
	rename f4  e4_x
	rename f5  e5_x
	rename f5_1  e5a
	rename f5_2  e5b
	rename f5_3  e5c
	rename f5_4  e5d
	rename f5_5  e5e
	rename f6  e5f
	rename f7  e6_x
	rename f8  e7_x
	rename f9  e7a
	rename f10_ch_1 e8_1
	rename f10_ch_2 e8_2
	rename f10_ch_3 e8_3
	rename f10_ch_4 e8_4
	rename f10_ch_5 e8_5
	rename f11  e8a
	rename f12  e9_x
	rename f13  e9a
	rename f14  e9b
	rename f16  f1_x
	rename f16_1  f1a
	rename f16_2  f1b
	rename f16_3  f1c
	rename f16_4  f1d
	rename f16_5  f1e
	rename f16_6  f1f
	rename f22  f1g
	rename f23  f1h
	rename f24  f1i
	rename f25  f1j
	rename f17  f2_x
	rename f18  f3_x
	rename f20  f4_x
	rename f21  f5_x
	rename f26  f6_x
	rename f27  f7_x
	rename f28  f7a
	rename f29  f7b
	rename f34_1  f8_x
	rename f34_2  f9_x
	rename f30  f10a
	rename f31  f10b
	rename f32  f10c
	rename f33_4  f11a
	rename f33_3  f11b
	rename f33_2  f11c
	rename f33_1  f11d
	rename f35_1u  f12a
	rename f35_2u  f12b
	rename f35_3u  f12c
	rename f35_4u  f12d
	rename f35_1o  f13a
	rename f35_2o  f13b
	rename f35_3o  f13c
	rename f35_4o  f13d
	rename f38_ch_1 f14_1
	rename f38_ch_2 f14_2
	rename f38_ch_3 f14_3
	rename f38_ch_4 f14_4
	rename f38_ch_5 f14_5
	rename f38_ch_6 f14_6
	rename f38_ch_7 f14_7
	order	f14_1-f14_7, after(f13d)
	
	rename f38_1  f14a
	rename f38_2  f14b
	rename f38_3  f14c
	rename f38_4  f14d
	rename f38_5  f14e
	rename f38_6  f14f
	rename f36_v  f15_x
	rename f36_1_1  f16d
	rename f36_2_1  f16c
	rename f36_3_1  f16b
	rename f36_4_1  f16a
		order	f16a f16b f16c f16d, after(f15_x)
	rename f37_1  f17d
	rename f37_2  f17c
	rename f37_3  f17b
	rename f37_4  f17a
		order	f17a f17b f17c f17d, after(f16d)
	rename f44_v  f18_x
	rename f44_ch_1 f18a_1
	rename f44_ch_2 f18a_2
	rename f44_ch_3 f18a_3
	rename f44_ch_4 f18a_4
		order	f18a_1 f18a_2 f18a_3 f18a_4, after(f18_x)
	rename f39  g1_x
	rename f40  g2_x
	rename f41  g3_x
	rename f42  g4_x
	rename f43  g5_x
	rename d1_x d1
	rename d2_x d2
	rename d3_x d3
	rename d4_x d4
	rename d5_x d5
	rename d6_x d6
	rename d7_x d7
	rename e1_x e1
	rename e2_x e2
	rename e3_x e3
	rename e4_x e4
	rename e5_x e5
	rename e6_x e6
	rename e7_x	e7
	rename e9_x e9
	rename f1_x f1
	rename f2_x f2
	rename f3_x f3
	rename f4_x f4
	rename f5_x f5
	rename f6_x f6
	rename f7_x f7
	rename f8_x f8
	rename f9_x f9
	rename f15_x f15
	rename f18_x f18
	rename g1_x g1
	rename g2_x g2
	rename g3_x g3
	rename g4_x g4
	rename g5_x g5

	rename g10_?	i6_?
	rename g11		i7
	
	
	** Labeling variables
	label var  hfid	"Facility ID"
	label var  ownership	"Ownership"
	label var  time_start	"Time after consent"
	label var  time_end		"Time after the last question"
	lab	var	key				"SurveyCTO ID"
	lab	var	date			"Survey Date"
	lab	var	time			"Survey Time"
	
	label var  b1 "Are you..."
	label var  b1a "What is your name?"
		order	b1a, after(b1)
	label var  b1b "Are you the person who is in charge of this facility today? if a different person from listing"
	label var  b1c_1 "Respondent's job title includes: Clinical Officer"
	label var  b1c_2 "Respondent's job title includes: Community health worker"
	label var  b1c_3 "Respondent's job title includes: Dentist"
	label var  b1c_4 "Respondent's job title includes: Doctor or medical officer"
	label var  b1c_5 "Respondent's job title includes: Hospital administrator/executive director/superintendent"
	label var  b1c_6 "Respondent's job title includes: Intern/Student"
	label var  b1c_7 "Respondent's job title includes: Lab technologist/lab technician"
	label var  b1c_8 "Respondent's job title includes: Laboratory scientist"
	label var  b1c_9 "Respondent's job title includes: Midwife"
	label var  b1c_10 "Respondent's job title includes: Nurse (BSc, KRHCN or EHCN)"
	label var  b1c_11 "Respondent's job title includes: Nurse Aides"
	label var  b1c_12 "Respondent's job title includes: Nutritionist"
	label var  b1c_13 "Respondent's job title includes: Pharmacist/pharmacy technologist/dispenser"
	label var  b1c_14 "Respondent's job title includes: Public health officer (PHO)"
	label var  b1c_15 "Respondent's job title includes: Specialists (e.g., haemotologists, radiographers)"
	label var  b1c_16 "Respondent's job title includes: Therapist/counselor"
	label var  b1c_17 "Respondent's job title includes: Don't know"
	label var  b1c_18 "Respondent's job title includes: Recepcionist"
	
	order	b1c_? b1c_??, after(b1b)
	
	lab	define	typel	1	"Dispensary"	///
						2	"District Hospital"	///
						3	"Health Centre"	///
						4	"Maternity Home"	///
						5	"Medical Centre"	///
						6	"Medical Clinic"	///
						7	"National Referral Hospital"	///
						8	"Nursing home w/ maternity"	///
						9	"Nursing home w/o maternity"	///
						10	"Provincial General Hospital"	///
						11	"Sub-District Hospital"
	lab	value	c2	typel

	
	label var  c7_1 "Water source includes: No water source"
	label var  c7_2 "Water source includes: Piped water 24 hours"
	label var  c7_3 "Water source includes: Piped water less than 24 hours"
	label var  c7_4 "Water source includes: Clean tank water"
	label var  c7_5 "Water source includes: outside HF"
	label var  c7_6 "Water source includes: Unknown"
	order	c7_?, after(c6a)
	
	label var  c10_1 "Available phones at HF includes: Mobile phone (owned by HF)"
	label var  c10_2 "Available phones at HF includes: Functioning landline (owned by HF)"
	label var  c10_3 "Available phones at HF includes: Phone (owned by staff)"
	label var  c10_4 "Available phones at HF includes: No phone available"
	order	c10_?, after(c9b)
	
	label var  c11 "Does the facility own a functioning computer or laptop?"
	label var  c12 "If we want to send you information, could we send this to your email address? (if there is access to email or internet)"
	label var  c12b "Please specify you email"
	label var  d1 "Do you know that the boards/councils/MOH are conducting Joint Inspections where they inspect all departments at the same time?"
	label var  d2 "Have you ever seen the Joint Inspection Checklist that was gazetted by the government in 2012?"
	label var  d3 "In the last 12 months, did the boards/councils/MOH come to conduct a joint inspection of the entire HF with a Joint Inspections Checklist?"
	label var  d4 "In the last 12 months, did the health management team from the county, subcounty or both come to do any type of supervision?"
		lab	define	localgov	1	"County"	///
								2	"Subcounty"	///
								3	"Both"	///
								0	"None of the above"
		lab	val	d4	localgov		
	label var  d5_1 "Boards and councils inspections includes:  Clinical Officers Council (12 months)"
	label var  d5_2 "Boards and councils inspections includes:  Kenya Medical Laboratory Technicians and Technologists Board 12 months"
	label var  d5_3 "Boards and councils inspections includes:  Medical Practitioners and Dentists Board 12 months"
	label var  d5_4 "Boards and councils inspections includes:  Nursing Council of Kenya 12 months"
	label var  d5_5 "Boards and councils inspections includes:  Nutrition Council 12 months"
	label var  d5_6 "Boards and councils inspections includes:  Pharmacy and Poisons Board 12 months"
	label var  d5_7 "Boards and councils inspections includes:  Public Health Technologists Board 12 months"
	label var  d5_8 "Boards and councils inspections includes:  Radiation Protection Board 12 months"
	label var  d5_9 "Boards and councils inspections includes:  Do not remember which one(s) came 12 months"
	label var  d5_10 "Boards and councils inspections includes:  None of the above 12 months"
	order	d5_?	d5_10, after(d5)
	drop	d5

	label var  d6	"Which of the following social franchises are you an active member of?"
		lab	define	socialfranchises	1	"Tunza (Population Services International)"	///
										2	"AMUA (Marie Stopes International)"	///
										3	"CFW Shops (HealthStore Foundation)"	///
										4	"Gold Star (FHI 360)"	///
										5	"Huduma Poa Health Network (Kisumu Medical and Education Trust)"	///
										6	"Other, please specify"	///
										0	"Not part of a social franchise"
		lab	value	d6	socialfranchises
	
	label var  d6c_1	"Do you send periodic information to Tunza about your health facility?"
	label var  d6c_2	"Do you send periodic information to AMUA about your health facility?"
	label var  d6c_3	"Do you send periodic information to CFW Shops about your health facility?"
	label var  d6c_4	"Do you send periodic information to Gold Star about your health facility?"
	label var  d6c_5	"Do you send periodic information to Huduma Poa Health Network about your health facility?"
	
	label var  d6b_6 "Which year did you become part of other social franchise?"
	label var  d6c_6 "Do you send periodic information to that franchise about your health facility?"
	label var  d6c1_6 "How often do you send information?"
	label var  d6c2_6 "Select the units: months/years"
	label var  d6d_6 "When was the last time the other social franchise came?"
	label var  d6e_6 "Enter the year"
	label var  d6f_6 "How much time did the other socialfranchise spend in the last visit?(hours)"
	label var  d6h_6 "How often does other social franchise come ? (months)"
	
	
	label var  d7 "Is your health facility accredited by any of the following accreditation agencies?"
	label var  d7_1 "Accreditation includes: National Hospital Insurance Fund (NHIF)"
	label var  d7_2 "Accreditation includes: Safecare"
	label var  d7_3 "Accreditation includes: Other, please specify"
	label var  d7_4 "Accreditation includes: Not accredited"
	label var  d7a "Accreditation: Other, please specify"
	order	d7_1-d7_4, before(d7a)
	
	label var  d7b_3 "Which year did you obtain accreditation from other agency?"
	label var  d7f_3 "When was the last time the other agency came?"
	label var  d7h_3 "How much time did  the other agency spend in the last visit?"
	label var  d7j_3 "How often does the other agency come? (months)"
	
	lab	define	d8	0	"Not accredited"	///
					1	"KENAS"	///
					2	"Other, please specify"
	lab	val	d8	d8
	
	label var  d8_1 "Lab accreditation includes: KENAS "
	label var  d8_2 "Lab accreditation includes: Other accreditation agency "
	label var  d8_3 "Lab accreditation includes: Not accredited"
	order	d8_1 d8_2 d8_3, after(d7j_3)
	
	label var  d8a "Lab accreditation includes: other, please specify"
	label var  d8b_1 "In which year did you obtain accreditation from KENAS?"
	label var  d8c_1 "Do you send periodic information to this accrediting agency about the laboratory?"
	label var  d8j_1 "How often does KENAS come? (months)"
	label var  d8b_2 "In which year did you obtain accreditation from other lab agency?"
	label var  d8f_2 "When was the last time the other lab agency came?"
	label var  d8h_2 "How much time did the other lab agency spend in the last visit? (hours)"
	label var  d8j_2 "How often does the other lab agency come? (months)"

	label var  e8_1 "Performance Indicators includes: Infant mortality"
	label var  e8_2 "Performance Indicators includes: Maternal mortality"
	label var  e8_3 "Performance Indicators includes: Immunization"
	label var  e8_4 "Performance Indicators includes: Notifiable diseases"
	label var  e8_5 "Performance Indicators includes: None of the above"
	order	e8_1-e8_5, after(e7a)
	
	label var  f11a "No. of outpatients: November 2014 (if MOH 717 form or own books available)"	
	label var  f11b "No. of outpatients: December 2014 (if MOH 717 form or own books available)"	
	label var  f11c "No. of outpatients: January 2015 (if MOH 717 form or own books available)"	
	label var  f11d "No. of outpatients: February 2015 (if MOH 717 form or own books available)"
	order	f11a f11b f11c f11d, after(f10c)
	label var  f12a "No. of outpatients under 5: November 2014 (if over 5 under 6 books are available)"	
	label var  f12b "No. of outpatients under 5: December 2014 (if over 5 under 6 books are available)"	
	label var  f12c "No. of outpatients under 5: January 2015 (if over 5 under 6 books are available)"	
	label var  f12d "No. of outpatients under 5: February 2015 (if over 5 under 6 books are available)"	
	label var  f13a "No. of outpatients over 5: November 2014"	
	label var  f13b "No. of outpatients over 5: December 2014"	
	label var  f13c "No. of outpatients over 5: January 2015"	
	label var  f13d "No. of outpatients over 5: February 2015"	

	label var  f14_1 "Lab services includes: Malaria blood smear"
	label var  f14_2 "Lab services includes: Stool O/C"
	label var  f14_3 "Lab services includes: Tuberculosis (Sputum test for AFB)"
	label var  f14_4 "Lab services includes: Urinalysis"
	label var  f14_5 "Lab services includes: Brucella"
	label var  f14_6 "Lab services includes: Blood type"
	label var  f14_7 "Lab services includes: None of the above"
	
	label var  f14a "Lab prices: Malaria blood smear"
	label var  f14b "Lab prices: Stool O/C"
	label var  f14c "Lab prices: Tuberculosis (Sputum test for AFB)"
	label var  f14d "Lab prices: Urinalysis"
	label var  f14e "Lab prices: Brucella"
	label var  f14f "Lab prices: Blood type"
	label var  f15  "Does the facility have records on lab patients and lab tests performed?"
	label var  f16a "# of patients received lab test: November 2014"
	label var  f16b "# of patients received lab test: December 2014"
	label var  f16c "# of patients received lab test: January 2015"
	label var  f16d "# of patients received lab test: February 2015"
	label var  f17a "# of lab tets received: November 2014"
	label var  f17b "# of lab tets received: December 2014"
	label var  f17c "# of lab tets received: January 2015"
	label var  f17d "# of lab tets received: February 2015"
	
	
	label var  f18 "Were there any months where the lab was partially operating or not operating, in the 4 months for which information is requested for?"
	label var  f18a_1 "Partially/not operating lab includes: November 2014"
	label var  f18a_2 "Partially/not operating lab includes: December 2014"
	label var  f18a_3 "Partially/not operating lab includes: January 2015"
	label var  f18a_4 "Partially/not operating lab includes: February 2015"
	
	
	label var  g1 "Is there a service contract for maintenance?"
	label var  g2 "Is there a written schedule (including next service date) for maintaining equipment?"
	label var  g3 "Is there a written calibration schedule available at the area where equipment is used?"
	label var  g4 "Is there a document showing regular calibration?"
	label var  g5 "Are contracts available at the facility administration?"
	label var  h1 "Does the owner of this health facility work in this health facility part time or full time?"
	label var  h2a "How many staff, NOT INCLUDING THE OWNER, work in this health facility, paid or unpaid, part time or full time? "
	label var  h2b "How many staff work in this health facility, paid or unpaid, part time or full time?"
	
	label var  i5_1 "Language used during the survey includes: English"
	label var  i5_2 "Language used during the survey includes: Swahili"
	label var  i5_3 "Language used during the survey includes: Mijikenda"
	label var  i5_4 "Language used during the survey includes: Kimeru"
	label var  i5_5 "Language used during the survey includes: Luhya"
	label var  i5_6 "Language used during the survey includes: Other languages"	
	order	i5_1 i5_2 i5_3 i5_4 i5_5 i5_6, after(i4a)

	lab var i6_1	"% of survey completed: in English"
	lab var i6_2	"% of survey completed: in Swahili"
	lab var i6_3	"% of survey completed: in Mijikenda"
	lab var i6_4	"% of survey completed: in Kimeru"
	lab var i6_5	"% of survey completed: in Luhya"
	lab var i6_6	"% of survey completed: in Other languages"
	
	order	latitude longitude hfid	hfname county subcounty location sublocation level ownership date	time	time_start time_end	supervisorid	supervisorname	enumeratorid	enumeratorname
	
	* Drop more variables after re-naming and re-labling is done
	drop	d7 f18 speedviolcount speedviollist g9_ch_1 g9_ch_2 g9_ch_3 g9_ch_4 g9_ch_5 g9_ch_6 g9_ch_7 g9_ch_8 g9_ch_9 g9_ch_10 g9_ch_11 ///
			g9_ch_12 g9_ch_13 g9_ch_14 g9_ch_15 g24_v	time_start_d time_end_d time_start_e time_end_e time_start_f time_end_f ///
			time_start_g time_end_g /*faith_c*/	 patients labtest h2_total	///
			f36_t1_1 f37_t2  f37_1_c  f37_2_c  f37_3_c  f37_4_c  f37_s  f37_s_v  f37_1_c2  f37_2_c2  f37_3_c2  f37_4_c2   f36_1_c_1 f36_2_c_1 f36_3_c_1 f36_4_c_1 f36_s_1 ///
			f36_1_c_4 f36_2_c_4 f36_3_c_4 f36_4_c_4 f36_s_total f36_s_v_1 f36_t2_1 f37_t1	///
			f33_t1	f33_t2	f33_1_c f33_2_c f33_3_c f33_4_c f33_s f33_4_s_v f35_t1	f35_1u_c f35_2u_c f35_3u_c f35_4u_c f35_u_s f35_u_s_v ///
			f35_t2 f35_1o_c f35_2o_c f35_3o_c f35_4o_c f35_o_s f35_o_s_v	g9	respondentname

	
	
	* Clean value lables
	
		* Create macros for each type of variables
		qui	ds	*
		global	allvars	`r(varlist)'
		
		global	excludevars	latitude	longitude	hfid	hfname	location	sublocation	date	time	time_start	time_end	supervisorid	supervisorname	enumeratorid	enumeratorname	///
							a2	a2a	a2d	a3	a4	a5	b1	b1a	c1a	c9b	c10b	c12b	d5a_4	d5b_4	d5c_4	d6a	d6c2_1	d6g_1	d6c2_2	d6g_2	d6c2_3	d6g_3	d6c2_4	///
							d6g_4	d6c2_5	d6g_5	d6c2_6	d6g_6	d7a	d7e_1	d7i_1	d7e_2	d7i_2	d7e_3	d7i_3	d8a	d8e_1	d8i_1	d8e_2	d8i_2	f7b	///
							i1a	i2a	i3a	i4a	key

		qui	ds	a2b	a6	a7	b1b	b1c_?	b1c_??	c1	c5	c7_?	c10_?	c11	c12		d1	d2	d5_?	d5_10	///
				d6c_?	d7_?	d8_?	e1	e2	e3	e4	e5	e5a	e5b	e5c	e5d	e5e	e5f	e6	e7	e7a	e8_?	///
				e8a	e9	e9a	e9b	f1	f1a	f1b	f1c	f1d	f1e	f1g	f1h	f1i	f1j	f3	f4	f5	f6	f7	f10a	f10b	f10c	f14_?	///
				f18a_1	f18a_2	f18a_3	f18a_4	///
				g1	g2	g3	g4	g5	h1	i5_1	i5_2	i5_3	i5_4	i5_5	i5_6
		global	dummyvars	`r(varlist)'
		
		global	categoryvars	county	subcounty	level	ownership	a2c	c2	c6	c8	c9a	c12a	d3	d4	d5a_1	d5a_2	d5b_1	d5b_2	d5c_1	d5c_2	///
								d6	d6b_1	d6d_1	d6e_1	d6h_1	d6b_2	d6d_2	d6e_2	d6h_2	d6b_3	d6d_3	d6e_3	d6h_3	d6b_4	///
								d6d_4	d6e_4	d6b_5	d6d_5	d6e_5	d6h_5	d6d_6	d6e_6	d6h_6	d7b_1	d7f_1	d7g_1	d7j_1	d7b_2	///
								d7c_1	d7c_2	d7c_3	d7f_2	d7g_2	d7j_2	d7b_3	d7f_3	d7g_3	d7j_3	d8	d8b_1	d8c_1	d8c_2	d8f_1	d8g_1	d8j_1	d8b_2	d8f_2	d8g_2	d8j_2	///
								f1f	f15	i1	i2	i3	i4	i6_1	i6_2	i6_3	i6_4	i6_5	i6_6	i7

		global	coutinuousvars	c3	c4	c5a	c6a	c10a	d5a_3	d5a_5	d5b_3	d5b_5	d5c_3	d5c_5	d6c1_1	d6f_1	d6c1_2	d6f_2	///
								d6c1_3	d6f_3	d6c1_4	d6f_4	d6h_4	d6c1_5	d6f_5	d6b_6	d6c1_6	d6f_6	d7d_1	d7h_1	d7d_2	d7h_2	///
								d7d_3	d7h_3	d8d_1	d8h_1	d8d_2	d8h_2	f7a	f8	f9	f11d	f11c	f11b	f11a	f12a	f12b	f12c	///
								f12d	f13a	f13b	f13c	f13d	f14a	f14b	f14c	f14d	f14e	f14f	f16a	f16b	f16c	f16d	f17a	f17b	f17c	f17d	h2a	h2b

			
		* Assign unique "yesno" label to all dummy vars
		lab	define	yesno	0	"No"	1	"Yes"	-99	"Don't know"
		foreach	dummyvar	of	global	dummyvars	{
			cap	lab	drop	`dummyvar'
			lab	val	`dummyvar'	yesno
		}
		*

		*Replacing all the missing -99 by missing // Double check
		foreach var of varlist * {
		capture confirm string var `var'
		
		if _rc != 0 {
			replace `var' =.d if inlist(`var',-9,-99,99)
		}
		
		else { 
			replace `var' = "Don't Know" if inlist(`var',"-99","_99","-98")
		}
		
	}	
		
	* Eliminating additional variables that do not make sense once the profile information and the pre-loaded data have been merged (confirming names from the pre-loaded data)
	drop a2 a2b a2c a2d a2a a3 c1 c1a b1
	
	* Dropping variables which exist in staff roster data
	drop	h1 h2a h2b

********************************************************************************

	** Part X: Save & Exit

********************************************************************************

	
	* Save identified data
	
		* Make dta
		notes	drop _dta
		notes:	QPS1_clean_pii / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of QPS1 survey

		/* Git branch info
		stgit9 
		notes : QPS1_clean_pii / Git branch `r(branch)'; commit `r(sha)'.
			
		compress
		
		
		save	"${qps1_clean_pii}", replace
		
		
		*/

	* Save anonymized data
		*use	"${qps1_clean_pii}", clear
	
		* Merge with the inventory data to have alternate ID.
		merge	1:1	hfid	using	"${profile_bl}", keepusing(hfid_m) assert(2 3) keep(3) nogen
		order	hfid_m, after(hfid)
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
		
		* List of PII
		loc	PII	latitude longitude hfname location sublocation a4 a5 c12b
		drop	`PII'
		
		* additional to drop
		
		drop supervisorname enumeratorname b1a 
	
		* Make dta
		notes	drop _dta
		notes:	QPS1_clean_nopii / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of QPS1 survey, anonymized to be published.

		/* Git branch info
		stgit9 
		notes : QPS1_clean_nopii / Git branch `r(branch)'; commit `r(sha)'.
		*/
		/* Generate dictionary
		
		preserve
			tempfile dictionarydta
			descsave, saving(`dictionarydta', replace)
			
			use	`dictionarydta', clear
			drop order format vallab
			
			export excel using "${qps1_clean_nopii_dic}", firstrow(varlabels) replace
		restore
		*/

		* Save

			save	"${qps1_bl}", replace
		*
		
	/*

	* Variable tabulation
		
	use	"${qps1_cleaned}", clear
	
	cap log close
	
	log using	"${bl_do}/Cleaning/logs/variable_tabulation_QPS1", replace
	
	
	foreach var of global allvars	{
		loc	varlab:	variable	label	`var'
		di "Variable: `var', `varlab'"
		loc	in_exclude:			list	posof	"`var'"	in	global(excludevars)
		loc	in_dummy:			list	posof	"`var'"	in	global(dummyvars)
		loc	in_category:		list	posof	"`var'"	in	global(categoryvars)
		loc	in_continuous:		list	posof	"`var'"	in	global(coutinuousvars)

		
		if	`in_exclude'!=0	{
			di	"`var'	is excluded from the tabulation"
		}
		else	if	`in_dummy'!=0	{
			tab1	`var'
		}
		else	if	`in_category'!=0	{
			tab1	`var'
		}
		else	if	`in_continuous'!=0	{
			tabstat `var', s(n mean min max) format(%10.2fc)
		}
		di ""
	}
	*
	
	log	close
	
	exit
*/
	* Dismount
	veracrypt, dismount drive("${mount}") 
	