	/*****************************************************************
	PROJECT: 		KePSIE, Kenya Patient Safety Impact Evaluation
					
	TITLE:			Clean_helper_microdata_catalog.do
				
	AUTHOR: 		Rebecca de Guttry [rdeguttry@worldbank.org], based on code by Tatiana Zarate
				
	DATE CREATED:	Sep 11, 2017

	LAST EDITED:	Sep 12, 2017, by Rebecca de Guttry [rdeguttry@worldbank.org]

	DESCRIPTION: 	This do-file cleans the staff roster helper for publishing on WB Microdata Catalog.
		
	ORGANIZATION:	0 -	Preamble
					1 -	Basic cleaning
					2 - Save 
						2.1. Merge with listing for updated HF information 
						2.2. Save full clean dataset
						2.3. Save anonymzed clean dataset


	INPUTS: 		* Raw helper data	
						"${KePSIE_DB}/DataAnalysis/Baseline/RawData/Helper_Roster_final.dta"	
					* Listing data
						"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017"

	OUTPUTS: 		* Cleaned full roster helper data
						"${bl_out}/DataSets/Final/HCW_Roster_Helper_clean_pii.dta"

					* Cleaned anonymized roster helper data, to be published to the micro data catalog
						"${bl_out}/DataSets/Final/HCW_Roster_Helper_clean_nopii.dta"		
						
					* Dictionary of anonymized data
						"${bl_out}/DataSets/Final/HCW_Roster_Helper_clean_nopii_dictionary.xls"


	NOTE:			*	The helper survey is filled out and submitted for those facilities with more than 15 staff.
						In these facilities, only a subsample of staff are surveyed. The helper survey first asks 
						the enumerator to provide the total number of staff per cadre working in the HF. 
						Then, it returns the total number of staff per cadre on which to collect data.
										
	******************************************************************/
 
 
 
	/****************************************************************
		** Part 0: Preamble			 									
	****************************************************************/	
		
	* Input files
	glo qps1_helper_bl_raw 		"${volume}/qps1_helper_bl_raw.dta"	
	glo profile_bl				"${dt_mast}/profile_bl.dta"
	
	* Output files
	glo qps1_helper_bl			"${dt_bl_clean}/qps1_helper_bl.dta"
	
	/****************************************************************
		** Part 1: Basic cleaning			 									
	****************************************************************/	

	clear all
	
	* Mount veracrypt drive
	veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	
	use "${qps1_helper_bl_raw}",clear
	
	* Keep only necessary variables 
	keep 	a5  c1	c3_*_c c3_s_v co_final	mo_final	hospitaladmin_final	labsci_final ///	
			labtech_final	pharm_final	specialist_final	chw_final	den_final	intern_final ///
			mw_final	nutri_final	pho_final	ther_final	clinicaloth_final	supportoth_final ///
			adminoth_final	nurse_bsc_final	nurse_r_final	nurse_e_final nurse_a_final c3_s ///
			key starttime endtime

	/* Drop an observation related to a HF visited in June, when there was a partial refusal 
	   (the HF was then visited again in July and gave permission to complete the QPS1, 
	   so we only need to preserve the last survey) */
	drop if key == "uuid:8422f5e0-57ec-494a-aad6-abdf0a5a430b"
	
	* Correct for a survey where the enumerator entered the wrong HF ID (should have been 16038 and not 15955)
	replace a5 = 16038 if key == "uuid:2e9be125-dc84-4574-b942-47d60d1e5f0c"

	* Destrig various variables
	foreach var in	c3_s  c3_*_c co_final  mo_final  hospitaladmin_final  labsci_final  ///
					labtech_final  pharm_final  specialist_final  chw_final  den_final	///
					intern_final  mw_final  nutri_final  pho_final  ther_final  		///
					clinicaloth_final  supportoth_final  adminoth_final					///
					nurse_bsc_final  nurse_r_final  nurse_e_final  nurse_a_final	{
		destring `var', replace
	}
	*
	
	* Rename variables	
	rename a5		hfid
	rename c1		b1
	rename c3_1_c	b2a
	rename c3_2_c 	b2b
	rename c3_20_c 	b2c
	rename c3_6_c 	b2d
	rename c3_3_c 	b2e
	rename c3_4_c 	b2f
	rename c3_5_c 	b2g
	rename c3_7_c 	b2h
	rename c3_16_c 	b2i
	rename c3_17_c 	b2j
	rename c3_18_c 	b2k
	rename c3_8_c 	b2l
	rename c3_9_c 	b2m
	rename c3_10_c 	b2n
	rename c3_11_c 	b2o
	rename c3_12_c 	b2p
	rename c3_13_c 	b2q
	rename c3_14_c 	b2r
	rename c3_21_c 	b2s
	rename c3_15_c 	b2t
	rename c3_19_c 	b2u
	rename c3_s 	b2_total
	rename c3_s_v 	b2_total_v
	
	lab var hfid "Facility ID"
	lab var b1 	"Owner works in the health facility part-time or full-time"
	lab var b2a "Clinical officers (total)"
	lab var b2b "Community health workers (total)"
	lab var b2c "Dentists (total)"
	lab var b2d "Doctors, medical officers (total)"
	lab var b2e "Hospital administrators, executive directors, superintendents (total)"
	lab var b2f "Interns, students (total)"
	lab var b2g "Medical laboratory scientists (total)"
	lab var b2h "Medical laboratory technologists / technicians (total)"
	lab var b2i "Midwives (total)"
	lab var b2j "BSc nurses (total)"
	lab var b2k "Registered community health nurses (KRHCN) (total)"
	lab var b2l "Enrolled community health nurses (EHCN) (total)"
	lab var b2m "Nurse aides (total)"
	lab var b2n "Nutritionists (total)"
	lab var b2o "Pharmacists, pharmacy technologists (total)"
	lab var b2p "Public health officers (PHO) (total)"
	lab var b2q "Specialists (e.g., radiographers, haematologists) (total)"
	lab var b2r "Therapists, counselors (total)"
	lab var b2s "Other clinical staff (total)"
	lab var b2t "Other administrative staff (total)"
	lab var b2u "Other support staff (total)"
	lab var b2_total "Total staff (calculated sum of all categories)"
	lab var b2_total_v "Verification of total number of staff"
	

	rename co_final 			b2a_f
	rename chw_final			b2b_f
	rename den_final	 		b2c_f
	rename mo_final 			b2d_f
	rename hospitaladmin_final 	b2e_f
	rename intern_final	 		b2f_f
	rename labsci_final 		b2g_f
	rename labtech_final 		b2h_f
	rename mw_final 			b2i_f
	rename nurse_bsc_final 		b2j_f
	rename nurse_r_final		b2k_f
	rename nurse_e_final 		b2l_f
	rename nurse_a_final 		b2m_f
	rename nutri_final 			b2n_f
	rename pharm_final 			b2o_f
	rename pho_final 			b2p_f
	rename specialist_final 	b2q_f
	rename ther_final 			b2r_f
	rename clinicaloth_final 	b2s_f
	rename adminoth_final 		b2t_f
	rename supportoth_final 	b2u_f


	lab var b2a_f "Clinical officers (to be sampled, calculated)"
	lab var b2b_f "Community health workers (to be sampled, calculated)"
	lab var b2c_f "Dentists (to be sampled, calculated)"
	lab var b2d_f "Doctors, medical officer (to be sampled, calculated)"
	lab var b2e_f "Hospital administrators / executive directors / superintendents (to be sampled, calculated)"
	lab var b2f_f "Interns, students (to be sampled, calculated)"
	lab var b2g_f "Medical laboratory scientists (to be sampled, calculated)"
	lab var b2h_f "Medical laboratory technologists / technicians (to be sampled, calculated)"
	lab var b2i_f "Midwives (to be sampled, calculated)"
	lab var b2j_f "BSc nurses (to be sampled, calculated)"
	lab var b2k_f "Registered community health nurses (KRHCN) (to be sampled, calculated)"
	lab var b2l_f "Enrolled community health nurses (EHCN) (to be sampled, calculated)"
	lab var b2m_f "Nurse aides (to be sampled, calculated)"
	lab var b2n_f "Nutritionists (to be sampled, calculated)"
	lab var b2o_f "Pharmacists, pharmacy technologists (to be sampled, calculated)"
	lab var b2p_f "Public health officers (PHO) (to be sampled, calculated)"
	lab var b2q_f "Specialists (e.g., radiographers, haematologists) (to be sampled, calculated)"
	lab var b2r_f "Therapists, counselors (to be sampled, calculated)"
	lab var b2s_f "Other clinical staff (to be sampled, calculated)"
	lab var b2t_f "Other administrative staff (to be sampled, calculated)"
	lab var b2u_f "Other support staff (to be sampled, calculated)"
		
	rename	starttime time_start
	rename	endtime time_end
	
	lab var time_start 	"Start time"
	lab var time_end		"End time"
	
	global t_staff		b1 b2a	b2b	b2c	b2d	b2e	b2f	b2g	b2h	b2i	b2j	b2k	b2l	b2m	b2n	b2o ///
						b2p	b2q	b2r	b2s	b2t	b2u b2_total b2_total_v
	global f_staff		b2a_f b2d_f	b2e_f b2g_f	b2h_f b2o_f	b2q_f b2b_f	b2c_f b2f_f	b2i_f b2n_f ///
						b2p_f b2r_f	b2s_f b2u_f	b2t_f b2j_f	b2k_f b2l_f b2m_f
	global a_info		key
	
	order hfid $t_staff $f_staff $a_info time_start time_end

********************************************************************************
	** Part 2: Save 
********************************************************************************

	*-----------------------------------------------------------------*
	* 2.1. Merge with listing for updated HF information 
	*-----------------------------------------------------------------*

		* Prepare listing for merging
		preserve 
			use "$profile_bl", clear
			keep latitude	longitude	hfid 	hfid_m 	hfname	county	subcounty	location	sublocation 	level 	ownership 	market_all  
			tempfile listing 
			save `listing'
		restore
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
		
		* Merge with listing
		merge m:1 hfid using `listing', assert(2 3) keep(3) nogen

		* Order identifying variables first
		order hfid 	hfid_m 	hfname	county	subcounty	location	sublocation	level	ownership market_all, first
		
	*-----------------------------------------------------------------*
	* 2.2. Save full clean dataset
	*-----------------------------------------------------------------*
	/*
		* Make dta
		notes	drop _dta
		notes:	QPS1_cleaned_nopii_${date} / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of staff roster helper survey.
		
		* Save
		if		c(stata_version)>=14	{
				saveold	"$helper_clean_pii", v(13) replace
		}
		else	{	
			save "$helper_clean_pii", replace
		}
		
		*/
	*-----------------------------------------------------------------*
	* 2.3. Save anonymzed clean dataset
	*-----------------------------------------------------------------*
	
		* Drop identifying information
		drop hfname location sublocation latitude longitude  market_all // hfid
		
		/*
		* Make dta
		notes	drop _dta
		notes:	QPS1_cleaned_nopii_${date} / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of staff roster helper survey, anonymized to be published.
		*/
		* Save

			save "${qps1_helper_bl}", replace
	
	/*-----------------------------------------------------------------*
	* 2.3. Generate dictionary
	*-----------------------------------------------------------------*
	
		descsave, saving("${bl_out}/Helper_clean_nopii_dictionary.dta", replace)
		
		use	"${bl_out}/Helper_clean_nopii_dictionary.dta", clear
		drop order format vallab
		
		export excel using "$helper_clean_nopii_dictionary", firstrow(varlabels) replace
		erase	"${bl_out}/Helper_clean_nopii_dictionary.dta"
		*/
		
	* Dismount
	veracrypt, dismount drive("${mount}") 
		