/*******************************************************************************	
*		Project: KePSIE
*		Last udpate: March 10, 2016
********************************************************************************			

** PURPOSE: 	This do-file cleans the QPS2 dataset

** OUTLINE:		Part 0. Paths
				Part 1. Revises and cleans QPS2
				Part 2. Creates Checklist groups
				Part 3. Generates descriptive statistics table
				
** INPUTS:     	QPS2_final.dta

** OUTPUTS:     QPS2_clean_$date.dta

** Written by: Amy Dolinger & Tatiana Zarate

*******************************************************************************/

*---------------------------------------------------------------------------------------------
* Part 0. Paths
*---------------------------------------------------------------------------------------------

glo qps2_bl_raw 	"${volume}/qps2_bl_raw.dta"
glo qps2_bl_q		"${doc_bl}/codebooks/qps2_bl_equestionnaire.xlsx"
glo qps2_bl 		"${dt_bl_clean}/qps2_bl.dta"

clear all
drop _all
set more off, permanently
set matsize 10000

*---------------------------------------------------------------------------------------------- 
* Part 1. Revises and cleans QPS2
*---------------------------------------------------------------------------------------------- 
* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")


use "${qps2_bl_raw}", clear
sort a5

* Split select_multiple questions

qui {
cap prog drop splitmult
prog def splitmult

syntax anything using
	import excel `using', clear first
	keep if regexm(type,"^select_multiple")
	count
	local nQuestions = `r(N)'
	forvalues i = 1/`nQuestions' {

		import excel `using', clear first
			keep if regexm(type,"^select_multiple")

			local theName = name[`i']
			local theChoices = type[`i']
				local theChoices = regexr("`theChoices'","select_multiple ","")
			
		import excel `using', clear first sheet("choices")
			keep if list_name == "`theChoices'"
			
			count
			local nChoices = `r(N)'
			
			forvalues j = 1/`nChoices' {
			
				local theNextLabel = label[`j']
				local theNextValue  = name[`j']
			
				local `theName'L `" ``theName'L' "`theNextLabel'" "'
				local `theName'V ``theName'V' `theNextValue'
				
				}
				
		use `anything', clear
			
			forvalues j = 1/`nChoices' {
				
				local theNextLabel : word `j' of ``theName'L'
				local theNextValue : word `j' of ``theName'V'
				
				cap tostring `theName', replace
				
				cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
					cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
					cap label var `theName'_ch_`j' "`theNextLabel'"
					
				}
				
			save `anything', replace
				
		}
		
end
}


tempfile split
save `split', replace
splitmult `split' using "${qps2_bl_q}" 
save `split', replace

* Rename key vars
	
	rename a10 enumeratorid
	rename a10_c enumname
	rename a6 supervisorid
	rename a6_c supname
	rename a1latitude lat
	rename a1longitude lon
	rename pri_string private
	
* Destring

	replace private = "0" if private=="public"
	replace private = "1" if private=="private"
	destring private, replace
	replace level = "2" if level=="Level 2"
	destring level, replace
	destring facilitycode, replace
	destring s10b_g2_c, replace

* Drop duplicates

	duplicates tag a5, gen(tag2)
	replace a5=900846 if facilitycode==900846
	drop if a5==11424 & enumeratorid==28
	drop if a5==11977 & key=="uuid:926ff6b0-6c1a-4130-b024-ea3f354f2f4b"
	drop if a5==12097 & key=="uuid:e0516275-2cf7-4a79-944d-9d3557d7cb28"
	drop if a5==15807 & key=="uuid:edd2cf2b-29a8-4bc8-8b15-a0f59ac52653"
	drop if a5==18624 & key=="keyuuid:551e3423-7a47-4314-86c3-6cf046a36f99"
	drop if a5==900142 & key=="uuid:f1b325e7-b3c7-4bf5-ae76-73bb089463aa"
	drop if a5==900600 & key=="uuid:cc1d3ea6-57a1-4aac-8637-ed3f9cfd1748"
	drop tag2 
	drop if a9==0
	// Update Dec2015: QPS2 was completed on 17-Jun-2015 and QPS1 was completed on 01-Dec-2015 based on the raw data, so we don't need to dropp it from the database
	drop if a5==18700 | a5==800028 //| a5==900462 
	drop if a5==900899
	
* Format date

	gen date1 = date(date,"DMY")
	format date1 %td
	drop date
	rename date1 date
	
* Generate county as numerical value

	gen county_n =1 if county == "Kakamega" 
	replace county_n = 2 if county == "Kilifi"
	replace county_n = 3 if county == "Meru"
	drop county
	rename county_n county
	lab define countyl 1 "Kakamega" 2 "Kilifi" 3 "Meru"
	lab val county countyl

* Drop temporarily 

	local surveyrel deviceid subscriberid simid devicephonenum key formdef_version audio v121 v148 v181 v185 v245 v275 v339 v425 v488 v629 v245 v275 v339 v425 v470 v488 v567 v470 v629 v642 v567
	local datetime a2_1 a2_3 time f9_1 f9_2 a2_2 a2_4 starttime endtime submissiondate
	local lonlat a1_cal a1_v a1altitude a1accuracy f10latitude f10longitude f10altitude f10accuracy f10_2 f10_c 
	local verify a7 a11 a12
	local nocode a4 a4_pri a4_1 a4_county a4_level pri
	local ipc_policies s2c_1 s2c_2 s2c_3 s2c_4 s2c_5 s2c_6 s2c_7 s2c_8 s2c_2_ch_1 s2c_2_ch_2 s2c_2_ch_3 s2c_2_ch_4 s2c_2_ch_5 s2c_2_ch_6 s2c_3_ch_1 s2c_3_ch_2 s2c_3_ch_3 s2c_3_ch_4 s2c_3_ch_5 s2c_3_ch_6
	drop `surveyrel' `datetime' `lonlat' `verify' `nocode' `ipc_policies'

*---------------------------------------------------------------------------------------------- 
* Part 1a. Building Checklist vars, when different from QPS2
*---------------------------------------------------------------------------------------------- 

* These vars have an additional/third option in QPS2 so building yes/no vars
	
global thirdoption s1b_5 s2a_8 s2a_9 s2a_10 s2a_15
foreach var of varlist $thirdoption {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==2 | `var'_other==0
}
	label var s1b_5 "Are clean toilets available for both male and female clients?"
	label var s2a_8 "Is the paint work acceptable?"
	label var s2a_9 "Is the floor smooth?"
	label var s2a_10 "Is the ceiling free of cobwebs and dust?"
	label var s2a_15 "Is the site free of odor?"
	
global nograss s2a_13 s2a_14
foreach var of varlist $nograss {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==0
	replace `var'=. if `var'_other==2
}
	label var s2a_13 "Is the grass well maintained?"
	label var s2a_14 "Are the bushes neatly kept?"
	
* These are the Likert scale questions. Building separate yes/no vars for each option choice.
	
global satisfactory s1a_7 s1a_8 s2a_7 s7a_1 s7a_2
foreach var of varlist $satisfactory {

	gen `var'_ch_1 = .
	replace `var'_ch_1 = 1 if `var'==4
	replace `var'_ch_1=0 if `var'==1 | `var'==2 | `var'==3
	gen `var'_ch_2 = .
	replace `var'_ch_2 = 1 if `var'==3
	replace `var'_ch_2=0 if `var'==1 | `var'==2 | `var'==4
	gen `var'_ch_3 = .
	replace `var'_ch_3 = 1 if `var'==2
	replace `var'_ch_3=0 if `var'==1 | `var'==3 | `var'==4
	gen `var'_ch_4 = .
	replace `var'_ch_4 = 1 if `var'==1
	replace `var'_ch_4=0 if `var'==2 | `var'==3 | `var'==4
}

	label var s1a_7_ch_1 "Ventilation: Very Dissatisfactory"
	label var s1a_7_ch_2 "Ventilation: Dissatisfactory"
	label var s1a_7_ch_3 "Ventilation: Satisfactory"
	label var s1a_7_ch_4 "Ventilation: Very Satisfactory"
	label var s1a_8_ch_1 "Lighting: Very Dissatisfactory"
	label var s1a_8_ch_2 "Lighting: Dissatisfactory"
	label var s1a_8_ch_3 "Lighting: Satisfactory"
	label var s1a_8_ch_4 "Lighting: Very Satisfactory"
	
* Building new vars for (a) color-coded bins and (b) matching bags (in all IPC sub-sections)
	
global bins s3b_6 s4b_6 s5b_6 s6b_6 s7e_6 s8e_6 s10f_6
	
foreach var of varlist $bins {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if [`var'_ch_1==1 & `var'_ch_2==1] | [`var'_ch_2==1 & `var'_ch_3==1] | [`var'_ch_1==1 & `var'_ch_3==1] 
	replace `var'=0 if `var'!=1 & [[`var'_ch_1==0 | `var'_ch_2==0] | [`var'_ch_2==0 | `var'_ch_3==0] | [`var'_ch_1==0 | `var'_ch_3==0]] 
	label var `var' "Are there at least two color-coded bins (red, black and/or yellow)?"

	
	}



	
foreach x in s3b s4b s5b s6b s7e s8e s10f {

	gen `x'_bb=.
	replace `x'_bb=1 if `x'_6_ch_3==1 & `x'_9 == 3
	replace `x'_bb = 0 if [`x'_9 !=3 & `x'_9 !=.] | `x'_6_ch_3==0
	gen `x'_yy = 1 if `x'_6_ch_2 == 1 & `x'_8 == 2
	replace `x'_yy = 0 if [`x'_8 != 2 & `x'_8 != .] | `x'_6_ch_2==0
	gen `x'_rr = 1 if `x'_6_ch_1 ==1 & `x'_7 == 1
	replace `x'_rr = 0 if [`x'_7 != 1 & `x'_7 != .] | `x'_6_ch_1==0 

	gen `x'_match=.
	replace `x'_match=1 if `x'_6==1 & [(`x'_bb==1 & `x'_yy==1) | (`x'_bb==1 &`x'_rr==1) | (`x'_yy==1 &`x'_rr==1)]
	replace `x'_match=0 if `x'_6==1 & [(`x'_bb==0 & `x'_yy==0) | (`x'_bb==0 &`x'_rr==0) | (`x'_yy==0 &`x'_rr==0)]
	label var `x'_match "Are there coded lining bags that match the color of the bins?"
}
	
	
	
* Imputing zeros for theatre questions that have a filter in QPS2 for theatre areas (receiving room, scrubbing area, etc.)

global receivingarea s6a_2 s6a_3 s6a_4 s6a_5 
foreach var of varlist $receivingarea {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==0 | s6a_1_ch_1==0
}
	label var s6a_2 "Does the receiving area have a barrier?"
	label var s6a_3 "Does the receiving area have a shoe rack?"
	label var s6a_4 "Does the receiving area have a coach?"
	label var s6a_5 "Does the receiving area have adequate lighting?"
	
global changingarea s6a_6 s6a_7 s6a_8 s6a_9 s6a_10 
foreach var of varlist $changingarea {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==0 | s6a_1_ch_2==0
}
	label var s6a_6 "Does the theatre have male and female changing rooms with barrier?"
	label var s6a_7 "Do changing rooms have clean clothing?"
	label var s6a_8 "Do changing rooms have masks?"
	label var s6a_9 "Do changing rooms have caps?"
	label var s6a_10 "Do changing rooms have theatre shoes?"

global scrubbingarea s6a_11
foreach var of varlist $scrubbingarea {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==0 | s6a_1_ch_3==0
}
	label var s6a_11 "Is there a hands-free tap?"
	label var s6a_1_ch_3 "Is there a scrubbing area present?"
	
global recoveryroom s6a_27 s6a_28 s6a_29
foreach var of varlist $recoveryroom {

	rename `var' `var'_other
	gen `var'=.
	replace `var'=1 if `var'_other==1
	replace `var'=0 if `var'_other==0 | s6a_1_ch_5==0
}
	label var s6a_27 "Does the recovery room have adequate lighting?"
	label var s6a_28 "Does the recovery room have a monitor?"
	label var s6a_29 "Does the recovery room have a drip stand?"
	
* Building yes/no var for theatre nurses from question with multiple option choices

	rename s6a_25 s6a_25_other
	gen s6a_25=.
	replace s6a_25=1 if s6a_25_ch_1==1 & s6a_25_ch_2==1 & s6a_25_ch_3==1
	replace s6a_25=0 if s6a_25_ch_1==0 | s6a_25_ch_2==0 | s6a_25_ch_3==0
	label var s6a_25 "Are there at least three nurses (scrub, runner and anaesthetic nurse)?"
	
* Building yes/no var for resuscitaire from question with multiple option choices

	rename s4a_17 s4a_17_other
	gen s4a_17=.
	replace s4a_17=1 if s4a_17_other==1 & s4a_17_a_ch_1==1 & s4a_17_a_ch_2==1 & s4a_17_a_ch_3==1
	replace s4a_17=0 if s4a_17_other==0 | s4a_17_a_ch_1==0 | s4a_17_a_ch_2==0 | s4a_17_a_ch_3==0
	label var s4a_17 "Is a functional resuscitaire available with oxygen, suction machine and ambu bags?"

* Legible signage outside and inside the facility. Keeping accurate/relevant for outside only

	replace s1a_1 = 0 if s1a_4!=1	
	
	label var s1a_1 "Does the facility display legible signage?"
	lab var s1a_2 "Does the facility display signage that is accurate (relevant)?"
	lab var s1a_3 "Does the signage include the facility name?"
	lab var s1a_5 "Does the signage include department names and direction?"
				
		*check 
		sum s1a_1 s1a_2 s1a_3 s1a_4 s1a_5

	* relevant s3a_b (rather than the first question available)
	
	rename s3a_1 s3a_1_other
	rename s3a_b s3a_b_other
	
	gen s3a_b=.
	replace s3a_b=1 if s3a_b_other==1
	replace s3a_b=0 if s3a_b!=1
	
	sum s3a_b
	
	label var s3a_b "Does the facility have a triage area with a qualified nurse(s)?"
	clonevar s3a_1=s3a_b
	lab var s3a_1 "Does the facility have a triage area with a qualified nurse(s)?"
	
		*fixing dependent. Note that the location is assumed for both triage and the nurse if they don't have both, the following question doesnt' appear
		*				   the SOP can be there wihtout the triage
		
			replace s3a_3=0 if s3a_3!=1

	* relevant s3a_17b (rather than the first question available)

	rename s3a_17 s3a_17_other
	rename s3a_17b s3a_17b_other
	
	gen s3a_17b=.
	replace s3a_17b=1 if s3a_17b_other==1	
	replace s3a_17b=0 if s3a_17b!=1
	label var s3a_17b "Does the facility have an emergency tray available at designated sites?"
	
* Building vars if question is conditional on HF level 
	
	rename s1c_5 s1c_5_other
	rename s1c_6 s1c_6_other
	gen s1c_5=.
	
	replace s1c_5=1 if s1c_5_other==1 & level>=4 & level<.
	replace s1c_5=0 if s1c_5_other==0 & level>=4 & level<.
	
	replace s1c_5=1 if s1c_6_other==1 & level<=3
	replace s1c_5=0 if s1c_6_other==0 & level<=3 
	label var s1c_5 "Does the facility have a fire assembly point or fire assembly protocol?"	
	
	rename s1c_4 s1c_4_other
	gen s1c_4=.
	replace s1c_4=1 if s1c_4_other==1 & level>=4 & level<.
	replace s1c_4=0 if s1c_4_other==0 & level>=4 & level<.
	label var s1c_4 "Is the equipment available in the reception area as well as specific departments?"
	
	rename s1c_10 s1c_10_other
	gen s1c_10=.
	replace s1c_10=1 if s1c_10_other==1 & level>=4 & level<.
	replace s1c_10=0 if s1c_10_other==0 & level>=4 & level<.
	label var s1c_10 "Does the facility display fire assembly point signage?"
	
	replace s1c_10=0 if s1c_5_other==0
	replace s1c_4=0 if s1c_3==0 & [level==4 | level==5] 
	replace s1c_4=. if a5==11976
	label var s9a_5 "Is there evidence of quality assurance of the image processing system?"
	
* Create new section vars

***ADD DELIVERIES, MINOR OPERATIONS AND DRUGS?? OR WE ONLY ANSWER FOR DELIVERIES????
* Not that the protocols were such that survyeors will go back if there were somebody to answer question in the next 7 days if it was closed... that's why the a8_v`'i appear in this formulas

	gen consultation=.
	replace consultation=1 if a8_ch_1==1 
	replace consultation=0 if consultation!=1
	label var consultation "Medical and Dental Consultation Services"
	
	gen labour=.
	replace labour=1 if a8_ch_2==1 & a8_v2!=1
	replace labour=1 if a8_ch_2==1 & a8_v2_b==1
	replace labour=0 if labour!=1
	label var labour "Labour Ward Services"
	
	
	gen deliveries=.
	
	replace deliveries=1 if a8_1==1 & a8_v9!=1
	replace deliveries=1 if a8_1==1 & a8_v9_b==1
	replace deliveries=0 if deliveries!=1
	label var deliveries "No Labour Ward but Deliveries Services"
	
	gen wards=.
	replace wards=1 if a8_ch_3==1 & a8_v3!=1
	replace wards=1 if a8_ch_3==1 & a8_v3_b==1
	replace wards=0 if wards!=1
	label var wards "Medical and Pediatric Ward Services"
	
	gen theatre=.
	replace theatre=1 if a8_ch_4==1 & a8_v4!=1
	replace theatre=1 if a8_ch_4==1 & a8_v4_b==1
	replace theatre=0 if theatre!=1
	label var theatre "Theatre Services"
	
	gen pharmacy=.
	replace pharmacy=1 if a8_ch_5==1 & a8_v5!=1
	replace pharmacy=1 if a8_ch_5==1 & a8_v5_b==1
	replace pharmacy=0 if pharmacy!=1
	label var pharmacy "Pharmacy Services"
	
	gen lab=.
	replace lab=1 if a8_ch_6==1 & a8_v8!=1
	replace lab=1 if a8_ch_6==1 & a8_v8_b==1
	replace lab=. if a8_ch_6==1 & a8_v==0
	replace lab=0 if lab!=1
	
	label var lab "Laboratory Services"
	
	gen radiology=.
	replace radiology=1 if a8_ch_7==1 & a8_v6!=1
	replace radiology=1 if a8_ch_7==1 & a8_v6_b==1
	replace radiology=0 if radiology!=1

	label var radiology "Radiology Services"
	
	gen nutrition=.
	replace nutrition=1 if a8_ch_9==1 & a8_v7!=1
	replace nutrition=1 if a8_ch_9==1 & a8_v7_b==1
	replace nutrition=0 if nutrition!=1
	
	gen inpatients=nutrition

	label var nutrition "Inpatient Services (activates Nutrition Services)"
	
	
	
*---------------------------------------------------------------------------------------------- 
* Part 2. Creates Checklist groups
*---------------------------------------------------------------------------------------------- 
	
* S1: HF Infrastructure (S2 in Checklist)

	* A. Building

	local s1_a_1 s1a_1 s1a_2 s1a_3 s1a_5 s1a_6
	local s1_a_2 s1a_7_ch_1 s1a_7_ch_2 s1a_7_ch_3 s1a_7_ch_4 
	local s1_a_3 s1a_8_ch_1 s1a_8_ch_2 s1a_8_ch_3 s1a_8_ch_4
	
	* B. Utilities

	local s1_b_1 s1b_1 s1b_2
	local s1_b_2 s1b_3
	local s1_b_3 s1b_5 s1b_6
		
	* C. Security
	local s1_c_1 s1c_1 s1c_2
	local s1_c_2 s1c_3 s1c_4
	local s1_c_3 s1c_5 s1c_7 s1c_9 s1c_10
	local s1_c_4 s1c_11 
		
	global s1_infrastructure `s1_a_1' `s1_a_2' `s1_a_3' `s1_b_1' `s1_b_2' `s1_b_3' `s1_c_1' `s1_c_2' `s1_c_3' `s1_c_4'

	* A. Building

	local s1_a_1 s1a_1 s1a_2 s1a_3 s1a_5 s1a_6
	local s1_a_2 s1a_7_ch_1 s1a_7_ch_2 s1a_7_ch_3 s1a_7_ch_4 
	local s1_a_3 s1a_8_ch_1 s1a_8_ch_2 s1a_8_ch_3 s1a_8_ch_4
	
	* B. Utilities

	local s1_b_1 s1b_1 s1b_2
	local s1_b_2 s1b_3
	local s1_b_3 s1b_5 s1b_6
		
	* C. Security
	local s1_c_1 s1c_1 s1c_2
	local s1_c_2 s1c_3 s1c_4
	local s1_c_3 s1c_5 s1c_7 s1c_9 s1c_10
	local s1_c_4 s1c_11 
		
	global s1_infrastructure `s1_a_1' `s1_a_2' `s1_a_3' `s1_b_1' `s1_b_2' `s1_b_3' `s1_c_1' `s1_c_2' `s1_c_3' `s1_c_4'

* S2: IPC (S4 in Checklist)
		
	* A. General
	local s2_a_1 s2a_1 s2a_2		
	local s2_a_2 s2a_3 s2a_4 s2a_5
	local s2_a_3 s2a_7_ch_1 s2a_7_ch_2 s2a_7_ch_3 s2a_7_ch_4 s2a_8 s2a_9 s2a_10
	local s2_a_4 s2a_13 s2a_14 s2a_15
		
	* B. Sterilization Services
	local s2_b_1 s2b_1 s2b_2 s2b_3 s2b_4 
		
	global s2_ipc `s2_a_1' `s2_a_2' `s2_a_3' `s2_a_4' `s2_b_1'
		
* S3: Medical and Dental Consultation Services (S5 in Checklist)

	* A. General
	local s3_a_1 s3a_b s3a_2 s3a_3 s3a_4
	local s3_a_2 s3a_5 s3a_6 s3a_7		
	local s3_a_3 s3a_8 s3a_9 s3a_10 s3a_11 s3a_12 s3a_13 s3a_14 s3a_15 s3a_16
	local s3_a_4 s3a_17b s3a_18 s3a_19_ch_1 s3a_19_ch_2 s3a_19_ch_3 s3a_19_ch_4 s3a_19_ch_5 s3a_20_ch_1 s3a_20_ch_2 s3a_20_ch_3 s3a_20_ch_4 s3a_20_ch_5

	* B. IPC
	local s3_b_1 s3b_1
	local s3_b_2 s3b_3 s3b_4
	local s3_b_3 s3b_6 s3b_match s3b_5
	local s3_b_4 s3b_11 s3b_12
	local s3_b_5 s3b_13 s3b_14 s3b_15 s3b_16
		
	global s3_consultation `s3_a_1' `s3_a_2' `s3_a_3' `s3_a_4' `s3_b_1' `s3_b_2' `s3_b_3' `s3_b_4' `s3_b_5' 
		
* S4: Labour Ward (S6 in Checklist)

	* A. General
	local s4_a_1 s4a_1 s4a_2 s4a_3 s4a_4 s4a_5 s4a_6 s4a_7 s4a_8 s4a_9
	local s4_a_2 s4a_10 s4a_11 s4a_12
	local s4_a_3 s4a_13 s4a_14 s4a_15
	local s4_a_4 s4a_16 s4a_17	
	local s4_a_5 s4a_18 s4a_19 
	local s4_a_6 s4a_20 s4a_21 s4a_22 s4a_23 s4a_24 s4a_25 s4a_26
	local s4_a_7 s4a_27 s4a_28 s4a_29 s4a_30 s4a_31		
	local s4_a_8 s4a_32 s4a_33 s4a_34 s4a_35
		
	* B. IPC
	local s4_b_1 s4b_1
	local s4_b_2 s4b_3 s4b_4
	local s4_b_3 s4b_6 s4b_match s4b_5
	local s4_b_4 s4b_11 s4b_12		
	local s4_b_5 s4b_13 s4b_14 s4b_15 s4b_16
		
	global s4_labour `s4_a_1' `s4_a_2' `s4_a_3' `s4_a_4' `s4_a_5' `s4_a_6' `s4_a_7' `s4_a_8' `s4_b_1' `s4_b_2' `s4_b_3' `s4_b_4' `s4_b_5'
		
* S5: Medical and Pediatric Wards (S7 in Checklist)
	
	* A. General
	local s5_a_1 s5a_1 s5a_2 s5a_3 s5a_4
	local s5_a_2 s5a_5 s5a_6
	local s5_a_3 s5a_7 s5a_8 s5a_9 s5a_10 s5a_11
			
	* B. IPC
	local s5_b_1 s5b_1
	local s5_b_2 s5b_3 s5b_4
	local s5_b_3 s5b_6 s5b_match s5b_5
	local s5_b_4 s5b_11 s5b_12
	local s5_b_5 s5b_13 s5b_14 s5b_15 s5b_16

	global s5_wards `s5_a_1' `s5_a_2' `s5_a_3' `s5_b_1' `s5_b_2' `s5_b_3' `s5_b_4' `s5_b_5'  

	
* S6: Theatre (S8 in Checklist)
	
	* A. General
	local s6_a_1 s6a_2 s6a_3 s6a_4 s6a_5
	local s6_a_2 s6a_6 s6a_7 s6a_8 s6a_9 s6a_10 s6a_1_ch_3 s6a_11 s6a_12
	local s6_a_3 s6a_13 s6a_14 s6a_15 s6a_16 s6a_17 s6a_18 s6a_19 s6a_20 s6a_21 s6a_22 s6a_23 s6a_24
	local s6_a_4 s6a_25 s6a_26
	local s6_a_5 s6a_27 s6a_28 s6a_29

	* B. IPC
	local s6_b_1 s6b_1
	local s6_b_2 s6b_3 s6b_4
	local s6_b_3 s6b_6 s6b_match s6b_5
	local s6_b_4 s6b_11 s6b_12
	local s6_b_5 s6b_13 s6b_14 s6b_15 s6b_16
		
	global s6_theatre `s6_a_1' `s6_a_2' `s6_a_3' `s6_a_4' `s6_a_5' `s6_b_1' `s6_b_2' `s6_b_3' `s6_b_4' `s6_b_5'  
			
* S7: Pharmacy (S9 in Checklist)
	
	* A. General condition of permises
	local s7_a_1 s7a_1_ch_1 s7a_1_ch_2 s7a_1_ch_3 s7a_1_ch_4
	local s7_a_2 s7a_2_ch_1 s7a_2_ch_2 s7a_2_ch_3 s7a_2_ch_4 s7a_3
		
	* B. Storage and display of commodities
	local s7_b s7b_1 s7b_2 s7b_3
		
	* C. Record keeping and documentation
	local s_7_c s7c_1 s7c_2 s7c_3 s7c_4 s7c_5 s7c_6
		
	* D. Reference and materials and policies
	local s_7_d s7d_1 s7d_2
		 
	* E. IPC
	local s7_e_1 s7e_1
	local s7_e_2 s7e_3 s7e_4
	local s7_e_3 s7e_6 s7e_match s7e_5
	local s7_e_4 s7e_11 s7e_12
	local s7_e_5 s7e_13 s7e_14 s7e_15 s7e_16
	
	global s7_pharmacy `s7_a_1' `s7_a_2' `s7_b' `s_7_c' `s_7_d' `s7_e_1' `s7_e_2' `s7_e_3' `s7_e_4' `s7_e_5'  

* S8: Laboratory (S10 in Checklist)

	* A. Policies, guidelines, and SOPs
	local s8_a_2 s8a_1 s8a_3
	local s8_a_3 s8a_4 s8a_5
	local s8_a_4 s8a_6 s8a_7
	local s8_a_5 s8a_8
		
	* B. Equipment management program
	local s8_b_1 s8b_2 s8b_3
	local s8_b_2 s8b_4 s8b_5
	local s8_b_3 s8b_6
	local s8_b_4 s8b_7 s8b_8
		
	* C. Record keeping and documentation
	local s8_c s8c_1
		
	* D. Quality control of tests
	local s8_d_1 s8b_1 s8d_1 s8d_2 s8d_3 s8d_4 s8d_5
	local s8_d_2 v478 s8d_6
		
	* E. IPC
	local s8_e_1 s8e_1
	local s8_e_2 s8e_3 s8e_4
	local s8_e_3 s8e_6 s8e_match s8e_5
	local s8_e_4 s8e_11 s8e_12
	local s8_e_5 s8e_13 s8e_14 s8e_15 s8e_16

	global s8_lab `s8_a_2' `s8_a_3' `s8_a_4' `s8_a_5' `s8_b_1' `s8_b_2' `s8_b_3' `s8_b_4' `s8_c' `s8_d_1' `s8_d_2' `s8_e_1' `s8_e_2' `s8_e_3' `s8_e_4' `s8_e_5'

* S9: Radiology (S11 in Checklist)
	
	* A. Radiation protection
	local s9_a_1 s9a_1 
	local s9_a_2 s9a_2
	local s9_a_3 s9a_3
	local s9_a_4 s9a_4
	local s9_a_5 s9a_5
		
	* B. Policies, SOPs, and registers
	local s9_b_1 s9b_1 s9b_3
	local s9_b_2 s9b_4
	local s9_b_3 s9b_5
	local s9_b_4 s9b_6 s9b_7 s9b_8 s9b_9
		
	* C. Radioactive waste management
	local s9_c_1 s9c_1 s9c_2
	local s9_c_2 s9c_3 s9c_4
	local s9_c_3 s9c_5
		
	* D. IPC
	local s9_d_1 s9d_1
	local s9_d_2 s9d_3 s9d_4
	local s9_d_3 s9d_5 s9d_6
	local s9_d_4 s9d_7 s9d_8 s9d_9 s9d_10
		
	global s9_radiation `s9_a_1' `s9_a_2' `s9_a_3' `s9_a_4' `s9_a_5' `s9_b_1' `s9_b_2' `s9_b_3' `s9_b_4' `s9_c_1' `s9_c_2' `s9_c_3' `s9_d_1' `s9_d_2' `s9_d_3' `s9_d_4' 
	
* S10: Nutrition (S12 in Checklist)
	
	* A. Nutrition equipment, tools and supplies
	global s10_a_1 s10a_1 s10a_2 s10a_3 s10a_4 s10a_5 s10a_6 s10a_7
	global s10_a_2 s10a_8 s10a_9 s10a_10 s10a_11 s10a_12 s10a_13 s10a_14 s10a_15 s10a_16 s10a_17
		
	* B. SOPs for nutrition care processes and other services
	global s10_b s10b_1 s10b_2 s10b_3 s10b_4 s10b_5 s10b_6 s10b_7 s10b_8
		
	* C. Record keeping and documentation
	global s10_c s10c_1 s10c_2 s10c_3 s10c_4
		
	* D. Patient feeding
	global s10_d_1 s10d_1 s10d_2 s10d_3 s10d_4 s10d_5 s10d_6 s10d_7
	global s10_d_2 s10d_8 s10d_9
		
	* E. Food preparation unit
	global s10_e_1 s10e_2 s10e_3 s10e_4 s10e_5 s10e_6 s10e_7
	global s10_e_2 s10e_8 s10e_9 s10e_10 s10e_11 s10e_12
	global s10_e_3 s10e_13 s10e_14

	* F. IPC
	global s10_f_1 s10f_1
	global s10_f_2 s10f_3 s10f_4
	global s10_f_3 s10f_6 s10f_match s10f_5
	global s10_f_4 v635 s10f_11 
	global s10_f_5 s10f_12 s10f_13 s10f_14 s10f_15
			
	global s10_nutrition $s10_a_1 $s10_a_2 $s10_b $s10_c $s10_d_1 $s10_d_2 $s10_e_1 $s10_e_2 $s10_e_3 $s10_f_1 $s10_f_2 $s10_f_3 $s10_f_4 $s10_f_5
	order facilitycode facilityname enumeratorid enumname supervisorid supname lat lon county location sublocation level private
	
	global basicinfo county private level 
	global surveyrel g1 g1_2 g3 g3_2 g5 g5_2 g7 g7_2
	global units consultation labour deliveries wards theatre pharmacy lab radiology inpatients nutrition
	global services a8_1 a8_2 a8_3 a8_4 a8_5
	global closedtemp a8_v2 a8_v9 a8_v3 a8_v4 a8_v5 a8_v8 a8_v6 a8_v7
	global howlongclosed a8_v2_a a8_v9_a a8_v3_a a8_v4_a a8_v5_a a8_v8_a a8_v6_a a8_v7_a
	global available7days a8_v2_b a8_v9_b a8_v3_b a8_v4_b a8_v5_b a8_v8_b a8_v6_b a8_v7_b
	global catvars s1b_5 s2a_7 s2a_8 s2a_9 s2a_10 s2a_13 s2a_14 s2a_15 s3b_7 s3b_8 s3b_9 s3b_10 s4b_7 s4b_8 s3b_9 s4b_10 s5b_7 s5b_8 s5b_9 s5b_10 s6b_7 s6b_8 s6b_9 s6b_10 s7a_1 s7a_2 s7e_7 s7e_8 s7e_9 s7e_10 s8e_8 s8e_9 s8e_10 s8e_7 s10f_8 s10f_9 s10f_10
	global confirm s3a_19 s3a_20 s3b_6 s4a_17_a s4b_6 s6a_1 s6a_25
	global all $units $s1_infrastructure $s2_ipc $s3_consultation $s4_labour $s5_wards $s6_theatre $s7_pharmacy $s8_lab $s9_radiation $s10_nutrition s10e_1
	global labels $s1_infrastructure $s2_ipc $s3_consultation $s4_labour $s5_wards $s6_theatre $s7_pharmacy $s8_lab $s9_radiation $s10_nutrition 
	global profile $departments $services
	
	clonevar hfid=facilitycode
	
save "${qps2_bl}", replace
	/*
/*---------------------------------------------------------------------------------------------- 
* Part 3. Generates descriptive statistics table
*---------------------------------------------------------------------------------------------- */

*global tablename qps2_summary_dec
global tablename qps2_summary_jul2016


cd "$directory/DataAnalysis/Baseline/Outputs/Tables/SumStats"
tabstat $all, s(N mean sd min max) f(%10.2f) c(s) save
tabstatmat temp
matrix temp = temp'
putexcel B1=matrix(temp, names) using $tablename, replace
putexcel A1 = ("Variables") B1 = ("Labels") C1 = ("N") D1 = ("Mean") E1 = ("SD") F1 = ("Min") G1 = ("Max") using $tablename, modify
	
local i = 2
foreach var of varlist $all {
  putexcel A`i'= ("`var'") using $tablename, modify  
  local varlabel : variable label `var'
  putexcel B`i'= ("`varlabel'") using $tablename, modify
  local i = `i' + 1 
  }
  

xml_tab temp, save($tablename.xls) t("Table 1. Checklist Descriptive Statistics") sh("Table 1") cnames(N Mean SD Min Max) replace rblanks(a8_ch_1 "Please indicate whether your health facility has each of the following:",	a8_1 "Services offered (only if response is 'No' to corresponding department)",	a8_v2 "Are any of these departments/services temporarily closed?",	a8_v2_a "How long (in days) have the following departments or services been closed?",	a8_v2_b "Will someone be able to answer the questions in the following departments within the next 7 days (not including Sundays)?",	nutrition "Section 1: HF Infrastructure (Section 2 of Checklist)",	nutrition "A. Building",	nutrition "1. Signage",	s1a_7_ch_1 "2. Ventilation",	s1a_8_ch_1 "3. Lighting",	s1b_1 "B. Utilities",	s1b_1 "1. Water",	s1b_3 "2. Electricity",	s1b_5 "3. Toilet facilities",	s1c_1 "C. Security",	s1c_1 "1. Lockable door",	s1c_3 "2. Fire control mechanism",	s1c_5 "3. Fire assembly point",	s1c_11 "4. Security",	s2a_1 "Section 2: Infection Prevention and Control (Section 4 of Checklist)",	s2a_1 "A. General",	s2a_1 "1. Hygiene protocol",	s2a_3 "2. Solid waste management" ,	s2a_7_ch_1 "3. General facility cleanliness",	s2a_13 "4. General compound cleanliness",	s2b_1 "B. Sterilization Services",	s2b_1 "1. Central supply unit",	s3a_b "Section 3: Medical and Dental Consultation Services (Section 5 in Checklist)",	s3a_b "A. General",	s3a_b "1. Triage",	s3a_5 "2. Examination room",	s3a_8 "3. Examination equipment",	s3a_17b "4. Emergency tray",	s3b_1 "B. IPC",	s3b_1 "1. Hygiene protocol",	s3b_3 "2. Hand washing",	s3b_6 "3. Solid waste management",	s3b_11 "4. Use of disinfectants",	s3b_13 "5. Protective equipment",	s4a_1 "Section 4:Labour Ward (Section 6 in Checklist)" ,	s4a_1 "A. General",	s4a_1 "1. Labour ward",	s4a_10 "2. Labour room floor",	s4a_13 "3. Oxygen source",	s4a_16 "4. Procedures for obstetrics emergency",	s4a_18 "5. Access to theatre",	s4a_20 "6. Procedure for monitoring labour",	s4a_27 "7. New born unit",	s4a_32 "8. Sluice room",	s4b_1 "B. IPC",	s4b_1 "1. Hygiene protocol",	s4b_3 "2. Hand washing",	s4b_6 "3. Solid waste management",	s4b_11 "4. Use of disinfectants",	s4b_13 "5. Protective equipment",	s5a_1 "Section 5: Medical and Pediatric Wards (Section 7 in Checklist)",	s5a_1 "A. General",	s5a_1 "1. Patient oversight",	s5a_5 "2. Patient records",	s5a_7 "3. Monitoring equipment",	s5b_1 "B. IPC",	s5b_1 "1. Hygiene protocol",	s5b_3 "2. Hand washing",	s5b_6 "3. Solid waste management",	s5b_11 "4. Use of disinfectants",	s5b_13 "5. Protective equipment",	s6a_2 "Section 6: Theatre (Section 8 in Checklist)",	s6a_2 "A. General",	s6a_2 "1. Receiving area",	s6a_6 "2. Changing rooms and scrubbing area" ,	s6a_13 "3. Operating area" ,	s6a_25 "4. Staff requirements" ,	s6a_27 "5. Recovery room" ,	s6b_1 "B. IPC",	s6b_1 "1. Hygiene protocol",	s6b_3 "2. Hand washing",	s6b_6 "3. Solid waste management",	s6b_11 "4. Use of disinfectants",	s6b_13 "5. Protective equipment",	s7_a_1_ch_1 "Section 7: Pharmacy (Section 9 in Checklist)",	s7_a_1_ch_1 "A. General condition of premises",	s7_a_1_ch_1 "1. Ventilation",	s7_a_2_ch_1 "2. Lighting",	s7b_1 "B. Storage and display of commodities",	s7c_1 "C. Record keeping and documentation",	s7d_1 "D. Reference and materials and policies",	s7e_1 "E. IPC",	s7e_1 "1. Hygiene protocol",	s7e_3 "2. Hand washing",	s7e_6 "3. Solid waste management",	s7e_11 "4. Use of disinfectants",	s7e_13 "5. Protective equipment",	s8a_1 "Section 8: Laboratory (Section 10 in Checklist)",	s8a_1 "A. Policies, guidelines, and SOPs",	s8a_1 "2. Reporting procedures",	s8a_4 "3. Handling, labeling and storage of specimen",	s8a_6 "4. Disposal of specimens",	s8a_8 "5. Standard quality operation manual",	s8b_2 "B. Equipment management program",	s8b_2 "1. Calibration and validation of equipment",	s8b_4 "2. Equipment maintenance documents",	s8b_6 "3. System for procurement of equipment",	s8b_7 "4. Inventory of equipment",	s8c_1 "C. Record keeping and documentation",	s8b_1 "D. Quality control of tests",	s8b_1 "1. Quality control practices",	v478 "2. Procurement and storage of reagents",	s8e_1 "E. IPC",	s8e_1 "1. Hygiene protocol",	s8e_3 "2. Hand washing",	s8e_6 "3. Solid waste management",	s8e_11 "4. Use of disinfectants",	s8e_13 "5. Protective equipment",	s9a_1 "Section 9: Radiology (Section 11 in Checklist)",	s9a_1 "A. Radiation protection",	s9a_1 "1. Personal radiation dose monitoring",	s9a_2 "2. Radiation safety service provider",	s9a_3 "3. Adequate number of lead aprons",	s9a_4 "4. Radiological examination in pregnancy",	s9a_5 "5. Quality assurance of image processing",	s9b_1 "B. Policies, SOPs, and registers",	s9b_1 "1. Policies, SOPs and code of practice",	s9b_4 "2. Reporting, testing and calibration",	s9b_5 "3. Register of eradiating activities",	s9b_6 "4. Quality assurance program",	s9c_1 "C. Radioactive waste management",	s9c_1 "1. Personal safety measures",	s9c_3 "2. Radioactive waste management programs in place",	s9c_5 "3. Designated staff for radioactive waste management programs",	s9d_1 "D. IPC",	s9d_1 "1. Hygiene protocol",	s9d_3 "2. Hand washing",	s9d_5 "3. Use of disinfectants",	s9d_7 "4. Protective equipment",	s10a_1 "Section 10: Nutrition (Section 12 in Checklist)",	s10a_1 "A. Nutrition equipment, tools and supplies",	s10a_1 "1. Nutrition equipment and tools",	s10a_8 "2. Food supplies, formulations and nutrition supplements",	s10b_1 "B. SOPs for nutrition care processes and other services",	s10c_1 "C. Record keeping and documentation",	s10d_1 "D. Patient feeding",	s10d_1 "1. Inpatient feeding",	s10d_8 "2. Maternity feeding",	s10e_2 "E. Food preparation unit",	s10e_2 "1. Kitchen equipment and fuel",	s10e_8 "2. Food preparation unit layout",	s10e_13 "3. Kitchen personnel",	s10f_1 "F. IPC",	s10f_1 "1. Hygiene protocol",	s10f_3 "2. Hand washing",	s10f_6 "3. Solid waste management",	v635 "4. Use of disinfectants",	s10f_12 "5. Protective equipment") lines(COL_NAMES 13	a8_ch_1 2	a8_1 2	a8_v2 2	a8_v2_a 2	a8_v2_b 2	nutrition 4	s1b_1 2	s1c_1 2	s2a_1 4	s2a_1 2	s2b_1 2	s3a_b 4	s3a_1 2	s3b_1 2	s4a_1 4	s4a_1 2	s4b_1 2	s5a_1 4	s5a_1 2	s5b_1 2	s6a_2 4	s6a_2 2	s6b_1 2	s7_a_1_ch_1 4	s7_a_1_ch_1 2	s7b_1 2	s7c_1 2	s7d_1 2	s7e_1 2	s8a_1 4	s8a_1 2	s8b_2 2	s8c_1 2	s8b_1 2	s8e_1 2	s9a_1 4	s9a_1 2	s9b_1 2	s9c_1 2	s9d_1 2	s10a_1 4	s10a_1 2	s10b_1 2	s10c_1 2	s10d_1 2	s10e_2 2	s10f_1 2) font("Calibri" 9)
*/
	* Dismount
	veracrypt, dismount drive("${mount}") 
