/*******************************************************************************	

Project:  		KePSIE
Created on:  	December 12, 2018
Last udpate on: December 12, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			


THIS DO FILE: 	This do-file constructs the price / demand database baseline  

CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Constructing price variable.
				Part 2 - Creating demand variables 
						2.1 Setting globals and labels
						2.2 Outpatients recorded in books
						2.3 Outpatients under 5 and over 5
						2.4 Aggregating the variables
				Part 3 - Patients yesterday or the day before
				Part 4 - Flagging facilities with low data

INPUTS:     	* Database prepared with all the needed variables 
				"${KePSIE_DB}/Baseline/DataSets/Intermediate/Fees_Outpatient_QPS1_clean_bl.dta"

OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Final price / demand database
					"${KePSIE_DB}/Baseline/DataSets/Intermediate/Fees_Outpatient_clean_bl.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Final price / demand database
					"${bl_dt}/Intermediate/Fees_Outpatient_clean_bl.dta"
					

*******************************************************************************/


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off	
set varabbrev on			

	* Input files
		glo qps1_fees_outp_bl			"${dt_bl_clean}/qps1_fees_outp_bl.dta"

	* Output files
		glo fees_outp_bl 				"${dt_bl_const}/fees_outp_bl.dta"


********************************************************************************
*** # Part 1: Constructing price variable. 
********************************************************************************
use "${qps1_fees_outp_bl}", clear

gen price_date_bl = date
format price_date_bl %td
label var price_date_bl "Date on which price was collected"

//// Replace whenever possible as we trust supervisors more than the other surveyors
// so that we know for each price the date on which it was collected. Same as before, if both prices are the same, keep original 
replace price_date_bl  			= bcheck_date 		if !mi(bcheck_f8) & bcheck_f8 != f8 
gen 	price_consultation_bl 	= f8
replace price_consultation_bl 	= bcheck_f8 		if !mi(bcheck_f8)

drop 	bcheck_f8 

*Extracting month and year from the date of the price collection
gen price_year_bl  = year(price_date_bl)
label var price_year_bl "Year on which price was collected"
gen price_month_bl = month(price_date_bl) 
label var price_month_bl "Month on which price was collected"

label define month 1 "jan" 2 "feb" 3 "mar" 4 "apr" 5 "may" 6 "jun" 7 "jul" 8 "aug" 9 "sep" 10 "oct" 11 "nov" 12 "dec"
label value price_month_bl month


********************************************************************************

*** # Part 2: Creating demand variables 
/// 2 outcomes to create: one coming from MOH 717, one from under 5 + over 5 then aggregate

********************************************************************************

	*--------------------------------*
	* 2.1 Setting globals and labels *
	*--------------------------------*

global a November(2014)
global b December(2014)
global c January(2015) 
global d February(2015) 



	*-----------------------------------*
	* 2.2 Outpatients recorded in books *
	*-----------------------------------*

foreach month in a b c d {
*Main outcome
	gen 	book_outpatient_`month'_bl = f11`month' 							  
	
* Date of the outcome collection	
	gen 	book_outpatient_date_`month'_bl = date 					
	format  book_outpatient_date_`month'_bl 	%td

* Labelling
	label var book_outpatient_`month'_bl 				"$`month':Monthly outpatients from book source"
	label var book_outpatient_date_`month'_bl 			"Date when data was collected for $`month' for outpatients from book source"
}


* Doing the same with the variables of the supervisor back checks, also more reliable than original data, though only a few variables are covered
foreach month in a b c d {
	replace book_outpatient_`month'_bl 		= bcheck_f11`month' 		if !mi(bcheck_f11`month') 
	replace book_outpatient_date_`month'_bl = bcheck_date 				if !mi(bcheck_f11`month') 
}


	*------------------------------------*
	* 2.3 Outpatients under 5 and over 5 *
	*------------------------------------*

foreach month in a b c d {
	*Generating the date and variables, as complete as possible. 

* Main outcome
	replace	f12`month' 	= bcheck_f12`month' 				if !mi(bcheck_f12`month') | !mi(bcheck_f13`month') //if any data was collected by supervisor, replace both
	replace f13`month' 	= bcheck_f13`month' 				if !mi(bcheck_f12`month') | !mi(bcheck_f13`month')

	gen 	UO5_`month'_bl = f12`month' + f13`month' // If only have one of the two, it will then be missing
	
* Date of the outcome collection
	gen 	UO5_date_`month'_bl = date
	replace UO5_date_`month'_bl = bcheck_date  				if !mi(bcheck_f12`month') | !mi(bcheck_f13`month')
	format  UO5_date_`month'_bl %td

* Labelling
	label var UO5_`month'_bl 				"$`month':Monthly outpatients from adding o/u 5 outpatient"
	label var UO5_date_`month'_bl			"Date when data was collected for $`month' for outpatients o/u 5 from any book source"	
}


	*-------------------------------*
	* 2.4 Aggregating the variables *
	*-------------------------------*

foreach month in a b c d {
* Origin of data which should be used, either from books or from UO5
	gen 	data_use`month'_bl = 1
	replace data_use`month'_bl = 2 if  mi(book_outpatient_`month'_bl) & !mi(UO5_`month'_bl)

* Main outcome
	gen 	outpatient_`month'_bl = book_outpatient_`month'_bl							  
	replace outpatient_`month'_bl = UO5_`month'_bl 							if data_use`month'_bl == 2 // For now, priority on books over the addition of u/o 5 outpatient calculation

* Date of the outcome collection
	gen 	outpatient_date_`month'_bl = book_outpatient_date_`month'_bl
	replace outpatient_date_`month'_bl = UO5_date_`month'_bl  				if data_use`month'_bl == 2 
	format  outpatient_date_`month'_bl %td

* Labelling
	label var outpatient_`month'_bl 				"$`month':Monthly outpatients"
	label var outpatient_date_`month'_bl 			"Date when data was collected for $`month' for outpatients"

	drop data_use`month'_bl  
}


*Extracting month and year from the date of the outpatient data collection
foreach month in a b c d {
	gen outpatient_year_`month'_bl  = year(outpatient_date_`month')
	label var outpatient_year_`month'_bl "Year on which outpatient data was collected for $`month'"
	gen outpatient_month_`month'_bl = month(outpatient_date_`month') 
	label var outpatient_month_`month'_bl "Month on which outpatient data  was collected for $`month'"

	label value outpatient_month_`month'_bl month
}


********************************************************************************

*** # Part 4: Patients on average day - self reported

********************************************************************************
	gen 	outpatient_d_sf_bl 	= d37
	gen 	date_sf_bl  		= listing_date
	label var date_sf_bl "Date Recording of Outpatients Daily - Self Reported"


	gen date_sf_year_bl  = year(date_sf_bl)
	label var date_sf_year_bl "Year Recording of Outpatients Daily - Self Reported"
	gen date_sf_month_bl = month(date_sf_bl) 
	label var date_sf_month_bl "Month Recording of Outpatients Daily - Self Reported"

	label value date_sf_month_bl month


********************************************************************************

*** # Part 5: Flagging facilities with low data 

********************************************************************************


********************************************************************************

*** # Part : Saving the final data

********************************************************************************

*Keep only the variable of interest
*keep hfid price* book* UO5* outpatient*
 
		save "${fees_outp_bl}", replace

************************************************End of do file****************************************************
