/*******************************************************************************	
*		Project:
*			KePSIE IE
*		Created on:		2018-09-20

********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file creates the JHIC database to compute the JHIC instrument		
				
** INPUTS:     	QPS1_clean.dta path: Github/kepsie/DataWork/Endline/DataSets/Intermediate


** OUTLINE: 	Part 0: Initiate and import the database
				Part 1: Rename the variables following JHIC checklist
				Part 2: Adding JHIC checklist questions collected in QPS2
				Part 3: Importing questions maximum scores from excel file
				Part 4 : Save final dataset

** OUTPUTS:    JHIC_end.dta /path: Github/kepsie/DataWork/Endline/DataSets/Intermediate
							Dropbox/Kenya Health IE/Data_Analysis/DataWork/Endline/DataSets/Intermediate
							
** Written by: Thomas Escande

*******************************************************************************/


********************************************************************************

*** # Part 0: Initiate and import the database

********************************************************************************

clear all
set more off

*Setting globals 

*Inputs
glo qps1_clean 			"${dt_end_clean}/qps1_end.dta"
glo qps2_clean 			"${dt_end_clean}/qps2_end.dta"
glo	jhic_max			"${doc_end}/codebooks/jhic_allvars.xls"

*Outputs
glo jhic_clean 		 	"${dt_end_clean}/jhic_end_clean"

********************************************************************************

*** # Part 1: Rename the variables following JHIC checklist

********************************************************************************

use "${qps1_clean}", clear

	rename 	    e1 			s3a_1a
	rename      e2 			s3a_1b
	rename 	    e3 			s3a_1c 
	rename 	    e4     		s3a_1d

	rename 	    e51 		s3a_2a
	rename 	    e52 	  	s3a_2b
	rename 	    e5a 		s3a_2c
	rename 	    e5b 		s3a_2d
	rename 	    e5c 		s3a_2e
	rename 	    e5d  	  	s3a_2f
	rename 	    e5e 		s3a_2g
	rename      e5f 		s3a_2h

	rename 	    e6a 		s3a_3a	
	rename 	    e6b 		s3a_3b

	rename 		e6c_1 		s3b_1a_1
	rename 		e6c_2 		s3b_1a_2
	rename 		e6c_3 		s3b_1a_3
	rename 		e6c_4 		s3b_1a_4
	rename 		e6c_5 		s3b_1a_5
	rename 	    e7 			s3b_1b
	rename 	    e7a			s3b_1c

	rename 	    e8_1 		s3b_2a  
	rename 	    e8_2 		s3b_2b 
	rename 	    e8_3 		s3b_2c 
	rename 	    e8_4 		s3b_2d 
	rename 	    e8a 		s3b_2e

	rename 	    e9  		s3b_3a
	rename 	    e9a 		s3b_3b
	rename 	    e9b 		s3b_3c

	rename 		f1_JHIC   	s3c_1a
	rename 		f1a_JHIC 	s3c_1b
	rename 		f1b_JHIC 	s3c_1c

	rename 		f3_JHIC 	 s3c_2a
	rename 		f4_JHIC 	 s3c_2b
	rename 		f5_JHIC 	 s3c_2c
	rename 		f6_JHIC 	 s3c_2d

	rename 		f7_JHIC  	s3c_3a
	rename 		f8_JHIC  	s3c_3b
	rename 		f9_JHIC  	s3c_3c

	rename  	f10_JHIC 	s3c_4a
    rename 		f11_JHIC 	s3c_4b 

    rename 		f12_JHIC  	s3c_5a
    rename 		f13_1_JHIC 	s3c_5b_1
    rename 		f13_2_JHIC 	s3c_5b_2
    rename 		f13_3_JHIC 	s3c_5b_3
    rename 		f13_4_JHIC 	s3c_5b_4
    rename 		f13_5_JHIC 	s3c_5b_5
    rename 		f13_6_JHIC 	s3c_5b_6
    rename 		f13_7_JHIC 	s3c_5b_7

    rename 		e10 		s3d_1a
    rename 		e11 		s3d_1b
    rename 		e12 		s3d_2a
    rename 		e13 		s3d_2b
    rename 		e14  		s3d_2c


    keep hfid s3* 
	sort hfid s3*
	

********************************************************************************

*** # Part 2: Adding JHIC checklist questions collected in QPS2

********************************************************************************


merge 1:1 hfid using "${qps2_clean}"

assert _merge == 3 //Making sure that all the observations are matching which should be the case 
drop _merge

*Changing the names of survey specific var
foreach var of varlist g1 g1_2 g3 g3_2 g5 g5_2 g7 g7_2 key {
	rename `var' `var'_QPS2
}

*prepare the merge by creating a variable on which the merge will be done
gen merge_score = 1 

*Save a temporary database to be able to import the excel file
tempfile original_JHIC
save "`original_JHIC'" 


********************************************************************************

*** # Part 3: Importing questions maximum scores from excel file

********************************************************************************

import excel "${jhic_max}", clear sheet("MaxScores") firstrow // Import max scores


*Reshaping dataset in wide to be able to easily use it 
gen i = 1 
rename maxscore m
reshape wide m, i(i) j(var) string
drop i

drop ms6_ms_d ms7_ms_d ms8_ms_d ms9_ms_d ms10_ms_d ms11_ms_d ms12_ms_d //Dropping these variables as they are duplicates

*Getting the name of variable right
foreach var of varlist * {
		local size 		= length("`var'") - 4  // length minus space at the beginning and "_ms"
		local name 		= substr("`var'",2,.)  //space at the beginning of each variable name
		local label 	= substr("`name'",1,`size') //Actual name of the variable (without the "_ms")
			disp "`name'"
			disp "`label'"
			rename `var' `name'	
			label var `name' "`label' maxscore"
	}

*prepare the merge by creating a variable on which the merge will be done
gen merge_score = 1 

*Final Merging
merge 1:m merge_score using "`original_JHIC'", nogenerate 
drop merge_score

* Adding some max score questions which are missing
replace s11c_1_ms   = 10
replace s11c_1a_ms  = 5
replace s11c_1b_ms  = 5

replace s11c_2_ms   = 5
replace s11c_2a_ms  = 2.5
replace s11c_2b_ms  = 2.5

replace s11c_3_ms   = 5
replace s11c_3a_ms  = 5


********************************************************************************

*** # Part 4 : Save final dataset

******************************************************************************** 
	order *, seq


		saveold "${jhic_clean}", replace



************************************************End of do file****************************************************









