/*******************************************************************************	

Project:  		KePSIE
Created on:  	September 2, 2018
Last udpate on: Oct 12, 2018

Written by:  	Rebecca de Guttry and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the endline Patient Exit database 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
						 1.1. - Manual corrections
						 1.2. - Calculate response rates
				Part 2 - Complete variables
						 2.1. - Replace “Don’t answer”/“Don’t know” to missing
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionnary					
						 4.6 - Descriptive statistics 

INPUTS:     	* Raw data
				"${KePSIE_DB}/Endline/DataSets/Raw/PatientExit.dta"
				
				* HF profile information
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"

OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Maria Camila)
				
					* Anonymized data for microdata catalog
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PE_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PE_clean_pii.dta"
					
					* Dictionary
					"${KePSIE_DB}/Endline/Output/Final/PE_clean_dictionary_end.xlsx"
					
					* Response rate table
					"${KePSIE_DB}/Endline/Output/Final/PE_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${KePSIE_DB}/Endline/Output/Final/PE_desc_stats_end.csv"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Anonymized data for microdata catalog
					"${end_dt}/Intermediate/PE_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${end_dt}/Intermediate/PE_clean_pii.dta"
					
					* Dictionary
					"${end_out}/Final/PE_clean_dictionary_end.xlsx"
					
					* Response rate table
					"${end_out}/Final/PE_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${end_out}/Final/PE_desc_stats_end.csv"

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off

	* Input files
		glo pe_raw				"${volume}/pe_end_raw.dta"
		glo profile_end			"${dt_mast}/listing_end.dta"
	
	* Output files
		glo pe_clean 			"${dt_end_clean}/pe_end.dta"
		
********************************************************************************
	** Part 1: Complete database to estimate response rates
********************************************************************************
		
* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")
		
	use "${pe_raw}", clear
	
	* Drop unnecessary variables
		drop submissiondate deviceid subscriberid simid devicephonenum a7 a11_2_v ///
		f4 g2 k3 e3_v g3_v h1a_v h1b_v h2a_v h3a_v j1_v j2_v j3_v j4_v j1_v2 ///
		j2_v2 j3_v3 j4_v4 facilityname county level pri pri_string a10 a9 time_formopen ///
		formdef_version a6_c b3_c b3_c1 b8_c c4_c1 c5_c c11_c j1_c j1_v j2_c j2_v ///
		j3_c j3_v j4_c j4_v j1_v2 j2_v2 j3_v3 j4_v4 total_paid greater_outofpocket ///
		d1_v d3s_v d3t_v d3u_v d3v_v d3w_v d3x_v time_endinteraction_e1 ///
		time_endinteraction_e2 speedviolcount speedviollist starttime endtime ///
		time_endinteraction2 diff2 time_startinteraction2 e1 g6b g7b l3 l6 l9 l15

	*------------------------*
	* 1.1 Manual corrections *
	*------------------------*
	
	* Manual corrections // RdG: I am not sure who wrote this or where the records for this are
		replace facilitycode = 11401	if	facilitycode ==	11
		replace	facilitycode = 20578	if	facilitycode ==	205
		drop if facilitycode == 23083
			
	* Clean date
		gen 	date_td=date(date,"DMY")	if	a2_1_v==1
		replace	date_td=a2_2				if	a2_1_v==0
		replace	date_td=date(diff1,"YMD")	if	mi(date_td)
		drop date
		rename date_td date
		format date %td
		lab var date "Survey date"
		
	* Format time
		gen double time_start = clock(time_startinteraction, "hm")
		gen double time_end = clock(time_endinteraction, "hm")
		format time_start time_end %tc_HH:MM	 
		drop time_startinteraction time_endinteraction
			
	* Detect duplicates among observations with patient ID
		/*	Note from Salome on duplicate patient ID 22859:
			[Salome]: Hi Rebecca, sorry for taking so long, I have checked 
			and confirmed with the available DO PPS that this 
			patient ID belongs to a Female Patient aged between 
			19-30 years. Linet could not remember much concerning this 
			since she interviewed alot of people/
			[RdG]: Unfortunately both observations concern a female 
			in her early thirties, so no way of finding out which is
			the correct one for now – might be able to by checking 
			data from PPS_DO more thoroughly (based on services received). */
	
	* From communication with Salome in Data flags gsheet on 15Jun2018, fix a duplicate patient ID:
		replace a11_1=25624 if key=="uuid:3a74247d-ceda-4f1d-970a-07ebc1c7daff"
		
		/*
		preserve
			
			*	Save incomplete surveys separately
			keep	if	complete!=1
			
			tempfile	PE_incomplete
			save		`PE_incomplete'
			
		restore, preserve
		
			* Keep complete surveys with patient ID.
			keep	if	complete==1
			keep	if	!mi(patientid)
			
			*	Detect and drop duplicates for further inspection
			tostring	hfid date interid patientid, force u gen(hfid_s date_s interid_s patientid_s)
			gen 	PE_uniqueid = hfid_s+"-"+date_s+"-"+interid_s+"-"+patientid_s
			ieduplicates PE_uniqueid,	folder("${interm}/Duplicates/PE") uniquevars(key) ///
										keepvars(date time_startinteraction2 time_endinteraction2 hfid county intername a11_1 a12 a13 a14 b1 c2 c3 c4_1 c4_2)
			
			* Assign new IDs for patients which used same ID by mistake (and we couldn't track them).
			replace	patientid_s	=	"11714-01"	if	key=="uuid:c2e9504e-ef23-40ed-af63-c3de0298e186"
			replace	patientid_s	=	"11714-02"	if	key=="uuid:fa35e52d-9ed1-4142-a286-ea55b52b3d16"
			
			drop	hfid_s date_s interid_s a11_1_s PE_uniqueid
			
			tempfile	PE_nondup_withID
			save		`PE_nondup_withID'
		restore
		
		drop	if	complete!=1
		drop	if	!mi(a11_1)
		
		append	using	`PE_incomplete'
		append	using	`PE_nondup_withID'
		*/	

	*-------------------------------*
	* 1.2. Calculate response rates *
	*-------------------------------*
		
	* Attempted
		mat T = J(4,1,.)
		count
		scalar 	attemp = r(N)
		display attemp
		mat T[1,1] = attemp
	* Consent
		count if a12 == 1
		scalar 	consent = r(N)
		display consent
		mat T[2,1] = consent
	* Able to proceed
		count if a14 == 1
		scalar 	proceed = r(N)
		display proceed
		mat T[3,1] = proceed	
	* Response rate
		scalar resp_rate = proceed/attemp*100
		display resp_rate
		mat T[4,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "Consent" "Able to proceed" "Response rate"
		matlist T
		
	/* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify sheet("Patient Exit")
		putexcel A2 = ("Attempted") A3 = ("Consent") A4 = ("Able to proceed") A5 = ("Response rate") ///
		B2 = matrix(T) 
	*/
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
	
	* Those who gave consent
		keep if a12 == 1
	* Those who were able to proceed
		keep if a14 == 1
	
********************************************************************************
	** Part 2: Complete variables
********************************************************************************
	
	*-----------------------------------------------------*
	* 2.1. Replace "Don't answer"/"Don't know" to missing *
	*-----------------------------------------------------*
	
	* Don't know
		local dk_vars "h4a h4b h4c h4d h4e h4f h4g h4h h4i h4j h4k h4l h4m l2 e2a e2b e2c e2d f3 f5 i1a i1b i1c i1d i1e i1f i1g l1 l8a l8b l10 l13 m1 b3_1 b3_2 c4_1 c4_2 c5 e3 g3 h1a h1b h2a h3a j1 j2 j3 j4 d1 d3s d3t d3u d3v d3w d3x g1"
		local dk_l3 "1 2 _97"
		local dk_l6 "1 2 3 4 5 _97"
		local dk_l9 "1 2 3 _97"
		
		foreach var of local dk_vars {
			replace `var' = .d if `var'==-99
		}
		
		foreach var in l3 l6 l9 {
			foreach option of local dk_`var' {
				replace `var'_`option' = .d if `var'__99==1
			}
		}
	
	* Don't answer
		local da_vars "l1 l4 l8 l10 l14"
		local da_l6 "1 2 3 4 5 _97"
		local da_l15 "1 2 3 4 5 6 _97"
		
		foreach var of local da_vars {
			replace `var' = .r if `var'==-98
		}
		
		foreach var in l6 l15 {
			foreach option of local da_`var' {
				replace `var'_`option' = .r if `var'__98==1
			}
		}
	
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************
	
	*------------------------------------*
	* 3.1. Label define and label values *
	*------------------------------------*
	
	*-----------------------------------------------------------------------*
	* 3.2. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
	
	* Timestamps
		rename facilitycode			 hfid
	
	* Cover and consent
		rename a8 enumeratorid
		rename a8_c enumeratorname
		rename a11_v a3
		rename a11_1 a4
		rename a11_3 a5
		rename a6 a_6
		rename a12 a6
		rename a13 a7
		rename a14 a8
		
	* Respondent's details
		rename b3_1 b2
		rename b3_2 b3
	
	* Patient's details
		rename c2 	c1
		rename c3 	c2
		rename c4_1 c3a
		rename c4_2 c3b
		rename c5 	c4a
		rename c6 	c4b
		*rename c7 	c5
		rename c8 	c6
		rename c9 	c6a
		rename c10	c6b
	
	* Patient's health details
		rename d* d_* 
		rename e1_preventative d1_1
		rename e1_monitoring d1_2
		rename e1_acute d1_3
		rename e5 d2
		rename e2a d3a
		rename e2b d3b
		rename e2c d3c
		rename e2d d3d
		rename e3 d4a
		rename e4 d4b
		rename e6a d5a
		rename e6b d5b
		rename e6e d5c
		rename e6f d5d
		rename e6g d5e
		rename e6h d5f
		rename e6k d5g
		rename e6n d5h
		rename e6c d5i
		rename e6d d5j
		rename e6i d5k
		rename e6j d5l
		rename e6l d5m
		rename e6m d5n
		rename e6o d5o
		
	* Patient's travel details
		rename f1 e1a
		rename f2 e1b
		rename f3 e2
		rename f4_1 e3a
		rename f4_2 e3b
		rename f4_3 e3c
		rename f4_4 e3d
		rename f4_5 e3e
		rename f4_6 e3f
		rename f4_7 e3g
		rename f4_8 e3h
		rename f4_9 e3i
		rename f4_0 e3j
		rename f5 e4
	
	* Alternative details
		rename g3 f1
		rename g1 f2
		rename g2_1 f3_1
		rename g2_2 f3_2
		rename g2_3 f3_3
		rename g2_4 f3_4
		rename g2_5 f3_5
		rename g2_6 f3_6
		rename g2_7 f3_7
		rename g2_8 f3_8
		rename g2_11 f3_11
		rename g2_12 f3_12
		rename g2_13 f3_13
		rename g2_14 f3_14
		rename g2_15 f3_15
		rename g2_16 f3_16
		rename g2_17 f3_17
		rename g2__97 f3_18
		rename g4 f4
		rename g5 f5
		rename g6a f4a
		rename g6b_1 f4b_1
		rename g6b_2 f4b_2
		rename g6b_3 f4b_3
		rename g6b_4 f4b_4
		rename g6b_5 f4b_5
		rename g6b_6 f4b_6
		rename g6b_7 f4b_7
		rename g6b_8 f4b_8
		rename g6b_11 f4b_11
		rename g6b_12 f4b_12
		rename g6b_13 f4b_13
		rename g6b_14 f4b_14
		rename g6b_15 f4b_15
		rename g6b_16 f4b_16
		rename g6b_17 f4b_17
		rename g6b__97 f4b_18
		rename g7a f5a
		rename g7b_1 f5b_1
		rename g7b_2 f5b_2
		rename g7b_3 f5b_3
		rename g7b_4 f5b_4
		rename g7b_5 f5b_5
		rename g7b_6 f5b_6
		rename g7b_7 f5b_7
		rename g7b_8 f5b_8
		rename g7b_11 f5b_11
		rename g7b_12 f5b_12
		rename g7b_13 f5b_13
		rename g7b_14 f5b_14
		rename g7b_15 f5b_15
		rename g7b_16 f5b_16
		rename g7b_17 f5b_17
		rename g7b__97 f5b_18
		rename g8a f6a
		rename g8b f6b
		rename g8c f6c
		
	* Service details
		rename h1 g1
		rename h1a g1a
		rename h1b g1b
		rename h2 g2
		rename h2a g2a
		rename h2b g2b
		rename h3 g3
		rename h3a g3a
		rename h3b g4
		rename h4a g5a
		rename h4b g5b
		rename h4c g5c
		rename h4d g5d
		rename h4e g5e
		rename h4f g5f
		rename h4g g5g
		rename h4h g5h
		rename h4i g5i
		rename h4j g5j
		rename h4k g5k
		rename h4l g5l
		rename h4m g5m
	
	* Quality perception and awareness // no rename needed
		
	* Hypothetical questions // no rename needed
	
	* Service satisfaction details
		rename i1a h1a
		rename i1b h1b
		rename i1c h1c
		rename i1d h1d
		rename i1e h1e
		rename i1f h1f
		rename i1g h1g
		rename i2 h2
		
	* Payment details
		rename j1 i1
		rename j2 i2 
		rename j3 i3
		rename j4 i4
	
	* Patient's household details
		rename d_1 j1
		rename d_2 j2
		rename d_3a j3a
		rename d_3b j3b
		rename d_3c j3c
		rename d_3d j3d
		rename d_3e j3e
		rename d_3f j3f
		rename d_3g j3g
		rename d_3h j3h
		rename d_3i j3i
		rename d_3j j3j
		rename d_3k j3k
		rename d_3l j3l
		rename d_3m j3m
		rename d_3n j3n
		rename d_3o j3o
		rename d_3p j3p
		rename d_3q j3q
		rename d_3r j3r
		rename d_3s j3s
		rename d_3t j3t
		rename d_3u j3u
		rename d_3v j3v
		rename d_3w j3w
		rename d_3x j3x
		rename d_3y j3y
		rename d_3z j3z

	* Final details
	    
		rename k1_1	k2
		rename k1_1_o k2_o
		rename k1_2	k3
		rename k1_2_o k3_o
		rename k1_3 k4
		rename k1_3_o k4_o
		rename k2_1 k5
		rename k6 k_6
		rename k2_2 k6
		rename k2_3 k7
		rename k2_4 k8
		rename k3_english k9_1
		rename k3_swahili k9_2
		rename k3_mijikenda k9_3
		rename k3_kimeru k9_4
		rename k3_luhya k9_5
		rename k3__97 k9_6	
		rename k5_1 k10_1
		rename k5_2 k10_2
		rename k5_3 k10_3
		rename k5_4 k10_4
		rename k5_5 k10_5
		rename k5_6 k10_6	
		rename k11* k13*
		rename k_6 k11
		rename a_6 k12
		rename d_ate date
		
	*----------------------*
	* 3.3. Label variables *
	*----------------------*
	
	* Preloaded data
		lab var date			"Survey date"
		lab var time			"Survey time"
		lab var hfid 			"Facility ID"
		lab var key 			"Survey CTO ID"
		lab var time_end 		"Time after last question"
		lab var time_start 		"Time before consent"
				
	* Cover and consent
		lab var enumeratorid	"Enumerator ID"
		lab var enumeratorname	"Enumerator Name"
		lab var a3 				"Patient has and ID number"
		lab var a4 				"Patient ID"
		lab var a5 				"Which language you will be conducting this survey in?"
		lab var a6 				"Patient's consent"
		lab var a7 				"Someone else is speaking for the patient"
		lab var a8 				"Are you able to proceed with the survey?"
	
	* Respondent's details
		lab var b1 "Respondent: Relationship with the patient (if a8 = 1 and a9 = 1)"
		lab var b2 "Respondent: Year of birth (if a8 = 1 and a9 = 1)"
		lab var b3 "Respondent: Age (if a8 = 1 and a9 = 1)"
		lab var b4 "Respondent: Gender (if a8 = 1 and a9 = 1)"
		lab var b5 "Respondent: Are you in school right now? (if a8 = 1 and a9 = 1)"
		lab var b6 "Respondent: What level of education are you at? (if b5 = 1)"
		lab var b7 "Respondent: Highest completed education level (if b5 = 0)"
	
	* Patient's details	
		lab var c1  "Patient: Gender"
		lab var c2  "Patient: Is under two years old?"
		lab var c3a "Patient: Year of birth (if c2 = 0)"
		lab var c3b "Patient: Year of birth (if c2 = 1)"
		lab var c4a "Patient: Age (if c2 = 0)"
		lab var c4b "Patient: Age (if c2 = 1)"
		lab var c6  "Patient: Is still in school? (if c4a >= 6)"	
		lab var c6a "Patient: Where is going to for school? (if c6 = 1 and c4a >= 6)"
		lab var c6b "Patient: Highest qualification (if c6 = 0 and c4a >= 6)"
	
	* Patient's health details
		lab var d1_1 "Reasons to come includes: Preventive visit such as ANC or vaccination"
		lab var d1_2 "Reasons to come includes: Ongoing monitoring or medication for an ongoing illness"
		lab var d1_3 "Reasons to come includes: Diagnosis and treatment"
		lab var d2	"Overall health state"
		lab var d3a "Comfortable when putting on clothes (if c4a > 6 and d1_3 = 1)"
		lab var d3b "Comfortable when doing light work around house (if c4a > 6 and d1_3 = 1)"
		lab var d3c "Comfortable when lifting a bag (5kg) & walking (100 m) (if c4a > 6 and d1_3 = 1)"
		lab var d3d "Comfortable when walking 200-300 m (if c4a > 6 and d1_3 = 1)"
		lab var d4a "How long have you been sick? (if d1_2 = 1 or d1_3 = 1)"
		lab var d4b "Units (if d1_2 = 1 or d1_3 = 1)"
		lab var d5a "Are you experiencing: Cough/cold (if d1_2 = 1 or d1_3 = 1)"
		lab var d5b "Are you experiencing: Fever (if d1_2 = 1 or d1_3 = 1)"
		lab var d5c "Are you experiencing: Sweats (if d1_2 = 1 or d1_3 = 1)"
		lab var d5d "Are you experiencing: Diarrhea (if d1_2 = 1 or d1_3 = 1)"
		lab var d5e "Are you experiencing: Vomiting (if d1_2 = 1 or d1_3 = 1)"
		lab var d5f "Are you experiencing: Chills (if d1_2 = 1 or d1_3 = 1)"
		lab var d5g "Are you experiencing: Skin problems (if d1_2 = 1 or d1_3 = 1)"
		lab var d5h "Are you experiencing: Shaking (if d1_2 = 1 or d1_3 = 1)"
		lab var d5i "Are you experiencing: Weakness (if d1_2 = 1 or d1_3 = 1)"
		lab var d5j "Are you experiencing: Fatigue (if d1_2 = 1 or d1_3 = 1)"
		lab var d5k "Are you experiencing: Stomach pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5l "Are you experiencing: Head pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5m "Are you experiencing: Chest pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5n "Are you experiencing: Limbs pain (if d1_2 = 1 or d1_3 = 1)"
		lab var d5o "Are you experiencing: Other (if d1_2 = 1 or d1_3 = 1)"
		
	* Patient's travel details
		lab var e1a "Patient's village/town/city name"
		lab var e1b "Settlement type"
		lab var e2  "Distance from home"
		lab var e3a "Mode of transport includes: Own vehicle"
		lab var e3b "Mode of transport includes: Bicycle"
		lab var e3c "Mode of transport includes: Taxi"
		lab var e3d "Mode of transport includes: By foot"
		lab var e3e "Mode of transport includes: Boat or ferry"
		lab var e3f "Mode of transport includes: Bus"
		lab var e3g "Mode of transport includes: Motorbike"
		lab var e3h "Mode of transport includes: Matatu"
		lab var e3i "Mode of transport includes: Train"
		lab var e3j "Mode of transport includes: Other Private Vehicle"
		lab var e4  "Total time from home to HF"
	
	* Alternative details	
		lab var f1 "In which year did you start coming to this facility?"
		lab var f2 "How many other facilities could you have gone to for this condition today?"
		lab var f3_1 "Reasons to choose the HF: Better services (if f2 != 0)"
		lab var f3_2 "Reasons to choose the HF: Wider variety of serices (if f2 != 0)"
		lab var f3_3 "Reasons to choose the HF: Higher quality (if f2 != 0)"
		lab var f3_4 "Reasons to choose the HF: Shorter waiting time (if f2 != 0)"
		lab var f3_5 "Reasons to choose the HF: Shorter distance/more convenient to travel (if f2 != 0)"
		lab var f3_6 "Reasons to choose the HF: Cheaper (if f2 != 0)"
		lab var f3_7 "Reasons to choose the HF: My insurance is accepted here (if f2 != 0)"
		lab var f3_8 "Reasons to choose the HF: Better staff (if f2 != 0)"
		lab var f3_11 "Reasons to choose the HF: Better results (if f2 != 0)"
		lab var f3_12 "Reasons to choose the HF: I always come to this health facility (if f2 != 0)"
		lab var f3_13 "Reasons to choose the HF: The facility I usually go to was closed (if f2 != 0)"
		lab var f3_14 "Reasons to choose the HF: Recommended by someone (if f2 != 0)"
		lab var f3_15 "Reasons to choose the HF: Trying this facility for the first time (if f2 != 0)"
		lab var f3_16 "Reasons to choose the HF: Better availability of essential medicines (if f2 != 0)"
		lab var f3_17 "Reasons to choose the HF: No reason (if f2 != 0)"
		lab var f3_18 "Reasons to choose the HF: Other (if f2 != 0)"
		lab var f4 "Public HF available to treat patient's condition if private HF & another HF available"
		lab var f5 "Private HF available to treat patient's condition if public HF & another HF available"
		lab var f4a "Reason choose private HF"
		lab var f4b_1 "Additional reasons: Better services if private & another HF available"
		lab var f4b_2 "Additional reasons: Wider variety of serices if private & another HF available"
		lab var f4b_3 "Additional reasons: Higher quality if private & another HF available"
		lab var f4b_4 "Additional reasons: Shorter waiting time if private & another HF available"
		lab var f4b_5 "Additional reasons: Shorter distance/more convenient to travel if private & another HF available"
		lab var f4b_6 "Additional reasons: Cheaper if private & another HF available"
		lab var f4b_7 "Additional reasons: My insurance is accepted here if private & another HF available"
		lab var f4b_8 "Additional reasons: Better staff if private & another HF available"
		lab var f4b_11 "Additional reasons: Better results if private & another HF available"
		lab var f4b_12 "Additional reasons: I always come to this private health facility if private & another HF available"
		lab var f4b_13 "Additional reasons: The public facility was closed if private & another HF available"
		lab var f4b_14 "Additional reasons: Recommended by someone if private & another HF available"
		lab var f4b_15 "Additional reasons: Trying this facility for the first time if private & another HF available"
		lab var f4b_16 "Additional reasons: Better availability of essential medicines if private & another HF available"
		lab var f4b_17 "Additional reasons: No other reason if private & another HF available"
		lab var f4b_18 "Additional reasons: Other if private & another HF available"
		lab var f5a "Reason choose public HF"
		lab var f5b_1 "Additional reasons: Better services  if public & another HF available"
		lab var f5b_2 "Additional reasons: Wider variety of serices  if public & another HF available"
		lab var f5b_3 "Additional reasons: Higher quality  if public & another HF available"
		lab var f5b_4 "Additional reasons: Shorter waiting time  if public & another HF available"
		lab var f5b_5 "Additional reasons: Shorter distance/more convenient to travel  if public & another HF available"
		lab var f5b_6 "Additional reasons: Cheaper  if public & another HF available"
		lab var f5b_7 "Additional reasons: My insurance is accepted here  if public & another HF available"
		lab var f5b_8 "Additional reasons: Better staff  if public & another HF available"
		lab var f5b_11 "Additional reasons: Better results  if public & another HF available"
		lab var f5b_12 "Additional reasons: I always come to this public health facility  if public & another HF available"
		lab var f5b_13 "Additional reasons: The private facility was closed  if public & another HF available"
		lab var f5b_14 "Additional reasons: Recommended by someone  if public & another HF available"
		lab var f5b_15 "Additional reasons: Trying this facility for the first time  if public & another HF available"
		lab var f5b_16 "Additional reasons: Better availability of essential medicines  if public & another HF available"
		lab var f5b_17 "Additional reasons: No other reason  if public & another HF available"
		lab var f5b_18 "Additional reasons: Other  if public & another HF available"
		lab var f6a "Type of care if chest pain/anxiety morning"
		lab var f6b "Type of care if a child of 8 months old has diarrhea for 2 days"
		lab var f6c "Type of care if high fevers, shaking chills, fatigue"
	
	* Service details
		lab var g1  "Examination from a health care worker recieved"
		lab var g1a "Minutes waited before examination (if g1 = 1)"
		lab var g1b "Minutes spent with the health care worker (if g1 = 1)"
		lab var g2  "Laboratory services received"
		lab var g2a "Minutes waited in line to run the tests (if g2 = 1)"
		lab var g2b "Blood test (if g2 = 1)"
		lab var g3  "Medicines from  pharmacy recived"
		lab var g3a "Minutes waited in line to receive the medicines (if g3 = 1)"
		lab var g4  "Injection with medicine for treatment recieved"
		lab var g5a "Did the provider: take your pulse (if g1 = 1)"
		lab var g5b "Did the provider: check your blood pressure (if g1 = 1)"
		lab var g5c "Did the provider: listen, either directly or through a stethoscope, to the front of your body (if g1 = 1)"
		lab var g5d "Did the provider: listen, either directly or through a stethoscope, to the back of your body (if g1 = 1)"
		lab var g5e "Did the provider: perform a throat exam (if g1 = 1)"
		lab var g5f "Did the provider: take your temperature with a thermometer (if g1 = 1)"
		lab var g5g "Did the provider: take your temperature by touch (if g1 = 1)"
		lab var g5h "Did the provider: conduct other tests e.g., malaria, stool (if g1 = 1)"
		lab var g5i "Did the provider: do a basic check e.g., weight, height (if g1 = 1)"
		lab var g5j "Did the provider: conduct other exams e.g., eye examination (if g1 = 1)"
		lab var g5k "Did the provider: do a follow-up check on you from a previous visit (if g1 = 1)"
		lab var g5l "Did the provider: refer you to another health facility for other services (if g1 = 1)"
		lab var g5m "Did the provider: give you medicines (or prescription) (if g1 = 1)"

	* Quality perception and awareness 
		lab var l3_1 "Who performs inspections includes: Central government / Ministry of Health"
		lab var l3_2 "Who performs inspections includes: County government / Sub-county office"
		lab var l3__97 "Who performs inspections includes: Other (Specify)"
		lab var l3__99 "Who performs inspections includes: Don’t know"
		lab var l6_1 "Reported the problem to: In-charge"
		lab var l6_2 "Reported the problem to: Owner (if HF is private)"
		lab var l6_3 "Reported the problem to: Central government / Ministry of Health"
		lab var l6_4 "Reported the problem to: County government / Sub-county office"
		lab var l6_5 "Reported the problem to: Boards and Councils"
		lab var l6__97 "Reported the problem to: Other (specify)"
		lab var l6__99 "Reported the problem to: Don’t know/Don’t remember"
		lab var l6__98 "Reported the problem to: Don’t answer"
		lab var l9_1 "Purpose of the scorecard includes: It is a form of recognition for the facility"
		lab var l9_2 "Purpose of the scorecard includes: It measures quality"
		lab var l9_3 "Purpose of the scorecard includes: It contains the result of an inspection"
		lab var l9__97 "Purpose of the scorecard includes: Other (specify)"
		lab var l9__99 "Purpose of the scorecard includes: Don’t know/Don’t remember"	
		lab var l15_1 "How closures affected the patient: I have less options to choose from"
		lab var l15_2 "How closures affected the patient: I have to go farther to receive health care"
		lab var l15_3 "How closures affected the patient: They closed my facility"
		lab var l15_4 "How closures affected the patient: I have to pay more for health care services"
		lab var l15_5 "How closures affected the patient: The facilities are more crowded / I have longer waiting times"
		lab var l15_6 "How closures affected the patient: I have better options to receive health care"
		lab var l15__97 "How closures affected the patient: Other (specify)"
		lab var l15__98 "How closures affected the patient: Don’t answer"
		
	* Hypothetical questions // no labeling needed
		lab var m1_o "If other, please specify"
	
	* Service satisfaction details
		lab var h1a "Problem discussing condition with HCW (if g1 = 1)"
		lab var h1b "Problem with explanations about problem or treatment (if g1 = 1)"
		lab var h1c "Problem quality exami. & treatment provided (if g1 = 1)"
		lab var h1d "Problem availability medicines/methods (if g1 = 1 or g3 = 1)"
		lab var h1e "Problem with cleanliness of HF"
		lab var h1f "Problem with how the staff treated you"
		lab var h1g "Problem with waiting time"
		lab var h2  "Satisfaction with HF"
	
	* Payment details
		lab var i1 "Total amount paid out of pocket for the visit"
		lab var i2 "Total amount paid for the examination (if g1 = 1 and i1 > 0)"
		lab var i3 "Total amount paid for laboratory services (if g2 = 1 and i1 > 0)"
		lab var i4 "Total amount paid for medicines (if g3 = 1 and i1 > 0)"
	
	* Patient's household details
		lab var j1 "Total number of people who live in the household"
		lab var j2 "Gender of the household breadwinner"
		lab var j3a "Household has: Electricity from the grid"
		lab var j3b "Household has: Running water in the house"
		lab var j3c "Household has: Clock"
		lab var j3d "Household has: Radio"
		lab var j3e "Household has: Television"
		lab var j3f "Household has: Mobile telephone"
		lab var j3g "Household has: Landline"
		lab var j3h "Household has: Refrigerator"
		lab var j3i "Household has: Solar Panel"
		lab var j3j "Household has: Bicycle"
		lab var j3k "Household has: Boat"
		lab var j3l "Household has: Car or truck"
		lab var j3m "Household has: Motorbike"
		lab var j3n "Household has: Animal drawn cart"
		lab var j3o "Household has: Ownership of the dwelling"
		lab var j3p "Household has: Ownership of the land the dwelling is built on"
		lab var j3q "Household has: Ownership of agricultural land (anywhere)"
		lab var j3r "Household has: Ownership of farm animals (anywhere)"
		lab var j3s "Household has: Number of milk cows or bulls (if j3r = 1)"
		lab var j3t "Household has: Number of horses, donkeys or mules (if j3r = 1)"
		lab var j3u "Household has: Number of goats (if j3r = 1)"
		lab var j3v "Household has: Number of sheep (if j3r = 1)"
		lab var j3w "Household has: Number of chicken (if j3r = 1)"
		lab var j3x "Household has: Number of rooms in your house that are used for sleeping"
		lab var j3y "Household has: Separate room that is used as a kitchen"
		lab var j3z "Household has: Toilet shared with other households"
	
	* Final details
		lab var k1  "Result of the survey (if a6 = 0 or a8 = 0)"
		lab var k2  "Why was it partially completed? (if k1 = 2)"
		lab var k3  "Why was it not started? (if k1 = 3)"
		lab var k4  "Why did respondent refuse? (if k2 == 1 or k3 == 1)"
		lab var k5  "Estimate the age group of the respondent"
		lab var k6  "Estimate the age group of the patient"
		lab var k7  "Enter the gender of the respondent"
		lab var k8  "Enter the gender of the patient"
		lab var k9_1 "Languages used: English"
		lab var k9_2 "Languages used: Swahili"
		lab var k9_3 "Languages used: Mijikenda (if Kilifi)"
		lab var k9_4 "Languages used: Kimeru (if Meru)"
		lab var k9_5 "Languages used: Luhya if (Kakamega)"
		lab var k9_6 "Languages used: Other languages"
		lab var k10_1 "How much of the survey did you conduct in English? (if k5_1 = 1)"
		lab var k10_2 "How much of the survey did you conduct in Swahili? (if k5_2 = 1)"
		lab var k10_3 "How much of the survey did you conduct in Mijikenda? (if k5_3 = 1)"
		lab var k10_4 "How much of the survey did you conduct in Kimeru? (if k5_4 = 1)"
		lab var k10_5 "How much of the survey did you conduct in Luhya? (if k5_5 = 1)"
		lab var k10_6 "How much of the survey did you conduct in another language? (if k5_6 = 1)"
		lab var k11 "Was a translator used?"
		
	* Drop additional variables
		drop a2_1_v a2_1 d_iff1 a2_2
		
	*---------------------*
	* 3.4. Order database *
	*---------------------*
				
		global preload		date time key time_start time_end
		
		global basics 		enumeratorid enumeratorname a3 a4 a5 a6 a7 a8 
							
		global respondent 	b1 b2 b3 b4 b5 b6 b7
							
		global charac_p		c1 c2 c3a c3b c4a c4b c6 c6a c6b
							
		global health_p		d1_1 d1_2 d1_3 d2 d3a d3b d3c d3d d4a d4b d5a d5b d5c d5d d5e d5f ///
							d5g	d5h	d5i	d5j d5k	d5l	d5m	d5n	d5o
							
		global travel_p		e1a	e1b e2 e3a	e3b	e3c e3d	e3e	e3f	e3g	e3h	e3i e3j	e4	     
												
		global altern_p		f1	f2 f3_1	f3_2 f3_3 f3_4 f3_5 f3_6 f3_7 f3_8 f3_11  ///	
							f3_12 f3_13 f3_14 f3_15 f3_16 f3_17	f3_18 f4 f4a f4b_1 f4b_2 f4b_3	 ///
							f4b_4	f4b_5 f4b_6	f4b_7	f4b_8 f4b_11 ///
							f4b_12	f4b_13 	f4b_14 f4b_15	f4b_16	f4b_17	f4b_18	///
							f5	f5a	f5b_1	f5b_2	f5b_3	f5b_4	f5b_5	f5b_6	///
							f5b_7 f5b_8	f5b_11	f5b_12	f5b_13	f5b_14	///
							f5b_15	f5b_16	f5b_17 f5b_18 f6a f6b f6c
							
		global service		g1	g1a	g1b	g2	g2a	g2b	g3	g3a	g4	g5a	g5b	g5c	g5d	g5e	///
							g5f	g5g	g5h	g5i	g5j	g5k	g5l	g5m		
							
		global perception   l1 l2 l3_1 l3_2 l3__97 l3__99 l3_o l4 l5 l6_1 l6_2 l6_3 ///
							l6_4 l6_5 l6__97 l6__99 l6__98 l6_o l7 l8 l8a l8a_o l8b ///
							l8b_o l9_1 l9_2 l9_3 l9__97 l9__99 l9_o l10 l11 l12 l13 ///
							l14 l15_1 l15_2 l15_3 l15_4 l15_5 l15_6 l15__97 l15__98 ///
							l15_o				
						
		global hyp_q		m1 m1_o
						
		global satisfac		h1a h1b h1c h1d h1e h1f h1g h2
	 
		global payment		i1	i2	i3	i4	j1
		
		global household	j2	j3a	j3b	j3c	j3d	j3e	j3f	j3g	j3h	j3i	j3j	j3k	j3l	j3m	///
							j3n	j3o	j3p	j3q	j3r	j3s	j3t	j3u	j3v	j3w	j3x	j3y	j3z
													
		global finald		k1 k2 k2_o k3 k3_o k4 k4_o k5 k6 k7 k8 k9_1 k9_2 k9_3 k9_4 k9_5 k9_6 ///
							k10* k11 k12 
							
		global gps			k13*
			
		order $preload $basics $respondent $charac_p $health_p $travel_p $altern_p $service $perception $hyp_q $satisfac $payment $household $finald $gps	 
  
********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 4.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Drop old profile information
		drop k13*
	
	* Merge profile information
		local prof_vars "latitude longitude hfid  hfname county subcounty private level" // hfid_m location sublocation ownership inchargename inchargenumber

		merge m:1 hfid using "${profile_end}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
	
	* Order dataset
		order `prof_vars', after(key)
		
	/*-------------------------------------*
	* 4.2. Save database for construction *
	*-------------------------------------*

	if c(stata_version)>=14 {
		saveold "${PE_clean_pii}", replace v(13)
	}
	else {
		save "${PE_clean_pii}", replace
	}
	*/
	*----------------*
	* 4.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude  //hfid hfname location sublocation inchargename inchargenumber enumeratorname

	*--------------------------------------------*
	* 4.4. Save database for microdata catalogue *
	*--------------------------------------------*A
	
		save "${pe_clean}", replace
		
	*preserve
	
	/*-----------------------*
	* 4.5. Build dictionary *
	*-----------------------*

	codebookout "${dictionary}", replace
	
	* Restore clean dataset
	restore

	*-----------------------------*
	* 4.6. Descriptive statistics *
	*-----------------------------*

	global select_one "county level a5 b1 b4 b6 b7 c1 c6a c6b d2 d3a d3b d3c d3d e1b e4 f4a f5a f6a f6b f6c l1 l8 l8a l8b l10 m1 h1a h1b h1c h1d h1e h1f h1g h2 j2"
	
	foreach var of global select_one {
		loc varlab: variable label `var'
		lab var `var' "`var': `varlab'"
		tab `var', gen(`var'_)
		order `var'_*, after(`var')
		replace `var'=.
	}
		
	
	ds, has(type numeric)
	local num_vars `r(varlist)'

	foreach var in `num_vars' {
		loc varlab: variable label `var'
		loc varlab_nocomma=subinstr("`varlab'",",","",.)
		lab var `var' "`varlab_nocomma'"
	}
	
	set matsize 500
	estpost	tabstat `num_vars', ///
					statistics(n mean sd min max p50 p90) ///
					columns(statistics)
						
	esttab 	using "${desc_stats}", ///
				cells("count(label(N)) mean(label(Mean) fmt(%9.2f)) sd(label(Std Dev) fmt(%9.2f)) min(label(Min)) max(label(Max)) p50(label(Median)) p90(label(p90))") ///
				label ///
				noobs nonumber mtitles("Descriptive Statistics") ///
				replace	
	*/
	
	* Dismount
	veracrypt, dismount drive("${mount}") 
