/*******************************************************************************	

Project:  		KePSIE
Created on:  	October 15, 2018
Last udpate on: Nov 9, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		Guadalupe Bedoya

********************************************************************************			

THIS DO FILE: 	Cleans the HCW-Patient observation checklist for upload in the WB microdata catalog


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
					 	 1.1 - Fixing/Completing variables
						 1.2 - Drop duplicates
						 1.3 - Correcting issues with facility_id and HCW_id
						 1.4 - Calculate response rates
				Part 2 - Basic cleaning
						 2.1 - Rename variables to coincide with printer-friendly questionnaire
						 2.2 - Inputations
						 2.3 - Label variables
						 2.4 - Additional fix
						 2.5 - Order database	
				Part 3 - Save different files and anonymize 
						 3.1 - Upload HF’s information with profile information corrected
						 3.2 - Save database for construction
						 3.3 - Anonymize
						 3.4 - Save database for microdata catalogue
						 3.5 - Build dictionnary					
						 
INPUTS:     	* Raw data
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/final_reconciliation.dta"
			
				* Spotchecker list
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/spotcheckers.xlsx"
				
				* Input IR
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PPS_DO_IR_Fix_24May2016.csv"
				
				* Input Corrected IDs
				"$KePSIE_DB/DataAnalysis/Baseline/RawData/PPS_Merge_CorrectedIDs_30May2016.csv"
				
				* HF Baseline profile data
				"${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta"

OUTPUTS:     	* Anonymized data for microdata catalog
				"${bl_dt}/Final/PPS_DO_clean_nopii.dta"
				
				* Non-anonymized data for further analysis
				"${bl_dt}/Final/PPS_DO_clean_pii.dta"

				* Quality checks 
				"${bl_dt}/Intermediate/PPS_DO_quality_checks.dta"
				
				* Dictionary
				"${bl_out}/Final/PPS_DO_clean_nopii_dictionary.xls"
				
				* Response rate table
				"${bl_out}/Final/PPS_DO_response_rate.xls"
				
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo pps_do 				"${volume}/pps_do_end_raw.dta"
		glo listing_end			"${dt_mast}/listing_end.dta"
		
	* Output files
		glo pps_do_clean		"${dt_end_clean}/pps_do_end.dta"

********************************************************************************
	** Part 1: Complete database
********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")
	
	use "${pps_do}", clear
		
	*----------------------------------*
	* 1.1. Fixing/Completing variables *
	*----------------------------------*
	
	/* PPS_DO notes for cleaning data: 
	- One HCW that was assigned two IDs (based on report in Data tab of Issues Tracking gsheet:
	[RK] In Emaraba Baptist Dispensary (500095) ,the team had visited this facility for the first time and 
	had done one pps observation,for the second visit the team had to asign the same Hcw another diffeerent ID.	
	[RdG] Thank you for reporting Rodgers. I guess they had to assign him/her another ID because the sticker was 
	no longer available? Could you just confirm which are the two IDs that identify the same HCW? I will make 
	a note to correct in the data once the PPS_DO data is entered. Also, I do not see any HCW survey for this HF?
	[RK] The two HCW IDs were 447,770 and the HCW survey was done and submitted.Thank you.
	--->     
	rename aa3 hfid
	assert hfid==500095 if inlist(aa4,"447","770")
	replace aa4="447" if aa4=="770"
*/

	
	
	* Renames of variables
		rename aa4 enuid
		rename aa3 facilityid
		rename aa10 patientid
		rename aa9 hcwid
		rename aa8_a aa8_a
		rename aa8_b aa8_b
		rename aa8_c aa8_c
		
		
	* Time format	
		gen double time_start = clock(aa6, "hm")
		replace time_start = clock(aa6, "hms") if mi(time_start)
		format time_start %tc_HH:MM
		order time_start, after(aa6)
		lab var time_start "Start time"
		drop aa6
		rename time_start aa6

			
	* Date
		/* Create flag
			gen flag_date = 1 if mi(aa5)
			replace flag_date=1 if aa5=="  3/7/2018"
			split aa5, p("/", ".", "-")
			replace flag_date=1 if inlist(aa52, "0", "03", "05", "2018", "3", "7", "Oct", "Sep")
			replace aa52="Apr" if aa52=="apr"
			replace flag_date=1 if aa53!="18" & !mi(aa53)
			replace flag_date=1 if mi(aa51) | mi(aa52) | mi(aa53) 
			replace flag_date=0 if mi(flag_date)
			br aa5* flag_date
			replace aa5="" if flag_date==1
			replace aa51="" if flag_date==1
			replace aa52="" if flag_date==1
			replace aa53="" if flag_date==1
			replace aa53="2018" if aa53=="18"
			-
		* Create date
			destring aa51 aa52 aa53, replace
			
					* Formatting date
		gen date = date(aa5,"DMY") if !mi(aa5)
		format date1 %td
		drop date
		rename date1 date

			-

			gen date = aa51 + "-" + aa5_date2 + "-" + aa5_date3
	*/

	*-------------------------*
	* 1.2. Manual corrections *
	*-------------------------*
	
	/* PPS_DO notes for cleaning data: 
		- One HCW that was assigned two IDs (based on report in Data tab of Issues Tracking gsheet:
		[RK] In Emaraba Baptist Dispensary (500095) ,the team had visited this facility for the first time and 
		had done one pps observation,for the second visit the team had to asign the same Hcw another diffeerent ID.	
		[RdG] Thank you for reporting Rodgers. I guess they had to assign him/her another ID because the sticker was 
		no longer available? Could you just confirm which are the two IDs that identify the same HCW? I will make 
		a note to correct in the data once the PPS_DO data is entered. Also, I do not see any HCW survey for this HF?
		[RK] The two HCW IDs were 447,770 and the HCW survey was done and submitted.Thank you.
		--->    
	*/
		assert facilityid==500095 if inlist(hcwid,"447","770")
		replace hcwid="447" if hcwid=="770"
		
	* Recode and destring patientid 
		replace patientid=".d" if patientid=="N/A" | patientid=="13+20"
		replace patientid=".r" if patientid=="Refused"
		destring patientid, replace
			
	* Correction of facilityid based on HCWid
		replace facilityid=800004 if hcwid=="68" & facilityid==8000004
		replace facilityid=19357 if hcwid=="344" & facilityid==19537
		replace facilityid=16141 if hcwid=="383" & facilityid==1614
		replace facilityid=16037 if hcwid=="397" & facilityid==1970
		replace facilityid=15906 if hcwid=="413" & facilityid==13906
		replace facilityid=15936 if hcwid=="415" & facilityid==15986
		replace facilityid=900904 if hcwid=="461" & facilityid==9009021
		replace facilityid=800076 if hcwid=="462" & facilityid==80076
		replace facilityid=800076 if hcwid=="462" & facilityid==80076
		replace facilityid=20041 if hcwid=="467" & facilityid==10041
		replace facilityid=15945 if hcwid=="491" & facilityid==15932
		replace facilityid=15873 if hcwid=="503" & facilityid==1438 // wrote the surveyid
		replace facilityid=15827 if hcwid=="506" & facilityid==.
		replace facilityid=17596 if hcwid=="511" & facilityid==19596
		replace facilityid=17596 if hcwid=="511" & facilityid==19596
		replace facilityid=17596 if hcwid=="511" & facilityid==19596
		replace facilityid=15914 if hcwid=="518" & facilityid==15314
		replace facilityid=17297 if hcwid=="525" & facilityid==117297
		replace facilityid=16865 if hcwid=="528" & facilityid==16
		replace facilityid=16865 if hcwid=="528" & facilityid==16856
		replace facilityid=15915 if hcwid=="576" & facilityid==435 // wrote the surveyid
		replace facilityid=17133 if hcwid=="581" & facilityid==217133
		replace facilityid=500004 if hcwid=="590" & facilityid==506004
		replace facilityid=901005 if hcwid=="591" & facilityid==9010050
		replace facilityid=901005 if hcwid=="591" & facilityid==9010050
		replace facilityid=901527 if hcwid=="600" & facilityid==601527
		replace facilityid=15801 if hcwid=="601" & facilityid==15701
		replace facilityid=20515 if hcwid=="626" & facilityid==5359 // wrote the surveyid
		replace facilityid=16111 if hcwid=="635" & facilityid==.
		replace facilityid=17298 if hcwid=="646" & facilityid==3265 // wrote the surveyid
		replace facilityid=16058 if hcwid=="690" & facilityid==16085
		replace facilityid=500097 if hcwid=="721" & facilityid==50097
		replace facilityid=15900 if hcwid=="805" & facilityid==.
		replace facilityid=16119 if hcwid=="820" & facilityid==.
		replace facilityid=15874 if hcwid=="841" & facilityid==1574
		replace facilityid=12049 if hcwid=="867" & facilityid==120449
		replace facilityid=12326 if hcwid=="870" & facilityid==136
		replace facilityid=555586 if hcwid=="881" & facilityid==5555586
		replace facilityid=12036 if hcwid=="889" & facilityid==1203
		replace facilityid=12290 if hcwid=="952" & facilityid==12209
		replace facilityid=12290 if hcwid=="952" & facilityid==12209
		replace facilityid=555558 if hcwid=="958" & facilityid==55558
		replace facilityid=12181 if hcwid=="972" & facilityid==16353
		replace facilityid=18700 if hcwid=="1003" & facilityid==.
		replace facilityid=18700 if hcwid=="1003" & facilityid==.
		replace facilityid=21682 if hcwid=="1022" & facilityid==21683
		replace facilityid=21682 if hcwid=="1022" & facilityid==21683
		replace facilityid=21682 if hcwid=="1022" & facilityid==21683
		replace facilityid=21682 if hcwid=="1022" & facilityid==21683
		replace facilityid=18017 if hcwid=="1066" & facilityid==18071
		replace facilityid=901312 if hcwid=="1078" & facilityid==16680 // wrote the surveyid
		replace facilityid=18704 if hcwid=="1082" & facilityid==16198
		replace facilityid=12337 if hcwid=="1136" & facilityid==123
		replace facilityid=12743 if hcwid=="1161" & facilityid==16379
		replace facilityid=555581 if hcwid=="1178" & facilityid==55558
		replace facilityid=12200 if hcwid=="1194" & facilityid==1220
		replace facilityid=12302 if hcwid=="1239" & facilityid==12309
		replace facilityid=18289 if hcwid=="1259" & facilityid==18239
		replace facilityid=18289 if hcwid=="1259" & facilityid==18239
		replace facilityid=17287 if hcwid=="1276" & facilityid==17714
		replace facilityid=19188 if hcwid=="1284" & facilityid==18947
		replace facilityid=20567 if hcwid=="1286" & facilityid==20569
		replace facilityid=500102 if hcwid=="1300" & facilityid==500103
		replace facilityid=500119 if hcwid=="1318" & facilityid==50049
		replace facilityid=901064 if hcwid=="1334" & facilityid==19404 // wrote the surveyid
		replace facilityid=17709 if hcwid=="1344" & facilityid==17719
		replace facilityid=11829 if hcwid=="1367" & facilityid==1829
		replace facilityid=11401 if hcwid=="1372" & facilityid==1140
		replace facilityid=11244 if hcwid=="1382" & facilityid==112444
		replace facilityid=20345 if hcwid=="1395" & facilityid==23045
		replace facilityid=11881 if hcwid=="1409" & facilityid==14314
		replace facilityid=11555 if hcwid=="1418" & facilityid==1555
		replace facilityid=11555 if hcwid=="1418" & facilityid==1555
		replace facilityid=11677 if hcwid=="1447" & facilityid==111677
		replace facilityid=11843 if hcwid=="1474" & facilityid==11655
		replace facilityid=21166 if hcwid=="1477" & facilityid==21162
		replace facilityid=18869 if hcwid=="1544" & facilityid==18006
		replace facilityid=18869 if hcwid=="1544" & facilityid==18030
		replace facilityid=12429 if hcwid=="1554" & facilityid==12129
		replace facilityid=510840 if hcwid=="1575" & facilityid==150840
		replace facilityid=510840 if hcwid=="1575" & facilityid==570840
		replace facilityid=11696 if hcwid=="1629" & facilityid==11865
		replace facilityid=11607 if hcwid=="1663" & facilityid==13496
		replace facilityid=11387 if hcwid=="1674" & facilityid==11389
		replace facilityid=11387 if hcwid=="1678" & facilityid==11378
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=11851 if hcwid=="1698" & facilityid==11581
		replace facilityid=20300 if hcwid=="1701" & facilityid==13378 // wrote the surveyid
		replace facilityid=16527 if hcwid=="1713" & facilityid==16227
		replace facilityid=900693 if hcwid=="1715" & facilityid==900613
		replace facilityid=11379 if hcwid=="1719" & facilityid==13391
		replace facilityid=11384 if hcwid=="1747" & facilityid==14546 // wrote the surveyid
		replace facilityid=19019 if hcwid=="1752" & facilityid==190190
		replace facilityid=11248 if hcwid=="1770" & facilityid==1124
		replace facilityid=20320 if hcwid=="1774" & facilityid==20120
		replace facilityid=20320 if hcwid=="1774" & facilityid==20230
		replace facilityid=11562 if hcwid=="1777" & facilityid==15662
		replace facilityid=555556 if hcwid=="1807" & facilityid==5555556
		replace facilityid=510140 if hcwid=="1812" & facilityid==51040
		replace facilityid=901162 if hcwid=="1816" & facilityid==9011
		replace facilityid=11528 if hcwid=="1827" & facilityid==11258
		replace facilityid=18324 if hcwid=="1829" & facilityid==18323
		replace facilityid=18325 if hcwid=="1840" & facilityid==18348
		replace facilityid=11305 if hcwid=="1853" & facilityid==12523
		replace facilityid=11237 if hcwid=="1875" & facilityid==12237
		replace facilityid=11730 if hcwid=="1879" & facilityid==11736
		replace facilityid=11883 if hcwid=="1888" & facilityid==11833
		replace facilityid=19020 if hcwid=="1891" & facilityid==16020
		replace facilityid=510510 if hcwid=="1924" & facilityid==12372 // wrote the surveyid
		replace facilityid=510510 if hcwid=="1924" & facilityid==12373 // wrote the surveyid
		replace facilityid=16190 if hcwid=="1937" & facilityid==16019
		replace facilityid=16190 if hcwid=="1937" & facilityid==19160
		replace facilityid=16009 if hcwid=="1960" & facilityid==61009
		replace facilityid=16010 if hcwid=="1997" & facilityid==61010
		replace facilityid=900526 if hcwid=="1998" & facilityid==6057 // wrote the surveyid
		replace facilityid=17850 if hcwid=="2043" & facilityid==17580
		replace facilityid=17681 if hcwid=="2055" & facilityid==17861
		replace facilityid=15859 if hcwid=="2069" & facilityid==15958
		replace facilityid=18779 if hcwid=="2071" & facilityid==187779
		replace facilityid=18941 if hcwid=="2096" & facilityid==18641
		replace facilityid=513000 if hcwid=="3003" & facilityid==51300
		replace facilityid=900386 if hcwid=="3005" & facilityid==90386
		replace facilityid=16010 if hcwid=="5259" & facilityid==61010
		replace facilityid=11432 if hcwid=="5345" & facilityid==71452
		replace facilityid=555582 if hcwid=="5353" & facilityid==12288 // wrote the surveyid
		replace facilityid=20348 if hcwid=="5376" & facilityid==23048
		replace facilityid=20348 if hcwid=="5380" & facilityid==23048
		replace facilityid=17689 if hcwid=="5386" & facilityid==17989
		replace facilityid=12174 if hcwid=="5975" & facilityid==12175
		replace facilityid=21318 if hcwid=="6005" & facilityid==21308
		replace facilityid=100005 if hcwid=="6011" & facilityid==10005
		replace facilityid=19143 if hcwid=="6022" & facilityid==17143
		replace facilityid=555615 if hcwid=="6023" & facilityid==555613
		replace facilityid=900715 if hcwid=="6035" & facilityid==900713
		replace facilityid=12675 if hcwid=="6064" & facilityid==12576
		replace facilityid=19141 if hcwid=="6069" & facilityid==18853 // wrote the surveyid
		replace facilityid=901624 if hcwid=="6151" & facilityid==907624
		replace facilityid=555572 if hcwid=="6157" & facilityid==907624 // wrote the surveyid
		replace facilityid=17062 if hcwid=="6160" & facilityid==17063
		replace facilityid=11471 if hcwid=="6305" & facilityid==1471
		replace facilityid=500077 if hcwid=="6728" & facilityid==500072
		replace facilityid=500077 if hcwid=="6728" & facilityid==500072
		replace facilityid=517050 if hcwid=="7121" & facilityid==51750
		replace facilityid=900807 if hcwid=="7154" & facilityid==900307
		replace facilityid=12684 if hcwid=="7192" & facilityid==12687
		replace facilityid=519090 if hcwid=="7220" & facilityid==509090
		replace facilityid=555587 if hcwid=="7247" & facilityid==555547
		
	* Checking with the HCW dataset
		replace facilityid=510310 if hcwid=="5216" & facilityid==8098
		replace facilityid=16590 if hcwid=="951" & facilityid==10590
		replace facilityid=11894 if hcwid=="1692" & facilityid==11874
		replace facilityid=15957 if hcwid=="5246" & facilityid==15757
		replace facilityid=800004 if hcwid=="891" & facilityid==80004
		
	* Check there are no obvious typos in facilityid, based on hcwid
		bys hcwid: egen max_facilityid = max(facilityid)
		bys hcwid: egen min_facilityid = min(facilityid)
		bys hcwid: egen mode_facilityid = mode(facilityid)
		bys hcwid: gen obs = _N
		gen tag=(max_facilityid!=min_facilityid)
		*br hcwid facilityid *_facilityid if tag==1	
		
		* Replace facilityid to the mode if they wrote the surveyid again in the facilityid
			replace facilityid=mode_facilityid if survey_id==facilityid & tag==1
			drop max_facilityid min_facilityid mode_facilityid obs
			drop tag
			
	*----------------------*
	* 1.3. Drop duplicates *
	*----------------------*
	
	* Drop IR
		* Replace IR=1 if ir_id is not missing
		tab enuid if ir==1
		replace ir=1 if !mi(ir_id)
		drop if ir==1
	
	* 1. Duplicate observations where start time is the same.
		duplicates tag facilityid hcwid patientid aa5 aa6, gen (dup) //  aa6_start_time
		tab dup
		sort facilityid hcwid patientid aa5 aa6 enuid
		*br facilityid hcwid patientid aa5 aa6 enuid if dup>0
		* There are 48 duplicates
		
		* We drop the ones that are usually IRs
			replace ir=1 if dup>0 & inlist(enuid, "10", "20", "25", "26", "90", "93", "94", "95")
			drop if ir==1 & dup>0
			drop dup
			
		* how many duplicates do we still have
			duplicates tag facilityid hcwid patientid aa5 aa6, gen (dup)
			tab dup
			* 8 duplicates left
			
		* From the duplicates left, we drop one randomnly	
			set seed 731903 //random number created with random.org
			gen random = uniform() if dup >0
			bys facilityid hcwid patientid aa5 aa6 (random): gen serial_dup = _n if dup == 1 //we order by this number and drop first obs, order will be random
			drop if serial_dup == 1
			drop dup
			
	* 2. Check duplicate observations, but start time is differente: check how different they are
		duplicates tag facilityid hcwid patientid aa5, gen(dup) //  aa6_start_time
		sort facilityid hcwid patientid aa5 aa6 aa6
		*br facilityid hcwid patientid aa5 aa6 enuid if dup>0
		bys facilityid hcwid patientid aa5: gen time_diff = aa6[_n]-aa6[_n-1]
		bys facilityid hcwid patientid aa5: egen time_diff2 = max(time_diff)
		format time_diff2 %tc_HH:MM
		
		* If difference is more than 5 minutes, we'll say it's a differente survey
			replace dup=0 if time_diff2>clock("00:05","hm")
			*br facilityid hcwid patientid aa5 aa6 enuid if dup>0
			tab dup
			* 169 dups left (166 with 2, 3 with 3)
			
		* We drop the ones that are usually IRs
			replace ir=1 if dup>0 & inlist(enuid, "10", "20", "25", "26", "90", "93", "94", "95")
			drop if ir==1 & dup>0
			drop dup

		* how many duplicates do we still have: We don't consider this duplicates, so we keep them
			duplicates tag facilityid hcwid patientid aa5, gen (dup)
			replace dup=0 if time_diff2>clock("00:05","hm")
			tab dup
			drop dup time_diff2 time_diff serial_dup random 

	 		 
	/*-------------------------------*
	* 1.4. Calculate response rates *
	*-------------------------------*
		
	* Attempted
		mat T = J(5,1,.)
		count
		scalar 	attemp = r(N)
		mat T[1,1] = attemp
	* HCW consent
		count if aa1 == 1
		scalar 	HCW_consent = r(N)
		mat T[2,1] = HCW_consent	
	* Patient consent
		count if aa2 == 1
		scalar 	patient_consent = r(N)
		mat T[3,1] = patient_consent
	* HCW & patient consent
		count if aa1== 1 & aa2 == 1
		scalar 	both_consent = r(N)
		mat T[4,1] = both_consent	
	* Response rate
		scalar resp_rate = both_consent/attemp*100
		mat T[5,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "HCW consent" "Patient consent" "HCW & patient consent" "Response rate"
		matlist T
		
	* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify 
		putexcel A2 = ("Attempted") A3 = ("HCW consent") A4 = ("Patient consent") A5 = ("HCW & patient consent") A6 = ("Response rate") ///
		B2 = matrix(T) 	
		*/
	*------------------------------------------------------------*
	* 1.5. Keep only those who consented and finished the survey *
	*------------------------------------------------------------*
	
	* Those with HCW consent 	
		keep if aa1 == 1
	* Those with patient consent
		keep if aa2 == 1
		
********************************************************************************
	** Part 2: Basic cleaning
********************************************************************************
		
	*-----------------------------------------------------------------------*
	* 2.1. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
	
	* AA. General details
	
	* AB. BEFORE/AFTER INTERVENTION

	* BA. HAND HYGIENE - HCW PREPARATION IN ALL SITES

	
	* BB. HAND HYGIENE (except for injections/blood draws)

	* BC. Hand Hygiene Characteristics (except for injections/blood draws)

	* C. Waste segregation & disinfection (except for injections/blood draws)
		rename (c3_a1_1 c3_a2_1 c3_a3_1) (c3_a1 c3_a2 c3_a3)
		rename (c4_a1_1 c4_a2_1 c4_a3_1) (c4_a1 c4_a2 c4_a3) 
		rename (c5_a1_1 c5_a2_1 c5_a3_1) (c5_a1 c5_a2 c5_a3) 
		rename (dd4_a1_1_n1 dd4_a2_1_n1 dd4_a3_1_n1 dd4_a1_1_n2 dd4_a2_1_n2 dd4_a3_1_n2) (dd4_a1_n1 dd4_a2_n1 dd4_a3_n1 dd4_a1_n2 dd4_a2_n2 dd4_a3_n2) 
		rename (dd5_a1_1_n1 dd5_a2_1_n1 dd5_a3_1_n1 dd5_a1_1_n2 dd5_a2_1_n2 dd5_a3_1_n2) (dd5_a1_n1 dd5_a2_n1 dd5_a3_n1 dd5_a1_n2 dd5_a2_n2 dd5_a3_n2) 
	
	* D. INJECTION/BLOOD TEST

	*----------------------*
	* 2.2. Label variables *
	*----------------------*

	* AA. General details
	lab var aa11_a "Patient's gender: Male"
	lab var aa11_b "Patient's gender: Female"
	lab var aa12_a "Patient's age: U5 (<5)"
	lab var aa12_b "Patient's age: Child (5-18)"
	lab var aa12_c "Patient's age: Young (19-30)"
	lab var aa12_d "Patient's age: Middle (31-55)"
	lab var aa12_e "Patient's age: Old (>55)"
	
	* AB. BEFORE/AFTER INTERVENTION
	lab var ab_a "Before/After: Patient coming with test results"

	* BA. HAND HYGIENE - HCW PREPARATION IN ALL SITES

	
	* BB. HAND HYGIENE (except for injections/blood draws)
	lab var bb4_1a "After touching: HR"
	lab var bb4_1b "After touching: HW w/ soap"

	* BC. Hand Hygiene Characteristics (except for injections/blood draws)

	* C. Waste segregation & disinfection (except for injections/blood draws)

	
	* D. INJECTION/BLOOD TEST	
	
	*------------------*
	* 2.3. Inputations *
	*------------------*	

	
* 1. Create vars with the number of non-missing values
*-------------------------------------------------------
	
	* We need these vars because they will determine whether the indicator is active or not
	
	* BA. Hand hygene (all sites)
	*----------------------------
	
		* Create globals of the variables WITHOUT the cannot be assessed option
			global ba2_1 ba2_1a ba2_1b 
			global ba2_2 ba2_2a ba2_2b ba2_2c ba2_2d 
			global ba2_3 ba2_3a ba2_3b ba2_3c ba2_3d ba2_3f 
			
		* Create globals for the cannot be assesed option
			global ba2_1_cba ba2_1c
			global ba2_2_cba ba2_2e
			global ba2_3_cba ba2_3e 
			
		* Create globals for root variable
			global ba2_1_root ba2
			global ba2_2_root ba2
			global ba2_3_root ba2
						
		* Check non-missing values
			foreach x in ba2_1 ba2_2 ba2_3 {
				* Without the cannot be assessed option 
					egen `x'_v = rownonmiss(${`x'})
					tab `x'_v, m
				* With the cannot be assessed option 
					egen `x'_cba_v = rownonmiss(${`x'} ${`x'_cba})
					tab `x'_cba_v, m
			}
				
	* BB. Hand hygine (examination) 
	*------------------------------
	
		* Create globals of the variables WITHOUT the cannot be assessed option
			global bb1_1 	bb1_1a bb1_1b bb1_1c bb1_1d  
			global bb1_2 	bb1_2a bb1_2b bb1_2c bb1_2d 
			global bb2 		bb2_1a bb2_1b bb2_1c bb2_1d 
			global bb3 		bb3_1a bb3_1b bb3_1c bb3_1d 
			global bb4 		bb4_1a bb4_1b bb4_1c bb4_1d 
			global bb5 		bb5_a bb5_b bb5_c bb5_d 
				
		* Create globals for the cannot be assesed option
			global bb1_1_cba 	bb1_1e 
			global bb1_2_cba 	bb1_2e
			global bb2_cba		bb2_1e
			global bb3_cba 		bb3_1e
			global bb4_cba 		bb4_1e
			global bb5_cba		bb5_e

		* Create globals for root variable
			global bb1_1_root 	bb1
			global bb1_2_root 	bb1
			global bb2_root		bb2
			global bb3_root 	bb3
			global bb4_root 	bb4

		* Check non-missing values
			foreach x in bb1_1 bb1_2 bb2 bb3 bb4 bb5 {
				* Without the cannot be assessed option 
					egen `x'_v = rownonmiss(${`x'})
					tab `x'_v, m
				* With the cannot be assessed option 
					egen `x'_cba_v = rownonmiss(${`x'} ${`x'_cba})
					tab `x'_cba_v, m
			}
			
	* Second level of disaggregation: bins, bags, swabs
	*-----------------------------------------------
	
		* We do all the second level of disaggregation here so it's easier later
		* These ones don't have the CBA option
		
		* Create globals of the variables WITHOUT the cannot be assessed option
			global c3_bin 			c3_a1 c3_a2 c3_a3 c3_a4
			global c3_bag 			c3_a1_2 c3_a2_2 c3_a3_2	
			global c4_bin 			c4_a1 c4_a2 c4_a3 c4_a4
			global c4_bag 			c4_a1_2 c4_a2_2 c4_a3_2			
			global c5_bin 			c5_a1 c5_a2 c5_a3 c5_a4
			global c5_bag 			c5_a1_2 c5_a2_2 c5_a3_2
			global db_n1 			db_a_n1 db_b_n1 // not suboption but doesn't have CBA option, we put it here
			global db_n2 			db_a_n2 db_b_n2 // not suboption but doesn't have CBA option, we put it here
			global dc2_n1			dc2_a_n1 dc2_b_n1 dc2_c_n1 dc2_d_n1 dc2_e_n1 // not suboption but doesn't have CBA option, we put it here
			global dc2_n2			dc2_a_n2 dc2_b_n2 dc2_c_n2 dc2_d_n2 dc2_e_n2 // not suboption but doesn't have CBA option, we put it here
			global dc5_a_n1 		dc5_a1_n1 dc5_a2_n1 dc5_a3_n1 dc5_a4_n1
			global dc5_a_n2 		dc5_a1_n2 dc5_a2_n2 dc5_a3_n2 dc5_a4_n2
			global dc5_n1			dc5_a_n1 dc5_b_n1 dc5_c_n1 // not suboption but doesn't have CBA option, we put it here
			global dc5_n2			dc5_a_n2 dc5_b_n2 dc5_c_n2 // not suboption but doesn't have CBA option, we put it here
			global dd1_123_a_n1 	dd1_123_a1_n1 dd1_123_a2_n1
			global dd1_123_a_n2 	dd1_123_a1_n2 dd1_123_a2_n2
			global dd1_123_c_n1 	dd1_123_c1_n1 
			global dd1_123_c_n2 	dd1_123_c1_n2
			global dd1_45_a_n1 		dd1_45_a1_n1 dd1_45_a2_n1
			global dd1_45_a_n2 		dd1_45_a1_n2 dd1_45_a2_n2
			global dd1_45_c_n1 		dd1_45_c1_n1 
			global dd1_45_c_n2 		dd1_45_c1_n2
			global dd2_a_n1 		dd2_a1_n1 dd2_a2_n1 
			global dd2_a_n2			dd2_a1_n2 dd2_a2_n2
			global dd3_a_n1 		dd3_a1_n1
			global dd3_a_n2			dd3_a1_n2
			global dd4_a_n1_bin		dd4_a1_n1 dd4_a2_n1 dd4_a3_n1 dd4_a4_n1
			global dd4_a_n2_bin 	dd4_a1_n2 dd4_a2_n2 dd4_a3_n2 dd4_a4_n2		
			global dd4_a_n1_bag 	dd4_a1_2_n1 dd4_a2_2_n1 dd4_a3_2_n1
			global dd4_a_n2_bag 	dd4_a1_2_n2 dd4_a2_2_n2 dd4_a3_2_n2				
			global dd5_a_n1_bag		dd5_a1_n1 dd5_a2_n1 dd5_a3_n1 dd5_a4_n1
			global dd5_a_n2_bag 	dd5_a1_n2 dd5_a2_n2 dd5_a3_n2 dd5_a4_n2		
			global dd5_a_n1_bin 	dd5_a1_2_n1 dd5_a2_2_n1 dd5_a3_2_n1
			global dd5_a_n2_bin 	dd5_a1_2_n2 dd5_a2_2_n2 dd5_a3_2_n2		
			
		* Create globals for root variable
			global c3_bin_root 			c3_a
			global c3_bag_root 			c3_a
			global c4_bin_root 			c4_a
			global c4_bag_root 			c4_a
			global c5_bin_root 			c5_a
			global c5_bag_root 			c5_a
			global db_n1_root 			db_n1
			global db_n2_root 			db_n2
			global dc5_a_n1_root 		dc5_a_n1
			global dc5_a_n2_root 		dc5_a_n2
			global dd1_123_a_n1_root 	dd1_123_a_n1 
			global dd1_123_a_n2_root 	dd1_123_a_n2
			global dd1_123_c_n1_root 	dd1_123_c_n1 
			global dd1_123_c_n2_root 	dd1_123_c_n2
			global dd1_45_a_n1_root 	dd1_45_a_n1
			global dd1_45_a_n2_root 	dd1_45_a_n2
			global dd1_45_c_n1_root 	dd1_45_c_n1 
			global dd1_45_c_n2_root 	dd1_45_c_n2
			global dd2_a_n1_root 		dd2_a_n1
			global dd2_a_n2_root		dd2_a_n2
			global dd3_a_n1_root 		dd3_a_n1
			global dd3_a_n2_root		dd3_a_n2
			global dd4_a_n1_bag_root	dd4_a_n1
			global dd4_a_n2_bag_root 	dd4_a_n2
			global dd4_a_n1_bin_root 	dd4_a_n1
			global dd4_a_n2_bin_root 	dd4_a_n2
			global dd5_a_n1_bag_root	dd5_a_n1
			global dd5_a_n2_bag_root 	dd5_a_n2
			global dd5_a_n1_bin_root 	dd5_a_n1
			global dd5_a_n2_bin_root 	dd5_a_n2
					
		* Check non-missing values
			foreach x in c3_bin c3_bag c4_bin c4_bag c5_bin c5_bag db_n1 db_n2 dc2_n1 dc2_n2 dc5_a_n1 dc5_a_n2 dc5_n1 dc5_n2 dd1_123_a_n1 dd1_123_a_n2 dd1_123_c_n1 dd1_123_c_n2 dd1_45_a_n1 dd1_45_a_n2 dd1_45_c_n1 dd1_45_c_n2 dd2_a_n1 dd2_a_n2 dd3_a_n1 dd3_a_n2 dd4_a_n1_bag dd4_a_n2_bag dd4_a_n1_bin dd4_a_n2_bin dd5_a_n1_bag dd5_a_n2_bag dd5_a_n1_bin dd5_a_n2_bin {
				* Without the cannot be assessed option 
					egen `x'_v = rownonmiss(${`x'})
					tab `x'_v, m
			}		
			
	* C. Waste segregation and disinfection (examination) 
	*----------------------------------------------------
	
		* Create globals of the variables WITHOUT the cannot be assessed option
			global c1 c1_a c1_b c1_c c1_d 
			global c2 c2_a c2_b c2_c 
			global c3 c3_a c3_b c3_c c3_d 
			global c4 c4_a c4_b c4_c 		
			global c5 c5_a c5_b
							
		* Create globals for the cannot be assesed option
			global c1_cba 	c1_e
			global c2_cba 	c2_d
			global c3_cba 	c3_e		
			global c4_cba 	c4_d 		
			global c5_cba 	c5_c
			
		* Create globals for root variable
			global c1_root c1
			global c2_root c2
			global c3_root c3
			global c4_root c4
			global c5_root c5				
			
		* Check non-missing values
			foreach x in c1 c2 c3 c4 c5 {
				* Without the cannot be assessed option 
					egen `x'_v = rownonmiss(${`x'})
					tab `x'_v, m
				* With the cannot be assessed option 
					egen `x'_cba_v = rownonmiss(${`x'} ${`x'_cba})
					tab `x'_cba_v, m
			}
			
				
	* D. Injection/Blood test
	*------------------------

		foreach obs in n1 n2 {
			* Create globals of the variables WITHOUT the cannot be assessed option
				global da_`obs' da_a_`obs' da_b_`obs' da_c_`obs'
		
			* Create globals for the cannot be assesed option
				global da_cba_`obs' da_d_`obs'
				
			* Create globals for root variable
				global da_root_`obs' da_`obs'

			* Check non-missing values
					foreach x in da {
						* Without the cannot be assessed option 
							egen `x'_v_`obs' = rownonmiss(${`x'_`obs'})
							tab `x'_v_`obs', m
						* With the cannot be assessed option 
							egen `x'_cba_v_`obs' = rownonmiss(${`x'_`obs'} ${`x'_cba_`obs'})
							tab `x'_cba_v_`obs', m
					}				
		}
	
	
	* DC. Disinfection and preparation
	*---------------------------------
		
		foreach obs in n1 n2 {
			* Create globals of the variables WITHOUT the cannot be assessed option
				global dc1_`obs'		dc1_a_`obs' dc1_b_`obs' dc1_c_`obs' dc1_d_`obs'  
				global dc3_123_`obs'	dc3_123_a_`obs' dc3_123_b_`obs'  
				global dc3_45_`obs'		dc3_45_a_`obs' dc3_45_b_`obs' 
				global dc4_`obs'		dc4_a_`obs' dc4_b_`obs'
				global dc6_`obs'		dc6_a_`obs' dc6_b_`obs' dc6_c_`obs' 
		
			* Create globals for the cannot be assesed option
				global dc1_cba_`obs'		dc1_e_`obs' 
				global dc3_123_cba_`obs'	dc3_123_c_`obs' 
				global dc3_45_cba_`obs'		dc3_45_c_`obs'
				global dc4_cba_`obs'		dc4_c_`obs' 
				global dc6_cba_`obs'		dc6_d_`obs'
				
			* Create globals for root variable
				global dc6_root_`obs'		dc6_`obs'

			* Check non-missing values
					foreach x in dc1 dc3_123 dc3_45 dc4 dc6 {
						* Without the cannot be assessed option 
							egen `x'_v_`obs' = rownonmiss(${`x'_`obs'})
							tab `x'_v_`obs', m
						* With the cannot be assessed option 
							egen `x'_cba_v_`obs' = rownonmiss(${`x'_`obs'} ${`x'_cba_`obs'})
							tab `x'_cba_v_`obs', m
					}				
		}
		
	* DD. Segregation/storage
	*-------------------------
		
		foreach obs in n1 n2 {
			
			* Create globals of the variables WITHOUT the cannot be assessed option
				global dd1_123_`obs' 	dd1_123_a_`obs' dd1_123_b_`obs' dd1_123_c_`obs' dd1_123_d_`obs' dd1_123_e_`obs'
				global dd1_45_`obs'		dd1_45_a_`obs' dd1_45_b_`obs' dd1_45_c_`obs' dd1_45_d_`obs' dd1_45_e_`obs'
				global dd2_`obs' 		dd2_a_`obs' dd2_b_`obs' dd2_c_`obs' dd2_d_`obs' 
				global dd3_`obs' 		dd3_a_`obs' dd3_b_`obs' dd3_c_`obs' dd3_d_`obs' dd3_e_`obs' dd3_f_`obs'
				global dd4_`obs' 		dd4_a_`obs' dd4_b_`obs'
				global dd5_`obs' 		dd5_a_`obs' dd5_b_`obs' dd5_c_`obs' 
				global dd6_`obs' 		dd6_a_`obs' dd6_b_`obs' dd6_c_`obs' dd6_d_`obs'
	
			* Create globals for the cannot be assesed option
				global dd1_123_cba_`obs' 	dd1_123_f_`obs'
				global dd1_45_cba_`obs'		dd1_45_f_`obs'
				global dd2_cba_`obs' 		dd2_e_`obs'
				global dd3_cba_`obs' 		dd3_g_`obs'
				global dd4_cba_`obs' 		dd4_c_`obs'
				global dd5_cba_`obs' 		dd5_d_`obs' 
				global dd6_cba_`obs' 		dd6_e_`obs'
				
			* Create globals for root variable
				global dd3_root_`obs' 		dd3_`obs'
				global dd4_root_`obs' 		dd4_`obs'
				global dd5_root_`obs' 		dd5_`obs' 
				
			* Check non-missing values
					foreach x in dd1_123 dd1_45 dd2 dd3 dd4 dd5 dd6 {
						* Without the cannot be assessed option 
							egen `x'_v_`obs' = rownonmiss(${`x'_`obs'})
							tab `x'_v_`obs', m
						* With the cannot be assessed option 
							egen `x'_cba_v_`obs' = rownonmiss(${`x'_`obs'} ${`x'_cba_`obs'})
							tab `x'_cba_v_`obs', m
					}				
		}
	
		
* 2. Replace root for one if one of the suboptions was selected
*--------------------------------------------------------------

* This includes:
	* a. Replace root for one if one of the suboptions was selected
	* b. Replace to missing where two or more options were selected
	* c. Replace to .c if cannot be assessed
	* d. Imputations of zeroes if indicator is active

	* BA. Hand hygene (all sites)
	*----------------------------

		foreach x in ba2_1 ba2_2 ba2_3 {
			
			* a. Replace root for one if one of the suboptions was selected
				replace ${`x'_root}=1 if `x'_cba_v>0
			
			* Gen tag for more than one option selected
					gen tag_num_selected_`x' = (`x'_cba_v>1)
					lab var tag_num_selected_`x' "Tag `x': Selected more than one option"
					tab tag_num_selected_`x'
			
			* Other imputations
				foreach var of global `x' {
					
					* b. Replace to missing where two or more options were selected
						replace `var' = . if !mi(`var') & `x'_cba_v>1
						
					* c. Replace to .c if cannot be assessed
						replace `var' = .c if ${`x'_cba}==1 & `x'_cba_v==1
						
					* d. Imputations of zeroes if indicator is active
						replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_cba_v==1
						
						tab `var' `x'_v, m
						tab `var' `x'_cba_v, m
				}
		}
		

	* BB. Hand hygine (examination) 
	*------------------------------
	
		foreach x in bb1_1 bb1_2 bb2 bb3 bb4 bb5 {
			
			* a. Replace root for one if one of the suboptions was selected
			if !inlist("`x'", "bb5") { // these ones don't have root or don't have the cba var
				replace ${`x'_root}=1 if `x'_cba_v>0
			}
			
			* Gen tag for more than one option selected
					gen tag_num_selected_`x' = (`x'_cba_v>1)
					lab var tag_num_selected_`x' "Tag `x': Selected more than one option"
					tab tag_num_selected_`x'
			
			* Other imputations
				foreach var of global `x' {
					
					* b. Replace to missing where two or more options were selected
						replace `var' = . if !mi(`var') & `x'_cba_v>1
						
					* c. Replace to .c if cannot be assessed
						replace `var' = .c if ${`x'_cba}==1 & `x'_cba_v==1
						
					* d. Imputations of zeroes if indicator is active
						replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_cba_v==1
						
						tab `var' `x'_v, m
						tab `var' `x'_cba_v, m
				}
		}
		
	* Second level of disaggregation: bins, bags, swabs
	*-----------------------------------------------
		
		foreach x in c3_bin c3_bag c4_bin c4_bag c5_bin c5_bag dc2_n1 dc2_n2 dc5_a_n1 dc5_a_n2 dc5_n1 dc5_n2 dd1_123_a_n1 dd1_123_a_n2 dd1_123_c_n1 dd1_123_c_n2 dd1_45_a_n1 dd1_45_a_n2 dd1_45_c_n1 dd1_45_c_n2 dd2_a_n1 dd2_a_n2 dd3_a_n1 dd3_a_n2 dd4_a_n1_bag dd4_a_n2_bag dd4_a_n1_bin dd4_a_n2_bin dd5_a_n1_bag dd5_a_n2_bag dd5_a_n1_bin dd5_a_n2_bin {
			
			* a. Replace root for one if one of the suboptions was selected
			if !inlist("`x'", "dc2_n1", "dc2_n2", "dc5_n1", "dc5_n2") { // these ones don't have root or don't have the cba var
				replace ${`x'_root}=1 if `x'_v>0
			}
			
			* Gen tag for more than one option selected
					gen tag_num_selected_`x' = (`x'_v>1)
					lab var tag_num_selected_`x' "Tag `x': Selected more than one option"
					tab tag_num_selected_`x'
			
			* Other imputations
				foreach var of global `x' {
					
					* b. Replace to missing where two or more options were selected
						replace `var' = . if !mi(`var') & `x'_v>1
						
					* d. Imputations of zeroes if indicator is active
						replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_v==1
						
						tab `var' `x'_v, m
				}
		}
	
	* C. Waste segregation and disinfection (examination) 
	*----------------------------------------------------
	
		foreach x in c1 c2 c3 c4 c5 {
			
			* a. Replace root for one if one of the suboptions was selected
				replace ${`x'_root}=1 if `x'_cba_v>0
			
			* Gen tag for more than one option selected
					gen tag_num_selected_`x' = (`x'_cba_v>1)
					lab var tag_num_selected_`x' "Tag `x': Selected more than one option"
					tab tag_num_selected_`x'
			
			* Other imputations
				foreach var of global `x' {
					
					* b. Replace to missing where two or more options were selected
						replace `var' = . if !mi(`var') & `x'_cba_v>1
						
					* c. Replace to .c if cannot be assessed
						replace `var' = .c if ${`x'_cba}==1 & `x'_cba_v==1
						
					* d. Imputations of zeroes if indicator is active
						replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_cba_v==1
						
						tab `var' `x'_v, m
						tab `var' `x'_cba_v, m
				}
		}
		
	* DC. Disinfection and preparation
	*---------------------------------

		foreach obs in n1 n2 {	
			foreach x in dc1 dc3_123 dc3_45 dc4 dc6 {
				
				* a. Replace root for one if one of the suboptions was selected
				if inlist("`x'", "dc6") { // these one is the only one with root
					replace ${`x'_root_`obs'}=1 if `x'_cba_v_`obs'>0
				}
				
				* Gen tag for more than one option selected
						gen tag_num_selected_`x'_`obs' = (`x'_cba_v_`obs'>1)
						lab var tag_num_selected_`x'_`obs' "Tag `x': Selected more than one option"
						tab tag_num_selected_`x'_`obs'
				
				* Other imputations
					foreach var of global `x'_`obs' {
						
						* b. Replace to missing where two or more options were selected
							replace `var' = . if !mi(`var') & `x'_cba_v_`obs'>1
							
						* c. Replace to .c if cannot be assessed
							replace `var' = .c if ${`x'_cba_`obs'}==1 & `x'_cba_v_`obs'==1
							
						* d. Imputations of zeroes if indicator is active
							replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_cba_v_`obs'==1
							
							tab `var' `x'_v_`obs', m
							tab `var' `x'_cba_v_`obs', m
					}
			}	
		}

	* DD. Segregation/storage
	*-------------------------
		
		foreach obs in n1 n2 {	
			foreach x in dd1_123 dd1_45 dd2 dd3 dd4 dd5 dd6 {
				
				* a. Replace root for one if one of the suboptions was selected
				if inlist("`x'", "dd3", "dd4", "dd5") { // these one is the only one with root
					replace ${`x'_root_`obs'}=1 if `x'_cba_v_`obs'>0
				}
				
				* Gen tag for more than one option selected
						gen tag_num_selected_`x'_`obs' = (`x'_cba_v_`obs'>1)
						lab var tag_num_selected_`x'_`obs' "Tag `x': Selected more than one option"
						tab tag_num_selected_`x'_`obs'
				
				* Other imputations
					foreach var of global `x'_`obs' {
						
						* b. Replace to missing where two or more options were selected
							replace `var' = . if !mi(`var') & `x'_cba_v_`obs'>1
							
						* c. Replace to .c if cannot be assessed
							replace `var' = .c if ${`x'_cba_`obs'}==1 & `x'_cba_v_`obs'==1
							
						* d. Imputations of zeroes if indicator is active
							replace `var' = 0 if `var'!=1 & `var'!=.c & `x'_cba_v_`obs'==1
							
							tab `var' `x'_v_`obs', m
							tab `var' `x'_cba_v_`obs', m
					}
			}	
		}
		

* 3. Imputations based on answers of other questions (discussed with Lupe)		
*-------------------------------------------------------------------------
	
	* This imputations only change descriptive statistics, not compliance. Therefore,
	* it doesn't matter where we do these imputations.
		
	* 3.1. Replace 2.3 HH after wearing gloves to doesn't apply if selected in 
	* 	   other questions and other options are missing
		*replace ba2_3f=1 if c4_b==1 & ba2_3_cba_v==0
		*replace ba2_3f=1 if (dd5_b_n1==1 | dd5_b_n2==1) & ba2_3_cba_v==0
	
	* 3.2. Replace gloves = 1 if it has been indicated in any other questions relating to gloves
		* ba2_3f==1 based in correction just made
		replace ba2=1 if ba2_3f==1 & mi(ba2)
		
		* bc3 HW/HR took plane with gloves on: 
		replace ba2=1 if bc3==1 & mi(ba2)
 
		* Indicated in c4 , dd5_n1 or dd5_n2
		replace ba2=1 if (c4_cba_v>0 | dd5_cba_v_n1>0 | dd5_cba_v_n2>0) & mi(ba2)			
 
		* Indicated in de3
		replace ba2=1 if de3==1 & mi(ba2)			
			
	* 3.3. Replace DD. segregation - syringe, slide and vacutainer based on DC. disinfection 		
		
		foreach obs in n1 n2 {
			foreach element in 1 2 3 {
				replace dd1_`element'_`obs' = 1 if dc3_`element'_`obs'==1 & mi(dd1_`element'_`obs')
			}
		}

	* 3.4. Replace ba2 gloves to zero if it's missing
		replace ba2 = 0 if mi(ba2)
	
	*----------------------*
	* 2.3. Label variables *
	*----------------------*

	* Final renames
		rename facilityid hfid
		rename survey_id key
		/*rename aa5 date
		rename enuid enumeratorid
		rename hcwid aa9
		rename patientid aa10
		*/
		
	* Drop intermadiate variables
		drop tag_num_selected_* *_v
		
	* Drop "Cannot be assessed" variables since they don't give additional information
		*drop ba2_1c ba2_2e ba2_3e bb1_1e bb1_2e bb2_1e bb3_1e bb4_1e bb5_e c1_e c2_d c3_e c4_d c5_c da_d_n1 dc1_e_n1 dc3_1_c_n1 dc3_2_c_n1 dc3_3_c_n1 dc3_4_c_n1 dc3_5_c_n1 dc4_c_n1 	dd1_1_f_n1 dd1_2_f_n1 dd1_3_f_n1 dd1_4_f_n1 dd1_5_f_n1 dd2_e_n1 dd3_g_n1 dd4_c_n1 dd5_d_n1 dd6_e_n1 da_d_n2 dc1_e_n2 dc3_1_c_n2 dc3_2_c_n2 dc3_3_c_n2 dc3_4_c_n2 dc3_5_c_n2 dc4_c_n2 dd1_1_f_n2 dd1_2_f_n2 dd1_3_f_n2 dd1_4_f_n2 dd1_5_f_n2 dd2_e_n2 dd3_g_n2 dd4_c_n2 dd5_d_n2 dd6_e_n2	
		
	*----------------------------------------------------------------------------*
	* 2.4. Reshape dataset to get only one observation for each IBT obsservation *
	*----------------------------------------------------------------------------*

	* Gen unique id
		gen count = _n  	

	* Keep relevant info
		preserve
		keep count da_* db_* dc* dd*
		drop *_v_*	
		
	* Gen dummy to identify if the observation took place
		gen d_n1 = 1 if da_n1 == 1 | db_n1 == 1
		gen d_n2 = 1 if da_n2 == 1 | db_n2 == 1
		order d_n1 d_n2, after(count)

	* Get labels
		global reshape_vars "d_ da_ da_a_ da_b_ da_c_ da_d_ db_ db_a_ db_b_ dc1_a_ dc1_b_ dc1_c_ dc1_d_ dc1_e_ dc2_a_ dc2_b_ dc2_c_ dc2_d_ dc2_e_ dc3_1_ dc3_2_ dc3_3_ dc3_123_a_ dc3_123_b_ dc3_123_c_ dc3_4_ dc3_5_ dc3_45_a_ dc3_45_b_ dc3_45_c_ dc4_a_ dc4_b_ dc4_c_ dc5_a_ dc5_a1_ dc5_a2_ dc5_a3_ dc5_a4_ dc5_b_ dc5_c_ dc6_ dc6_a_ dc6_b_ dc6_c_ dc6_d_ dd1_1_ dd1_2_ dd1_3_ dd1_123_a_ dd1_123_a1_ dd1_123_a2_ dd1_123_b_ dd1_123_c_ dd1_123_c1_ dd1_123_d_ dd1_123_e_ dd1_123_f_ dd1_4_ dd1_5_ dd1_45_a_ dd1_45_a1_ dd1_45_a2_ dd1_45_b_ dd1_45_c_ dd1_45_c1_ dd1_45_d_ dd1_45_e_ dd1_45_f_ dd2_a_ dd2_a1_ dd2_a2_ dd2_b_ dd2_c_ dd2_d_ dd2_e_ dd3_ dd3_a_ dd3_a1_ dd3_b_ dd3_c_ dd3_d_ dd3_e_ dd3_f_ dd3_g_ dd4_ dd4_a_ dd4_a1_ dd4_a2_ dd4_a3_ dd4_a1_2_ dd4_a2_2_ dd4_a3_2_ dd4_a4_ dd4_b_ dd4_c_ dd5_ dd5_a_ dd5_a1_ dd5_a2_ dd5_a3_ dd5_a1_2_ dd5_a2_2_ dd5_a3_2_ dd5_a4_ dd5_b_ dd5_c_ dd5_d_ dd6_a_ dd6_b_ dd6_c_ dd6_d_ dd6_e_"

		foreach var of global reshape_vars {
			display "`var'"
			loc	varlab`var':	var lab	`var'n1
			display "`varlab`var''"
		}		
		
	* Reshape
		reshape long $reshape_vars, i(count) j(obs) string
		keep if d_==1
		
	* Put labels back
		foreach var of global reshape_vars {
			display "`varlab`var''"
			lab	var `var' "`varlab`var''"
		}
		
	* Save tempfile
		tempfile obs_IBT
		save	`obs_IBT'
		restore	
		
	* Drop info that we are not repeating
		drop da_* db_* dc* dd*
		merge 1:m count using `obs_IBT', assert(1 3) nogen
		
	* Replace for missing in second observation, so we don't do double counting
	drop comment
		foreach var of varlist ab*  bb* bc* c* de1 de2 de3 de4 df dg dh { //
			replace `var'=. if obs=="n2"
		}
	
		rename *_ *
	
********************************************************************************
	** Part 3: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 3.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Merge profile information
		local prof_vars "latitude longitude hfid  hfname county subcounty private level" //sublocation inchargename inchargenumber

		merge m:1 hfid using "${listing_end}", keepus(`prof_vars') 
		
		
		/*
		    Result                           # of obs.
    -----------------------------------------
    not matched                           239
        from master                       170  (_merge==1)
        from using                         69  (_merge==2)

    matched                            18,777  (_merge==3)
    -----------------------------------------
	
	After correction
	
    Result                           # of obs.
    -----------------------------------------
    not matched                            72
        from master                         4  (_merge==1)
        from using                         68  (_merge==2)

    matched                            18,885  (_merge==3)
    -----------------------------------------
	*/
		keep if _merge == 3
		drop 	_merge
	
	* Order dataset
		order `prof_vars', after(key)	
		 
	*-------------------------------------*
	* 3.2. Save database for construction *
	*-------------------------------------*
	
		*save "${PPS_DO_clean_pii}", replace

			
	*----------------*
	* 3.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude hfid hfname  // location sublocation inchargename inchargenumber 
	
	*--------------------------------------------*
	* 3.4. Save database for microdata catalogue *
	*--------------------------------------------*
	
		save "${pps_do_clean}", replace
		
	/*------------------------*
	* 3.5. Build dictionnary *
	*------------------------*

	codebookout "${dictionary}", replace
	
	*-----------------------------*
	* 3.6. Descriptive statistics *
	*-----------------------------*
	
	ds, has(type numeric)
	local num_vars `r(varlist)'

	foreach var in `num_vars' {
		loc varlab: variable label `var'
		loc varlab_nocomma=subinstr("`varlab'",",","",.)
		lab var `var' "`varlab_nocomma'"
	}
	
	set matsize 500
	estpost	tabstat `num_vars', ///
					statistics(n mean sd min max p50 p90) ///
					columns(statistics)
						
	esttab 	using "${desc_stats}", ///
				cells("count(label(N)) mean(label(Mean) fmt(%9.2f)) sd(label(Std Dev) fmt(%9.2f)) min(label(Min)) max(label(Max)) p50(label(Median)) p90(label(p90))") ///
				label ///
				noobs nonumber mtitles("Descriptive Statistics") ///
				replace	
	*/
	
	* Dismount
	veracrypt, dismount drive("${mount}") 
