/*******************************************************************************	

Project:  		KePSIE
Created on:  	Sep 26, 2018
Last udpate on: Oct 30, 2018

Written by:  	Pretom Shome (pshome@worldbank.org/pshome@stanford.edu)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Health Care Worker data file for upload in the WB microdata catalog

CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
				Part 2 - Complete variables
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionary	
						 4.6 - Generate descriptive statistics
		
		INPUTS: 		* Raw data
						"${KePSIE_DB}/Endline/DataSets/Raw/PPS_HCW.dta"
						
						* HF Baseline profile data
						"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"

		OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Maria Camila)
				
					* Anonymized data for microdata catalog
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_HCW_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_HCW_clean_pii.dta"
					
					* Dictionary
					"${KePSIE_DB}/Endline/Output/Final/PPS_HCW_clean_dictionary_end.xlsx"
					
					* Response rate table
					"${KePSIE_DB}/Endline/Output/Final/PPS_HCW_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${KePSIE_DB}/Endline/Output/Final/PPS_HCW_desc_stats_end.csv"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Anonymized data for microdata catalog
					"${end_dt}/Intermediate/PPS_HCW_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${end_dt}/Intermediate/PPS_HCW_clean_pii.dta"
					
					* Dictionary
					"${end_out}/Final/PPS_HCW_clean_dictionary_end.xlsx"
					
					* Response rate table
					"${end_out}/Final/PPS_HCW_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${end_out}/Final/PPS_HCW_desc_stats_end.csv"
		
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo pps_hcw 			"${volume}/pps_hcw_end_raw.dta"
		glo listing_end			"${dt_mast}/listing_end.dta"
		
	* Output files
		glo pps_hcw_clean		"${dt_end_clean}/pps_hcw_end.dta"

********************************************************************************
	** Part 1: Complete database
********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")
	
	use "${pps_hcw}", clear
	
	*--------------------------*
	*     Manual Corrections   *
	*--------------------------*
	
	*One HCW assigned two IDs, as reported in Data tab of Issues Tracking gsheet
	assert facilitycode=="500095" if a4==770
	replace a4=447 if a4==770
	*One HCW that refused providing information survey then modified to allow for no answer
	replace b3=. if facilitycode=="12666" & a4==1055
	replace b4_2=. if facilitycode=="12666" & a4==1055
	/* One survey that shows as double because it was tagged as incomplete
	by SurveyCTO as some audio files could not be uploaded. However, after
	recovering it (on 25May2018) and accepting it as complete, it got added
	even though it was already in the dataset. Not sure why. */
	drop if key=="uuid:81a62aa7-dd6c-47cd-98ce-0a8b02dadb73"
	
	* Drop unnecessary variables		
		drop submissiondate deviceid subscriberid simid devicephonenum audio1 ///
			 audio2 formdef_version pri_string a1_c_v a3_v a2_v	///
			 facilitycode time_endinteraction2 starttime endtime
			 		 
	/*--------------------------*
	* Calculate response rates *
	*--------------------------*
		
	* Attempted
		mat T = J(3,1,.)
		count
		scalar 	attemp = r(N)
		mat T[1,1] = attemp
	* Able to proceed
		count if b2_v == 1
		scalar 	proceed = r(N)
		mat T[2,1] = proceed	
	* Response rate
		scalar resp_rate = proceed/attemp*100
		mat T[3,1] = resp_rate

	* Matrix rownames	
		mat rownames T = "Attempted" "Able to proceed" "Response rate"
		matlist T
		
	* Export to excel
		putexcel clear
		putexcel set "${resp_rate}", modify sheet("Patient Exit")
		putexcel A2 = ("Attempted") A3 = ("Able to proceed") A4 = ("Response rate") ///
		B2 = matrix(T) 	
	*/
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
	
	* Able to proceed
	keep if b2_v == 1
	

********************************************************************************
	** Part 2: Complete variables
********************************************************************************
	
	*Format Date variable
	gen date1=date([date],"DMY")
	format date1 %td
	drop date
	rename date1 date
	
	/*Format start and end time variable
	gen double time_start1=clock(time, "hm")
	format time_start1 %tc_HH:MM
	drop time_start
	rename time_start1 time_start
	gen time_end1=clock(time_end, "hm")
	format time_end1 %tc_HH:MM
	drop time_end
	rename time_end1 time_end
	*/

	
	*--------------------*
	* Destring variables * 
	*--------------------*
	
		* Cadre
			rename  b6 b6_string
			gen 	b6 = 1   if b6_string == "clinicalofficer"
			replace b6 = 2   if b6_string == "chw"
			replace b6 = 3   if b6_string == "dentist"
			replace b6 = 4	 if b6_string == "doctormo"
			replace b6 = 5   if b6_string == "intern"
			replace b6 = 6   if b6_string == "labtech"
			replace b6 = 7   if b6_string == "labsci"
			replace b6 = 8   if b6_string == "midwife"
			replace b6 = 9   if b6_string == "nurse"
			replace b6 = 10  if b6_string == "nurseaide"
			replace b6 = 11  if b6_string == "nutritionist"
			replace b6 = 12  if b6_string == "pharm"
			replace b6 = 13  if b6_string == "pho"
			replace b6 = 14  if b6_string == "specialist"
			replace b6 = 15  if b6_string == "therapist"
			replace b6 = 16  if b6_string == "otherclinical"
			replace b6 = -98 if b6_string == "noans"
			replace b6 = 100 if b6_string == "other"
			drop b6_string
			
		* Nurse type
			rename b7 b7_string
			gen 	b7 = 1 if b7_string == "nurse_bsc"
			replace b7 = 2 if b7_string == "nurse_r"
			replace b7 = 3 if b7_string == "nurse_e"	
			drop b7_string
			
		* Private
			destring pri, replace
		
		* Merge variable
			replace b4_2 = b4_1 if b4_2 == . & b4_1 != .
			drop b4_1
	
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************


	* Drop variables for which splitting has already been done/unnecessary variables
	drop a7 c4 c9 d2 d6 d7 d8 e1_1 e1_2 e1_3 e3 e4 f2 a4_c a4_v	
	
	*------------------------------------*
	* 3.1. Label define and label values *
	*------------------------------------*	

	* Ownership
		lab def ownership 1 "Private" 0 "Public"
		lab val pri ownership

	* Cadre
		lab def cadre 	1 "Clinical officer" ///
						2 "Community health worker" ///
						3 "Dentist" ///
						4 "Doctor or medical officer" ///
						5 "Intern/Student" ///
						6 "Lab technologist/lab technician" ///
						7 "Laboratory scientist" ///
						8 "Midwife" ///
						9 "Nurse" ///
						10 "Nurse Aides" ///
						11 "Nutritionist" ///
						12 "Pharmacist/pharmacy technologist/dispenser" ///
						13 "Public health officer (PHO)" ///
						14 "Specialists (e.g., haemotologists, radiographers)" ///
						15 "Therapist/counselor" ///
						16 "Other clinical staff" ///
						-97 "Other"
		lab val b6 cadre
		
	* Nurse 
		lab def nurse 	1 "Nurse (BSc)" ///
						2 "Nurse (Registered Community Health Nurse (KRHCN))" ///
						3 "Nurse (Enrolled Community Health Nurse (EHCN))"
		lab val b7 nurse
		
	* Yes/No
		*lab define yesno_l 1 "Yes" 0 "No"

		*foreach var in *_ch_* pri {
		*	lab values `var' yesno_l
		*}	
	
	*-----------------------------------------------------------------------*
	* 3.2. Rename variables to coincide with printer-friendly questionnaire *
	*-----------------------------------------------------------------------*
		
		
	* Preloaded
		rename a1			 		 hfid
		rename facilityname 		 hfname
		rename pri 					 ownership
		rename time_startinteraction time_start
		rename time_endinteraction1  time_end
		
	* Cover
		rename a3		 supervisorid
		rename a3_c		 supervisorname
		rename a2 		 enumeratorid
		rename a2_c		 enumeratorname
		rename a6		 a5
		rename a7_*	 	 a6_*
		rename a6_0		 a6_4
			
	* HCW General Information
		rename b3 	b4
		rename b7 	b8
		rename b6 	b7
		rename b5 	b6
		rename b4_2 b5
		rename b2_v b3
	
	* Hang Hygiene and PPE
		rename c1_1 	c1a
		rename c1_2 	c1b
		rename c2 		c2a
		rename c3 		c2b
		rename c4_* 	c3_*
		rename c3_0		c3__97
		rename c5 		c4a
		rename c6 		c4b
		rename c7 		c4c
		rename c8 		c4d
		rename c9_*		c5_*
		rename c5_0		c5__97

	* Injections and Blood Draws
		rename d1 		d1a
		rename d2_0 	d2__97
		rename d3 		d3a
		rename d4 		d3b
		rename d5 		d3c
		rename d6_* 	d4_* 
		rename d4__97	d4__99
		rename d4_0		d4__97		
		rename d7_*		d5_*                       
		rename d5__97	d5__99
		rename d5_0		d5__97
		rename d8_* 	d6_*                   
		rename d6__99	d6__97
		rename d6_0		d6__99
		rename d9 		d7a
		rename d10		d7b
		rename d11		d7c
	
	* Waste segregation and Disinfection of medical devices
		rename e3_1			e5_6
		rename e3_2			e5_1
		rename e3_3			e5_2
		rename e3_4			e5_3
		rename e3_5			e5_4
		rename e3_6			e5_5
		rename e3__99		e5__99
		rename e3_0			e5__97
		rename e4_1			e6_6
		rename e4_2			e6_1
		rename e4_3			e6_2
		rename e4_4			e6_3
		rename e4_5			e6_4
		rename e4_6			e6_5
		rename e4__99		e6__99
		rename e4_0			e6__97
		rename e1_1_*		e1_*
		rename e1_2_*		e2_*
		rename e1_3__*		e3__99
		rename e1_3_*		e3_*
		rename e2			e4
	
	* End
		rename f1_1 			f2
		rename f3 				f5
		rename f1_2 			f3
		rename f2_english 		f4_1
		rename f2_swahili 		f4_2
		rename f2_mijikenda 	f4_3
		rename f2_kimeru 		f4_4
		rename f2_luhya 		f4_5
		rename f2_0 			f4_6	
  		rename f2_* 			f4a_*
		
		
	*----------------------*
	* 3.3. Label variables *
	*----------------------*
		*Get rid of instances of "do not know"
		foreach var in b2 b5 b6 b7 b8 c2a c2b c4a c4b c4c c4d d1a d3a d3b d7a d7b d7c e4 {
			replace `var'=.d if `var'==-99
			replace `var'=.r if `var'==-98
		}
		
		* Preloaded data
		lab var date			"Survey date"
		lab var time			"Survey time"
		lab var hfid 			"Facility ID"
		lab var hfname 			"Health Facility name"
		lab var county 			"County"
		lab var ownership 		"Ownership"		
		lab var level 			"Level"		
		lab var key 			"Survey CTO ID"
		lab var time_end 		"Time after last question"
		lab var time_start 		"Time after consent"
	
	* Cover
		lab var supervisorid	"Supervisor ID"
		lab var supervisorname	"Supervisor Name"
		lab var enumeratorid	"Enumerator ID"
		lab var enumeratorname	"Enumerator Name"
		lab var a6_1 "Procedures observed includes: Consultation"
		lab var a6_2 "Procedures observed includes: Injections"
		lab var a6_3 "Procedures observed includes: Blood test"
		lab var a6_4 "Procedures observed includes: None"
		
	* HCW General Information
		lab var b1 "Enter HCW's gender"
		lab var b7 "What is your cadre?"
		lab var b8 "What kind of nurse are you?"
		
	* Hand Hygiene and PPE
		lab var c3_1 "Potential contact w/blood"
		lab var c3_2 "Potential contact w/body fluids, mucous membranes, non-intact skin"
		lab var c3_3 "Before performing invasive procedures"
		lab var c3_4 "Before handling contaminated waste items or surfaces"
		lab var c3__97 "Other"
		lab var c3__99 "Do not know"
		lab var c5_1 "Before touching a patient"
		lab var c5_2 "Before clean/aseptic procedure"
		lab var c5_3 "After body fluid exposure risk"
		lab var c5_4 "After touching a patient"
		lab var c5_5 "After touching patient surroundings"
		lab var c5_6 "Before performing an injection"
		lab var c5_7 "When dispensing drugs in pharmacy"
		lab var c5_8 "After handling specimen"
		lab var c5__97 "Do not know"
		lab var c5__99 "Other"

	* Injections and Blood Draws
		lab var d2_1 "Hep B virus"
		lab var d2_2 "Hep C virus"
		lab var d2_3 "HIV"
		lab var d2_4 "Ebola"
		lab var d2_5 "Other STDs (e.g., syphilis)"
		lab var d2__97 "Other"
		lab var d4_1 "Leak-proof puncture-resistant sharp/safety box"
		lab var d4_2 "Red bin"
		lab var d4_3 "Yellow bin"
		lab var d4_4 "Black bin"
		lab var d4__97 "Other"
		lab var d4__99 "Do not know"
		lab var d5_1 "Leak-proof puncture-resistant sharp/safety box"
		lab var d5_2 "Red bin"
		lab var d5_3 "Yellow bin"
		lab var d5_4 "Black bin"
		lab var d5__97 "Other"
		lab var d5__99 "Do not know"
		lab var d6_1 "Clean wounds, needlesticks & cuts w/soap and water"
		lab var d6_2 "Report incident to supervisor"
		lab var d6_3 "Have source patient tested for HIV & Hep B & C"
		lab var d6_4 "Immediately seek treatment, esp. PEP w/in 72 hrs" 
		lab var d6__97 "Does not know/Does not answer"
		lab var d6__99 "Other"

	
	* Waste segregation and Disinfection of medical devices
		lab var e1_1 "Highly infectious waste"
		lab var e1_2 "Infectious or hazardous healthcare waste"
		lab var e1_3 "Non-infectious waste"
		lab var e1__99 "Don't know"
		lab var e2_1 "Highly infectious wastes"
		lab var e2_2 "Infectious or hazardous healthcare waste"
		lab var e2_3 "Non-infectious waste"
		lab var e2__99 "Don't know"
		lab var e3_1 "Highly infectious waste"
		lab var e3_2 "Infectious or hazardous healthcare waste"
		lab var e3_3 "Non-infectious waste"
		lab var e3__99 "Don't know"
		lab var e5_1 "After use in contact w/patient"
		lab var e5_2 "After use on open wound/non-intact skin"
		lab var e5_3 "After contact w/blood"
		lab var e5_4 "Every day"
		lab var e5_5 "Once in a while"
		lab var e5__99 "Does not know/Does not answer"
		lab var e5__97 "Other"
		lab var e5_6 "Before use in contact w/patient"
		lab var e6_1 "After use in contact w/patient"
		lab var e6_2 "After use on open wound/non-intact skin"
		lab var e6_3 "After contact w/blood"
		lab var e6_4 "Every day"
		lab var e6_5 "Once in a while"
		lab var e6__99 "Does not know/Does not answer"
		lab var e6__97 "Other"
		lab var e6_6 "Before use in contact w/patient"
		lab var f4_1 "English"
		lab var f4_2 "Swahili"
		lab var f4_3 "Mijikenda"
		lab var f4_4 "Kimeru"
		lab var f4_5 "Luhya"
		lab var f4_6 "Other languages"
	
	* End


	*---------------------*
	* 3.4. Order database *
	*---------------------*
				
		global preload		date time hfid hfname county level ownership key time_start time_end
		
		global cover		supervisorid supervisorname enumeratorid enumeratorname a4 a5 a6_1 a6_2 a6_3 a6_4
		
		global HCW_info 	b1 b2 b3 b4 b5 b6 b7 b8	
							
		global hand_hyg 	c1 c1a c1b c2a c2b c3_1 c3_2 c3_3 c3_4 c3__97 c3__99 c4a ///
							c4b c4c c4d c5_1 c5_1 c5_2 c5_3 c5_4 c5_5 c5_6 c5_7 ///
							c5_8 c5__97 c5__99
							
		global injection	d1a d2_1 d2_2 d2_3 d2_4 d2_5 d2__97 d3a d3b d3c d4_1 ///
							d4_2 d4_3 d4_4 d4__97 d4__99 d5_1 d5_2 d5_3 d5_4 d5__97 d5__99 d6_1 ///
							d6_2 d6_3 d6_4 d6__97 d6__99 d7a d7b d7c
							
		global waste		e1_1 e1_2 e1_3 e1__99 e2_1 e2_2 e2_3 e2__99 e3_1 e3_2 ///
							e3_3 e3__99 e4 e5_1 e5_2 e5_3 e5_4 e5_5 e5_6 e5__97 e5__99  ///
							e6_1 e6_2 e6_3 e6_4 e6_5 e6_6 e6__97 e6__99
							
		global sv_end		f1 f2 f3 f4_1 f4_2 f4_3 f4_4 f4_5 f4_6 f4a_1 f4a_2 ///
							f4a_3 f4a_4 f4a_5 f4a_6 f5
												
		order $preload $cover $HCW_info $hand_hyg $injection $waste $sv_end	

********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************
	 
	*-----------------------------------------------------------------*
	* 4.1. Upload HF’s information with profile information corrected * 
	*-----------------------------------------------------------------*

	* Drop old profile information
		drop hfname county level
	
	* Merge profile information
		local prof_vars "latitude longitude hfid hfname county subcounty level"

		merge m:1 hfid using "${listing_end}", keepus(`prof_vars') 
		keep if _merge == 3
		drop 	_merge
	
	* Order dataset 
		order `prof_vars', after(key)
		
	*-------------------------------------*
	* 4.2. Save database for construction *
	*-------------------------------------*

	*save "${PPS_HCW_clean_pii}", replace 	
	
	*----------------*
	* 4.3. Anonymize * 
	*----------------*
	
	  * Replace hfid (codes are being used in many places for the government datasets)
	  * Eliminate names, GPS coordinates, nearest market, name of in-charge (if available here), name of surveyor
	  * Need to creat a file with identifier 
	  * Keep patient ID cause it's already anonymous 
	  
	  drop latitude longitude county subcounty hfid hfname supervisorname supervisorid enumeratorid enumeratorname
	
	*--------------------------------------------*
	* 4.4. Save database for microdata catalogue *
	*--------------------------------------------*A
	
	save "${pps_hcw_clean}", replace 
	
	
	/*------------------------*
	* 4.5. Build dictionary *
	*------------------------*

	codebookout "${dictionary}", replace
	
	*------------------------*
	* 4.6. Descriptive Stats *
	*------------------------*
	
	global select_one "level a5 b1 b4 b6 b7 c1 d3a d3b d3c e4"
			
	foreach var of global select_one {
		loc varlab: variable label `var'
		lab var `var' "`var': `varlab'"
		tab `var', gen(`var'_)
		order `var'_*, after(`var')
		replace `var'=.
	}
	
	ds, has(type numeric)
	local num_vars `r(varlist)'
	
	foreach var in `num_vars' {
		loc varlab: variable label `var'
		loc varlab_nocomma=subinstr("`varlab'",",","",.)
		lab var `var' "`varlab_nocomma'"
	}
	estpost tabstat `num_vars', ///
	statistics(n mean sd min max p50 p90) ///
	columns(statistics)
	esttab using "${desc_stats}", replace ///
	cells("count(label(N)) mean(label(Mean) fmt(%9.4f)) sd(label(Std Dev) fmt(%9.4f)) min(label(Min)) max(label(Max)) p50(label(Median)) p90(label(p90))") ///
	label plain ///
	noobs nonumber mtitles("Descriptive Statistics") ///
	*/
	
	* Dismount
	veracrypt, dismount drive("${mount}") 
	