/*******************************************************************************	

Project:  		KePSIE
Created on:  	
Last udpate on: 

Written by:  	Tsz Kwan Coco Yim (tyim@worldbank.org)
					with select code lines from : Maria Camila Ayala and 
												  Benjamin Daniels

Revision: 		Amy Dolinger (adolinger@worldbank.org)

********************************************************************************			

THIS DO FILE: 	Cleans the endline Practice of Patient Safety (PPS) 
				Site Observation (SO) database 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
						 1.1 - Manual corrections
						 1.2 - Calculate response rates
				Part 2 - Complete variables
						 2.1 - Replace ÒDonÕt answerÓ/ÒDonÕt knowÓ to missing
				Part 3 - Basic cleaning
						 3.1 - Clean variables
						 3.2 - Rename variables
						 3.3 - Label variables
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HFÕs information with profile information 
						       corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionary			
						 4.6 - Descriptive statistics
		
INPUTS:     	* Raw data
				"${KePSIE_DB}/Endline/DataSets/Raw/PPS_SO.dta"
				
				* HF profile information
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"
				
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Amy Dolinger)
				
					* Anonymized data for microdata catalog
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_SO_clean_nopii_end.dta"
					
					* Non-anonymized data for further analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_SO_clean_pii_end.dta"
					
					* Dictionary
					"${KePSIE_DB}/Endline/Output/Final/PPS_SO_dictionary_end.xlsx"
					
					* Response rate table
					"${KePSIE_DB}/Endline/Output/Final/PPS_SO_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${KePSIE_DB}/Endline/Output/Final/PPS_SO_desc_stats_end.csv"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Anonymized data for microdata catalog
					"${end_dt}/Intermediate/PPS_SO_clean_nopii_end.dta"
					
					* Non-anonymized data for further analysis
					"${end_dt}/Intermediate/PPS_SO_clean_pii_end.dta"
					
					* Dictionary
					"${end_out}/Final/PPS_SO_dictionary_end.xlsx"
					
					* Response rate table
					"${end_out}/Final/PPS_SO_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${end_out}/Final/PPS_SO_desc_stats_end.csv"
				

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************/

clear all
set more off

	* Input files
		glo pps_so	 			"${volume}/pps_so_end_raw.dta"
		glo listing_end			"${dt_mast}/listing_end.dta"
	
	* Output files
		glo pps_so_clean		"${dt_end_clean}/pps_so_end.dta"

********************************************************************************
	** Part 1: Complete database
********************************************************************************

* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")

	use "${pps_so}",clear

	*--------------------------*
	* 1.1 Manual corrections  *
	*--------------------------*

		* Manual revision of survey errors
			
			replace a1=900397 if key=="uuid:be9a771e-acc4-4b7e-9f28-cf6864bbcea7" 
			replace a1=11606 if key=="uuid:8be1523a-81c5-487c-b316-831dfe93493d"
			drop if key=="uuid:7698d0fb-3178-4149-8fb3-d3898d5f369b"
				
	*-------------------------------*
	* 1.2 Calculate response rates  *
	*-------------------------------*	
	
		* Gen survey complete indicator
		
			gen complete=(a9==1)
				lab var complete "Survey was completed"
				lab val complete yesno	
	
		/* Attempted
		
			mat T = J(3,1,.)
			count
			scalar 	attemp = r(N)
			mat T[1,1] = attemp
			
		* Able to proceed
		
			count if a9 == 1
			scalar 	proceed = r(N)
			mat T[2,1] = proceed
			
		* Response rate
		
			scalar resp_rate = proceed/attemp*100
			mat T[3,1] = resp_rate

		* Matrix rownames	
		
			mat rownames T = "Attempted" "Able to proceed" "Response rate"
			matlist T
			
		* Export to excel
		
			putexcel clear
			putexcel set "$resp_rate", modify sheet("Patient Exit")
			putexcel A2 = ("Attempted") A3 = ("Able to proceed") A4 = ("Response rate") ///
			B2 = matrix(T) 
			*/
	*-------------------------------------------------------*
	* Keep only those who consented and finished the survey *
	*-------------------------------------------------------*
		
		* Keep only those who consented and finished the survey
		
			keep if  a9 == 1	

********************************************************************************
	** Part 2: Complete variables
********************************************************************************

	*-----------------------------------------------------*
	* 2.1 Replace "Don't answer"/"Don't know" to missing  *
	*-----------------------------------------------------*

		* Split mult c7_* (Does the nearest hand-washing area have running water)
			
			gen c7_1 = 1 if c7 == 1 			//Running water (in sink, a bucket with a tap or a bucket with a pitcher)
				replace c7_1 = 0 if c7 == 2
			gen c7_2 = 1 if c7 == 2 			//No running water
				replace c7_2 = 0 if c7 == 1
			gen c7__99 = 1 if c7 == -99 		//Cannot be assessed
				replace c7__99 = 0 if c7 != -99
	
		* Replace variables__99 with the option "Cannot be Assessed" with ".c"
		
			foreach i of numlist 1(1)2 {
				replace c7_`i' = .c if c7==-99
				*replace c7__99 = .c if strmatch(c7, "-99")
					}		

			foreach i of numlist 1(1)5 {
				replace c8_`i' = .c if strmatch(c8, "-99")
				*replace c8__99 = 1 if strmatch(c8, "-99")
					}
	
			foreach i of numlist 1(1)3 {
				replace c9_`i' = .c if strmatch(c9, "-99")
				*replace c9__99 = .c if strmatch(c9, "-99")
					}
			
			foreach i of numlist 1(1)4 {
				replace c10_`i' = .c if strmatch(c10, "-99")
				*replace c10__99 = .c if strmatch(c10, "-99")
					}
			
			foreach i of numlist 1(1)4 {
				replace b1_`i' = .c if b1_`i'== -99
					}
					
			foreach x of varlist c1 c4 c6 c16 c17 {
				replace `x' = .c if `x'== -99
					}					
									
********************************************************************************
	** Part 3: Basic cleaning
********************************************************************************

	*-----------------------*
	* 3.1 Clean variables   *
	*-----------------------*
	
		* Clean profile vars

			* Date
			
				gen date_td=date(date,"DMY")
				drop date
				rename date_td date
				format date %td
				lab var date "Survey date"

				compare time_end1 time_end2 //not duplicates, cannot drop one of them
				compare time time_start	
					
			* Time
			
				rename time_end1 time_end
				gen double time_start_ = clock(time_start, "hm")
				gen double time_end_ = clock(time_end, "hm")
				drop time_start time_end
				ren time_start_ time_start
				ren time_end_ time_end
				format time_start time_end %tc_HH:MM	 
				
			* Site
				
				clonevar site = a7
				tab a7, gen(a7_)	
				
		* Destring vars
	
			foreach x of varlist c2_* {
			
				destring `x', replace
				
					}
					
			foreach x of varlist c2_* {
			
				gen `x'_ = 1 if `x'=="Black"
				replace `x'_ = 2 if `x'=="Red"
				replace `x'_ = 3 if `x'=="Yellow"
				replace `x'_ = 4 if `x'=="Other color"
				replace `x'_ = 5 if `x'=="Improvised"
				
				drop `x'
				ren `x'_ `x'
				
				lab def `x' 1 "Black" 2 "Red" 3 "Yellow" 4 "Other color" 5 "Improvised"
				lab val `x' `x'
			
					}							
					
		* Drop unnecessary vars
		
			* Survey vars
	
				drop subscriberid simid devicephonenum deviceid starttime endtime formdef_version submissiondate facilitycode time key a1_c_v a2_v a3_v a5_v_* a5_c_* a9 facilityname level pri f1 f1_1 f1_2 a8 time_end2 complete pri_string					
			
			* Roster vars 
			
				drop hcwidnumber_* hcwidnumber2_* b_g1_count binsrosternumber_* hhroster*	
				
			* Multiple selection vars	
				
					foreach x of varlist a7 c7 c8 c9 c10 {
					
						drop `x'
						
							}						
				
			* Duplicate vars
			
				compare hcw_count a4			  //duplicates
				drop hcw_count
					
				compare c1 binsroster_count		  //duplicates
				drop binsroster_count
					
				compare c2_2 c2type_2			  //duplicates
				compare c2_3 c2type_3
				compare c2_4 c2type_4
				compare c2_5 c2type_5
				compare c2_6 c2type_6
				compare c2_7 c2type_7
				drop c2type_*			
	
	*------------------------*
	* 3.2 Rename variables   *
	*------------------------*

		* Cover
			
			rename a1		 hfid								
			rename a2 		 enumeratorid
			rename a2_c		 enumeratorname	 	 
			rename a3		 supervisorid
			rename a3_c		 supervisorname		
				
		* Hand Hygiene Outside of Patient Interaction
				
			rename b2_*      b1a_*
			rename b3_*_1    b1b_1_*
			rename b3_*_2    b1b_2_*
			rename b3_*_3    b1b_3_*
			rename b3_*_4    b1b_4_*
			rename b3_*_5    b1b_5_*
			rename b3_*_6    b1b_6_*
			rename b3_*_7    b1b_7_*
			rename b3_*_8    b1b_8_* 				
				
	*-----------------------*
	* 3.3 Label variables   *
	*-----------------------*				

		* Cover
		
			lab var date			"Survey Date"
			lab var hfid 			"Facility ID"	
			lab var time_end 		"Time After Last Question"
			lab var time_start 		"Time After Consent"		
		
			lab var supervisorid	"Supervisor ID"
			lab var supervisorname	"Supervisor Name"
			lab var enumeratorid	"Enumerator ID"
			lab var enumeratorname	"Enumerator Name"
			
			lab var a7_1			"Observation site includes: Consultation Room"
			lab var a7_2			"Observation site includes: Laboratory"
			lab var a7_3			"Observation site includes: Injection Room"
			lab var a8_1 			"Procedure observed includes: Consultation"
			lab var a8_2 			"Procedure observed includes: Injections"
			lab var a8_3 			"Procedure observed includes: Blood test"
			lab var a8_0 			"Procedure observed includes: None of Above"
				
			foreach i of numlist 1(1)4 {
				lab var a5_`i' "Enter HCW ID [HCW `i']"
					}
			
		* Hand Hygiene Outside of Patient Interaction 
		
			foreach hcwnum of numlist 1(1)4 {          
				lab var b1_`hcwnum'	"Did [HCW `hcwnum'] perform hand hygiene outside of the time of the form?"	
				
					}
		
			foreach hcwnum of numlist 1(1)4 {          
				lab var b1a_`hcwnum'	"[HCW `hcwnum']: how many times perform hand hygiene?"	
				

			foreach hhnumber of numlist 1(1)8 {
				lab var b1b_`hhnumber'_`hcwnum' "Activity that triggered [HCW `hcwnum'] to perform hand hygiene `hhnumber'"
					} 
					
					}

		* Availability of Supplies and Infrastructure		
			
			lab var c7_1			"Running Water: Running Water (in sink, a bucket with a tap or a bucket with a pitcher)"
			lab var c7_2			"Running Water: No Running Water"
			lab var c7__99			"Running Water: Cannot be Assessed"
			
			lab var c8_1			"Type of Soap: Bar Soap"
			lab var c8_2			"Type of Soap: Liquid Soap in Dispenser"
			lab var c8_3			"Type of Soap: Liquid Soap in Improvised Bottle"
			lab var c8_4			"Type of Soap: No Soap Available"
			lab var c8_5			"Type of Soap: Other (Please Specify)"
			lab var c8__99			"Type of Soap: Cannot be Assessed" 
			
			lab var c9_1			"Hand-wash Sign: A Sign Explaining the Importance of Hand-Washing/Hand Hygiene"
			lab var c9_2			"Hand-wash Sign: A Sign Explaining Best Practices for Hand-Washing/Hand Hygiene"
			lab var c9_3			"Hand-wash Sign: No Signs Available"
			lab var c9__99			"Hand-wash Sign: Cannot be Assessed" 
			
			lab var c10_1			"Dry Supply: Disposable Towel"	
			lab var c10_2			"Dry Supply: Reusable Towel"
			lab var c10_3			"Dry Supply: No Towel"
			lab var c10_4			"Dry Supply: Electrical Dryer"
			lab var c10__99			"Dry Supply: Cannot be Assessed"
			
			lab var c12_1			"Sharp Container: Leak-Proof, Puncture-Resistant Sharp Container"
			lab var c12_2			"Sharp Container: Improvised Jerry Can"
			lab var c12_3			"Sharp Container: Improved Carton Box"
			lab var c12_4			"Sharp Container: Color-Coded Bin"
			lab var c12_5			"Sharp Container: Other Color Bin"
			lab var c12_0			"Sharp Container: None Available"	
			
			foreach bin of numlist 1(1)7 {              
				lab var c2_`bin' 	"Color of Bin `bin' Available in the Room"
				lab var c3_`bin' 	"Color of the Bag in the Bin `bin'"
					}
	

********************************************************************************
	** Part 4: Save different files and anonymize 
********************************************************************************

	*-----------------------------------------------------------------*
	* 4.1 Upload HFÕs information with profile information corrected  * 
	*-----------------------------------------------------------------*
		
		local profilevars hfid hfname county subcounty private level latitude longitude
			
			merge m:1 hfid using "${listing_end}", keepus(`profilevars')
				keep if _merge == 3 // need to check this -- 1 HF was a refusal but they completed SO (no DO)
				drop _merge
		
				order `profilevars'	

	*-------------------------------------*
	* 4.2 Save database for construction  *
	*-------------------------------------*
	
		* Order dataset	
			
			global preload		date hfid hfname county subcounty level private latitude longitude time_start time_end supervisorid supervisorname enumeratorid enumeratorname
			global cover 		a4 a5_* site a7_* a8_*					
			global handhyg	 	b1_* b1a_* b1b_* 	
			global supplies		c1 c2* c3* c4* c5* c6* c7* c8* c9* c10* c11* c12* c13* c14* c15* 
		
			order $preload $cover $handhyg $supplies
	
		* Save dataset	
					*save "${PPS_SO_clean_pii}", replace
					
					
	*----------------*
	* 4.3 Anonymize  * 
	*----------------*
	  
		drop latitude longitude hfid 
	
	*--------------------------------------------*
	* 4.4 Save database for microdata catalogue  *
	*--------------------------------------------*
	
				save "${pps_so_clean}", replace
				

	/*------------------------*
	* 4.5 Build dictionnary  *
	*------------------------*
	
		preserve	

			codebookout "${dictionary}", replace

		restore 
		
	*-----------------------------*
	* 4.6 Descriptive statistics  *
	*-----------------------------*

		ds, has(type numeric)
			local num_vars `r(varlist)'

			foreach var in `num_vars' {
				loc varlab: variable label `var'
				loc varlab_nocomma=subinstr("`varlab'",",","",.)
				lab var `var' "`varlab_nocomma'"
					}	
			
			set matsize 500
			estpost	tabstat `num_vars', ///
							statistics(n mean sd min max p50 p90) ///
							columns(statistics)
								
			esttab 	using "${desc_stats}", ///
						cells("count(label(N)) mean(label(Mean) fmt(%9.4f)) sd(label(Std Dev) fmt(%9.2f)) min(label(Min)) max(label(Max)) p50(label(Median)) p90(label(p90))") ///
						label ///
						noobs nonumber mtitles("Descriptive Statistics") plain ///
						replace
						*/
						
	
	* Dismount
	veracrypt, dismount drive("${mount}") 
