/*******************************************************************************	

Project:  		KePSIE
Created on:  	September 5, 2018
Last udpate on: Nov 7, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	This do-file cleans the raw data from QPS1 instrument   


CONTENT:		Part 1 - Create globals for directories and files 
				Part 2 - Merges with the missing data for price supply and demand 
				Part 3 - Renames and label variables and values
				Part 4 - Anonymize data for general dataset and save
				Part 5 - Create separate dataset using QPS1, backchecks and profile to isolate price / demand outcomes

INPUTS:     	* Raw data from the QPS1 instrument. 
				"$"{KePSIE_DB}/Endline/DataSets/Intermediate/QPS1_clean_nopii_end.dta"
				
				* Fees from Outpatients
				"${KePSIE_DB}/Endline/DataSets/Raw/Fees_Outpatients_servers/Fees_Outpatients1"

				* HF profile information
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"

				*Backchecks done by supervisors for QPS1
				"${KePSIE_DB}/Endline/DataSets/Intermediate/backcheck_QPS1_clean_end.dta"


OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Cleaned QPS1 database with no PII
					"${KePSIE_DB}/Endline/DataSets/Intermediate/QPS1_clean_nopii_end.dta"
		
					* Cleaned database ready for price / demand database construction
					"${KePSIE_DB}/Endline/DataSets/Intermediate/Fees_Outpatient_QPS1_clean_end.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Cleaned database ready for price / demand database construction
					"${end_dt}/Intermediate/Fees_Outpatient_QPS1_clean_end.dta"
					

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
	
		glo qps1_raw			"${volume}/qps1_end_raw.dta"
		glo qps1_fees1			"${volume}/supplemental/fees_outp_end_raw_1"
		glo qps1_fees2			"${volume}/supplemental/fees_outp_end_raw_2"
		glo profile_end			"${dt_mast}/listing_end.dta"
		glo qps1_bc_clean 		"${dt_end_clean}/qps1_end_bc.dta"
		
	* Output files: 
		glo qps1_clean 			"${dt_end_clean}/qps1_end.dta"
		glo qps1_fees_outp 		"${dt_end_clean}/qps1_fees_outp_end.dta"
	

* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")	
	
	use "${qps1_raw}", clear 

* Manual corrections
	replace subcounty_c="Lurambi" if key=="uuid:5accae88-0069-4588-85d9-493b537adcc0" // one exception that did not match inventory / Rodgers confirmed on May 8 being in Lurambi
	replace date="12-May-2018" if  key=="uuid:71dc084e-d916-442d-883a-b3539097e0a5"

* Drop unnecessary variables
	drop deviceid subscriberid simid devicephonenum	submissiondate starttime endtime formdef_version speedviollist speedviolcount formdef_version

*******************************************************************************************
*For now, dropping all the roster variables giving details on the employees of the facility
drop roster_repeat roster_repeat_v1 roster_repeat_v2 roster_repeat_c staff_ros_t1 staff_ros_t2 staff_ros__count c6* c5* c7* c8* c9* c10* c11* c12* c13* c14* c15* c16* c17* c18* c20 c21 

********************************************************************************************

* Getting rid of all the variables used for checks, merging all the variables in one correct cleaned variable
	
	*Date 	
		replace date = "30-Apr-2018" if key == "uuid:a842f5d8-c8bf-4b30-b233-a38a4a17f33e" // Done manually as only one observation for which there was an issue with the date
		drop a2 a2_1 a2_v

		* Clean date
			gen date_td=date(date,"DMY")
			drop date
			rename date_td date
			format date %td
			lab var date "Survey date"
				assert !mi(date) 

	*Starting time
		* Putting date in the same format
	gen a3_v_0 		= "0" + a3_v // Adding a 0 at the beginning of a3_v to facilitate the following string substraction 
	gen hour 		= 	substr(a3_v_0, -11 , 2)	 if a3 == 0
	gen minute 		= 	substr(a3_v_0, -8 , 2)	 if a3 == 0
	gen part_day 	= 	substr(a3_v_0, -2 , 2)	 if a3 == 0

	destring hour, replace

	replace hour 	= hour + 12 if part_day == "PM" & hour != 12
	gen s_hour 		= "0" + string(hour)
	gen s2_hour 	= substr(s_hour, -2, 2)

	replace time = s2_hour + ":" + minute 			if a3 == 0

	drop f36_t1_1_full f36_t2_1 f36_t1_1 f37_t1 f37_t1_full f37_t2 s2_hour s_hour a3 a3_v_0 hour minute part_day a3_v a3_1 f33_t1 f33_t2 f35_t1 f35_t2 time_startinteraction time_start_d time_end_d time_end_e time_start_e time_end_e time_start_gm time_end_gm time_start_staffroster time_endinteraction time_end_staffroster time_end_g time_endinteraction2

* Combining geolocalisation data in a unique set of variables
	gen latitude 	= .
	gen longitude 	= .
	gen altitude 	= .
	gen accuracy 	= .

	foreach var of varlist latitude longitude altitude accuracy {
		replace `var' = a1`var' 	if a1_v != 1  // When geolocalisation is entered at the end of the survey, add the info in the original variable
		replace `var' = h2_1`var' 	if a1_v == 1 		
	}

drop  altitude accuracy a1latitude a1longitude a1altitude a1accuracy a1_cal a1_cal h1_1 h1_2 h2_3 h2_1latitude h2_1longitude h2_1altitude h2_1accuracy h2_2 a1_v //Dropping all the unnecessary variables linked to geolocalisation  

* Facilities information
	drop facilitycode a10 nocounty nocounty_county //When can drop these variables as all the facility ID were entered correctly and all the counties were correctly registered

* Surveyor's information
	drop a9 a7 // The answer are always yes to these questions of control / verification

* Gen survey complete indicator
	gen complete=(a12==1)
	lab val complete yesno

* Check isid
	preserve
		keep if complete==1
		isid a5
	restore

* keep one observation maximum per hfid
	duplicates list a5 // Issue with a5 = 901250 & a5 = 901253
	drop if complete != 1 // The other non complete facilities will be added when merging with the listing. 
	drop  g1 g2 g3 g4 g5 g6 g7 g8 g9 // variables explaining why survey has not been completed 

* Ownership
	gen			pub	=	1	if	pri=="0" // Confusing but only solution to be consistent with the baseline encoding of the same variable
	replace		pub	=	0	if	pri=="1"
	lab	define	pub		1	"Public"	0	"Private"
	lab	val		pub	pub
	drop 		pri pri_string

* Calculating age of facility whenever possible. 
	replace d2_a = 2018 - d2_b if (d2_a == -99 | mi(d2_a)) & d2_b != -99 & !mi(d2_b) //We put all the information available in d2_a and drop d2_b
	drop 	d2_b

* Put job title variables in group + add from listing for the one prelisted
	destring b1, replace
	gen b1c_nurse = 1 if b1 == 0 & (b4_nurse_r == 1 | b4_nurse_e == 1 | b4_nurse_bsc == 1) //b4_nurse_bsc becomes variable for all nurses as in baseline
	gen b1c_19 = . // for the "don't know" to copy baseline
	gen b1c_20 = . // for "Receptionist" to copy baseline
 
	
* Drop the original multiple choice questions
	drop d9 e44 e46 d13 f38 f10 f28 f28_o f28_0 f28__97 e3 e3_8 e7 e15_how e20 e20_10 e20_6_det f7_list f7_list__97 e34 e34_5  e44_3 e46_2 

* Drop checking variables for now. 
	drop perc_tot f36_p_v f37_s_v


* Renaming variables to merge with listing 
	rename 	a5 	  hfid

* Drop variables which will be imported from the listing data later on 
	drop facilityname county_preloaded county subcounty_c d1 d1_v d2_a pub


********************************************************************************

	**  Part 2: Merges with the missing data for price supply and demand 

********************************************************************************

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
*3.1 Merging with Fees_Outpatients database: missing data that were collected later on

tempfile QPS1_incomplete
save `QPS1_incomplete'

use "${qps1_fees1}", clear
merge 1:1 a5 date using "${qps1_fees2}", force
rename a5 	hfid

*Cleaning of surveys which were not done and resolving potential issues with duplicates.
drop if g1 == 3 // Dropping surveys which were not started for various reasons, most of the time it is simply because the facility is closed

*Resolving duplicates
drop if key == "uuid:946cb2ea-3584-4cbb-921a-e632b2bc9a8e" // for hfid == 510010, on that day thought information not available but apparently found a way the second time
drop if key == "uuid:01f21272-44c5-4c1a-a333-00497cbf078d" // No information was collected on that day, no reason to keep this duplicate

*510020
gen date_price = "."
label var date_price "Date on which price was collected"

gen date_outpatient = "."
label var date_outpatient "Date on which outpatients data was collected"

replace date_price = date 				if missing_type_1 == 1
replace date_outpatient	= date 			if missing_type_2 == 1	


replace date_price = "26-Jun-2018" 		if key == "uuid:077483f2-19cd-45a1-a97a-28dc59899ede"
replace f34_1 = 150 					if key == "uuid:077483f2-19cd-45a1-a97a-28dc59899ede" // Adding the price to have all the info in one row
replace why_miss_cons = 4 				if key == "uuid:077483f2-19cd-45a1-a97a-28dc59899ede" 
replace missing_type_1 = 1 				if key == "uuid:077483f2-19cd-45a1-a97a-28dc59899ede" 

drop 									if key == "uuid:358c9c4f-1a12-4294-8a00-827a231c714d"

*588120
replace date_price = "28-May-2018"  	if key == "uuid:31de69a9-9aea-44d7-a75b-e81d98dad87b"
replace f34_1 = 0						if key == "uuid:31de69a9-9aea-44d7-a75b-e81d98dad87b" // Adding the price to have all the info in one row
replace why_miss_cons = 6 				if key == "uuid:31de69a9-9aea-44d7-a75b-e81d98dad87b"
replace why_miss_cons_o = "The facility does not charge patients any consultation fee. They calculate the total amount of treatment and the drugs and this is what is charged to the patients." /// 
										if key == "uuid:31de69a9-9aea-44d7-a75b-e81d98dad87b" 
replace missing_type_1 = 1 				if key == "uuid:31de69a9-9aea-44d7-a75b-e81d98dad87b" 

drop 									if key == "uuid:c6d71533-c66e-4c27-87d3-30978536c2bb"

*Keeping only the variables we are interested in and renaming all of them so that there is no conflict when merging
drop deviceid subscriberid simid devicephonenum a1latitude a1longitude a1altitude a1accuracy a1_cal a1_v a2 a2_1 time a3 a3_v a3_1 facilitycode ///
facilityname county_preloaded pri pri_string a10 a6 a6_c a7 a12 time_startinteraction missing_type time_start_cons time_end_cons time_start_outpatients /// 
f33_t1 f33_t2 f35_t1 f35_t2 time_end_outpatients g1 g2 g3 g4 g5 g6 g7 g8 time_endinteraction2 h1_1 h1_2 h2_1latitude h2_1longitude h2_1altitude /// 
h2_1accuracy h2_2 h2_3 speedviolcount speedviollist formdef_version submissiondate starttime endtime a2_v 

**** Nov-Feb months are sometimes stored 1-4 and sometimes 4-1, standardize November is for 1 and it then decreases
	foreach v in f33_miss_det_ f33_miss_ f35_miss_detu_ f35_miss_det_ f35_miss_  {

		forvalue i = 1/4 { // Create a new variable for each with reverse order
			disp `i'
			local a = 5 - `i' 
			clonevar `v'`a'c = `v'`i' 
			drop `v'`i'
		}

		forvalue j = 1/4 { 	// Rename the new variable with the correct name 
			rename `v'`j'c  `v'`j' 
		}
	}

* Have to do it again for f35_miss_*u as previous code does not work because of the final u. 
		forvalue i = 1/4 {
			disp `i'
			local a = 5 - `i' 
			clonevar f35_miss_`a'uc = f35_miss_`i'u 
			drop f35_miss_`i'u
		}

				forvalue j = 1/4 {
			rename f35_miss_`j'uc  f35_miss_`j'u 
		}



	*Renaming all the variables: just copy pasting what is done below
	rename 		f34_1 			f8
	rename 		f33_1 			f17a
	rename 		f33_2 			f17b
	rename 		f33_3 			f17c
	rename 		f33_4 			f17d
	rename 		f33_5 			f17e
	rename 		f33_6 			f17f
	rename 		f33_7 			f17g 

	rename 		f33_miss 		f17_miss
	rename 		f33_miss_1 		f17_miss_a
	rename 		f33_miss_2 		f17_miss_b
	rename 		f33_miss_3 		f17_miss_c
	rename 		f33_miss_4 		f17_miss_d
	rename 		f33_miss_5 		f17_miss_e
	rename 		f33_miss_6 		f17_miss_f
	rename 		f33_miss_7 		f17_miss_g
	rename 		f33_miss_det_1 	f17_miss_det_a
	rename 		f33_miss_det_2 	f17_miss_det_b
	rename 		f33_miss_det_3 	f17_miss_det_c
	rename 		f33_miss_det_4 	f17_miss_det_d
	rename 		f33_miss_det_5 	f17_miss_det_e
	rename 		f33_miss_det_6 	f17_miss_det_f
	rename 		f33_miss_det_7 	f17_miss_det_g	
	rename 		a_jan_c 		f17_complete_c
	rename 		a_feb_c 		f17_complete_d
	rename 		a_mar_c 		f17_complete_e
	rename 		a_apr_c 		f17_complete_f
	rename 		a_may_ask 		f17_complete_g


	rename 		f35_1u 			f18a
	rename 		f35_2u 			f18b
	rename 		f35_3u 			f18c
	rename 		f35_4u 			f18d
	rename 		f35_5u 			f18e
	rename 		f35_6u 			f18f
	rename 		f35_7u 			f18g

	rename 		f35_missu 			f18_miss
	rename 		f35_miss_1u 		f18_miss_a
	rename 		f35_miss_2u 		f18_miss_b
	rename 		f35_miss_3u 		f18_miss_c
	rename 		f35_miss_4u 		f18_miss_d
	rename 		f35_miss_5u 		f18_miss_e
	rename 		f35_miss_6u 		f18_miss_f
	rename 		f35_miss_7u 		f18_miss_g
	rename 		f35_miss_detu_1 	f18_miss_det_a
	rename 		f35_miss_detu_2 	f18_miss_det_b
	rename 		f35_miss_detu_3 	f18_miss_det_c
	rename 		f35_miss_detu_4 	f18_miss_det_d
	rename 		f35_miss_detu_5 	f18_miss_det_e
	rename 		f35_miss_detu_6 	f18_miss_det_f
	rename 		f35_miss_detu_7 	f18_miss_det_g	
	rename 		u_jan_c 			f18_complete_c
	rename 		u_feb_c 			f18_complete_d
	rename 		u_mar_c 			f18_complete_e
	rename 		u_apr_c 			f18_complete_f
	rename 		u_may_ask 			f18_complete_g

	rename 		f35_1o 			f19a
	rename 		f35_2o 			f19b
	rename 		f35_3o 			f19c
	rename 		f35_4o 			f19d
	rename 		f35_5o 			f19e
	rename 		f35_6o 			f19f
	rename 		f35_7o 			f19g

	rename 		f35_miss 		f19_miss
	rename 		f35_miss_1 		f19_miss_a
	rename 		f35_miss_2 		f19_miss_b
	rename 		f35_miss_3 		f19_miss_c
	rename 		f35_miss_4 		f19_miss_d
	rename 		f35_miss_5 		f19_miss_e
	rename 		f35_miss_6 		f19_miss_f
	rename 		f35_miss_7o 	f19_miss_g
	rename 		f35_miss_det_1 	f19_miss_det_a
	rename 		f35_miss_det_2 	f19_miss_det_b
	rename 		f35_miss_det_3 	f19_miss_det_c
	rename 		f35_miss_det_4 	f19_miss_det_d
	rename 		f35_miss_det_5 	f19_miss_det_e
	rename 		f35_miss_det_6 	f19_miss_det_f
	rename 		f35_miss_deto_7 f19_miss_det_g	
	rename 		o_jan_c 		f19_complete_c
	rename 		o_feb_c 		f19_complete_d
	rename 		o_mar_c 		f19_complete_e
	rename 		o_apr_c 		f19_complete_f
	rename 		o_may_ask 		f19_complete_g

	label var  f17a 	"Outpatients:  November 2017"
	label var  f17b 	"Outpatients:  December 2017"
	label var  f17c 	"Outpatients:  January 2018"
	label var  f17d 	"Outpatients:  February 2018"	
	label var  f17e 	"Outpatients:  March 2018"	
	label var  f17f 	"Outpatients:  April 2018"
	label var  f17g 	"Outpatients:  May 2018"	

	label var  f18a 	"UNDER 5 Outpatients:  November 2017"
	label var  f18b 	"UNDER 5 Outpatients:  December 2017"
	label var  f18c 	"UNDER 5 Outpatients:  January 2018"
	label var  f18d 	"UNDER 5 Outpatients:  February 2018"	
	label var  f18e 	"UNDER 5 Outpatients:  March 2018"	
	label var  f18f 	"UNDER 5 Outpatients:  April 2018"
	label var  f18g 	"UNDER 5 Outpatients:  May 2018"	

	label var  f19a 	"OVER 5 Outpatients:  November 2017"
	label var  f19b 	"OVER 5 Outpatients:  December 2017"
	label var  f19c 	"OVER 5 Outpatients:  January 2018"
	label var  f19d 	"OVER 5 Outpatients:  February 2018"	
	label var  f19e 	"OVER 5 Outpatients:  March 2018"	
	label var  f19f 	"OVER 5 Outpatients:  April 2018"	
	label var  f19g 	"OVER 5 Outpatients:  May 2018"

	label var 	f17_miss 		"Outpatients record incomplete for any month?"                          	
	label var 	f17_miss_a 		"November 2017:Num of days Outpatients records incomplete"           
	label var 	f17_miss_b 		"December 2017:Num of days Outpatients records incomplete"         
	label var 	f17_miss_c 		"January 2018:Num of days Outpatients records incomplete"         
	label var 	f17_miss_d  	"February 2018:Num of days Outpatients records incomplete"         
	label var 	f17_miss_e 		"March 2018:Num of days Outpatients records incomplete"             
	label var 	f17_miss_f 		"April 2018:Num of days Outpatients records incomplete"           
	label var 	f17_miss_g 		"May 2018:Number of days Outpatients records incomplete"      
	label var 	f17_miss_det_a	"November 2017:Outpatients records incomplete?"              
	label var 	f17_miss_det_b 	"December 2017:Outpatients records incomplete?"                    
	label var 	f17_miss_det_c 	"January 2018:Outpatients records incomplete?"                   
	label var 	f17_miss_det_d 	"February 2018:Outpatients records incomplete?"                  
	label var 	f17_miss_det_e 	"March 2018:Outpatients records incomplete?"               
	label var 	f17_miss_det_f 	"April 2018:Outpatients records incomplete?"                        
	label var 	f17_miss_det_g	"May 2018:Outpatients records incomplete?"                       
	label var 	f17_complete_c 	"January 2018:Are data complete for Outpatients?"          
	label var 	f17_complete_d 	"February 2018:Are data complete for Outpatients?"                      
	label var 	f17_complete_e 	"March 2018:Are data complete for Outpatients?"                 
	label var 	f17_complete_f 	"April 2018:Are data complete for Outpatients?"               
	label var 	f17_complete_g 	"Ask for May for Outpatients if survey done after May"            

	label var 	f18_miss 		"Outpatients UNDER 5 record incomplete for any month?"                   	
	label var 	f18_miss_a 		"November 2017:Num of days Outpatients UNDER 5 records incomplete"        
	label var 	f18_miss_b 		"December 2017:Num of days Outpatients UNDER 5 records incomplete"    
	label var 	f18_miss_c 		"January 2018:Num of days Outpatients UNDER 5 records incomplete"     
	label var 	f18_miss_d  	"February 2018:Num of days Outpatients UNDER 5 records incomplete"      
	label var 	f18_miss_e 		"March 2018:Num of days Outpatients UNDER 5 records incomplete"       
	label var 	f18_miss_f 		"April 2018:Num of days Outpatients UNDER 5 records incomplete"      
	label var 	f18_miss_g 		"May 2018:Number of days Outpatients UNDER 5 records incomplete"       
	label var 	f18_miss_det_a	"November 2017:Outpatients UNDER 5 records incomplete?"               
	label var 	f18_miss_det_b 	"December 2017:Outpatients UNDER 5 records incomplete?"                   
	label var 	f18_miss_det_c 	"January 2018:Outpatients UNDER 5 records incomplete?"                      
	label var 	f18_miss_det_d 	"February 2018:Outpatients UNDER 5 records incomplete?"                        
	label var 	f18_miss_det_e 	"March 2018:Outpatients UNDER 5 records incomplete?"                     
	label var 	f18_miss_det_f 	"April 2018:Outpatients UNDER 5 records incomplete?"                   
	label var 	f18_miss_det_g	"May 2018:Outpatients UNDER 5 records incomplete?"                          
	label var 	f18_complete_c	"January 2018:Are data complete for Outpatients UNDER 5?"           
	label var 	f18_complete_d 	"February 2018:Are data complete for Outpatients UNDER 5?"          
	label var 	f18_complete_e 	"March 2018:Are data complete for Outpatients UNDER 5 ?"                
	label var 	f18_complete_f 	"April 2018:Are data complete for Outpatients UNDER 5?"               
	label var 	f18_complete_g 	"Ask for May for Outpatients UNDER 5 if survey done after May"      

	label var 	f19_miss 		"Outpatients OVER 5 record incomplete for any month?"               	
	label var 	f19_miss_a 		"November 2017:Num of days Outpatients OVER 5 records incomplete" 
	label var 	f19_miss_b 		"December 2017:Num of days Outpatients OVER 5 records incomplete" 
	label var 	f19_miss_c 		"January 2018:Num of days Outpatients OVER 5 records incomplete"   
	label var 	f19_miss_d  	"February 2018:Num of days Outpatients OVER 5 records incomplete"   
	label var 	f19_miss_e 		"March 2018:Num of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_f 		"April 2018:Num of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_g 		"May 2018:Number of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_det_a	"November 2017:Outpatients OVER 5 records incomplete?"            
	label var 	f19_miss_det_b 	"December 2017:Outpatients OVER 5 records incomplete?"             
	label var 	f19_miss_det_c 	"January 2018:Outpatients OVER 5 records incomplete?"               
	label var 	f19_miss_det_d 	"February 2018:Outpatients OVER 5 records incomplete?"                 
	label var 	f19_miss_det_e 	"March 2018:Outpatients OVER 5 records incomplete?"               
	label var 	f19_miss_det_f 	"April 2018:Outpatients OVER 5 records incomplete?"                 
	label var 	f19_miss_det_g	"May 2018:Outpatients OVER 5 records incomplete?"                  
	label var 	f19_complete_c 	"January 2018:Are data complete for Outpatients OVER 5?"               
	label var 	f19_complete_d 	"February 2018:Are data complete for Outpatients OVER 5?"               
	label var 	f19_complete_e 	"March 2018:Are data complete for Outpatients OVER 5 ?"          
	label var 	f19_complete_f 	"April 2018:Are data complete for Outpatients OVER 5?"           
	label var 	f19_complete_g 	"Ask for May for Outpatients OVER 5 if survey done after May"            


	foreach var of varlist * {    
		local lbl : variable label `var'
    	label var `var' `"Added from missing fees: `lbl'"'
		rename `var' add_`var'
	}

rename add_hfid hfid

*Merge with QPS1
merge 1:1 hfid using `QPS1_incomplete'
rename _merge missing 
replace missing = (missing==3)

label define mis 1 "Second survey collected" 0 "No other survey collected"
label values missing mis

label var missing "observations for which surveyors had to go again to collect the data"




*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
*Back to cleaning the database

**** Nov-Feb months are sometimes stored 1-4 and sometimes 4-1, standardize November is for 1 and it then decreases
	foreach v in f33_miss_det_ f33_miss_ f35_miss_detu_ f35_miss_det_ f35_miss_  {

		forvalue i = 1/4 { // Create a new variable for each with reverse order
			disp `i'
			local a = 5 - `i' 
			clonevar `v'`a'c = `v'`i' 
			drop `v'`i'
		}

		forvalue j = 1/4 { 	// Rename the new variable with the correct name 
			rename `v'`j'c  `v'`j' 
		}
	}

* Have to do it again for f35_miss_*u as previous code does not work because of the final u. 
		forvalue i = 1/4 {
			disp `i'
			local a = 5 - `i' 
			clonevar f35_miss_`a'uc = f35_miss_`i'u 
			drop f35_miss_`i'u
		}

				forvalue j = 1/4 {
			rename f35_miss_`j'uc  f35_miss_`j'u 
		}

********************************************************************************

	** Part 3: Renames and label variables and values

********************************************************************************		

*Section A: Cover 
	* Rename variables to follow the baseline
	rename 		a8 		 		foid
	rename 		a8_c			foname 
	rename 		a6				sfoid 
	rename 		a6_c			sfname	 
	rename 		a11 			a6

** Labeling variables

	label var  	date 			"Data collection date"
	label var  	time 			"Data collection time"
	label var 	latitude 		"Latitude"
	label var 	longitude		"Longitude"
	label var  	foid 			"FO ID"
	label var  	foname 			"FO name"
	label var  	sfoid 			"Senior FO ID"
	label var  	sfname 			"Senior FO name"
	label var  	a6 				"Rural/Urban"
	label var  	complete 		"Survey was completed"

*Section B: Cover 
	* Rename variables to follow the paper questionnaire
	rename 		b2 					b1a
	rename 		b3 					b1b
	rename 		b4_clinicalofficer 	b1c_1
	rename 		b4_chw 				b1c_2
	rename 		b4_dentist 			b1c_3
	rename 		b4_doctormo 		b1c_4
	rename 		b4_hospitaladmin 	b1c_5
	rename 		b4_intern 			b1c_6
	rename 		b4_labtech 			b1c_7
	rename 		b4_labsci 			b1c_8
	rename 		b4_midwife 			b1c_9
	rename 		b4_nurse_bsc 		b1c_10
	rename 		b4_nurse_r 			b1c_11
	rename 		b4_nurse_e 			b1c_12
	rename 		b4_nurseaide 		b1c_13
	rename 		b4_nutritionist 	b1c_14
	rename 		b4_pharm 			b1c_15
	rename 		b4_pho 				b1c_16
	rename 		b4_specialist 		b1c_17
	rename 		b4_therapist 		b1c_18



** Labeling variables
	label var  b1 			"Respondent's code"
	label var  b1a 			"Respondent's name"
	label var  b1b 			"Are you the person who is in charge of this facility today? if a different person from listing"
	label var  b1c_1 		"Respondent's job title includes:Clinical Officer"
	label var  b1c_2 		"Respondent's job title includes:Community health worker"
	label var  b1c_3 		"Respondent's job title includes:Dentist"
	label var  b1c_4 		"Respondent's job title includes:Doctor or medical officer"
	label var  b1c_5 		"Respondent's job title includes:Hospital administrator/executive director/superintendent"
	label var  b1c_6 		"Respondent's job title includes:Intern/Student"
	label var  b1c_7 		"Respondent's job title includes:Lab technologist/lab technician"
	label var  b1c_8 		"Respondent's job title includes:Laboratory scientist"
	label var  b1c_9 		"Respondent's job title includes:Midwife"
	label var  b1c_10  		"Respondent's job title includes: Nurse BSc"
	label var  b1c_11 		"Respondent's job title includes: Nurse (KRHCN)"
	label var  b1c_12  		"Respondent's job title includes: Nurse (EHCN)"
	label var  b1c_nurse	"Respondent's job title includes: Nurse (BSc, KRHCN or EHCN)"
	label var  b1c_13 		"Respondent's job title includes:Nurse Aides"
	label var  b1c_14 		"Respondent's job title includes:Nutritionist"
	label var  b1c_15 		"Respondent's job title includes:Pharmacist/pharmacy technologist/dispenser"
	label var  b1c_16 		"Respondent's job title includes:Public health officer (PHO)"
	label var  b1c_17 		"Respondent's job title includes:Specialists (e.g., haemotologists, radiographers)"
	label var  b1c_18 		"Respondent's job title includes:Therapist/counselor"	
	label var  b1c_19 		"Respondent's job title includes:Don't know"
	label var  b1c_20 		"Respondent's job title includes:Receptionist"

* Section C
	* Rename variables to follow the paper questionnaire
	rename 		c1  	h1
	rename 		c2_1 	h2a
	rename 		c2_2 	h2b
	rename 		c2_c 	h2_total
	
	rename 		d2 		c2
	rename 		d3 		c3
	rename 		d4 		c4
	rename 		d5 		c5
	rename 		d6 		c5a
	rename 		d7 		c6
	rename 		d8 		c6a
	rename 		d9_1  	c7_1
	rename 		d9_2 	c7_2
	rename 		d9_3 	c7_3
	rename 		d9_4 	c7_4
	rename 		d9_5 	c7_5
	rename 		d9__99	c7_6 
	rename 		d9_6 	c7_7

	rename 		d10 	c8
	rename 		d11 	c9a 
	rename 		d12 	c9b
	rename 		d13_1 	c10_1
	rename 		d13_2 	c10_2
	rename 		d13_3 	c10_3
	rename 		d13_0 	c10_4
	rename 		d14 	c10a
	rename 		d15 	c10b
	rename 		d16 	c11
	rename 		d17 	c12
	rename 		d18 	c12a 
	rename 		d18_1 	c12b 

** Labeling variables
	label var  c3 		"How many consultation rooms are there in this facility?"
	label var  c4 		"How many health care workers are seeing patients in the consultation room(s) today?"
	label var  c5 		"Do you have a dedicated injection room?"
	label var  c5a 		"How many health care workers are there in the injection room today?"
	label var  c6 		"Do you offer lab services?"
	label var  c6a 		"How many health care workers are there giving laboratory services today?"
	label var  c7_1 	"Water source: No water source"
	label var  c7_2 	"Water source: Piped water 24 hours"
	label var  c7_3 	"Water source: Piped water less than 24 hours"
	label var  c7_4 	"Water source: Clean tank water"
	label var  c7_5 	"Water source: outside HF"
	label var  c7_6 	"Water source: Unkown"
	label var  c7_7 	"Water source: Rain water"

	label var  c8 		"Reliability of electricity supply"
	label var  c10_1 	"Available phones at HF includes: Mobile phone (owned by HF)"
	label var  c10_2 	"Available phones at HF includes: Functioning landline (owned by HF)"
	label var  c10_3 	"Available phones at HF includes: Phones (owned by staff) "
	label var  c10_4 	"Available phones at HF includes: No phone available "
	label var  c11 		"Does the facility own a functioning computer or laptop?"
	label var  c12 		"Was there access to email or internet within or near the facility in the last 7 days?"
	label var  c12a  	"If we want to send you information, could we send this to your email address? (if there is access to email or internet)"
	label var  c12b 	"Please specify you email"
	label var  h2_total "HF's total staff"

* Section D
	* Rename variables to follow the paper questionnaire (this part is too different from baseline, no point in trying to follow baseline here)
	rename 		e1 			d1
	rename 		e2 			d2 
	rename 		e3_1 		d3_1
	rename 		e3_2 		d3_2
	rename 		e3_3 		d3_3
	rename 		e3_4 		d3_4
	rename 		e3_5 		d3_5
	rename 		e3_6 		d3_6
	rename 		e3_7 		d3_7
	rename 		e3__99 		d3_8
	rename 		e3_o     	d3_9
	rename  	e4 			d4 
	rename 		e5 			d5 
	rename 		e6  		d6 
	rename 		e8 			d8 
	rename 		e7_1 		d7_1
	rename 		e7_2 		d7_2
	rename 		e7_3 		d7_3
	rename 		e7_4 		d7_4
	rename 		e7_5 		d7_5
	rename 		e7_6 		d7_6
	rename 		e7_7 		d7_7
	rename 		e7_8 		d7_8
	rename 		e7_9 		d7_9
	rename 		e7_0 		d7_0

	rename 		e9_1 		d9_1
	rename 		e9_2 		d9_2
	rename 		e9_3 		d9_3
	rename 		e9_4 		d9_4
	rename 		e9_5 		d9_5
	rename 		e9_6 		d9_6
	rename 		e9_7 		d9_7
	rename 		e9_8 		d9_8
	rename 		e10 		d10
	rename 		e11 		d11
	rename 		e12 		d12
	rename 		e13 		d13
	rename 		e14 		d14 
	rename 		e15 		d15
	rename 		e15_how_1 	d15_1
	rename 		e15_how_2 	d15_2
	rename 		e16 		d16
	rename 		e17 		d17 
	rename 		e19 		d19
	rename 		e20_1 		d20_1
	rename 		e20_2 		d20_2
	rename 		e20_3 		d20_3
	rename 		e20_4 		d20_4
	rename 		e20_5 		d20_5
	rename 		e20_6 		d20_6
	rename 		e20_7 		d20_7
	rename 		e20_8 		d20_8
	rename 		e20_9 		d20_9
	rename 		e20_o 		d20_10	
	rename 		e20_6_det_1 d20_6_1
	rename 		e20_6_det_2 d20_6_2
	rename 		e21_1 		d21_1
	rename 		e21_2 		d21_2
	rename 		e21_3 		d21_3
	rename 		e21_4 		d21_4
	rename 		e21_5 		d21_5
	rename 		e21_6_1 	d21_6_1
	rename 		e21_6_2 	d21_6_2
	rename 		e21_7 		d21_7
	rename 		e21_8 		d21_8
	rename 		e21_9 		d21_9
	rename 		e21_10 		d21_10
	rename 		e23 		d23 
	rename  	e24_low 	d24_1 
	rename 		e24_mod 	d24_2 
	rename 		e24_high 	d24_3 
	rename 		e27 		d27
	rename 		e28 		d28
	rename 		e25 		d25 
	rename 		e26 		d26 
	rename  	e29_1 		d29a
	rename  	e29_2 		d29b
	rename  	e29_3 		d29c
	rename  	e29_4 		d29d
	rename  	e29_5 		d29e
	rename  	e29_6 		d29f
	rename  	e29_7 		d29g
	rename  	e29_8 		d29h
	rename 		e30 		d30 
	rename 		e31 		d31 
	rename 		e33 		d33 
	rename 		e34_1 		d34_1 
	rename 		e34_2 		d34_2 
	rename 		e34_3 		d34_3 
	rename 		e34_4 		d34_4 
	rename 		e34_o 		d34_5 
	rename 		e35 		d35 
	rename 		e36 		d36 
	rename 		e38 		d38 
	rename 		e39 		d39 
	rename 		e40 		d40 
	rename 		e41 		d41
	rename 		e42			d42
	rename 		e42_1 		d42_1
	rename 		e42_2 		d42_2 
	rename 		e42_3 		d42_3 
	rename 		e42_4 		d42_4 
	rename 		e42_5 		d42_5 
	rename 		e42_6 		d42_6 
	rename 		e42_o 		d42_o 
	rename 		e42_0 		d42_7
	rename 		e43 		d43 
	rename 		e44_1 		d44_1
	rename 		e44_2 		d44_2
	rename 		e44_o 		d44_3
	rename 		e44_0 		d44_4
	rename 		e45 		d45 
	rename 		e46_1 		d46_1 
	rename 		e46_o 		d46_2 
	rename 		e46_0 		d46_3
	rename 		e47 		d47 
	rename 		e48 		d48 
	rename 		e49 		d49 
	rename  	e50 		d50



	label var  d3_1 	"New regulation changes include: Inspections are carried out by one inspector only (instead of various inspectors)"
	label var  d3_2 	"New regulation changes include: Public facilities are also inspected"
	label var  d3_3 	"New regulation changes include: Compliance categories are established"
	label var  d3_4 	"New regulation changes include: Facilities receive a performance score"
	label var  d3_5 	"New regulation changes include: Facilities may be closed for not complying"
	label var  d3_6 	"New regulation changes include: Facilities may be closed for not improving over time"
	label var  d3_7 	"New regulation changes include: Facilities are given time to improve"
	label var  d3_8 	"New regulation changes include: Don't know"
	label var  d3_9 	"New regulation changes include: Other, specify"

	label var  d7_1 	"Inspection by regulatory board include:Clinical Officers Council"
	label var  d7_2 	"Inspection by regulatory board include:Kenya Medical Laboratory Technicians and Technologists Board"
	label var  d7_3 	"Inspection by regulatory board include:Medical Practitioners and Dentists Board"
	label var  d7_4 	"Inspection by regulatory board include:Nursing Council of Kenya"
	label var  d7_5 	"Inspection by regulatory board include:Kenya Nutritionists and Dieticians Institute"
	label var  d7_6 	"Inspection by regulatory board include:Pharmacy and Poisons Board"
	label var  d7_7 	"Inspection by regulatory board include:Public Health Technologists Board"
	label var  d7_8 	"Inspection by regulatory board include:Radiation Protection Board"
	label var  d7_9 	"Inspection by regulatory board include:Do not remember which one(s) came"
	label var  d7_0 	"Inspection by regulatory board include:None of the above"

	label var  d15_1 	"Received copy of complete report include:As a printed copy"
	label var  d15_2 	"Received copy of complete report include:As a soft copy (by email)"

	label var  d20_1 	"Changes implemented to comply include:Renewed / obtained licenses"
	label var  d20_2 	"Changes implemented to comply include:Requested help from the county office"
	label var  d20_3 	"Changes implemented to comply include:Developed new SOPs or facility protocols"
	label var  d20_4 	"Changes implemented to comply include:Bought minor equipment or supplies"
	label var  d20_5	"Changes implemented to comply include:Contributed to the upgrade of facility infrastructure"
	label var  d20_6 	"Changes implemented to comply include:Hired additional staff"
	label var  d20_7 	"Changes implemented to comply include:Changed the management structure or oversight, e.g., created a new committee"
	label var  d20_8 	"Changes implemented to comply include:Developed new reporting tools"
	label var  d20_9 	"Changes implemented to comply include:Made a plan with goals "
	label var  d20_10 	"Changes implemented to comply include:Other (please specify)"
	label var  d20_6_1 	"New staff hired include:Temporary"
	label var  d20_6_2 	"New staff hired include:Permanent"
	
	label var  d21_1 	"additional cost incurred for Renewing / obtaining licenses"
	label var  d21_2 	"additional cost incurred for Requesting help from the county office"
	label var  d21_3 	"additional cost incurred for Developing new SOPs or facility protocols"
	label var  d21_4 	"additional cost incurred for Buying minor equipment or supplies"
	label var  d21_5 	"additional cost incurred for Upgrading the facility infrastructure"
	label var  d21_6_1 	"additional cost incurred for Hiring additional staff (temporary)"
	label var  d21_6_2 	"additional cost incurred for Hiring additional staff (permanent)"
	label var  d21_7  	"additional cost incurred for Making changes to management structure or oversight"
	label var  d21_8  	"additional cost incurred for Developing new reporting tools"
	label var  d21_9  	"additional cost incurred for Making a plan with goals"
	label var  d21_10 	"additional cost incurred for Other changes (as specified)"

	label var  d24_1 	"Proportion of required changes implying no to low cost"
	label var  d24_2	"Proportion of required changes implying moderate cost"
	label var  d24_3 	"Proportion of required changes implying high cost"

	label var  d29a 	"Rate Inspection on: Overall experience with the Joint Health Inspection system"
	label var  d29b 	"Rate Inspection on: Clarity of the content of the inspections"
	label var  d29c 	"Rate Inspection on: Fairness of the scoring system and recommendations"
	label var  d29d 	"Rate Inspection on: Clarity of the recommendations given during inspections"
	label var  d29e 	"Rate Inspection on: Professionalism and attitude of inspectors"
	label var  d29f 	"Rate Inspection on: Availability of channels for reporting issues, if there are any"
	label var  d29g 	"Rate Inspection on: Fairness of closing the facilities or departments if they do not hold the necess"
	label var  d29h 	"Rate Inspection on: Fairness of closing down facilities if they do not improve compliance over time"	

	label var  d34_1 	"Scoreboard helpful include:helps improve to give good impression to patients"
	label var  d34_2 	"Scoreboard helpful include:acts as a visible goal"
	label var  d34_3 	"Scoreboard helpful include:helps know where facility stand"
	label var  d34_4 	"Scoreboard helpful include:helps compare with other facility"
	label var  d34_5 	"Scoreboard helpful include:Other, specify"

	label var  d42 		"Active member of social franchise"
	label var  d42_1 	"Active member of social franchise include: Tunza (Population Services International)"
	label var  d42_2 	"Active member of social franchise include: AMUA (Marie Stopes International)"
	label var  d42_3 	"Active member of social franchise include: CFW Shops (HealthStore Foundation)"
	label var  d42_4 	"Active member of social franchise include: Gold Star (FHI 360)"
	label var  d42_5 	"Active member of social franchise include: Huduma Poa Health Network (Kisumu Medical and Education Trust)"
	label var  d42_6 	"Active member of social franchise include: Other"
	label var  d42_7 	"Active member of social franchise include: Not part of a social franchise"
	label var  d42_o 	"Active member of social franchise include: Other, please specify"
	
	label var  d44_1 	"Health facility accredited by include: National Hospital Insurance Fund (NHIF)"
	label var  d44_2 	"Health facility accredited by include: Safecare"
	label var  d44_3 	"Health facility accredited by include: Other, specify"
	label var  d44_4 	"Health facility accredited by include: Not accredited"

	label var  d46_1 	"Health facility Laboratory accredited by include: KENAS"
	label var  d46_2 	"Health facility Laboratory accredited by include: Other, specify"
	label var  d46_3 	"Health facility Laboratory accredited by include: Not accredited"

*Section E
	* Rename variables to follow the paper questionnaire
	rename 	    f1 			e1
	rename      f2 			e2
	rename 	    f3 			e3 
	rename 	    f4     		e4

	rename 	    f5 			e51
	rename 	    f5_where  	e52
	rename 	    f5_1 		e5a
	rename 	    f5_2 		e5b
	rename 	    f5_3 		e5c
	rename 	    f5_4    	e5d
	rename 	    f5_5 		e5e
	rename      f6 			e5f

	rename 	    f7 			e6a	
	rename 	    f7_cert 	e6b

	rename 		f7_list_1 	e6c_1
	rename 		f7_list_2 	e6c_2
	rename 		f7_list_3 	e6c_3
	rename 		f7_list_4 	e6c_4
	rename 		f7_list_o 	e6c_5
	rename 		f7_list_0 	e6c_6
	rename 	    f8 			e7 
	rename 	    f9 			e7a

	rename 	    f10_1 		e8_1 
	rename 	    f10_2 		e8_2 
	rename 	    f10_3 		e8_3 
	rename 	    f10_4 		e8_4 
	rename 		f10_0 		e8_5
	rename 	    f11 		e8a

	rename 	    f12 		e9 
	rename 	    f13 		e9a
	rename 	    f14 		e9b

	rename 		f16 		f1_JHIC  
	rename 		f16_1 		f1a_JHIC
	rename 		f16_2 		f1b_JHIC

	rename 		f17 		f3_JHIC
	rename 		f18  		f4_JHIC
	rename 		f20 		f5_JHIC
	rename 		f21 		f6_JHIC

	rename 		f22 		f7_JHIC
	rename 		f23 		f8_JHIC
	rename 		f24 		f9_JHIC

	rename  	f26 		f10_JHIC
    rename 		f25 		f11_JHIC 

    rename 		f27 		f12_JHIC 
    rename 		f28_1 		f13_1_JHIC
    rename 		f28_2 		f13_2_JHIC
    rename 		f28_3 		f13_3_JHIC
    rename 		f28_4 		f13_4_JHIC
    rename 		f28_5 		f13_5_JHIC
    rename 		f28_6 		f13_6_JHIC
    rename 		f28_7 		f13_7_JHIC

    rename 		f39 		e10
    rename 		f40 		e11
    rename 		f41 		e12
    rename 		f42 		e13
    rename 		f43  		e14

	lab	define	yesno		1	"yes"	0	"no"

	foreach var of varlist e8_1 e8_2  e8_3 e8_4 e8_5 f13_1_JHIC f13_2_JHIC f13_3_JHIC f13_4_JHIC f13_5_JHIC f13_6_JHIC f13_7_JHIC {
		lab val	`var'	yesno	
	}
	

** Labeling variables
	label var  e51 			"Is a client service charter displayed in all key departments/areas?"
	label var  e5a 	 		"Does client service charter mention common services offered?"
	label var  e5b 	 		"Does client service charter mention obligations to clients?"
	label var  e5c 	 		"Does client service charter mention waiting times for clients?"
	label var  e5d 	 		"Does client service charter mention ways to communicate with management regarding problems/complaints?"
	label var  e5e 	 		"Does client service charter mention services offered for free"

	label var  e6c_1 		"Certifications or accrediting bodies include:National Hospital Insurance Fund (NHIF)"
	label var  e6c_2 		"Certifications or accrediting bodies include:Safecare"
	label var  e6c_3 		"Certifications or accrediting bodies include:KENAS (for laboratories only)"
	label var  e6c_4 		"Certifications or accrediting bodies include:ISO Certification"
	label var  e6c_5 		"Certifications or accrediting bodies include: Others, specify"
	label var  e6c_6 		"Certifications or accrediting bodies include: No Certification body associated with this facility"

	label var  e8_1			"Performance Indicators include: Infant mortality"
	label var  e8_2 		"Performance Indicators include: Maternal mortality"
	label var  e8_3 		"Performance Indicators include: Immunization"
	label var  e8_4 		"Performance Indicators include: Notifiable diseases"
	label var  e8_5 		"Performance Indicators include: None"

	label var  f13_1_JHIC	"(Not scored) Facility contributes to include:Huduma Poa Health Network (Kisumu Medical and Education Trust)"
	label var  f13_2_JHIC	"(Not scored) Facility contributes to include:Gold Star (FHI 360)"
	label var  f13_3_JHIC 	"(Not scored) Facility contributes to include:CFW Shops (HealthStore Foundation)"
	label var  f13_4_JHIC	"(Not scored) Facility contributes to include:AMUA (Marie Stopes International)"
	label var  f13_5_JHIC	"(Not scored) Facility contributes to include:Tunza (Population Services International)"
	label var  f13_6_JHIC	"(Not scored) Facility contributes to include:KENAS (for laboratories only)"
	label var  f13_7_JHIC	"(Not scored) Facility contributes to include:National Hospital Insurance Fund (NHIF)"

*Section f 
	* Rename variables to follow the baseline/ paper questionnaire
	rename 		f34_1 			f8
	rename 		f34_2 			f9
	rename 		f38_1   		f14_1
	rename 		f38_2 			f14_2
	rename 		f38_3 			f14_3
	rename 		f38_4 			f14_4
	rename 		f38_5 			f14_5
	rename 		f38_6 			f14_6
	rename 		f38_0 			f14_7

	rename 		v402 			f14a
	rename 		v403 			f14b 
	rename 		v404  			f14c 
	rename 		v405 			f14d 
	rename 		v406 			f14e 
	rename 		v407 			f14f

	rename 		f36_v 			f15 
	rename 		f33_1 			f17a
	rename 		f33_2 			f17b
	rename 		f33_3 			f17c
	rename 		f33_4 			f17d
	rename 		f33_5 			f17e
	rename 		f33_6 			f17f
	rename 		f33_7 			f17g 

	rename 		f33_miss 		f17_miss
	rename 		f33_miss_1 		f17_miss_a
	rename 		f33_miss_2 		f17_miss_b
	rename 		f33_miss_3 		f17_miss_c
	rename 		f33_miss_4 		f17_miss_d
	rename 		f33_miss_5 		f17_miss_e
	rename 		f33_miss_6 		f17_miss_f
	rename 		f33_miss_7 		f17_miss_g
	rename 		f33_miss_det_1 	f17_miss_det_a
	rename 		f33_miss_det_2 	f17_miss_det_b
	rename 		f33_miss_det_3 	f17_miss_det_c
	rename 		f33_miss_det_4 	f17_miss_det_d
	rename 		f33_miss_det_5 	f17_miss_det_e
	rename 		f33_miss_det_6 	f17_miss_det_f
	rename 		f33_miss_det_7 	f17_miss_det_g	
	rename 		a_jan_c 		f17_complete_c
	rename 		a_feb_c 		f17_complete_d
	rename 		a_mar_c 		f17_complete_e
	rename 		a_apr_c 		f17_complete_f
	rename 		a_may_ask 		f17_complete_g


	rename 		f35_1u 			f18a
	rename 		f35_2u 			f18b
	rename 		f35_3u 			f18c
	rename 		f35_4u 			f18d
	rename 		f35_5u 			f18e
	rename 		f35_6u 			f18f
	rename 		f35_7u 			f18g

	rename 		f35_missu 			f18_miss
	rename 		f35_miss_1u 		f18_miss_a
	rename 		f35_miss_2u 		f18_miss_b
	rename 		f35_miss_3u 		f18_miss_c
	rename 		f35_miss_4u 		f18_miss_d
	rename 		f35_miss_5u 		f18_miss_e
	rename 		f35_miss_6u 		f18_miss_f
	rename 		f35_miss_7u 		f18_miss_g
	rename 		f35_miss_detu_1 	f18_miss_det_a
	rename 		f35_miss_detu_2 	f18_miss_det_b
	rename 		f35_miss_detu_3 	f18_miss_det_c
	rename 		f35_miss_detu_4 	f18_miss_det_d
	rename 		f35_miss_detu_5 	f18_miss_det_e
	rename 		f35_miss_detu_6 	f18_miss_det_f
	rename 		f35_miss_detu_7 	f18_miss_det_g	
	rename 		u_jan_c 			f18_complete_c
	rename 		u_feb_c 			f18_complete_d
	rename 		u_mar_c 			f18_complete_e
	rename 		u_apr_c 			f18_complete_f
	rename 		u_may_ask 			f18_complete_g

	rename 		f35_1o 			f19a
	rename 		f35_2o 			f19b
	rename 		f35_3o 			f19c
	rename 		f35_4o 			f19d
	rename 		f35_5o 			f19e
	rename 		f35_6o 			f19f
	rename 		f35_7o 			f19g

	rename 		f35_miss 		f19_miss
	rename 		f35_miss_1 		f19_miss_a
	rename 		f35_miss_2 		f19_miss_b
	rename 		f35_miss_3 		f19_miss_c
	rename 		f35_miss_4 		f19_miss_d
	rename 		f35_miss_5 		f19_miss_e
	rename 		f35_miss_6 		f19_miss_f
	rename 		f35_miss_7o 	f19_miss_g
	rename 		f35_miss_det_1 	f19_miss_det_a
	rename 		f35_miss_det_2 	f19_miss_det_b
	rename 		f35_miss_det_3 	f19_miss_det_c
	rename 		f35_miss_det_4 	f19_miss_det_d
	rename 		f35_miss_det_5 	f19_miss_det_e
	rename 		f35_miss_det_6 	f19_miss_det_f
	rename 		f35_miss_deto_7 f19_miss_det_g	
	rename 		o_jan_c 		f19_complete_c
	rename 		o_feb_c 		f19_complete_d
	rename 		o_mar_c 		f19_complete_e
	rename 		o_apr_c 		f19_complete_f
	rename 		o_may_ask 		f19_complete_g

	rename 		f36_full 		f22d
	rename 		f36 			f22d_2
	rename 		f37_full  		f23d 	
	rename 		f37 			f23d_2

	rename 		f44_v_full 		f25
	rename 		f44_full 		f25_1
	rename 		f44_v 			f26
	rename 		f44 			f26_1

	rename 		f36_op 			f22	


** Labeling variables
	label var  f8 		"How much do outpatients pay for consultations' fees for first-time visits?"
	label var  f9 		"How much is the registration fee for outpatients?"

	label var  f17a 	"Outpatients:  November 2017"
	label var  f17b 	"Outpatients:  December 2017"
	label var  f17c 	"Outpatients:  January 2018"
	label var  f17d 	"Outpatients:  February 2018"	
	label var  f17e 	"Outpatients:  March 2018"	
	label var  f17f 	"Outpatients:  April 2018"
	label var  f17g 	"Outpatients:  May 2018"	

	label var  f18a 	"UNDER 5 Outpatients:  November 2017"
	label var  f18b 	"UNDER 5 Outpatients:  December 2017"
	label var  f18c 	"UNDER 5 Outpatients:  January 2018"
	label var  f18d 	"UNDER 5 Outpatients:  February 2018"	
	label var  f18e 	"UNDER 5 Outpatients:  March 2018"	
	label var  f18f 	"UNDER 5 Outpatients:  April 2018"
	label var  f18g 	"UNDER 5 Outpatients:  May 2018"	

	label var  f19a 	"OVER 5 Outpatients:  November 2017"
	label var  f19b 	"OVER 5 Outpatients:  December 2017"
	label var  f19c 	"OVER 5 Outpatients:  January 2018"
	label var  f19d 	"OVER 5 Outpatients:  February 2018"	
	label var  f19e 	"OVER 5 Outpatients:  March 2018"	
	label var  f19f 	"OVER 5 Outpatients:  April 2018"	
	label var  f19g 	"OVER 5 Outpatients:  May 2018"

	label var  f14_1 	"Lab services include: Malaria blood smear"
	label var  f14_2 	"Lab services include: Stool O/C"
	label var  f14_3 	"Lab services include: Tuberculosis (Sputum test for AFB)"
	label var  f14_4 	"Lab services include: Urinalysis"
	label var  f14_5 	"Lab services include: Brucella"
	label var  f14_6 	"Lab services include: Blood type"
	label var  f14_7 	"Lab services include: None of the above"
	label var  f14a 	"Lab prices: Malaria blood smear"
	label var  f14b 	"Lab prices: Stool O/C"
	label var  f14c 	"Lab prices: Tuberculosis (Sputum test for AFB)"
	label var  f14d 	"Lab prices: Urinalysis"
	label var  f14e 	"Lab prices: Brucella"
	label var  f14f 	"Lab prices: Blood type"
	
	label var  f22      "Lab services reported for first half of February or entire February"
	label var  f22d 	"February 2018 (No. patients received lab tests)"
	label var  f22d_2 	"First half of February 2018 (No. patients received lab tests)"
	label var  f23d 	"February 2018 (No. of lab tests)"
	label var  f23d_2 	"First half of February 2018 (No. of lab tests)"

	label var  f25 		"Fully operating lab: February 2018"
	label var  f25_1 	"Number of days not operating: February 2018"
	label var  f26 		"Fully operating lab: First half February 2018"
	label var  f26_1 	"Number of days not operating: First half February 2018"

	label var 	f17_miss 		"Outpatients record incomplete for any month?"                          	
	label var 	f17_miss_a 		"November 2017:Num of days Outpatients records incomplete"           
	label var 	f17_miss_b 		"December 2017:Num of days Outpatients records incomplete"         
	label var 	f17_miss_c 		"January 2018:Num of days Outpatients records incomplete"         
	label var 	f17_miss_d  	"February 2018:Num of days Outpatients records incomplete"         
	label var 	f17_miss_e 		"March 2018:Num of days Outpatients records incomplete"             
	label var 	f17_miss_f 		"April 2018:Num of days Outpatients records incomplete"           
	label var 	f17_miss_g 		"May 2018:Number of days Outpatients records incomplete"      
	label var 	f17_miss_det_a	"November 2017:Outpatients records incomplete?"              
	label var 	f17_miss_det_b 	"December 2017:Outpatients records incomplete?"                    
	label var 	f17_miss_det_c 	"January 2018:Outpatients records incomplete?"                   
	label var 	f17_miss_det_d 	"February 2018:Outpatients records incomplete?"                  
	label var 	f17_miss_det_e 	"March 2018:Outpatients records incomplete?"               
	label var 	f17_miss_det_f 	"April 2018:Outpatients records incomplete?"                        
	label var 	f17_miss_det_g	"May 2018:Outpatients records incomplete?"                       
	label var 	f17_complete_c 	"January 2018:Are data complete for Outpatients?"          
	label var 	f17_complete_d 	"February 2018:Are data complete for Outpatients?"                      
	label var 	f17_complete_e 	"March 2018:Are data complete for Outpatients?"                 
	label var 	f17_complete_f 	"April 2018:Are data complete for Outpatients?"               
	label var 	f17_complete_g 	"Ask for May for Outpatients if survey done after May"            

	label var 	f18_miss 		"Outpatients UNDER 5 record incomplete for any month?"                   	
	label var 	f18_miss_a 		"November 2017:Num of days Outpatients UNDER 5 records incomplete"        
	label var 	f18_miss_b 		"December 2017:Num of days Outpatients UNDER 5 records incomplete"    
	label var 	f18_miss_c 		"January 2018:Num of days Outpatients UNDER 5 records incomplete"     
	label var 	f18_miss_d  	"February 2018:Num of days Outpatients UNDER 5 records incomplete"      
	label var 	f18_miss_e 		"March 2018:Num of days Outpatients UNDER 5 records incomplete"       
	label var 	f18_miss_f 		"April 2018:Num of days Outpatients UNDER 5 records incomplete"      
	label var 	f18_miss_g 		"May 2018:Number of days Outpatients UNDER 5 records incomplete"       
	label var 	f18_miss_det_a	"November 2017:Outpatients UNDER 5 records incomplete?"               
	label var 	f18_miss_det_b 	"December 2017:Outpatients UNDER 5 records incomplete?"                   
	label var 	f18_miss_det_c 	"January 2018:Outpatients UNDER 5 records incomplete?"                      
	label var 	f18_miss_det_d 	"February 2018:Outpatients UNDER 5 records incomplete?"                        
	label var 	f18_miss_det_e 	"March 2018:Outpatients UNDER 5 records incomplete?"                     
	label var 	f18_miss_det_f 	"April 2018:Outpatients UNDER 5 records incomplete?"                   
	label var 	f18_miss_det_g	"May 2018:Outpatients UNDER 5 records incomplete?"                          
	label var 	f18_complete_c	"January 2018:Are data complete for Outpatients UNDER 5?"           
	label var 	f18_complete_d 	"February 2018:Are data complete for Outpatients UNDER 5?"          
	label var 	f18_complete_e 	"March 2018:Are data complete for Outpatients UNDER 5 ?"                
	label var 	f18_complete_f 	"April 2018:Are data complete for Outpatients UNDER 5?"               
	label var 	f18_complete_g 	"Ask for May for Outpatients UNDER 5 if survey done after May"      

	label var 	f19_miss 		"Outpatients OVER 5 record incomplete for any month?"               	
	label var 	f19_miss_a 		"November 2017:Num of days Outpatients OVER 5 records incomplete" 
	label var 	f19_miss_b 		"December 2017:Num of days Outpatients OVER 5 records incomplete" 
	label var 	f19_miss_c 		"January 2018:Num of days Outpatients OVER 5 records incomplete"   
	label var 	f19_miss_d  	"February 2018:Num of days Outpatients OVER 5 records incomplete"   
	label var 	f19_miss_e 		"March 2018:Num of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_f 		"April 2018:Num of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_g 		"May 2018:Number of days Outpatients OVER 5 records incomplete"     
	label var 	f19_miss_det_a	"November 2017:Outpatients OVER 5 records incomplete?"            
	label var 	f19_miss_det_b 	"December 2017:Outpatients OVER 5 records incomplete?"             
	label var 	f19_miss_det_c 	"January 2018:Outpatients OVER 5 records incomplete?"               
	label var 	f19_miss_det_d 	"February 2018:Outpatients OVER 5 records incomplete?"                 
	label var 	f19_miss_det_e 	"March 2018:Outpatients OVER 5 records incomplete?"               
	label var 	f19_miss_det_f 	"April 2018:Outpatients OVER 5 records incomplete?"                 
	label var 	f19_miss_det_g	"May 2018:Outpatients OVER 5 records incomplete?"                  
	label var 	f19_complete_c 	"January 2018:Are data complete for Outpatients OVER 5?"               
	label var 	f19_complete_d 	"February 2018:Are data complete for Outpatients OVER 5?"               
	label var 	f19_complete_e 	"March 2018:Are data complete for Outpatients OVER 5 ?"          
	label var 	f19_complete_f 	"April 2018:Are data complete for Outpatients OVER 5?"           
	label var 	f19_complete_g 	"Ask for May for Outpatients OVER 5 if survey done after May"            


*Section g
	* Rename variables to follow the paper questionnaire
	rename g9_english 	g9_ch_1
	rename g9_swahili 	g9_ch_2
	rename g9_mijikenda g9_ch_3
	rename g9_0 		g9_ch_4
	rename g9_kimeru 	g9_ch_7
	rename g9_luhya 	g9_ch_9

** Labeling variables
 	label var  g9_ch_1 	"Language used for the survey include:English"
 	label var  g9_ch_2 	"Language used for the survey include:Swahili"
 	label var  g9_ch_3 	"Language used for the survey include:Mijikenda"
 	label var  g9_ch_4 	"Language used for the survey include:Other languages"
 	label var  g9_ch_7  "Language used for the survey include:Kimeru"
 	label var  g9_ch_9  "Language used for the survey include:Luhya"


** Labelling of all dummies variable
	foreach var of varlist b1c_1 b1c_2 b1c_3 b1c_4 b1c_5 b1c_6 b1c_7 b1c_8 b1c_9 b1c_10 b1c_11 b1c_12 b1c_13 b1c_14 b1c_15 b1c_16 b1c_17 b1c_18 ///
	 c7_1 c7_2 c7_3 c7_4 c7_5 c7_7 c7_6 c10_1 c10_2 c10_3 c10_4 d3_1 d3_2 d3_3 d3_4 d3_5 d3_6 d3_7 d3_8 d7_1 d7_2 d7_3 d7_4 d7_5 d7_6 d7_7 d7_8 /// 
	 d7_9 d42_1 d42_2 d42_3 d42_4 d42_5 d42_7 d44_1 d44_2 d44_4 d46_1 d46_3 d15_1 d15_2 d20_1 d20_2 d20_3 d20_4 d20_5 d20_6 d20_7 d20_8   ///
	 d20_9 d20_6_1 d20_6_2 d34_1 d34_2 d34_3 d34_4 e6c_1 e6c_2 e6c_3 e6c_4 e6c_6 g9_ch_1 g9_ch_2 g9_ch_3 g9_ch_4 g9_ch_7 g9_ch_9 b1c_nurse b1c_19 b1c_20 ///
	 {
		lab val	`var'	yesno	
	}


********************************************************************************

	** Part 4: Anonymize data for general dataset and save

********************************************************************************	\

* Dropping geo localisation
	drop latitude longitude 

* Dropping HF names
	drop sfname foname

* Changing the format of d41 to allow saving in old version => some data loss, come back here if need d41 accurate
	recast str244 d41, force 

* Saving 

		save "${qps1_clean}", replace


********************************************************************************

	** Part 5: Create separate dataset using QPS1, backchecks and profile to isolate price / demand outcomes

********************************************************************************	

***********A : Keep variables of interest ******************************
	
keep f17* f18* f19* add_* f30 f31 f32 f33 f33_type est_2018 f34_3 f8 out_seven missing key date hfid
drop add_d2_a add_d2_b



***********		B :  Merging with facilities profile database ******************************

merge 1:1 hfid using "${profile_end}", keepusing(startyear daysopen f_status)
keep if _merge == 3
drop _merge
gen inactive = (f_status == 0)



***********		C :  Renaming and labelling variables, formating date variables ******************************

label var add_date "Date of the data of the later survey done to get the missing data"

	gen date_td=date(add_date,"DMY")
	drop add_date
	rename date_td add_date
	format add_date %td

	gen date_td=date(add_date_price,"DMY")
	drop add_date_price
	rename date_td add_date_price
	format add_date_price %td

	gen date_td=date(add_date_outpatient,"DMY")
	drop add_date_outpatient
	rename date_td add_date_outpatient
	format add_date_outpatient %td




*********** 	D :  Merge with back checks done by supervisor


rename hfid bcheck_hfid 

merge 1:1 bcheck_hfid using "${qps1_bc_clean}", keepusing(bcheck_out_seven /// 
bcheck_f8 bcheck_f30 bcheck_f31 bcheck_f32 bcheck_f17a bcheck_f17d bcheck_f17_miss bcheck_f33_miss_det bcheck_f17_miss_d bcheck_f17_miss_a /// 
bcheck_f18a bcheck_f18d bcheck_f18_miss bcheck_f35_miss_detu bcheck_f18_miss_d bcheck_f18_miss_a bcheck_f19a bcheck_f19d bcheck_f19_miss /// 
bcheck_f35_miss_det bcheck_f19_miss_d bcheck_f19_miss_a bcheck_date)
drop _merge 

rename bcheck_hfid hfid


*Replacing I don't know using .d

*For hfid 521090 add_f17g is equal to -9 which is most likely a mistake for -99
replace add_f17g = -99 if add_f17g == -9

foreach var of varlist f17* f18* f19* add_f17* add_f18* add_f19* bcheck_f17* bcheck_f18* bcheck_f19* f8 add_f8 bcheck_f8 *seven add_pa*  {
	cap replace `var' = .d if `var' == -99 //Use a cap so that it just pass the string variables without breaking
}

*1) In quite a few observations, the surveyor put a don't know for the number of patient for a specific month and then also enter the number of missing days as the whole month
*In this case, we should put the number of missing days as missing

*2) In the same idea, some variables have 0 for the number of outpatients and the total number of missing days is more or less the whole month
*For these variables, put as missing for the number of outpatient and as missing for the number of missing days (answer should have been no data)  

foreach var in f17 f18 f19 add_f17 add_f18 add_f19 {

	foreach month in a b c d e f g {
	//1
	replace `var'_miss_`month' = . if `var'`month'== .d  | `var'`month'==. 

	//2
	gen 	flag`var'`month' = 0
	replace flag`var'`month' = 1 if `var'`month'== 0  & `var'_miss_`month'> 25 & !mi(`var'_miss_`month')

	replace `var'_miss_`month' 	= . if flag`var'`month' == 1 
	replace `var'`month' 		= .d if flag`var'`month' == 1
		}
}

foreach var in bcheck_f17 bcheck_f18 bcheck_f19 {

	foreach month in a d {

replace `var'_miss_`month' = . if `var'`month'==.d  | `var'`month'==.

		}
}




*********** 	E :  Save dataset ***********************************************


		save "${qps1_fees_outp}", replace
	
	* Dismount
	veracrypt, dismount drive("${mount}") 

	
************************************************End of do file****************************************************

