/*******************************************************************************	
Project:  		KePSIE
********************************************************************************			

THIS DO FILE: 	Cleans the Health Care Worker data file for upload in the WB microdata catalog

CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
				Part 2 - Complete variables
				Part 3 - Basic cleaning
						 3.1 - Label define and label values
						 3.2 - Rename variables to coincide with printer-friendly questionnaire
						 3.3 - Label variables
						 3.4 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionary	
						 4.6 - Generate descriptive statistics
		
		INPUTS: 		* Raw data
						"${KePSIE_DB}/Endline/DataSets/Raw/PPS_HCW.dta"
						
						* HF Baseline profile data
						"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"

		OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Maria Camila)
				
					* Anonymized data for microdata catalog
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_HCW_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/PPS_HCW_clean_pii.dta"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Anonymized data for microdata catalog
					"${end_dt}/Intermediate/PPS_HCW_clean_nopii.dta"
					
					* Non-anonymized data for further analysis
					"${end_dt}/Intermediate/PPS_HCW_clean_pii.dta"

		
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		glo qps1_raw			"${volume}/qps1_end_raw.dta"
		glo profile_end			"${dt_mast}/listing_end.dta"
	
	* Output files
		glo	qps1_roster			"${dt_end_clean}/qps1_roster_end.dta"
	
********************************************************************************
	** Part 1: Complete database
********************************************************************************
* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")	


	use "${qps1_raw}", clear

	*--------------------------*
	*     Manual Corrections   
	*--------------------------*
		replace subcounty_c="Lurambi" if key=="uuid:5accae88-0069-4588-85d9-493b537adcc0" // one exception that did not match inventory / Rodgers confirmed on May 8 being in Lurambi
		replace date="12-May-2018" if  key=="uuid:71dc084e-d916-442d-883a-b3539097e0a5"
		drop if key=="uuid:bf67130d-707f-4601-b11a-ec5a853c013e"
		
	*--------------------------*
	*    Basic Cleaning			   
	*--------------------------*
			
		* Gen survey complete indicator
			gen complete=(a12==1)
			lab val complete yesno

		* Check isid
			preserve
				keep if complete==1
				isid a5
			restore
			
		* Renaming variables to merge with listing 
			rename 	a5 hfid
			
		* Survey Date
		
			gen date1 = date(date,"DMY")
				format date1 %td
				drop date
				rename date1 date
				lab	var	date	"Survey Date"

		* Enumerator & Supervisor
		
			clonevar	enumeratorid	=	a8
			clonevar	enumeratorname	=	a8_c
			clonevar	supervisorid	=	a6
			clonevar	supervisorname	=	a6_c
			
			lab	var	enumeratorid	"Enumerator ID"
			lab	var	enumeratorname	"Enumerator Name"
			lab	var	supervisorid	"Supervisor ID"
			lab	var	supervisorname	"Supervisor Name"
		
			
		* Start time after consent & time survey done
		/*** SL,2017-9-4: Since this is the staff roster survey, I defined start time as "time the survey started staff roster section", and end time as "the time staff roster section is done"	***/
		
			clonevar	time_start=time_start_staffroster
			clonevar	time_end=time_end_staffroster
			
			lab var time_start "Time staff roster started"
			lab	var	time_end "Time staff roster ended"
				
		* Destring variables before cleaning
		
			foreach var in c2_c roster_repeat roster_repeat_c c14_a* c15* {
				destring `var', replace
					}			
					
			foreach var in c14_1 c14_2 c14_3 c14_4 c14_5 c14_6 c14_7 c14_8 c14_9 c14_10 c14_11 c14_12 c14_13 c14_14 c14_15 c14_16 c14_17 c14_18 {
			
				replace `var' = "1000" if `var' == "Kakamega"
				replace `var' = "2000" if `var' == "Kilifi"
				replace `var' = "3000" if `var' == "Meru"
				
				destring `var', replace
				
					}
					
		* SurveyCTO key
		
			lab	var	key	"SurveyCTO ID"
			
		* Globals
		
			* Profile
			
				global profile 		hfid 
				global survey 		date enumerator* supervisor* time_start time_end key
		
			* Staff summary and intro questions
			
				global staff_sum 	c1 c2_1 c2_2 c2_c roster_* staff_ros__count
				
			* Staff ID and name
			
				global staff_char 	c6* c7* c8*
			
			* Staff type
			
				global staff_type 	c5* c9*
			
			* Education
			
				global staff_educ 	c10* c11* c12* c13* c14* c15* c16*
			
			* Days per month and take home pay
			
				global staff_pay 	c17* c18* c20			
			
		* Update profile information from HF profile data

			keep $profile $survey $staff_sum $staff_char $staff_type $staff_educ $staff_pay 
			order $profile $survey $staff_sum $staff_char $staff_type $staff_educ $staff_pay 
			
			merge 1:1 hfid using "${profile_end}"			
				keep if _merge==3
				
				global profile 	hfid hfname county subcounty private level latitude longitude startyear
				
				keep $profile $survey $staff_sum $staff_char $staff_type $staff_educ $staff_pay 
				order $profile $survey $staff_sum $staff_char $staff_type $staff_educ $staff_pay 
		
	
		/* Update total number of staff variable from helper data
		
			merge 1:1 hfid using "${helper}", keepusing(b2_total) assert(1 3)
				gen		_helper=0	if	_merge==1
				replace	_helper=1	if	_merge==3
				lab	var	_helper	"Facility also completed Helper form"
				drop	_merge
				
				replace	c2_1	=	b2_total-1	if	_helper==1	&	c1==1
				replace	c2_2	=	b2_total	if	_helper==1	&	c1!=1
				drop	b2_total	*/
		
			
				
********************************************************************************
	** Part 2: Clean roster variables
********************************************************************************

	drop c9_? c9_??
	
		replace roster_repeat_v1 = roster_repeat if mi(roster_repeat_v1)
		
	* Renaiming variables to follow the paper questionnaire
	rename c1 				h1
	rename c2_1 			h2a
	rename c2_2 			h2b
	rename roster_repeat_v1	h3a
	rename roster_repeat_v2 h3b
	rename c20 				h16
	rename c6* 				h4*
	rename c5* 				h5*
	rename c7* 				h6*
	rename c8* 				h7*
	rename c9_1_* 			h8_1_*
	rename c9_2_* 			h8_2_*
	rename c9_3_* 			h8_3_*
	rename c10* 			h9*
	rename c11* 			h10*

	forvalues i = 1(1)18 {
		rename  c12_`i' h10a_`i'
		rename  c13_`i' h10c_`i'
		rename  c14_`i' h10e_`i'
		rename  c15_`i' h10h_`i'
	}

	rename c12_a* 		h10b*	
	rename c13_a* 		h10d*	
	rename c14_a* 		h10f*
	rename c14_b* 		h10g*
	rename c15_a* 		h10i*
	rename c16* 		h11*
	rename c17* 		h12*
	rename c18_? 		h13_?
	rename c18_?? 		h13_??
	rename c18_1_* 		h14a_*
	rename c18_2_? 		h14b_?
	rename c18_2_?? 	h14b_??
	rename c18_2_o_*	h14c_*
	rename c18_3_min* 	h14_min*
	rename c18_3_max* 	h14_max*
	
	rename staff_ros__count 	staff_c
	rename c2_c 				staff_total_noowner

	* Define value labels
	
		* Institution
		lab	define	institution	1 "Aga Khan University"  ///
								2 "AIC Kapsowar School of Nursing"  ///
								3 "AIC Litein School of Nursing"  ///
								4 "American World University"  ///
								5 "AMREF Virtual Nursing School"  ///
								6 "Armed Forces Memorial School of Nursing"  ///
								7 "Catherine McAuley School of Nursing"  ///
								8 "Central Memorial Hospital Thika"  ///
								9 "Chogoria Hospital"  ///
								10 "Clive Irvine College ofÀéursing"  ///
								11 "Consolata Hospital, Kiambu"  ///
								12 "Consolata Hospital, Nkubu School of Nursing"  ///
								13 "Consolata Hospital, Nyeri School of Nursing"  ///
								14 "Consolata Hospital, Ortum School of Nursing"  ///
								15 "Consolata Hospital, Wamba School of Nursing"  ///
								16 "Cooperative University College"  ///
								17 "Dar-es-salaam University"  ///
								18 "Egerton University"  ///
								19 "Eldoret EPAC College"  ///
								20 "Eldoret Polytechnic"  ///
								21 "Fidenza School of Nursing, Kyeni"  ///
								22 "Focus Business Institute"  ///
								23 "Getrudes Training Center"  ///
								24 "Gulu University"  ///
								25 "Haydom School Of Nursing"  ///
								26 "Health Management Agency"  ///
								27 "Hope Africa University"  ///
								28 "Hubert Kairuki Memorial University"  ///
								29 "Joan School of Nursing"  ///
								30 "Jomo Kenyatta University of Agriculture and Technology"  ///
								31 "Kabete Technical Training Institute"  ///
								32 "Kampala International University"  ///
								33 "KAPC Nairobi"  ///
								34 "Karen Hospital Training College"  ///
								35 "Kendu Adventist Hospital School of Nursing"  ///
								36 "Kendu Mission Hospital"  ///
								37 "Kenya Institute Of Professional Studies"  ///
								38 "Kenya Medical Training College"  ///
								39 "Kenya Methodist University"  ///
								40 "Kenya Polytechnic University College"  ///
								41 "Kenya Red Cross School of Emergency Technology"  ///
								42 "Kenyatta National Hospital Nursing School"  ///
								43 "Kenyatta University"  ///
								44 "Kijabe Mission Hospital"  ///
								45 "Kijabe School of Nursing"  ///
								46 "Kitui Afya Medical Centre"  ///
								47 "Kitui Mission Hospital"  ///
								48 "Kyeni Mission Hospital"  ///
								49 "Makerere University"  ///
								50 "Manipal University in India"  ///
								51 "Maseno Mission Hospital School of Nursing"  ///
								52 "Maseno University"  ///
								53 "Matata Hospital"  ///
								54 "Matric Institute of Professional Studies"  ///
								55 "Maua Methodist Hospital"  ///
								56 "Maua Methodist Hospital School of Nursing"  ///
								57 "Mbarara University"  ///
								58 "Mbukiwa College of Professional Studies"  ///
								59 "Moi Teaching and Referral Hospital"  ///
								60 "Moi University"  ///
								61 "Mombasa Polytechnic University College"  ///
								62 "Mount Kenya University"  ///
								63 "Multimedia University of Kenya"  ///
								64 "Muranga School of Nursing"  ///
								65 "Nairobi Aviation College"  ///
								66 "Nairobi Institute of Business Studies"  ///
								67 "Nairobi Technical Training Institute"  ///
								68 "Nairobi Womens Hospital"  ///
								69 "National University of Rwanda"  ///
								70 "Nazareth Medical College"  ///
								71 "Nazareth School of Nursing"  ///
								72 "Ndunyu Chege Youth Polytechnic"  ///
								73 "NEP College of Health Sciences"  ///
								74 "Ngozi University"  ///
								75 "North Coast Medical Training College"  ///
								76 "Nyansiongo High School"  ///
								77 "Nyanza School of Nursing"  ///
								78 "Nzoia College Nursing"  ///
								79 "Ortum Medical Training College"  ///
								80 "Our Lady Lourdes Mission Hospital School of Nursing, Mwea"  ///
								81 "Outspan Medical College"  ///
								82 "Parklands Training School"  ///
								83 "PC Kinyanjui Technical Training Institute"  ///
								84 "PCEA"  ///
								85 "PCEA Surburb College Nakuru"  ///
								86 "PCEA Tumutumu School of Nursing"  ///
								87 "Presbyterian University of East Africa"  ///
								88 "Pumwani Maternity School of Midwifery" ///
								89 "Ram School of Nursing"  ///
								90 "SAPTA"  ///
								91 "Shinyanga Medical Training College"  ///
								92 "St. Augustine Bugando University"  ///
								93 "St. Camillus School of Nursing"  ///
								94 "St. Clares Kaplong School of Nursing"  ///
								95 "St. Elizabeth School of Nursing, Mukumu"  ///
								96 "St. Joseph Kilgoris Medical Training College"  ///
								97 "St. Joseph÷≥ School of Nursing Nyabondo"  ///
								98 "St. Joseph”≥ School of Nursing, Nyabondo"  ///
								99 "St. Lukes Hospital School of Nursing, Kaloleni"  ///
								100 "St. Lukes Hospital School of Nursing, North Kinangop"  ///
								101 "St. Mary÷≥ Mission Hospital"  ///
								102 "St. Paul's University"  ///
								103 "Technical University of Kenya"  ///
								104 "Tenwek School of Nursing"  ///
								105 "The Nairobi Hospital Cicely McDonnell School of Nursing"  ///
								106 "Thika Nursing Home"  ///
								107 "Thika Technical Training Institute"  ///
								108 "Tumaini University"  ///
								109 "Universal Group of Colleges"  ///
								110 "University of Burundi"  ///
								111 "University of Nairobi"  ///
								112 "Uzima University"  ///
								113 "Vision Institute of Profesionals"  ///
								0 "Other, please specify" 
							
	
		* Location
		lab define location 	1 "Eldoret"  ///
								2 "Embu" ///
								3 "Garissa" ///
								4 "Homabay" ///
								5 "Kabernet" ///
								6 "Kakamega" ///
								7 "Kapkatet" ///
								8 "Kilifi" ///
								9 "Kisumu" ///
								10 "Kitui" ///
								11 "Lodwar" ///
								12 "Loitoktok" ///
								13 "Machakos" ///
								14 "Meru" /// 
								15 "Mombasa" ///
								16 "Msambweni" ///
								17 "Muranga" ///
								18 "Nairobi" ///
								19 "Nakuru" ///
								20 "NRB-Karen" ///
								21 "NRB-Mathare" ///
								22 "Nyeri" ///
								23 "Port Reitz" ///
								24 "Siaya" ///
								25 "Thika" ///
								26 "Webuye" ///
								0 "Others, please specify"
								
		* Overseas university
		lab define overseas_univ	1 "UK" ///
									2 "US" ///
									3 "India" ///
									4 "Tanzania" ///
									5 "Uganda" ///
									0 "Other, please specify"
									
		* Job group
		lab define jobgroup		0 "Other job group, please specify" ///
								1 "A" ///
								2 "B" ///
								3 "C" ///
								4 "D" ///
								5 "E" ///
								6 "F" ///
								7 "G" ///
								8 "H" ///
								9 "I" ///
								10 "J" ///
								11 "K" ///
								12 "L" ///
								13 "M" ///
								14 "N" ///
								15 "O" ///
								16 "P" ///
								17 "Q" ///
								18 "R" ///
								19 "S" ///
								20 "T"
							
	* Universities if health background: asign names to each value
	foreach var in h10a_1 h10a_2 h10a_3 h10a_4 h10a_5 h10a_6 h10a_7 h10a_8 h10a_9 h10a_10 h10a_11 h10a_12 h10a_13 h10a_14 h10a_15 h10a_16 h10a_17 h10a_18 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	institution
	}

	* Universities' location if health background: asign names to each value
	foreach var in h10c_1 h10c_2 h10c_3 h10c_4 h10c_5 h10c_6 h10c_7 h10c_8 h10c_9 h10c_10 h10c_11 h10c_12 h10c_13 h10c_14 h10c_15 h10c_16 h10c_17 h10c_18 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	location
	}
	
	/* Universities outsite Kenya: asign names to each value
	foreach var in h10f_1 h10f_2 h10f_3 h10f_4 h10f_5 h10f_6 h10f_7 h10f_8 h10f_9 h10f_10 h10f_11 h10f_12 h10f_13 h10f_14 h10f_15 h10f_16 h10f_17 h10f_18 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	overseas_univ	
	}

	*/
	* Job type categories: asign labels to each value
	foreach var in h14b_1 h14b_2 h14b_3 h14b_4 h14b_5 h14b_6 h14b_7 h14b_8 h14b_9 h14b_10 h14b_11 h14b_12 h14b_13 h14b_14 h14b_15 h14b_16 h14b_17 h14b_18 {
		replace `var' = "0"  if `var' == "0"
		replace `var' = "1"  if `var' == "A"
		replace `var' = "2"  if `var' == "B"
		replace `var' = "3"  if `var' == "C"
		replace `var' = "4"  if `var' == "D"
		replace `var' = "5"  if `var' == "E"
		replace `var' = "6"  if `var' == "F"
		replace `var' = "7"  if `var' == "G"
		replace `var' = "8"  if `var' == "H"
		replace `var' = "9"  if `var' == "I"
		replace `var' = "10" if `var' == "J"
		replace `var' = "11" if `var' == "K"
		replace `var' = "12" if `var' == "L"
		replace `var' = "13" if `var' == "M"
		replace `var' = "14" if `var' == "N"
		replace `var' = "15" if `var' == "O"
		replace `var' = "16" if `var' == "P"
		replace `var' = "17" if `var' == "Q"
		replace `var' = "18" if `var' == "R"
		replace `var' = "19" if `var' == "S"
		replace `var' = "20" if `var' == "T"	
		
		destring `var', replace		
	 
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	jobgroup
	}

	** These variables should be string
	foreach var in h10i_16	h10i_17	h10i_18 {
		tostring `var', replace	
		replace `var' = "" if `var' == "."
		replace `var' = "" if `var' == "99"
	}
		

********************************************************************************

	** Part 3: Reshape the data and clean long-format data

********************************************************************************

	* Drop unnecessary variables before reshaping
	drop roster_repeat roster_repeat_c 

	**  Reshape the database 
	reshape long h4_ h5_ h6_ h7_ h8_1_ h8_2_ h8_3_ h9_ h10_ h10a_ h10b_ h10c_ h10d_ h10e_ h10f_ h10g_ h10h_ h10i_ h11_ h12_ h13_ h14a_ h14b_ h14c_ h15_ h14_min_ h14_max_, i(hfid) j(j)

		drop if (h4_ == "" | h4_ == "0" | h4_ =="-99")

	/* Combine h10f and h10g
	decode	h10f_, gen(h10f_str)
	replace h10f_str = h10g_ if h10f_str=="Other, please specify"
	replace h10f_str = "Don't know" if inlist(h10f_str,"-99","_99")
	replace h10f_str = itrim(trim(upper(h10f_str)))
	order	h10f_str, after(h10f_)
	drop	h10f_		h10g_
	rename	h10f_str	h10f_
	
	*/
	
	** Labeling staff variables 
	lab var h4_ 		"Enter staff name"
	lab var h5_ 		"Enter [staff name]'s detailed staff type"
	lab var h6_ 		"Enter [staff name]'s gender"
	lab var h7_ 		"Enter [staff name]'s age"
	lab var h8_1_ 		"Staff type group includes: Clinical staff"
	lab var h8_2_ 		"Staff type group includes: Administrative staff"
	lab var h8_3_ 		"Staff type group includes: Support staff"
	lab var h9_			"Enter the highest level of education [staff name] has completed"
	lab var h10_ 		"Enter if [staff name] has a health background"
	lab var h10a_ 		"Enter institution where [staff name] completed his/her most recent health-related education?"
	lab var h10b_ 		"Other, please specify"
	lab var h10c_ 		"Enter the branch of KMTC [staff name] attended"
	lab var h10d_ 		"Other, please specify"
	lab var h10e_ 		"Enter county that [staff name] completed his/her most recent health-related education"
	lab var h10f_ 		"If not in Kenya, in which country?"
	*lab var h10g_ 		"Other, please specify"
	lab var h10h_ 		"Enter city or town that this institution is located in"
	lab var h10i_ 		"Other, please specify"
	lab var h11_ 		"Enter year in which [staff name] completed his/her education"
	lab var h12_ 		"How many days per month does [staff name] usually work at this facility?"
	lab var h13_	 	"How will you be entering take-home pay?"
	lab var h14a_ 		"How much take-home pay does [staff name] receive every month from working in this health facility?"
	lab var h14b_		"Which job group does [staff name]'s take-home pay every month from working in this health facility fall under?"
	lab var h14c_ 		"Other, please specify"
	lab var h14_min_ 	"Take-home pay: Range minimum"
	lab var h14_max_ 	"Take-home pay: Range maximum"
	lab var h15_ 		"Is the take-home pay:"
	
	** Labeling categories for cities
	lab define h10h_ 	0 "Other, please specify" ///	
						1 "Mombasa" ///
						2 "Eldama Ravine" ///
						3 "Bomet" ///
						4 "Bungoma" ///
						5 "Kimilili" ///
						6 "Malakisi" ///
						7 "Webuye" ///
						8 "Busia" ///
						9 "Malaba" ///
						10 "Nambale" ///
						11 "Iten/Tambach" ///
						12 "Embu" ///
						13 "Runyenjes" ///
						14 "Garissa" ///
						15 "Homa Bay" ///
						16 "Kendu Bay" ///
						17 "Mbita Point" ///
						18 "Isiolo" ///
						19 "Kitengela" ///
						20 "Ngong" ///
						21 "Ongata Rongai" ///
						22 "Kakamega" ///
						23 "Malava" ///
						24 "Mumias" ///
						25 "Kericho" ///
						26 "Kipkelion" ///
						27 "Litein" ///
						28 "Londiani" ///
						29 "Juja" ///
						30 "Karuri" ///
						31 "Kiambu" ///
						32 "Kikuyu" ///
						33 "Limuru" ///
						34 "Ruiru" ///
						35 "Thika" ///
						36 "Kilifi" ///
						37 "Malindi" ///
						38 "Mariakani" ///
						39 "Mtwapa" ///
						40 "Kerugoya/Kutus" ///
						41 "Keroka" ///
						42 "Kisii" ///
						43 "Ogembo" ///
						44 "Suneka" ///
						45 "Tabaka" ///
						46 "Ahero" ///
						47 "Awasi" ///
						48 "Kisumu" ///
						49 "Muhoroni" ///
						50 "Oyugis" ///
						51 "Kitui" ///
						52 "Mwingi" ///
						53 "Ukunda" ///
						54 "Nanyuki" ///
						55 "Nyahururu" ///
						56 "Rumuruti" ///
						57 "Athi River(Mavoko)" ///
						58 "Kangundo-Tala" ///
						59 "Machakos" ///
						60 "Matuu" ///
						61 "Mandera" ///
						62 "Moyale" ///
						63 "Maua" ///
						64 "Meru" ///
						65 "Kehancha" ///
						66 "Migori" ///
						67 "Rongo" ///
						68 "Makuyu" ///
						69 "Maragua" ///
						70 "Nairobi" ///
						71 "Gilgil" ///
						72 "Molo" ///
						73 "Naivasha" ///
						74 "Nakuru" ///
						75 "Kapsabet" ///
						76 "Narok" ///
						77 "Nyamira" ///
						78 "Nyansiongo" ///
						79 "Ol Kalou" ///
						80 "Nyeri" ///
						81 "Maralal" ///
						82 "Bondo" ///
						83 "Siaya" ///
						84 "Ugunja" ///
						85 "Ukwala" ///
						86 "Yala" ///
						87 "Taveta" ///
						88 "Voi" ///
						89 "Wundanyi" ///
						90 "Chuka" ///
						91 "Kitale" ///
						92 "Nandi Hills" ///
						93 "Kakuma" ///
						94 "Lodwar" ///
						95 "Burnt Forest" ///
						96 "Eldoret" ///
						97 "Luanda" ///
						98 "Vihiga" ///
						99 "Wajir" ///
						100 "Kapenguria"
	lab values h10h_ h10h_
	
	lab define h10e_ 	1 "Mombasa" ///
						2 "Baringo" ///
						3 "Bomet" ///
						4 "Bungoma" ///
						8 "Busia" ///
						11 "Elgeyo-Marakwet" ///
						12 "Embu" ///
						14 "Garissa" ///
						15 "Homa Bay" ///
						18 "Isiolo" ///
						19 "Kajiado" ///
						22 "Kakamega" ///
						25 "Kericho" ///
						29 "Kiambu" ///
						36 "Kilifi" ///
						40 "Kirinyaga" ///
						41 "Kisii" ///
						46 "Kisumu" ///
						51 "Kitui" ///
						53 "Kwale" ///
						54 "Laikipia" ///
						57 "Machakos" ///
						62 "Marsabit" ///
						63 "Meru" ///
						65 "Migori" ///
						68 "Murang'a" ///
						70 "Nairobi" ///
						71 "Nakuru" ///
						75 "Nandi" ///
						76 "Narok" ///
						77 "Nyamira" ///
						79 "Nyandarua" ///
						80 "Nyeri" ///
						81 "Samburu" ///
						82 "Siaya" ///
						87 "Taita-Taveta" ///
						91 "Trans-Nzoia" ///
						93 "Turkana" ///
						95 "Uasin Gishu" ///
						97 "Vihiga" ///
						99 "Wajir" ///
						100 "West Pokot" ///
						101 "Outside of Kenya" ///
						102 "Lamu" ///
						103 "Tana River" ///
						104 "Tharaka Nithi" ///
						105 "Mandera" ///
						106 "Makueni" ///
						1000 "Kakamega" ///
						2000 "Kilifi" ///
						3000 "Meru" 
	lab values h10e_ h10e_	
	
	lab def h13_ 	0 "Not available" ///
					1 "Kenyan shillings" ///
					2 "Job group" ///
					3 "Range" 
					
					lab val h13_ h13_
	

	** Gen dummy variables for staff type question	
	gen h5_1 = 1 if strpos(h5_, "clinicalofficer")
	gen h5_2 = 1 if strpos(h5_, "chw")
	gen h5_3 = 1 if strpos(h5_, "dentist")
	gen h5_4 = 1 if strpos(h5_, "doctormo")
	gen h5_5 = 1 if strpos(h5_, "hospitaladmin")
	gen h5_6 = 1 if strpos(h5_, "intern")
	gen h5_7 = 1 if strpos(h5_, "labtech")
	gen h5_8 = 1 if strpos(h5_, "labsci")
	gen h5_9 = 1 if strpos(h5_, "midwife")
	gen h5_10 = 1 if strpos(h5_, "nurse_bsc")
	gen h5_11 = 1 if strpos(h5_, "nurse_r")
	gen h5_12 = 1 if strpos(h5_, "nurse_e")
	gen h5_13 = 1 if strpos(h5_, "nurseaide")
	gen h5_14 = 1 if strpos(h5_, "nutritionist")
	gen h5_15 = 1 if strpos(h5_, "pharm")
	gen h5_16 = 1 if strpos(h5_, "pho")
	gen h5_17 = 1 if strpos(h5_, "specialist")
	gen h5_18 = 1 if strpos(h5_, "therapist")
	gen h5_19 = 1 if strpos(h5_, "otherclinical")
	gen h5_20 = 1 if strpos(h5_, "otheradmin")
	gen h5_21 = 1 if strpos(h5_, "othersupport")

	replace h5_1 = 0 if h5_1 ==. & h5_ != ""
	replace h5_2 = 0 if h5_2 ==. & h5_ != ""
	replace h5_3 = 0 if h5_3 ==. & h5_ != ""
	replace h5_4 = 0 if h5_4 ==. & h5_ != ""
	replace h5_5 = 0 if h5_5 ==. & h5_ != ""
	replace h5_6 = 0 if h5_6 ==. & h5_ != ""
	replace h5_7 = 0 if h5_7 ==. & h5_ != ""
	replace h5_8 = 0 if h5_8 ==. & h5_ != ""
	replace h5_9 = 0 if h5_9 ==. & h5_ != ""
	replace h5_10 = 0 if h5_10 ==. & h5_ != ""
	replace h5_11 = 0 if h5_11 ==. & h5_ != ""
	replace h5_12 = 0 if h5_12 ==. & h5_ != ""
	replace h5_13 = 0 if h5_13 ==. & h5_ != ""
	replace h5_14 = 0 if h5_14 ==. & h5_ != ""
	replace h5_15 = 0 if h5_15 ==. & h5_ != ""
	replace h5_16 = 0 if h5_16 ==. & h5_ != ""
	replace h5_17 = 0 if h5_17 ==. & h5_ != ""
	replace h5_18 = 0 if h5_18 ==. & h5_ != ""
	replace h5_19 = 0 if h5_19 ==. & h5_ != ""
	replace h5_20 = 0 if h5_20 ==. & h5_ != ""
	replace h5_21 = 0 if h5_21 ==. & h5_ != ""
	
	** Checking
	//br h5_  h5_1 h5_2 h5_3 h5_4 h5_5 h5_6 h5_7 h5_8 h5_9 h5_10 h5_11 h5_12 h5_13 h5_14 h5_15 h5_16 h5_17 h5_18
	drop h5_
	
	label var h5_1 "Staff type includes: Clinical officer"
	label var h5_2 "Staff type includes: Community health worker"
	label var h5_3 "Staff type includes: Dentist"
	label var h5_4 "Staff type includes: Doctor or medical officer"
	label var h5_5 "Staff type includes: Hospital administrator/executive director/superintendent"
	label var h5_6 "Staff type includes: Intern/Student"
	label var h5_7 "Staff type includes: Lab technologist/lab technician"
	label var h5_8 "Staff type includes: Laboratory scientist"
	label var h5_9 "Staff type includes: Midwife"
	label var h5_10 "Staff type includes: Nurse (BSc)"
	label var h5_11 "Staff type includes: Nurse (Registered Community Health Nurses (KRHCN))"
	label var h5_12 "Staff type includes: Nurse (Enrolled Community Health Nurses (EHCN))"
	label var h5_13 "Staff type includes: Nurse Aides"
	label var h5_14 "Staff type includes: Nutritionist"
	label var h5_15 "Staff type includes: Pharmacist/pharmacy technologist/dispenser"
	label var h5_16 "Staff type includes: Public health officer (PHO)"
	label var h5_17 "Staff type includes: Specialists (e.g., haemotologists, radiographers)"
	label var h5_18 "Staff type includes: Therapist/counselor"
	label var h5_19 "Staff type includes: Other clinical staff"
	label var h5_20 "Staff type includes: Other administrative staff"
	label var h5_21 "Staff type includes: Other support staff"
	
	** Job groups I and O do not exist in the official documents 
	replace h14b_ = . if h14b_ == 9 | h14b_ == 15
	replace h14b_ = . if h14b_ == -97
	
	* Rename variables
	/* SL, 2017-9-4: I constructed "staff ID" variable to give unique ID for each staff within facility. Should I drop it?	*/
	rename	j	staffid
		lab	var	staffid	"Staff ID"
	rename h4_ h4
	rename h6_ h6
	rename h7_ h7
	rename h8_1_ h8_1
	rename h8_2_ h8_2
	rename h8_3_ h8_3
	rename h9_	h9
	rename h10_ h10
	rename h10a_ h10a
	rename h10b_ h10b
	rename h10c_ h10c
	rename h10d_ h10d
	rename h10e_ h10e
	rename h10f_ h10f
	*rename h10g_ h10g
	rename h10h_ h10h
	rename h10i_ h10i
	rename h11_ h11
	rename h12_ h12
	rename h13_ h13
	rename h14a_ h14a
	rename h14b_ h14b
	rename h14c_ h14c
	rename h14_min_ h14_min
	rename h14_max_ h14_max
	rename h15_ h15
						
		
	* Order variables
	order	latitude	longitude	date	hfid	hfname	county	subcounty	///
			level	private	supervisorid	supervisorname	enumeratorid	enumeratorname	time_start	time_end
	order	key, last
	
	order	staffid,	after(h3b)
	order	h8_?, after(h7)
	order	h5_*, after(h4)
	order	h16, after(h15)
	
	
	* Clean value lables
	
		* Create macros for each type of variables
		qui	ds	*
		global	allvars	`r(varlist)'
		
		global	excludevars	hfid	latitude	longitude	date	time	hfname	supervisorid	supervisorname	///
							enumeratorid	enumeratorname	time_start	time_end	a2a	a3	a4	a5	staffid	h4	h10b	h10d	h10f	h10g	///
							h10h	h10i	h14c	key


		qui	ds	h1	h5_? h5_??	h8_1	h8_2	h8_3	h10	h16
		global	dummyvars	`r(varlist)'
		
		global	categoryvars	county	subcounty	level	ownership	a2c	a2d	a6	a7	h6	h9	h10a	h10c	h10e	h11	h13	h14b	h15

		global	coutinuousvars	h2a	h2b	h3a	h3b	h7	h12	h14a
		
		* Assign unique "yesno" label to all dummy vars
		
		foreach x in h8_1 h8_2 h8_3 {
		
			destring `x', replace
			
				}
		
		foreach	dummyvar	of	global	dummyvars	{
			cap	lab	drop	`dummyvar'
			lab def `dummyvar' 1 "Yes" 0 "No"
			lab	val	`dummyvar' `dummyvar'	
		}
	
			
	
	* Corrections
	
		replace h4 = proper(h4)
		drop h15
		replace h14a = . if h14a ==-99
		replace h14b = . if h14a ==-97
		replace h12 = . if h12 ==-99
		destring staff_c, replace
	
		gen h2_total = h2a
			replace h2_total = h2b if mi(h2_total)
			lab var h2_total "Total Staff in Facility"
			
		gen h3_total = h3a
			replace h3_total = h3b if mi(h3_total)
			lab var h3_total "Total Staff with Salary Data Collected"
			
				lab var staff_c "Staff Completed in Survey"
					drop staff_total_noowner
	
			global profile 	hfid hfname county subcounty private level latitude longitude startyear
			
			order $profile
			
	*--------------------------*
	*    Save 
	*--------------------------*	
	save "${qps1_roster}", replace

						
	* Dismount
	veracrypt, dismount drive("${mount}") 

							

							
							
							
							
							
							
							
							
							
							
							
							

