/*******************************************************************************	

Project:  		KePSIE
Created on:  	
Last udpate on: 

Written by:  	Seungmin Lee (eatorange@gmail.com), Rebecca de Guttry (Rebecca_deGuttry@hotmail.com), and Amy Dolinger (adolinger@ifc.org)
							with select code lines from: Benjamin Daniels and 
														 Tatiana Zarate

********************************************************************************			

THIS DO FILE: 	Cleans the Health Facility Quality of Care and Patient Safety Survey 2 (QPS2)  


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Complete database
						 1.1 - Manual corrections
						 1.2 - Calculate response rates
				Part 2 - Complete variables
						 2.1 - Replace “Don’t answer”/“Don’t know” to missing
				Part 3 - Basic cleaning
						 3.1 - Rename & Reorder variables to coincide with 
						       printer-friendly questionnaire
						 3.2 - Label variables
						 3.3 - Order database	
				Part 4 - Save different files and anonymize 
						 4.1 - Upload HF’s information with profile information 
						       corrected
						 4.2 - Save database for construction
						 4.3 - Anonymize
						 4.4 - Save database for microdata catalogue
						 4.5 - Build dictionary			
						 4.6 - Descriptive statistics
		
INPUTS:     	* Raw data
				"${KePSIE_DB}/Endline/DataSets/Raw/QPS2.dta"
				
				* HF profile information
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Profile_clean_end.dta"
				
				* QPS2 eQuestionnaire
				"${KePSIE_DB}/Endline/Questionnaire/Questionnaire Documentation/QPS2_eQuestionnaire.xlsx"
				
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Amy Dolinger)
				
					* Anonymized data for microdata catalog
					"${KePSIE_DB}/Endline/DataSets/Intermediate/QPS2_clean_nopii_end.dta"
					
					* Non-anonymized data for further analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/QPS2_clean_pii_end.dta"
					
					* Dictionary
					"${KePSIE_DB}/Endline/Output/Final/QPS2_dictionary_end.xlsx"
					
					* Response rate table
					"${KePSIE_DB}/Endline/Output/Final/QPS2_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${KePSIE_DB}/Endline/Output/Final/QPS2_desc_stats_end.csv"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Anonymized data for microdata catalog
					"${end_dt}/Intermediate/QPS2_clean_nopii_end.dta"
					
					* Non-anonymized data for further analysis
					"${end_dt}/Intermediate/QPS2_clean_pii_end.dta"
					
					* Dictionary
					"${end_out}/Final/QPS2_dictionary_end.xlsx"
					
					* Response rate table
					"${end_out}/Final/QPS2_response_rate_end.xlsx"
					
					* Descriptive statistics table
					"${end_out}/Final/QPS2_desc_stats_end.csv"	
					
********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************/

clear all
set more off

	* Input files
		glo qps2_raw			"${volume}/qps2_end_raw.dta"
		glo profile_end			"${dt_mast}/listing_end.dta"
		glo	qps2_q				"${doc_end}/codebooks/qps2_equestionnaire.xlsx"
	
	* Output files
		glo qps2_end 			"${dt_end_clean}/qps2_end.dta"
	  
*******************************************************************************/

********************************************************************************
	** Part 1: Complete database
********************************************************************************
* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")	


	use "${qps2_raw}", clear
	
			*---------------------------------------------------------------------------------
			* 1.1 Clean profile vars
			*---------------------------------------------------------------------------------

				* Goecodes
				
					gen latitude  = a1latitude 
					replace latitude = f10latitude if !mi(f10latitude)
					lab var latitude "Latitude"
					gen longitude  = a1longitude
					replace longitude = f10longitude if !mi(f10longitude)
					lab var longitude "Longitude"
				
				* Date
				
					gen date1 = date(date,"DMY") if	a2_1_v==1
					replace	date1 = a2_2 if	a2_1_v==0
					format date1 %td
					order date1, after(date)
					drop date
					rename date1 date
					lab	var	date "Survey Date"
				
				* Time
				
					* Survey time
					gen	time1 = a2_3
					gen	time2 =	subinstr(a2_4,":00 AM","",.) if	a2_3_v==0 & regexm(a2_4,"AM")
					replace	time2 =	subinstr(a2_4,":00 PM","",.) if	a2_3_v==0 &	regexm(a2_4,"PM")
					replace	time1 =	time2 if a2_3_v==0
					gen double time3 = clock(time1, "hm")
					replace	time3 =	time3 +	(1000*60*60*12) if regexm(a2_4,"PM")
					format time3 %tcHH:MM
					drop time time1	time2
					rename time3 time
					tostring time, replace usedisplayformat force
					lab	var	time "Survey time"
					
					* Survey duration 						
					gen double time_start = clock(time_startinteraction2, "YMDhms")	
					format time_start %tcHH:MM
					gen time_start_ = clock(time_startinteraction2, "hm")
					format time_start_ %tcHH:MM
					replace time_start = time_start_ if mi(time_start)
					drop time_start_
					tostring time_start, replace usedisplayformat force
					replace time_start = "" if time_start == "."
					lab	var	time_start "Time after consent"
					
					gen double time_end = clock(time_endnteraction_s2, "YMDhms")	
					format time_end %tcHH:MM
					gen time_end_ = clock(time_endnteraction_s2, "hm")
					format time_end_ %tcHH:MM
					replace time_end = time_end_ if mi(time_end)
					drop time_end_
					tostring time_end, replace usedisplayformat force
					replace time_end = "" if time_end == "."
					lab	var	time_end "Time after the last question"					
					
				* HF profile
				
					* HF ID
					rename facilitycode hfid
					destring hfid, replace	
					lab	var	hfid "Facility ID"
				
					* HF Name
					rename facilityname hfname
					lab	var	hfname "Facility Name"	
					
					* County
					gen county_n =1 if county == "Kakamega" 
					replace county_n = 2 if county == "Kilifi"
					replace county_n = 3 if proper(county) == "Meru"
					drop county
					rename county_n county
					lab define countyl 1 "Kakamega" 2 "Kilifi" 3 "Meru"
					lab val county countyl
					lab	var	county	"County"
					
					* Level
					replace level = "2" if level=="Level 2"
					destring level, replace
					lab	define levell	2	"Level 2"	///
										3	"Level 3"	///
										4	"Level 4"	///
										5	"Level 5"
					lab	val	level levell
					lab	var	level "Level"
					
					* Ownership
					replace pri_string = "0" if pri_string=="public"
					replace pri_string = "1" if pri_string=="private"
					destring pri_string, replace
					rename	pri_string	ownership
					lab	define ownershipl 0	"Public" 1 "Private"
					lab	val	ownership ownershipl
					lab	var	ownership "Ownership"
				
				* Enumerator 
				
					* Enumerator
					clonevar enumeratorid =	a10
					clonevar enumeratorname	= a10_c
					lab	var	enumeratorid "Enumerator ID"
					lab	var	enumeratorname "Enumerator Name"
					
					* Supervisor
					clonevar supervisorid =	a6
					clonevar supervisorname	= a6_c
					lab	var	supervisorid "Supervisor ID"
					lab	var	supervisorname "Supervisor Name"
					
				* Survey key
				
					lab	var	key	"SurveyCTO ID"
					
				* Organize vars
				
					local profile_vars hfid hfname county level ownership date time time_start time_end enumeratorname enumeratorid supervisorname supervisorid latitude	longitude
					order `profile_vars'
								
			
			*---------------------------------------------------------------------------------
			* 1.2 Drop unnecessary survey vars
			*---------------------------------------------------------------------------------

				* Survey-related vars	
					
					local device_drop deviceid subscriberid simid devicephonenum formdef_version  
					local profile_drop a1altitude a1accuracy a1latitude a1longitude a1_cal a1_v a5 pri a11 a10 a10_c a12 a6 a6_c a7 f10latitude f10longitude f10altitude f10accuracy f10_c f10_2
					local time_drop f9_1 f9_2 a2_2 submissiondate starttime endtime a2_1_v a2_1 a2_3_v a2_4 a2_3 time_endinteraction time_endinteraction_s1	time_endinteraction_s3 time_endinteraction_s4 time_endinteraction_s5 time_endinteraction_s6	time_endinteraction_s7	time_endinteraction_s8	time_endnteraction_s10	time_endnteraction_s2	time_endnteraction_s9	time_startinteraction	time_startinteraction_s1	time_startinteraction_s3	time_startinteraction_s4	time_startinteraction_s5	time_startinteraction_s6	time_startinteraction_s7	time_startinteraction_s8	time_startinteraction_s9	time_startinteraction2	time_startnteraction_s10	time_startnteraction_s2
					local label_drop labels_em_drugs labels_em_equip labels_f10e_1 labels_s4a_6	labels_s5a_3 labels_s6a_1 labels_s6a_2 labels_s6a_3	labels_s6a_5 lables_s10f_5	lables_s3b_5	lables_s4b_5	lables_s5b_5	lables_s6b_5	lables_s7e_5	lables_s8e_5	lables_s9d_5	list_examequip
					local version_drop a8_6 a8_7 a8_8 a8_9 a8_10 // these were created as split-mult after version changes so not trusting them; will rebuild from grouped string var (using them for checks only)
					
					drop `device_drop' `profile_drop' `time_drop' `label_drop' `version_drop' 
		
			*---------------------------------------------------------------------------------
			* 1.3 Clean HF services vars
			*---------------------------------------------------------------------------------

				* HF departments

					/*** AD, 2018-09-10: Confirmed SL comment below for endline data. There is only 1 split-mult variable in the endline raw data (a8). 
										 Also checked the output and no errors found.
						 SL, 2017-09-03: The split code is the old one (NOT the new one Camila corrected) since the raw QPS2 is modified and the new code cannot be applied to the modified data
									     checked all the multiple-selection variables and no errors found	*/
										
					* Reconstructing because of minor issues in merging last round of raw data due to version changes (see also version_drop local in Section 1.2 above) // to be checked by Camila
					drop a8_3 a8_4 a8_5
					ren	v48	a8_3
					ren v49	a8_4
					ren v50	a8_5
					lab var a8_3 "Does the facility dispense medications to patients?"
					lab var a8_4 "Does the facility perform lab tests?"
					lab var a8_5 "Is there a kitchen serving patients?"
					
					qui {
					cap prog drop splitmult
					prog def splitmult

					syntax anything using
						import excel `using', clear first
						keep if regexm(type,"^select_multiple")
						count
						local nQuestions = `r(N)'
						forvalues i = 1/`nQuestions' {

							import excel `using', clear first
								keep if regexm(type,"^select_multiple")

								local theName = name[`i']
								local theChoices = type[`i']
									local theChoices = regexr("`theChoices'","select_multiple ","")
								
							import excel `using', clear first sheet("choices")
								keep if list_name == "`theChoices'"
								
								count
								local nChoices = `r(N)'
								
								forvalues j = 1/`nChoices' {
								
									local theNextLabel = label[`j']
									local theNextValue  = name[`j']
								
									local `theName'L `" ``theName'L' "`theNextLabel'" "'
									local `theName'V ``theName'V' `theNextValue'
									
									}
									
							use `anything', clear
								
								forvalues j = 1/`nChoices' {
									
									local theNextLabel : word `j' of ``theName'L'
									local theNextValue : word `j' of ``theName'V'
									
									cap tostring `theName', replace
									
									cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
										cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
										cap label var `theName'_ch_`j' "`theNextLabel'"
										
									}
									
								save `anything', replace
									
							}
							
							end
							}

					tempfile split
					save `split', replace

					splitmult `split' using "${qps2_q}"
					save `split', replace
					
					rename a8_? a8_a?
					rename a8_ch_# a8_#, renumber(1)
					order a8_?, after(a8)
					
					lab	var	a8_1	"Facility includes: Consultation Services"
					lab	var	a8_2	"Facility includes: Labour Ward"
					lab	var	a8_3	"Facility includes: Medical and Pediatric Wards"
					lab	var	a8_4	"Facility includes: Theatre"
					lab	var	a8_5	"Facility includes: Pharmacy"
					lab	var	a8_6	"Facility includes: Laboratory"
					lab	var	a8_7	"Facility includes: Radiology Department"
					lab	var	a8_8	"Facility includes: Nutrition Department"
					drop a8 a8_g3_c a8_g1_c s10b_g2_c s4_closed s5_closed s6_closed s7_closed s8_closed s9_closed		
					
				* Temporarily closed departments	
				
					foreach	secnum	in	2 3 4 5 8 6 	{
					loc	varlab_a8_v`secnum':	var	lab	a8_v`secnum'
					lab	var	a8_v`secnum'	"Temporarily closed: `varlab_a8_v`secnum''"
					lab	var	a8_v`secnum'_a	"Days of temporarily closed: `varlab_a8_v`secnum''"
					lab	var	a8_v`secnum'_b	"Respondent available in the next 7 days: `varlab_a8_v`secnum''"
					lab	var	a8_v`secnum'_c	"Date when respondent available in the next 7 days: `varlab_a8_v`secnum''"
					}
					order	a8_v2	a8_v3	a8_v4	a8_v5	a8_v6	a8_v8	///
							a8_v2_a	a8_v3_a	a8_v4_a	a8_v5_a	a8_v6_a	a8_v8_a	///
							a8_v2_b	a8_v3_b	a8_v4_b	a8_v5_b	a8_v6_b	a8_v8_b	///
							a8_v2_c	a8_v3_c	a8_v4_c	a8_v5_c	a8_v6_c	a8_v8_c, after(a9)
							
				* Organize vars
				
					local dept_vars a8_1 a8_2 a8_3 a8_4 a8_5 a8_6 a8_7 a8_8 a8_a1 a8_a2 a8_a3 a8_a4 a8_a5 a9 a8_v2 a8_v3 a8_v4 a8_v5 a8_v6 a8_v8 a8_v2_a a8_v3_a a8_v4_a a8_v5_a a8_v6_a a8_v8_a a8_v2_b a8_v3_b a8_v4_b a8_v5_b a8_v6_b a8_v8_b a8_v2_c a8_v3_c a8_v4_c a8_v5_c a8_v6_c a8_v8_c
					order `profile_vars' `dept_vars'	
					
			*---------------------------------------------------------------------------------
			* 1.4 Clean section vars
			*---------------------------------------------------------------------------------
			
				* Consultation services
				
					* Emergency tray
						lab	var	s3a_19a	"Emergency tray has essential drugs includes: Glucose"
						lab	var	s3a_19b	"Emergency tray has essential drugs includes: Adrenaline"
						lab	var	s3a_19c	"Emergency tray has essential drugs includes: Sodium bicarbonate"
						lab	var	s3a_19d	"Emergency tray has essential drugs includes: Diazepam"
						lab	var	s3a_19e	"Emergency tray has essential drugs includes: Phenobarbitone"
						
					* Emergency equipment
						lab	var	s3a_20a	"Available emergecy equipment includes: Ambu bag and mask available in pediatric and adult sizes"
						lab	var	s3a_20b	"Available emergecy equipment includes: Adjustable bed"
						lab	var	s3a_20c	"Available emergecy equipment includes: Functional suction machine"
						lab	var	s3a_20d	"Available emergecy equipment includes: Oxygen cylinder and flowmeter, or piped oxygen"
						lab	var	s3a_20e	"Available emergecy equipment includes: Endotracheal tubes"
					
			*---------------------------------------------------------------------------------
			* 1.5 Rename vars for scores
			*---------------------------------------------------------------------------------
			
					ren s1a_1 s2a_1a
					ren s1a_2 s2a_1b
					ren s1a_3 s2a_1c
					ren s1a_5 s2a_1d
					ren s1a_6 s2a_1e
					ren s1a_7 s2a_2a
					ren s1a_8 s2a_3a
					ren s1b_1 s2b_1a
					ren s1b_2 s2b_1b
					ren s1b_3 s2b_2a
					ren s1b_5 s2b_3a
					ren s1b_6 s2b_3b
					ren s1c_1 s2c_1a
					ren s1c_2 s2c_1b
					ren s1c_3 s2c_2a
					ren s1c_4 s2c_2b
					ren s1c_5 s2c_3a
					ren s1c_7 s2c_3b
					ren s1c_9 s2c_3c
					ren s1c_10 s2c_3d
					ren s1c_11 s2c_4a
					ren s3a_1 s5a_1a
					ren s3a_2 s5a_1b
					ren s3a_3 s5a_1c
					ren s3a_4 s5a_1d
					ren s3a_5 s5a_2a
					ren s3a_6 s5a_2b
					ren s3a_7 s5a_2c
					ren s3a_8 s5a_3a
					ren s3a_9 s5a_3b
					ren s3a_10 s5a_3c
					ren s3a_11 s5a_3d
					ren s3a_12 s5a_3e
					ren s3a_13 s5a_3f
					ren s3a_14 s5a_3g
					ren s3a_15 s5a_3h
					ren s3a_16 s5a_3i
					ren s3a_17 s5a_4a
					ren s3a_18 s5a_4b
					ren s3a_19a s5a_4c
					ren s3a_19b s5a_4d
					ren s3a_19c s5a_4e
					ren s3a_19d s5a_4f
					ren s3a_19e s5a_4g
					ren s3a_20a s5a_4h
					ren s3a_20b s5a_4i
					ren s3a_20c s5a_4j
					ren s3a_20d s5a_4k
					ren s3a_20e s5a_4l
					ren s3b_1 s5b_1a
					ren s3b_2 s5b_1b
					ren s3b_3 s5b_2a
					ren s3b_4 s5b_2b
					ren s3b_5 s5b_3a
					ren s3b_6 s5b_3b
					ren s3b_7 s5b_3c
					ren s3b_11 s5b_4a
					ren s3b_12 s5b_4b
					ren s3b_13 s5b_5a
					ren s3b_14 s5b_5b
					ren s3b_15 s5b_5c
					ren s3b_16 s5b_5d
					ren s4a_1 s6a_1a
					ren s4a_2 s6a_1b
					ren s4a_3 s6a_1c
					ren s4a_4 s6a_1d
					ren s4a_5 s6a_1e
					ren s4a_6 s6a_1f
					ren s4a_7 s6a_1g
					ren s4a_8 s6a_1h
					ren s4a_9 s6a_1i
					ren s4a_10 s6a_2a
					ren s4a_11 s6a_2b
					ren s4a_12 s6a_2c
					ren s4a_13 s6a_3a
					ren s4a_14 s6a_3b
					ren s4a_15 s6a_3c
					ren s4a_16 s6a_4a
					ren s4a_17 s6a_4b
					ren s4a_18 s6a_5a
					ren s4a_19 s6a_5b
					ren s4a_20 s6a_6a
					ren s4a_21 s6a_6b
					ren s4a_22 s6a_6c
					ren s4a_23 s6a_6d
					ren s4a_24 s6a_6e
					ren s4a_25 s6a_6f
					ren s4a_26 s6a_6g
					ren s4a_27 s6a_7a
					ren s4a_28 s6a_7b
					ren s4a_29 s6a_7c
					ren s4a_30 s6a_7d
					ren s4a_31 s6a_7e
					ren s4a_32 s6a_8a
					ren s4a_33 s6a_8b
					ren s4a_34 s6a_8c
					ren s4a_35 s6a_8d
					ren s4b_1 s6b_1a
					ren s4b_2 s6b_1b
					ren s4b_3 s6b_2a
					ren s4b_4 s6b_2b
					ren s4b_5 s6b_3a
					ren s4b_6 s6b_3b
					ren s4b_7 s6b_3c
					ren s4b_11 s6b_4a
					ren s4b_12 s6b_4b
					ren s4b_13 s6b_5a
					ren s4b_14 s6b_5b
					ren s4b_15 s6b_5c
					ren s4b_16 s6b_5d
					ren s5a_1 s7a_1a
					ren s5a_2 s7a_1b
					ren s5a_3 s7a_1c
					ren s5a_4 s7a_1d
					ren s5a_5 s7a_2a
					ren s5a_6 s7a_2b
					ren s5a_7 s7a_3a
					ren s5a_8 s7a_3b
					ren s5a_9 s7a_3c
					ren s5a_10 s7a_3d
					ren s5a_11 s7a_3e
					ren s5b_1 s7b_1a
					ren s5b_2 s7b_1b
					ren s5b_3 s7b_2a
					ren s5b_4 s7b_2b
					ren s5b_5 s7b_3a
					ren s5b_6 s7b_3b
					ren s5b_7 s7b_3c
					ren s5b_11 s7b_4a
					ren s5b_12 s7b_4b
					ren s5b_13 s7b_5a
					ren s5b_14 s7b_5b
					ren s5b_15 s7b_5c
					ren s5b_16 s7b_5d
					ren s6a_receiving s8a_receiving
					ren s6a_2 s8a_1a
					ren s6a_3 s8a_1b
					ren s6a_4 s8a_1c
					ren s6a_5 s8a_1d
					ren s6a_changing s8a_changing
					ren s6a_6 s8a_2a
					ren s6a_7 s8a_2b
					ren s6a_8 s8a_2c
					ren s6a_9 s8a_2d
					ren s6a_10 s8a_2e
					ren s6a_scrubbing s8a_2f
					ren s6a_11 s8a_2g
					ren s6a_12 s8a_2h
					ren s6a_13 s8a_3a
					ren s6a_14 s8a_3b
					ren s6a_15 s8a_3c
					ren s6a_16 s8a_3d
					ren s6a_17 s8a_3e
					ren s6a_18 s8a_3f
					ren s6a_19 s8a_3g
					ren s6a_20 s8a_3h
					ren s6a_21 s8a_3i
					ren s6a_22 s8a_3j
					ren s6a_23 s8a_3k
					ren s6a_24 s8a_3l
					ren s6a_25 s8a_4a
					ren s6a_26 s8a_4b
					ren s6a_recovery s8a_recovery
					ren s6a_27 s8a_5a
					ren s6a_28 s8a_5b
					ren s6a_29 s8a_5c
					ren s6b_1 s8b_1a
					ren s6b_2 s8b_1b
					ren s6b_3 s8b_2a
					ren s6b_4 s8b_2b
					ren s6b_5 s8b_3a
					ren s6b_6 s8b_3b
					ren s6b_7 s8b_3c
					ren s6b_11 s8b_4a
					ren s6b_12 s8b_4b
					ren s6b_13 s8b_5a
					ren s6b_14 s8b_5b
					ren s6b_15 s8b_5c
					ren s6b_16 s8b_5d
					ren s7a_1 s9a_1a
					ren s7a_2 s9a_2a
					ren s7a_3 s9a_2b
					ren s7b_1 s9b_1a
					ren s7b_2 s9b_2a
					ren s7b_3 s9b_3a
					ren s7c_1 s9c_1a
					ren s7c_2 s9c_2a
					ren s7c_3 s9c_3a
					ren s7c_4 s9c_4a
					ren s7c_5 s9c_5a
					ren s7c_6 s9c_6a
					ren s7d_1 s9d_1a
					ren s7d_2 s9d_2a
					ren s7e_1 s9e_1a
					ren s7e_2 s9e_1b
					ren s7e_3 s9e_2a
					ren s7e_4 s9e_2b
					ren s7e_5 s9e_3a
					ren s7e_6 s9e_3b
					ren s7e_7 s9e_3c
					ren s7e_11 s9e_4a
					ren s7e_12 s9e_4b
					ren s7e_13 s9e_5a
					ren s7e_14 s9e_5b
					ren s7e_15 s9e_5c
					ren s7e_16 s9e_5d
					ren s8a_1 s10a_2a
					ren s8a_3 s10a_2b
					ren s8a_4 s10a_3a
					ren s8a_5 s10a_3b
					ren s8a_6 s10a_4a
					ren s8a_7 s10a_4b
					ren s8a_8 s10a_5a
					ren s8b_2 s10b_1a
					ren s8b_3 s10b_1b
					ren s8b_4 s10b_2a
					ren s8b_5 s10b_2b
					ren s8b_6 s10b_3a
					ren s8b_7 s10b_4a
					ren s8b_8 s10b_4b
					ren s8c_1 s10c_1a
					ren s8b_1 s10d_1a
					ren s8d_1 s10d_1b
					ren s8d_2 s10d_1c
					ren s8d_3 s10d_1d
					ren s8d_4 s10d_1e
					ren s8d_5 s10d_1f
					ren v478 s10d_2a
					ren s8d_6 s10d_2b
					ren s8e_1 s10e_1a
					ren s8e_2 s10e_1b
					ren s8e_3 s10e_2a
					ren s8e_4 s10e_2b
					ren s8e_5 s10e_3a
					ren s8e_6 s10e_3b
					ren s8e_7 s10e_3c
					ren s8e_11 s10e_4a
					ren s8e_12 s10e_4b
					ren s8e_13 s10e_5a
					ren s8e_14 s10e_5b
					ren s8e_15 s10e_5c
					ren s8e_16 s10e_5d
					ren s9a_1 s11a_1a
					ren s9a_2 s11a_2a
					ren s9a_3 s11a_3a
					ren s9a_4 s11a_4a
					ren s9a_5 s11a_5a
					ren s9b_1 s11b_1a
					ren s9b_2 s11b_1b
					ren s9b_3 s11b_1c
					ren s9b_4 s11b_2a
					ren s9b_5 s11b_3a
					ren s9b_6 s11b_4a
					ren s9b_7 s11b_4b
					ren s9b_8 s11b_4c
					ren s9b_9 s11b_4d
					ren s9c_1 s11c_1a
					ren s9c_2 s11c_1b
					ren s9c_3 s11c_2a
					ren s9c_4 s11c_2b
					ren s9c_5 s11c_3a
					ren s9d_1 s11d_1a
					ren s9d_2 s11d_1b
					ren s9d_3 s11d_2a
					ren s9d_4 s11d_2b
					ren s9d_5 s11d_3a
					ren s9d_6 s11d_3b
					ren s9d_7 s11d_4a
					ren s9d_8 s11d_4b
					ren s9d_9 s11d_4c
					ren s9d_10 s11d_4d
					ren s10a_1 s12a_1a
					ren s10a_2 s12a_1b
					ren s10a_3 s12a_1c
					ren s10a_4 s12a_1d
					ren s10a_5 s12a_1e
					ren s10a_6 s12a_1f
					ren s10a_7 s12a_1g
					ren s10a_8 s12a_2a
					ren s10a_9 s12a_2b
					ren s10a_10 s12a_2c
					ren s10a_11 s12a_2d
					ren s10a_12 s12a_2e
					ren s10a_13 s12a_2f
					ren s10a_14 s12a_2g
					ren s10a_15 s12a_2h
					ren s10a_16 s12a_2i
					ren s10a_17 s12a_2j
					ren s10b_1 s12b_1a
					ren s10b_2 s12b_1b
					ren s10b_3 s12b_1c
					ren s10b_4 s12b_1d
					ren s10b_5 s12b_1e
					ren s10b_6 s12b_1f
					ren s10b_7 s12b_1g
					ren s10b_8 s12b_1h
					ren s10c_1 s12c_1a
					ren s10c_2 s12c_1b
					ren s10c_3 s12c_1c
					ren s10c_4 s12c_1d
					ren s10d_1 s12d_1a
					ren s10d_2 s12d_1b
					ren s10d_3 s12d_1c
					ren s10d_4 s12d_1d
					ren s10d_5 s12d_1e
					ren s10d_6 s12d_1f
					ren s10d_7 s12d_1g
					ren s10d_8 s12d_2a
					ren s10d_9 s12d_2b
					ren s10e_1 s12e_kitchen
					ren s10e_2 s12e_1a
					ren s10e_3 s12e_1b
					ren s10e_4 s12e_1c
					ren s10e_5 s12e_1d
					ren s10e_6 s12e_1e
					ren s10e_7 s12e_1f
					ren s10e_8 s12e_2a
					ren s10e_9 s12e_2b
					ren s10e_10 s12e_2c
					ren s10e_11 s12e_2d
					ren s10e_12 s12e_2e
					ren s10e_13 s12e_3a
					ren s10e_14 s12e_3b
					ren s10f_1 s12f_1a
					ren s10f_2 s12f_1b
					ren s10f_3 s12f_2a
					ren s10f_4 s12f_2b
					ren s10f_5 s12f_3a
					ren s10f_6 s12f_3b
					ren s10f_7 s12f_3c
					ren s10f_11 s12f_4a
					ren s10f_12 s12f_4b
					ren s10f_13 s12f_5a
					ren s10f_14 s12f_5b
					ren s10f_15 s12f_5c
					ren s10f_16 s12f_5d
					ren s2a_1 s4a_1a
					ren s2a_2 s4a_1b
					ren s2a_3 s4a_2a
					ren s2a_4 s4a_2b
					ren s2a_5 s4a_2c
					ren s2a_7 s4a_3a
					ren s2a_8 s4a_3b
					ren s2a_9 s4a_3c
					ren s2a_10 s4a_3d
					ren s2a_13 s4a_4a
					ren s2a_14 s4a_4b
					ren s2a_15 s4a_4c
					ren s2b_1 s4b_1a
					ren s2b_2 s4b_1b
					ren s2b_3 s4b_1c
					ren s2b_4 s4b_1d			
																		
*---------------------------------------------------------------------------------------------
* Part 2. Check sample
*---------------------------------------------------------------------------------------------
		
		* Duplicates and manual revisions
		
			/*** RdG, 2018-05-30: Manual corrections:
			 			          Wrong HFID entered: no consequences as both HFs are level 2 private */
			replace hfid = 12725 if key == "uuid:351c8e21-ae46-4feb-9bfa-5317ad98a840"	
			
		* Update profile vars as of lastest information from HF inventory data (as of Aug 2018)
		
			merge 1:1 hfid using "${profile_end}", keepus(hfname county level ownership latitude longitude) update replace
				drop if _merge==2
				drop _merge
				lab drop ownership
				lab def ownership 1 "Public" 2 "Private"
				lab val ownership ownership		
				
		* Organize vars
		
			local section_vars s2* s4* s5* s6* s7* s8* s9* s10* s11* s12*
			local final_vars g1 g1_2 g3 g3_2 g5 g5_2 g7 g7_2 key
			* label drop s2* s4* s5* s6* s7* s8* s9* s10* s11* s12*
			
			order `profile_vars' `dept_vars' `section_vars' `final_vars'
				
*---------------------------------------------------------------------------------------------
* Part 3. Estimate response rates
*---------------------------------------------------------------------------------------------
				
		* Temp dropping refusal HF (there is only 1 submitted, so we will need to merge with inventory for refusal rates)
		
			drop if a9==0				
	
*---------------------------------------------------------------------------------------------
* Part 4. Generate outputs
*---------------------------------------------------------------------------------------------
		/*
			*---------------------------------------------------------------------------------
			* 4.1 Clean dataset
			*---------------------------------------------------------------------------------
			
				if	c(stata_version)>=14	{
						saveold "${QPS2_clean_pii}", replace v(13)
					}
					else {
						save "${QPS2_clean_pii}", replace
					}	
					*/
			*----------------*
			* 4.3 Anonymize  * 
			*----------------*
			  
				drop latitude longitude  
			
			*--------------------------------------------*
			* 4.4 Save database for microdata catalogue  *
			*--------------------------------------------*
			
				save "${qps2_end}", replace
							

			/*---------------------------------------------------------------------------------
			* 4.2 Summary tables
			*---------------------------------------------------------------------------------

				* Summary stats
				
					set matsize 500
					ds, has(type numeric)
					local num_vars `r(varlist)'

					foreach var in `num_vars' {
						loc varlab: variable label `var'
						loc varlab_nocomma=subinstr("`varlab'",",","",.)
						lab var `var' "`varlab_nocomma'"
					}
					estpost	tabstat `num_vars', ///
									statistics(n mean sd min max p50 p90) ///
									columns(statistics)
										
					esttab using "${desc_stats}", ///
								cells("count(label(N)) mean(label(Mean) fmt(%9.2f)) sd(label(Std Dev) fmt(%9.2f)) min(label(Min)) max(label(Max)) p50(label(Median)) p90(label(p90))") ///
								label ///
								noobs nonumber mtitles("Descriptive Statistics") ///
								replace
				
			*---------------------------------------------------------------------------------
			* 4.3 Dictionary
			*---------------------------------------------------------------------------------

				preserve	

					codebookout "${dictionary}", replace

				restore 
					*/	
	
	* Dismount
	veracrypt, dismount drive("${mount}") 
