/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare JHIC item-level compliance (cost and functional categories) for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Reshape to item-level database
			Part 2: Assign item classifications
			Part 3: Construct cost and functional category variables
			Part 4: Export
			
DATE: 		May 2019
UPDATED: 	May 2021	
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************end
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo jhic_scores 		"${dt_end_const}/jhic_end_scores"
	glo	jhic_costgrp		"${doc_end}/codebooks/jhic_items.xlsx"
	glo profile_clean		"${dt_mast}/profile_end.dta"
	
	* Output 
	glo jhic_items 			"${dt_end_const}/jhic_compliance_items.dta"
		
********************************************************************************
** Part 1: Reshape to item-level database
********************************************************************************
use "${jhic_scores}", clear

	* Keep only adherence (0/1) vars and lowest level items (most disaggregated)
	keep hfid *_a
	drop a8_* 
	foreach x in *_a {					
	ren `x' item_adh`x'					
	}	
	reshape long item_adh, i(hfid) j(root_adh) string // Reshape
	split root_adh, p("_a") gen(root) // item root name
	ren root1 root
	keep if item_adh!=.
	replace item_adh = 1 if inlist(item_adh,3,4) // convert likert scale to binary adherence
	replace item_adh = 0 if inlist(item_adh,2) // 1 if satisfactory or above, 0 otherwise
	keep hfid root item_adh 
			
********************************************************************************
** Part 2: Assign item classifications
********************************************************************************
	* Import classifications defined in Google sheet: make any classification changes in Google sheet 
	preserve
	import excel using "${jhic_costgrp}", first clear 
	tempfile items
	save `items'
	restore
	merge m:1 root using `items', nogen 
	merge m:1 hfid using "${profile_clean}", keepus(t s0 s1 s2 market_all_expanded marketsize_rand_* strata_expanded level level_3 level_4_5 county private private_t) nogen keep(3) // keep sample only
	
********************************************************************************
** Part 3: Construct cost and functional category variables
********************************************************************************
	* Cost categories	
	encode cost_type, gen(cost_type_ds)
	recode cost_type_ds (4=1) (1=4)
	drop cost_type
	ren cost_type_ds cost_type
	lab def cost_type 1 "Lowest cost" 2 "Low cost" 3 "Medium cost" 4 "High cost", modify
	lab val cost_type cost_type
	forvalues i=1/4 {
	gen c`i' = 1 if cost_type==`i'
	replace c`i' = 0 if mi(c`i') & !mi(cost_type)
	}
	
	* Marginal-fixed cost categories
	gen mar = 1 if marginal=="Marginal"
	replace mar = 0 if marginal=="Fixed"
	drop marginal
	ren mar marginal
	lab def marginal 1 "Marginal" 0 "Fixed", modify
	lab val marginal marginal
	clonevar fixed=marginal
	recode fixed (1=0) (0=1)
		
	* Functional categories	
	tab item_group, gen(item_group_)
	bysort hfid: gen counter_hf = _n
	bysort root: gen counter_item = _n
	
	* Medical records group (for management analysis)
	gen med_record = 1 if inlist(root,"s3c_1a","s3c_1b") 
	gen med_record_c = 1 if inlist(root,"s6a_6f","s6a_6g","s3c_1c","s6a_6e")
	replace med_record_c = 1 if inlist(root,"s6a_6a","s6a_6c","s6a_6d","s6a_6b","s7a_2a","s7a_1a")
	
	* JHIC section 
	gen item_split = strpos(root,"_")
	gen section = ""
	replace section = substr(root,2,item_split - 3)
	drop item_split
	destring section, replace
	
	* Interactions
	glo c c1 c2 c3 c4 item_group_1 item_group_2 item_group_3 item_group_4 item_group_5 item_group_6 item_group_7
	foreach x of glo c {
	gen `x'_t=t*`x'
	}
	glo c c1 c2 c3 c4 item_group_1 item_group_2 item_group_3 item_group_4 item_group_5 item_group_6 item_group_7
	foreach x of glo c {
	gen private_t_`x'=private*t*`x'
	}

********************************************************************************
** Part 4: Export
********************************************************************************
	* Order
	glo profile	hfid county private t market_all_expanded strata_expanded
	glo item root item_adh c1 c2 c3 c4 cost_type item_group section item_label
	order hfid $profile $item 
	
	* Label
	lab var item_adh "Item Adherence"
	lab var root "Item ID"
	lab var marginal "Marginal or Fixed Cost"
	lab var marginal "Marginal Cost"
	lab var fixed "Fixed Cost"
	lab var cost_type "Cost Type"
	lab var item_group "Item Group"
	lab var item_label "Item Label"
	lab var section "JHIC Section"	
	lab var counter_hf "HF Counter"
	lab var counter_item "Item Counter"
	lab var med_record "Medical Records in Facility Management"
	lab var med_record_c "Medical Records in Patient Care"
	lab var c1_t "Lowest Cost x T"
 	lab var c2_t "Low Cost x T"
 	lab var c3_t "Medium Cost x T"	
 	lab var c4_t "High Cost x T"
 	lab var item_group_1_t "Equipment x T"
 	lab var item_group_2_t "Infrastructure x T"
 	lab var item_group_3_t "Management x T"
 	lab var item_group_4_t "Medical Records x T"
 	lab var item_group_5_t "SOPs x T"
 	lab var item_group_6_t "Supplies (Low cost) x T"
 	lab var item_group_7_t "Supplies (Medium cost) x T"						
 	lab var private_t_c1 "Private x T x Lowest Cost"
 	lab var private_t_c2 "Private x T x Low Cost"
 	lab var private_t_c3 "Private x T x Medium Cost"	
 	lab var private_t_c4 "Private x T x High Cost"		
 	lab var private_t_item_group_1 "Private x T x Equipment "
 	lab var private_t_item_group_2 "Private x T x Infrastructure"
 	lab var private_t_item_group_3 "Private x T x Management"
 	lab var private_t_item_group_4 "Private x T x Medical Records"
 	lab var private_t_item_group_5 "Private x T x SOPs"
 	lab var private_t_item_group_6 "Private x T x Supplies (Low cost)"
 	lab var private_t_item_group_7 "Private x T x Supplies (Medium cost)"		
	lab var item_group_1 "Equipment"
	lab var item_group_2 "Infrastructure"
	lab var item_group_3 "Management"
	lab var item_group_4 "Medical Records"
	lab var item_group_5 "SOPs"
	lab var item_group_6 "Supplies (Low cost)"
	lab var item_group_7 "Supplies (Medium cost)"	
	lab var c1 "Lowest Cost"
	lab var c2 "Low Cost"
	lab var c3 "Medium Cost"
	lab var c4 "High Cost"		
	lab def section 2 "Infrastructure" /// 
					3 "Management" ///
					4 "IPC" /// 
					5 "Consultation" /// 
					6 "Labour ward" /// 
					7 "Medical wards" /// 
					8 "Theatre" /// 
					9 "Pharmacy" /// 
					10 "Laboratory" /// 
					11 "Radiology" /// 
					12 "Nutrition"
					lab val section section		
		
	* Save	
	save "${jhic_items}", replace				
				
