/*******************************************************************************	
*		Project:
*			KePSIE IE
*		Created on:		2018-09-25

********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file computes the scores using the JHIC database 	
				
** INPUTS:     	JHIC_clean_end path: Github/kepsie/DataWork/Endline/DataSets/Intermediate
				


** OUTLINE: 	Part 0: Initiate and import the database, setting up programs useful for the do file 
				Part 1: Preparing the dataset for computing scores by creating the global and adapting the questions
					1.1 : Dealing with the issue of skipped questions
					1.2 : setting up the globals
					1.3 : Dealing with skipped sections due to specific facilities characteristics
				Part 2 : Computing the scores and the per facility maximum scores
				Part 3 : Cleaning the dataset: adding not applicable and rounding up scores
				Part 4: Creating adherence variables, missing becomes 0 unless question is not applicable or whole section is not being asked
				Part 5 : Save final dataset

** OUTPUTS:    JHIC_scores_end.dta /path: Github/kepsie/DataWork/Endline/DataSets/Final
							
				

** Written by: Thomas Escande

*******************************************************************************/

*******************************************************************************/
version 13

********************************************************************************

*** # Part 0: Initiate and import the database, setting up programs useful for the do file 

********************************************************************************

clear all
set more off

*inputs
glo jhic_clean 		 	"${dt_end_clean}/jhic_end_clean"

*Outputs
glo jhic_scores 		"${dt_end_const}/jhic_end_scores"

*Program to be used after
*The program simply checks whether a string "t" is in a list of strings "global_list". If it is it returns "1" and "0" otherwise 

cap prog drop variable_check_list //clearing any program that might exist under that name. Always start with that line

	prog def variable_check_list, rclass 
	args t global_list

		local r = 0

	foreach var in $`global_list' {
		 if "`var'" == "`t'" local r = `r' + 1
	}

	return local res = `r'


	end //


********************************************************************************

*** # Part 1: Preparing the dataset for computing scores by creating the global and adapting the questions

********************************************************************************

use "${jhic_clean}"  , clear

// Yes or No questions, with yes giving the points and no giving no points

global tot_score s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12  // The final score is the sum of the score of each section 

gen 		tot_score_s 	= 0
label var 	tot_score_s 	"Total score obtained by the facility"

gen 		tot_score_ms_f	 = 0
label var 	tot_score_ms_f	 "maximum score that could be obtained by the facility"


*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	* 1.1. Dealing with the issue of skipped questions 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

*Adapting scores and maximum scores for questions or sections which can be skipped


*Changing scores for fire control mechanism
	replace s2c_2a_ms 	= 10 	if level < 4
	replace s2c_2b_ms 	= 0 	if level < 4 

	replace s2c_2b		= .n 	if level < 4  // .n stands for "Not applicable"

*Changing scores for fire assembly protocol
	replace s2c_3a_ms 	= 1.67 	if level < 4
	replace s2c_3b_ms 	= 1.67 	if level < 4
	replace s2c_3c_ms 	= 1.67 	if level < 4
	replace s2c_3d_ms 	= 0 	if level < 4 

	replace s2c_3d 	 	= .n 	if level < 4 

*Changing maximum scores for question s4a_4a / b depending on whether there is grass and / or a bush (original scoring assumes it has both)
	*Add a temporary id variable on the situation of grass / bush to manipulate the variables without impacting them

	gen 	bush_grass_id = 1 if s4a_4a == 2 & s4a_4b == 2 // No bush and No grass 
	replace bush_grass_id = 2 if s4a_4a != 2 & s4a_4b == 2 // No bush but grass 
	replace bush_grass_id = 3 if s4a_4a == 2 & s4a_4b != 2 // Bush but no grass 

 	*If No grass and no bush
	replace s4a_4a_ms 	= 0 	if bush_grass_id == 1
	replace s4a_4b_ms 	= 0 	if bush_grass_id == 1
	replace s4a_4c_ms 	= 10 	if bush_grass_id == 1

	replace s4a_4a 		= .n 	if bush_grass_id == 1
	replace s4a_4b 		= .n 	if bush_grass_id == 1

	*If grass and no bush
	replace s4a_4a_ms 	= 5 	if bush_grass_id == 2
	replace s4a_4b_ms 	= 0 	if bush_grass_id == 2
	replace s4a_4c_ms 	= 5 	if bush_grass_id == 2

	replace s4a_4b 	 	= .n 	if bush_grass_id == 2

	*If bush and no grass
	replace s4a_4a_ms 	= 0 	if bush_grass_id == 3
	replace s4a_4b_ms 	= 5 	if bush_grass_id == 3
	replace s4a_4c_ms 	= 5 	if bush_grass_id == 3

	replace s4a_4a 		= .n 	if bush_grass_id == 3

	drop bush_grass_id

*Changing scores for inpatients records
	replace s3c_2a_ms 	= 2.5 	if s3c_2b == 2
	replace s3c_2b_ms 	= 0 	if s3c_2b == 2
	replace s3c_2c_ms 	= 0 	if s3c_2b == 2
	replace s3c_2d_ms 	= 2.5 	if s3c_2b == 2 

	replace s3c_2c 		= .n 	if s3c_2b == 2
	replace s3c_2b 		= .n 	if s3c_2b == 2

	
*Label the value 0 for variables which might be non applicable
 	label define NA  0 "N/A"  

	label values s2c_2b_ms NA 
	label values s2c_3d_ms NA

	label values s4a_4a_ms NA	
	label values s4a_4b_ms NA	
	label values s4a_4c_ms NA

	label values s3c_2b_ms NA	
	label values s3c_2c_ms NA




*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	* 1.2. Creates globals for adherence variables 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
	****List of variables which will be treated differently as they are not simple yes or no question
 	global	diff_var 			s2a_2a s2a_3a s4a_3a s9a_1a s9a_2a							
 						
	* S2: HF Infrastructure 

	* A. Building
	global s2a_1		s2a_1a s2a_1b s2a_1c s2a_1d s2a_1e
	global s2a_2		s2a_2a
	global s2a_3		s2a_3a

		global s2a 			s2a_1 s2a_2 s2a_3
	
	* B. Utilities
	global s2b_1 	s2b_1a s2b_1b
	global s2b_2		s2b_2a	
	global s2b_3		s2b_3a s2b_3b

		global s2b 			s2b_1 s2b_2 s2b_3
		
	* C. Security
	global s2c_1 	s2c_1a s2c_1b		
	global s2c_2 	s2c_2a s2c_2b		
	global s2c_3 	s2c_3a s2c_3b s2c_3c s2c_3d
	global s2c_4 	s2c_4a			
		
		global s2c 		s2c_1 s2c_2 s2c_3 s2c_4

			global s2 		s2a s2b s2c

	    * S3: General Management and Recording of Information

	* A. General Management 
	global s3a_1 	s3a_1a s3a_1b s3a_1c s3a_1d			
	global s3a_2 	s3a_2a s3a_2b s3a_2c s3a_2d s3a_2e s3a_2f s3a_2g s3a_2h 
	global s3a_3 	s3a_3a s3a_3b
	
		global s3a 			s3a_1 s3a_2 s3a_3

	* B. Quality management
	*global s3b_1_a s3b_1a s3b_1b_a	// Not scored questions so not created, maybe different / better way to do this ? 
	global s3b_2 	s3b_2a s3b_2b s3b_2c s3b_2d s3b_2e
	global s3b_3 	s3b_3a s3b_3b s3b_3c	

		global s3b 			s3b_2 s3b_3	
	
	* C. Medical records and information systems
	global s3c_1 	s3c_1a s3c_1b s3c_1c	
	global s3c_2 	s3c_2a s3c_2b s3c_2c s3c_2d
	global s3c_3 	s3c_3a s3c_3b s3c_3c	
	*global s3c_4 	s3c_4a s3c_4b	// Not scored questions
	global s3c_5 	s3c_5a
						
		global s3c 			s3c_1 s3c_2 s3c_3 s3c_5	  		
	
	* D. Equipment management
	global s3d_1 	s3d_1a s3d_1b
	global s3d_2 	s3d_2a s3d_2b s3d_2c
	
		global s3d 			s3d_1 s3d_2

			global s3 			s3a s3b s3c s3d
					
	* S4: (Infection Prevention and Control)
		
	* A. General
	global s4a_1 	s4a_1a s4a_1b					
	global s4a_2 	s4a_2a s4a_2b s4a_2c				
	global s4a_3 	s4a_3a s4a_3b s4a_3c s4a_3d
	global s4a_4 	s4a_4a s4a_4b s4a_4c

		global s4a 			s4a_1 s4a_2 s4a_3 s4a_4	 			
	
	* B. Sterilization Services
	global s4b_1 	s4b_1a s4b_1b s4b_1c s4b_1d

		global s4b 			s4b_1

			global s4 			s4a s4b

	* S5: Medical and Dental Consultation Services 

	* A. General
	global s5a_1 	s5a_1a	s5a_1b s5a_1c s5a_1d								
	global s5a_2 	s5a_2a	s5a_2b s5a_2c									
	global s5a_3 	s5a_3a	s5a_3b s5a_3c s5a_3d s5a_3e	s5a_3f s5a_3g s5a_3h s5a_3i			
	global s5a_4 	s5a_4a	s5a_4b s5a_4c s5a_4d s5a_4e s5a_4f s5a_4g s5a_4h s5a_4i s5a_4j s5a_4k s5a_4l

		global s5a 			s5a_1 s5a_2 s5a_3 s5a_4

	* B. IPC
	global s5b_1 	s5b_1a s5b_1b
	global s5b_2 	s5b_2a s5b_2b		
	global s5b_3 	s5b_3a s5b_3b s5b_3c	
	global s5b_4 	s5b_4a s5b_4b		
	global s5b_5 	s5b_5a s5b_5b s5b_5c s5b_5d
	
		global s5b 			s5b_1 s5b_2 s5b_3 s5b_4 s5b_5

			global s5 			s5a s5b  

	* S6: Labour Ward 

	global s6a_1 	s6a_1a s6a_1b s6a_1c s6a_1d s6a_1e s6a_1f s6a_1g s6a_1h s6a_1i
	global s6a_2 	s6a_2a s6a_2b s6a_2c						
	global s6a_3 	s6a_3a s6a_3b s6a_3c						
	global s6a_4 	s6a_4a s6a_4b							
	global s6a_5 	s6a_5a s6a_5b							
	global s6a_6 	s6a_6a s6a_6b s6a_6c s6a_6d s6a_6e s6a_6f s6a_6g 		
	global s6a_7 	s6a_7a s6a_7b s6a_7c s6a_7d s6a_7e				
	global s6a_8 	s6a_8a s6a_8b s6a_8c s6a_8d	

		global s6a 			s6a_1 s6a_2 s6a_3 s6a_4 s6a_5 s6a_6 s6a_7  s6a_8	
	
	* B. IPC	
	global s6b_1 	s6b_1a s6b_1b			
	global s6b_2 	s6b_2a s6b_2b		
	global s6b_3 	s6b_3a s6b_3b s6b_3c	
	global s6b_4 	s6b_4a s6b_4b		
	global s6b_5 	s6b_5a s6b_5b s6b_5c s6b_5d

		global s6b 			s6b_1 s6b_2 s6b_3 s6b_4 s6b_5

			global s6 			s6a s6b 

	* S7: Medical and Pediatric Wards 
	
	* A. General
	global s7a_1 	s7a_1a s7a_1b s7a_1c s7a_1d		
	global s7a_2 	s7a_2a s7a_2b				
	global s7a_3 	s7a_3a s7a_3b s7a_3c s7a_3d	s7a_3e

		global s7a 			s7a_1 s7a_2 s7a_3 
	
	* B. IPC	
	global s7b_1 	s7b_1a s7b_1b		
	global s7b_2 	s7b_2a s7b_2b		
	global s7b_3 	s7b_3a s7b_3b s7b_3c	
	global s7b_4 	s7b_4a s7b_4b		
	global s7b_5 	s7b_5a s7b_5b s7b_5c s7b_5d
	
		global s7b 			s7b_1 s7b_2 s7b_3 s7b_4 s7b_5

			global s7 			s7a s7b 

	* S8: Theatre 
	
	* A. General
	global	s8a_1	s8a_1a s8a_1b s8a_1c s8a_1d								
	global	s8a_2	s8a_2a s8a_2b s8a_2c s8a_2d s8a_2e s8a_2f s8a_2g s8a_2h				
	global	s8a_3	s8a_3a s8a_3b s8a_3c s8a_3d s8a_3e s8a_3f s8a_3g s8a_3h s8a_3i s8a_3j s8a_3k s8a_3l
	global	s8a_4	s8a_4a s8a_4b										
	global	s8a_5	s8a_5a s8a_5b s8a_5c											
	
		global s8a 			s8a_1 s8a_2 s8a_3 s8a_4 s8a_5

	* B. IPC	
	global	s8b_1	s8b_1a s8b_1b			
	global	s8b_2	s8b_2a s8b_2b		
	global	s8b_3	s8b_3a s8b_3b s8b_3c	
	global	s8b_4	s8b_4a s8b_4b		
	global	s8b_5	s8b_5a s8b_5b s8b_5c s8b_5d					
 
 		global s8b 			s8b_1 s8b_2 s8b_3 s8b_4 s8b_5

			global s8 			s8a s8b 

	* S9: Pharmacy 

	* A. General condition of permises	
	global	s9a_1	s9a_1a	
	global	s9a_2	s9a_2a s9a_2b

		global s9a 			s9a_1 s9a_2

	* B. Storage and display of commodities
	global	s9b_1	s9b_1a 
	global	s9b_2 	s9b_2a 
	global	s9b_3 	s9b_3a
	
		global s9b 			s9b_1 s9b_2 s9b_3
	
	* C. Record keeping and documentation
	global	s9c_1	s9c_1a 
	global	s9c_2	s9c_2a 
	global	s9c_3	s9c_3a 
	global	s9c_4	s9c_4a 
	global	s9c_5	s9c_5a 
	global	s9c_6	s9c_6a

		global s9c 			s9c_1 s9c_2 s9c_3 s9c_4 s9c_5 s9c_6  
	
	* D. Reference and materials and policies
	global	s9d_1	s9d_1a
	global	s9d_2 	s9d_2a

		global s9d 			s9d_1 s9d_2
	
	* E. IPC
	global	s9e_1	s9e_1a  s9e_1b			
	global	s9e_2	s9e_2a	s9e_2b		
	global	s9e_3	s9e_3a	s9e_3b	s9e_3c	
	global	s9e_4	s9e_4a	s9e_4b		
	global	s9e_5	s9e_5a	s9e_5b	s9e_5c	s9e_5d

		global s9e 			s9e_1 s9e_2 s9e_3 s9e_4 s9e_5

				global s9 			s9a s9b s9c s9d s9e
	
	* S10: Laboratory 

	* A. Policies, guidelines, and SOPs
	** S10a_1 is not included because QPS1/2 didn't ask for licenses. 
	global	s10a_2	s10a_2a	s10a_2b
	global	s10a_3	s10a_3a	s10a_3b
	global	s10a_4 	s10a_4a	s10a_4b
	global	s10a_5 	s10a_5a	
		
		global s10a 			s10a_2 s10a_3 s10a_4 s10a_5

	* B. Equipment management program
	global	s10b_1 	s10b_1a s10b_1b	
	global	s10b_2 	s10b_2a	s10b_2b	
	global	s10b_3 	s10b_3a		
	global	s10b_4 	s10b_4a	s10b_4b	

		global s10b 			s10b_1 s10b_2 s10b_3 s10b_4
		
	* C. Record keeping and documentation
	global 	s10c_1 	s10c_1a

		global s10c 			s10c_1
		
	* D. Quality control of tests
	global	s10d_1 	s10d_1a	s10d_1b	s10d_1c	s10d_1d	s10d_1e	s10d_1f
	global	s10d_2 	s10d_2a	s10d_2b		

		global s10d 			s10d_1 s10d_2 		
		
	* E. IPC
	global	s10e_1 	s10e_1a s10e_1b			
	global	s10e_2 	s10e_2a	s10e_2b		
	global	s10e_3 	s10e_3a	s10e_3b	s10e_3c	
	global	s10e_4 	s10e_4a	s10e_4b		
	global	s10e_5 	s10e_5a	s10e_5b	s10e_5c	s10e_5d	

		global s10e 			s10e_1 s10e_2 s10e_3 s10e_4 s10e_5

			global s10 				s10a s10b s10c s10d s10e    	


	* S11: Radiology 

	* A. Radiation protection
	global	s11a_1 	s11a_1a
	global	s11a_2 	s11a_2a
	global	s11a_3 	s11a_3a
	global	s11a_4 	s11a_4a
	global	s11a_5 	s11a_5a

		global s11a 			s11a_1 s11a_2 s11a_3 s11a_4 s11a_5
	
	* B. Policies, SOPs, and registers
	global	s11b_1 	s11b_1a	s11b_1b	s11b_1c	
	global	s11b_2 	s11b_2a			
	global	s11b_3 	s11b_3a			
	global	s11b_4 	s11b_4a	s11b_4b	s11b_4c	s11b_4d

		global s11b 			s11b_1 s11b_2 s11b_3 s11b_4
	
	* C. Radioactive waste management
	global	s11c_1 	s11c_1a	s11c_1b
	global	s11c_2 	s11c_2a	s11c_2b
	global	s11c_3 	s11c_3a			
	
		global s11c 			s11c_1 s11c_2 s11c_3

	* D. IPC	
	global	s11d_1 	s11d_1a s11d_1b			
	global	s11d_2 	s11d_2a	s11d_2b		
	global	s11d_3 	s11d_3a	s11d_3b		
	global	s11d_4 	s11d_4a	s11d_4b	s11d_4c	s11d_4d
	
		global s11d 			s11d_1 s11d_2 s11d_3 s11d_4

			global s11 				s11a s11b s11c s11d 
	
	* S12: Nutrition 

	* A. Nutrition equipment, tools and supplies
	global	s12a_1 	s12a_1a	s12a_1b	s12a_1c	s12a_1d	s12a_1e	s12a_1f	s12a_1g			
	global	s12a_2 	s12a_2a	s12a_2b	s12a_2c	s12a_2d	s12a_2e	s12a_2f	s12a_2g	s12a_2h	s12a_2i	s12a_2j

		global s12a 			s12a_1 s12a_2 
	
	* B. SOPs for nutrition care processes and other services	
	global	s12b_1 	s12b_1a	s12b_1b	s12b_1c	s12b_1d	s12b_1e	s12b_1f	s12b_1g	s12b_1h		

		global s12b 			s12b_1 

	* C. Record keeping and documentation
	global	s12c_1 	s12c_1a	s12c_1b	s12c_1c	s12c_1d	

		global s12c 			s12c_1 				
	
	* D. Patient feeding
	global	s12d_1 	s12d_1a	s12d_1b	s12d_1c	s12d_1d	s12d_1e	s12d_1f	s12d_1g
	global	s12d_2 	s12d_2a	s12d_2b	

		global s12d 			s12d_1 s12d_2 									

	* E. Food preparation unit
	global	s12e_1 	s12e_1a	s12e_1b	s12e_1c	s12e_1d	s12e_1e	s12e_1f
	global	s12e_2 	s12e_2a	s12e_2b	s12e_2c	s12e_2d	s12e_2e	
	global	s12e_3 	s12e_3a	s12e_3b									
	
		global s12e 			s12e_1 s12e_2 s12e_3	

	* F. IPC	
	global	s12f_1 	s12f_1a s12f_1b			
	global	s12f_2 	s12f_2a	s12f_2b		
	global	s12f_3 	s12f_3a	s12f_3b	s12f_3c	
	global	s12f_4 	s12f_4a	s12f_4b		
	global	s12f_5 	s12f_5a	s12f_5b	s12f_5c	s12f_5d

		global s12f 			s12f_1 s12f_2 s12f_3 s12f_4	s12f_5 

			global s12 				s12a s12b s12c s12d s12e s12f


*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	* 1.3. Dealing with skipped sections due to specific facilities characteristics
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
***Replacing max scores per 0 when the sections should not have been done because the facility does not have the characteristics

	
	*Section 11 on nuclear waste management: Only counts if the facility produces radioactive waste (answering yes to s11c_1a)
	global s11c_1a s11c_1a
	gen s11c_1a_id = s11c_1a //save the original variable as s11c_1a will be modified

	foreach var in $s11c_1 $s11c_2 $s11c_3 {
		variable_check_list "`var'" s11c_1a // Simply checking whether var = s11c_1a. Can also be done with an "if"
		local a = r(res)

		replace `var'_ms 	= 0  if s11c_1a_id != 1 & !mi(s11c_1a_id) 
		replace `var'		= .n if s11c_1a_id != 1 & !mi(s11c_1a_id) & "`a'" == "0" //All questions but s11c_1a are not applicable if there are no radioactive waste
		label values `var'_ms NA
	}
	drop s11c_1a_id

******Per big sections which should not be done
* Some renamings to allow a loop 
rename a8_v6   	a8_v7        	// Radiology department (a8_7)
rename a8_v6_a 	a8_v7_a         
rename a8_v6_b 	a8_v7_b         
rename a8_v6_c 	a8_v7_c        
rename a8_v8   	a8_v6           // Laboratory (a8_6)
rename a8_v8_a 	a8_v6_a              
rename a8_v8_b 	a8_v6_b        
rename a8_v8_c 	a8_v6_c       

	*Labour Ward - Medical and pediatric Wards - Theater - Pharmacy -Laboratory - Nutrition 

	//All facilities have Consultation services - Check again if reusing the code that likely that it will always be the case
	forvalues i = 6/11 {
		local j = `i' - 4
		local var  "s`i'"
		foreach var_2 in ${`var'} { 
			foreach var_3 in $`var_2' {
				foreach var_4 in $`var_3' {
					assert mi(`var_4')  if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0) 
					// Going through each question of the section and changing the maximum score to 0 / NA if the section was not to be done
					replace `var_4'_ms = 0 if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0) 
					// Replacing question with .NA to differentiate with any potential missing
					replace `var_4' = .n if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0) 
					label values `var_4'_ms NA                                              
				}
			}
		}
	} 
	
		foreach var_2 in $s12 { // Nutrition department - written differently as there is not the same check on 'closed' for Nutrition
		foreach var_3 in $`var_2' {
			foreach var_4 in $`var_3' {
				replace `var_4' = .n if a8_3 == 0  | (a8_v3 == 1 & a8_v3_b == 0) 
				replace `var_4'_ms = 0 if a8_3 == 0  | (a8_v3 == 1 & a8_v3_b == 0) 
				label values `var_4'_ms NA
			}
		}
	}


	
**************************************************************************************************************************************************************** 

*** # Part 2 : Computing the scores and the per facility maximum scores

**************************************************************************************************************************************************************** 


		foreach var_l1 in $tot_score 	{ 					// loop on s2, s3, .... (=var_l1)

		gen 		`var_l1'_s  = 0   					// The score variable for sections 2, 3 , 4 (level 1)
		gen 		`var_l1'_ms_f = 0  					// Create a new max score for each facility which will depend on which questions it had to answer 
		label var 	`var_l1'_s 		"Facility score for section `var_l1'"

			foreach var_l2 in $`var_l1' 	{ 				// loop on s2a, s2b, s2c, .... (=var_l2)

			gen 		`var_l2'_s = 0 					// The score variable for sections A, B , C (level 2)
			gen 		`var_l2'_ms_f = 0  					// Create a new max score for each facility which will depend on which questions it had to answer
			label var 	`var_l2'_s 		"Facility score for section `var_l2'"

				foreach var_l3 in $`var_l2' 		{		// loop on s2a_1, s2a_2, s2a_3, ... (=var_l3)

				gen 		`var_l3'_s = 0 				// The score variable for small sections (level 3)
				gen 		`var_l3'_ms_f = 0  					// Create a new max score for each facility which will depend on which questions it had to answer
				label var 	`var_l3'_s 		"Facility score for section `var_l3'"

					foreach var_l4 in $`var_l3'			{	// loop on s2a_1a, s2a_1b, s2a_1c (=var_l4)

					variable_check_list "`var_l4'" diff_var // whether the variable is part of the variables which should be treated differently
					local a = r(res)

					disp "`var_l4'"
					*** easy case when 1 is all the points and 0 is 0 points
					gen 		`var_l4'_s 	= `var_l4'_ms 			if `var_l4' == 1 & "`a'" == "0" 
					replace 	`var_l4'_s 	= 0 					if `var_l4' == 0 & "`a'" == "0"
					
					*** More complex cases 
					* Satisfactory questions
					replace 	`var_l4'_s 	= round(`var_l4'_ms/3*(4-`var_l4'),0.1) 	if "`a'" == "1" // small mistake as Satisfactory becomes 6.7 when max is 10 instead of 6.6 in paper survey


					*** Generate the percentage as score divided by maximum score multiplied by 100 for single question
					gen 		`var_l4'_ps = (`var_l4'_s / `var_l4'_ms) * 100 

					*** Label the newly created variables, score and percentage
					label var 	`var_l4'_s 		"Facility score for question `var_l4'"
					label var 	`var_l4'_ps 	"Percentage of maximum score for question `var_l4'" 

					*** Adding to the section score if non missing
					replace 	`var_l3'_s  	= `var_l3'_s + `var_l4'_s if !mi(`var_l4'_s) 
					replace 	`var_l3'_ms_f  	= `var_l3'_ms_f + `var_l4'_ms  
				}

				*** Generate the percentage as score divided by maximum score multiplied by 100 for single question
				gen 		`var_l3'_ps = (`var_l3'_s / `var_l3'_ms_f) * 100 
				label var 	`var_l3'_ps 	"Percentage of maximum score for section `var_l3'" 
				label values `var_l3'_ms_f NA
				*** Adding to the section score of the higher level if non missing
				replace 	`var_l2'_s  = `var_l2'_s + `var_l3'_s if !mi(`var_l3'_s) 
				replace 	`var_l2'_ms_f  	= `var_l2'_ms_f + `var_l3'_ms_f
			}

			*** Generate the percentage as score divided by maximum score multiplied by 100 for single question
			gen 		`var_l2'_ps = (`var_l2'_s / `var_l2'_ms_f) * 100 
			label var 	`var_l2'_ps 	"Percentage of maximum score for section `var_l2'"
			label values `var_l2'_ms_f NA
			*** Adding to the section score of the higher level if non missing
			replace 	`var_l1'_s  = `var_l1'_s + `var_l2'_s if !mi(`var_l2'_s) 
			replace 	`var_l1'_ms_f  	= `var_l1'_ms_f + `var_l2'_ms_f			
		}	

		*** Generate the percentage as score divided by maximum score multiplied by 100 for single question
		gen 		`var_l1'_ps = (`var_l1'_s / `var_l1'_ms_f) * 100 
		label var 	`var_l1'_ps 	"Percentage of maximum score for section `var_l3'"

		*** Adding to the total score of the higher level if non missing
		replace 	tot_score_s  = tot_score_s + `var_l1'_s if !mi(`var_l1'_s) 
		replace 	tot_score_ms_f = tot_score_ms_f + `var_l1'_ms_f
		label values `var_l1'_ms_f NA
	}

gen 		tot_score_ps = (tot_score_s / tot_score_ms_f) * 100 
label var 	tot_score_ps "Percentage of total maximum score obtained by the facility"	


**************************************************************************************************************************************************************** 

*** # Part 3 : Cleaning the dataset: adding not applicable and rounding up scores

****************************************************************************************************************************************************************Creating adherence variables 
 foreach var_l1 in $tot_score 	{ 					// loop on s2, s3, .... (=var_l1)
	foreach var_l2 in $`var_l1' 	{ 				// loop on s2a, s2b, s2c, .... (=var_l2)
		foreach var_l3 in $`var_l2' 	{		// loop on s2a_1, s2a_2, s2a_3, ... (=var_l3)			
			foreach var_l4 in $`var_l3'		{	// loop on s2a_1a, s2a_1b, s2a_1c (=var_l4)
				clonevar `var_l4'_a = `var_l4'			
			}			
		} 
	}
}
		
global s2a_1a s2a_1b s2a_1c s2a_1d s2a_1e 
global s5a_1a s5a_1b s5a_1c
global s5a_4a s5a_4b s5a_4c s5a_4d s5a_4e s5a_4f s5a_4g s5a_4h s5a_4i s5a_4j s5a_4k s5a_4l
global s5b_3a s5b_3b
global s5b_1a s5b_1b
global s6a_3a s6a_3b s6a_3c
global s6a_6a s6a_6b s6a_6c s6a_6d s6a_6e s6a_6f s6a_6g
global s6a_7a s6a_7b s6a_7c s6a_7d s6a_7e
global s6a_8a s6a_8b s6a_8c s6a_8d
global s6b_1a s6b_1b
global s6b_3a s6b_3b
global s7b_1a s7b_1b
global s7b_3a s7b_3b
global s8a_2f s8a_2g
global s8a_4a s8a_4b 

global s8a_receiving s8a_1a s8a_1b s8a_1c s8a_1d
global s8a_changing s8a_2a s8a_2b s8a_2c s8a_2d s8a_2e 
global s8a_recovery s8a_5a s8a_5b s8a_5c 

global s8b_1a s8b_1b
global s8b_3a s8b_3b
global s9d_1a s9d_2a 
global s9e_1a s9e_1b
global s9e_3a s9e_3b
global s10a_2a s10a_2b     
global s10a_3a s10a_3b
global s10a_4a s10a_4b
global s10b_1a s10b_1b
global s10e_1a s10e_1b
global s10e_3a s10e_3b
global s11b_1a s11b_1b 
global s11b_4a s11b_4b

global s11d_1a s11d_1b
global s12c_1a s12c_1c s12c_1d
global s12d_1a s12d_1b
global s12e_kitchen s12e_1a s12e_1b s12e_1c s12e_1d s12e_1e s12e_1f s12e_2a s12e_2b s12e_2c s12e_2d s12e_2e s12e_3a s12e_3b 
global s12f_1a s12f_1b
global s12f_3a s12f_3b
global s4a_1a s4a_1b
global s3a_1a s3a_1b
global s3a_2a s3a_2b s3a_2c s3a_2d s3a_2e s3a_2f s3a_2g s3a_2h
global s3b_3a s3b_3b s3b_3c 
global s3c_1a s3c_1b s3c_1c


global all_var s2a_1a s5a_1a s5a_4a s5b_3a s5b_1a s6a_3a s6a_6a s6a_7a s6a_8a s6b_1a s6b_3a s7b_1a ///
				s7b_3a s8a_2f s8a_4a s8a_receiving s8a_changing s8a_recovery s8b_1a s8b_3a s9d_1a s9e_1a s9e_3a s10a_2a s10a_3a s10a_4a s10b_1a s10e_1a ///
				s10e_3a s11b_1a s11b_4a s11c_1a  s11d_1a s12c_1a s12d_1a s12e_kitchen s12f_1a s12f_3a s4a_1a s3a_1a s3a_2a s3b_3a s3c_1a   ///

	foreach var_filter in $all_var {
			foreach var in $`var_filter' {
					if `var_filter' == 0 & !mi(`var') {
					disp "ERROR" 
					}
				replace `var'_a = 0 if `var_filter' == 0 & mi(`var')
			}
	}
	
replace s3c_3a_a = 0 if s3c_1a == 0 & mi(s3c_3a)
	
*More complex cases	
replace s3c_2c_a = 0 if  (s3c_2a == 0 | s3c_2b == 0) & mi(s3c_2c) & !mi(s3c_2b)

replace s3c_2d_a = 0 if  ((s3c_2a == 0 & s3c_2b == 0) | (s3c_2a == 0 & s3c_2b ==.n)) & mi(s3c_2d)
replace s3c_3b_a = 0 if  (s3c_1a == 0 | s3c_3a == 0) & mi(s3c_3b)
replace s3c_3c_a = 0 if  (s3c_1a == 0 | s3c_3a == 0) & mi(s3c_3c)

replace s3b_2e_a = 0 if (s3b_2a == 0 & s3b_2b == 0 & s3b_2c == 0 & s3b_2d == 0) & mi(s3b_2e)

replace s12b_1g_a = 0 if  (s12b_1a == 0 & s12b_1b == 0 & s12b_1c == 0 & s12b_1d == 0 & s12b_1e == 0 & s12b_1f == 0) & mi(s12b_1g) 
replace s12b_1h_a = 0 if  (s12b_1a == 0 & s12b_1b == 0 & s12b_1c == 0 & s12b_1d == 0 & s12b_1e == 0 & s12b_1f == 0 ) & mi(s12b_1h)

*When there are restrictions on whether the questions is asked or not: 
*s2c_2b asked if level 4 or more
replace s2c_2b_a = 0 if level >= 4 & !mi(level) & s2c_2a == 0    
replace s2c_2b_a = 0 if level >= 4 & !mi(level) & mi(s2c_2b_a) // Mistake for one observation, just correcting it here
replace s2c_2b_a = .n if mi(level) & mi(s2c_2b_a)

*s2c_2b asked if level 4 or more
replace s2c_3d_a = .n if  !mi(level)  & mi(s2c_3d)  



******************************************************************************************************************
****Replacing the scores at the section level with .n for Not applicable (cannot simply label 0 as NA as then cannot differentiate 0 score from skipped)
	forvalues i = 6/11 {
		local j = `i' - 4
		local var  "s`i'"
		replace `var'_s = .n if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0)
		foreach var_2 in ${`var'} { 
			replace `var_2'_s = .n if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0)  
			foreach var_3 in $`var_2' {
				replace `var_3'_s = .n if a8_`j' == 0 | (a8_v`j' == 1 & a8_v`j'_b == 0) 
			}
		}
	} 

***Now again for nutrition
	replace s12_s = .n if a8_3 == 0
		
	foreach var_2 in $s12 { 
		replace `var_2'_s = .n if a8_3 == 0  | (a8_v3 == 1 & a8_v3_b == 0) 
		foreach var_3 in $`var_2' {
				replace `var_3'_s = .n if a8_3 == 0  | (a8_v3 == 1 & a8_v3_b == 0) 
			}
		}
	

**********************************************************************************************************************
*Final rounding up of numbers to make it similar to the website
	foreach var_l1 in $tot_score 	{ 					// loop on s2, s3, .... (=var_l1)
		replace `var_l1'_s  	= round(`var_l1'_s, 0.01)
		replace `var_l1'_ps  	= round(`var_l1'_ps, 0.01)
		replace `var_l1'_ms 	= round(`var_l1'_ms, 0.01)
		replace `var_l1'_ms_f 	= round(`var_l1'_ms_f, 0.01)

			foreach var_l2 in $`var_l1' 	{ 				// loop on s2a, s2b, s2c, .... (=var_l2)
			replace `var_l2'_s 		= round(`var_l2'_s, 0.01)
			replace `var_l2'_ps  	= round(`var_l2'_ps, 0.01)
			replace `var_l2'_ms 	= round(`var_l2'_ms, 0.01)
			replace `var_l2'_ms_f 	= round(`var_l2'_ms_f, 0.01)

					foreach var_l3 in $`var_l2' 	{			// loop on s2a_1, s2a_2, s2a_3, ... (=var_l3)
					replace `var_l3'_s 		= round(`var_l3'_s, 0.01)
					replace `var_l3'_ps 	= round(`var_l3'_ps, 0.01)
					replace `var_l3'_ms 	= round(`var_l3'_ms, 0.01)
					replace `var_l3'_ms_f	= round(`var_l3'_ms_f, 0.01)	

							foreach var_l4 in $`var_l3'		{			// loop on s2a_1a, s2a_1b, s2a_1c (=var_l4)
							replace `var_l4'_s 	= round(`var_l4'_s, 0.01)
							replace `var_l4'_ps = round(`var_l4'_ps, 0.01)
							replace `var_l4'_ms = round(`var_l4'_ms, 0.01)

			}
		}
	}
}				
replace tot_score_ps 		= round(tot_score_ps, 0.01)
replace tot_score_s 		= round(tot_score_s, 0.01)


**************************************************************************************************************************************************************** 

*** # Part 4 : Creating adherence variables.
/*
It makes sure that there are non missing for all items. Some items are skipped because the answer would simply be 0, but need to appear as 0 in the dataset.
This could have been done before to be used in the previous code to compute scores, but in the previous code missings are already counted as 0 so this is not an issue, just adding it here for the sake of simplicity. 
************************************************************************************************************************************************************/



**************************************************************************************************************************************************************** 

*** # Part 5 : Save final dataset

****************************************************************************************************************************************************************  
	order *, seq

		saveold "${jhic_scores}", replace


************************************************End of do file****************************************************
