/*******************************************************************************	

Project:  		KePSIE
Created on:  	Oct 30, 2018
Last udpate on: May 26th, 2021

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 	    Lupe Bedoya (gbedoya@worldbank.org) on May 28, 2021. Only review of high-level decisions, not if each variable was constructed correctly. 

********************************************************************************			

THIS DO FILE: 	This do-file constructs one of the main outcomes: daily outpatients. However, it constructs multiple versions of the variable under different assumptions, which are used as robustness checks. If you want to look at only the construction of the variable used in the analysis, please look at outpatient_construction_end.do. 

				Due to differences in record keeping of facilities, data was collected from multiple sources and time periods: official and informal books for several months, and weekly and daily self-reports. 
				This dofile creates daily outpatients using all sources, and checks for quality and completeness.

				The monthly records include:(1) Ministry of Health (MOH) official reporting books for aggregate totals (MOH Form 717); (2) records by patient age (MOH under and over 5); and (3) any other available facility-based monthly patient registers. 
				Sources (2) and (3) were only asked if (1) was not available. We collect monthly data for 4 different months: November 2017 to February 2018 from any facility records in endline.
				For facilities that started operating in 2018, we also collect data for March, April and May of that year. 
				
				Number of days missing from the registers, if any, was also collected. 
				
				Self-reported weekly outpatients for the previous week are collected for all facilities. 
				
				Daily outpatients for the previous day and two days before the survey are collected for facilities that do not have monthly records.
				
				For all variables, there are bachecks and additional data collection by the supervisors (wherever outpatient data was missing), therefore, if available, these data is merged to the final data.
				
				
				
		- First, we create outpatient variables for each month that combines all data coming from books and another outpatient variable using in charge outpatient estimation (part 1) and identify potential issues in these data (part 2)
		- Second, we construct daily averages using month data under different assumptions: all the months, no matter the number of missing days (outpatient_missall_`month'); only months with no missing days (outpatient_complete_d_`month'); months with less than 5 missing days (outpatient_miss5_d_`month'); months with less than 10 missing days (outpatient_miss10_d_`month') (part 3). 
		- Third, we identify outliers for each type of variable by comparing the daily averages in each months and daily / weekly estimations. We first complete the month variables (which include outliers) by replacing missing observations with the  mean outpatient average across all the other months/ in charge estimation. We also use the month variables without outliers to construct a single variable that is the average across all the months. The missings in that variable are then imputed using the data from the in charge estimation of outpatients. 

		
		The variable we are going to use for the final analysis is outpatient_missall_input_d_c -month of january- (successively renamed as outpatient_missall_input_d_jan, outpatients_allsources_jan_d and finally outp_as_jan).
		It means that it includes all the months (even with missing days), that outliers were NOT replaced, and that missings are replaced with outpatient data averaged over all the other available months and sources. We pick this construction as it includes all available data from books (all months with data are included) and outliers. We use the month of January as it is the month with the lowest number of missings. 
		There are 1285 HFs. From MOH717, for the month of January, we have data for 1,052 HFs (82%). After adding data from MOH o/u5, we have outpatient data for 1,129 HFs (88%). In part 2, we put 9 observations as missing for various issues. We have now data for 1,120 HFs (87%). In part 3, we put 2 more observations as missing because the number of missing days is too high / outpatient data are inconsistent. We have now data for 1,118 HFs (87%). We identify 5 potential outliers in part 4, which are not replaced. The final 167 missing observations (13%) are replaced with the average of the data in the other months and in charge estimation. 
		
		All the other variables can be used to run robustness checks. 
		
		
                In the end, we pick the month of January, as it has the highest number of observations coming from facilities' books, hence the lowest number of imputations, and the variable
		outpatients_allsources_`month'_d (initially outpatient_missall_input_d_`month'), which also has the smallest number of imputations. We run robustness checks with the other variables. 
		

CONTENT:		Part 0 - Create globals for directories and files and locals to be used throughout the do file

				Part 1 - Create outpatient variables for each data source: books, In charge Weekly estimation, In charge last two days estimation
						1.1 Creating MONTHLY outpatient variables using books data (MOH 717, MOH U/O5, other books) 
								1.1.1 Construction of MONTHLY outpatient variables and date of data collection using information from MOH 717 or HF informal books
								1.1.2 Construction of MONTHLY outpatient variables using MOH under 5 and MOH over 5 
								1.1.3 Merging MOH 717 and own books with data from MOH under 5 and MOH over 5 when available
								
						1.2 Creating outpatient variables using In Charge estimations (last week and last two days)
								1.2.1 Number of outpatients over the last 7 days
								1.2.2 Number of outpatients yesterday or the day before
								

						
				Part 2: Indentifying potential issues in the data
						2.1 Issue 1 : Indentifying facilities with limited data available on outpatients
						2.2 Issue 2 : Indentifying months with a suspicious recording of zero outpatients, replacing them with missing
						2.3 Issue 3 : Set all data from 2017 as missing for facilities which started in 2018
						
				Part 3 - Constructing daily outpatient averages from the different sources (books or in charge estimations)
						3.1 Constructing daily outpatient averages from monthly books data
								3.1.1 Using all available monthly data, no replacement (apart from a few extreme outliers)
								3.1.2 Using data only for months with no missing days, replacing the other months as missing
								3.1.2 Using data from months with less than 5 or 10 missing days, replacing the other months as missing
								
						3.2 Constructing daily outpatient averages from weekly/daily outpatient estimations
						
				Part 4: Identifying and replacing outliers and missings using all the 8 sources of data available (7 months plus weekly) 
						4.1 Indentify outliers using the relative distance to the mean excluding the observation
						4.2 Impute all the missing observations in outpatient variables WITH outliers using the average across all the other available data sources 
						4.3 Create a single outpatient variable as the average of all the month variables WITHOUT outliers and replace the missing observations using outpatient estimations by the in-charge
						
				Part 5: Cleaning final variables 
				
				Part 6: Save dataset
						


INPUTS:     	* Database prepared with all the needed variables 
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Fees_Outpatient_QPS1_clean_end.dta"

OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Database with final outpatient outcomes ready for analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/Averages_Outpatient_end.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Database with final outpatient outcomes ready for analysis
					"${end_dt}/Intermediate/Averages_Outpatient_end.dta"
					

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
		glo qps1_fees_outp_end	"${dt_end_clean}/qps1_fees_outp_end.dta"
		glo profile_clean		"${dt_mast}/profile_end.dta"
	
	* Output files: 
		glo outp_av_end_r 		"${dt_end_const}/outp_av_end_robust.dta"
		
	 


global a November(2017)
global b December(2017)
global c January(2018) 
global d February(2018) 
global e March(2018) 
global f April(2018) 
global g May(2018) 


label define source 1 "MOH 717" 2 "MOH u/o 5" 3 "Own books" 4 "Other"


*Defining locals needed for the do file
*Number of days per month depending on the number of opening days to estimate daily variables.
*November
local days_a 		= 30
local days_a_6dw 	= 26 //assuming not working on sundays
local days_a_5dw 	= 22 //assuming not working on saturdays and sundays
local days_a_4dw 	= 18 //assuming not working on Mondays, saturdays and sundays

*December
local days_b 		= 31
local days_b_6dw 	= 26 //assuming not working on sundays
local days_b_5dw 	= 21 //assuming not working on saturdays and sundays
local days_b_4dw 	= 17 //assuming not working on Mondays, saturdays and sundays

*January
local days_c 		= 31
local days_c_6dw 	= 27 //assuming not working on sundays
local days_c_5dw 	= 23 //assuming not working on saturdays and sundays
local days_c_4dw 	= 19 //assuming not working on Mondays, saturdays and sundays

*February
local days_d 		= 28
local days_d_6dw 	= 24 //assuming not working on sundays
local days_d_5dw 	= 20 //assuming not working on saturdays and sundays
local days_d_4dw 	= 16 //assuming not working on Mondays, saturdays and sundays

*March
local days_e 		= 31
local days_e_6dw 	= 27 //assuming not working on sundays
local days_e_5dw 	= 22 //assuming not working on saturdays and sundays
local days_e_4dw 	= 18 //assuming not working on Mondays, saturdays and sundays

*April
local days_f 		= 30
local days_f_6dw 	= 25 //assuming not working on sundays
local days_f_5dw 	= 21 //assuming not working on saturdays and sundays
local days_f_4dw 	= 16 //assuming not working on Mondays, saturdays and sundays

*May
local days_g 		= 31
local days_g_6dw 	= 27 //assuming not working on sundays
local days_g_5dw 	= 23 //assuming not working on saturdays and sundays
local days_g_4dw 	= 19 //assuming not working on Mondays, saturdays and sundays


********************************************************************************
* # Part 1: Create outpatient variables for each data source: books, In charge Weekly estimation, In charge last two days estimation

********************************************************************************

use "${qps1_fees_outp_end}", clear


	*-------------------------------------------------------------------------------------*
	* 1.1 Creating MONTHLY outpatient variables using books data (MOH 717, MOH U/O5, other books) *
	*-------------------------------------------------------------------------------------*


********* 1.1.1 Construction of MONTHLY outpatient variables and date of data collection using information from MOH 717 or HF informal books *********

foreach month in a b c d e f g {
* Number of outpatients
	gen 	book_outpatient_`month' = f17`month' 							  
	replace book_outpatient_`month' = add_f17`month' 					if !mi(add_f17`month') //Adding outpatient data that were collected later on by supervisors for facilities for which outpatient data was missing
	
* Date of the outcome collection	
	gen 	book_outpatient_date_`month' = date 					
	replace book_outpatient_date_`month' = add_date_outpatient 			if !mi(add_f17`month') 
	format  book_outpatient_date_`month' %td

* Source of outcome (MOH 717 or own books)
	gen 	book_outpatient_source_`month' =  1 						if f30 == 1 // source is MOH717
	replace book_outpatient_source_`month' =  3 						if f32 == 1 // source is own books
	replace book_outpatient_source_`month' =  4 						if f33 == 1 // source is 'other'

	replace book_outpatient_source_`month' =  1 						if !mi(add_f17`month') & add_f30 == 1 // source is MOH717
	replace book_outpatient_source_`month' =  3 						if !mi(add_f17`month') & add_f32 == 1 // source is own books
	replace book_outpatient_source_`month' =  4 						if !mi(add_f17`month') & add_f33 == 1 // source is 'other'

	gen		book_outpatient_source_other_`month' = f33_type				if mi(add_f17`month')  & f33 == 1
	replace	book_outpatient_source_other_`month' = add_f33_type			if !mi(add_f17`month') & add_f33 == 1

*Number of missing days of data in MOH717 or other books for each month 
	gen 	book_outpatient_miss_`month' = f17_miss_`month'
	replace	book_outpatient_miss_`month' = add_f17_miss_`month'			if !mi(add_f17`month')

* Labelling
	label var book_outpatient_`month' 				"$`month':Monthly outpatients from book source"
	label var book_outpatient_date_`month' 			"Date when data was collected for $`month' for outpatients from book source"
	label var book_outpatient_source_`month' 		"Source outpatient data from book source for $`month'"
	label var book_outpatient_source_other_`month' 	"Other Source outpatient data from book source for $`month'"
	label var book_outpatient_miss_`month' 			"Number of missing days outpatient from book source for $`month'"

	label value book_outpatient_source_`month' source
}


* Replacing with the outpatient value collected through backchecks (collected by supervisors) when available (around 1% of observations)

foreach month in a d {
	replace book_outpatient_`month' 		= bcheck_f17`month' 		if !mi(bcheck_f17`month')  & bcheck_f17`month' != add_f17`month'

	replace book_outpatient_date_`month' 	= bcheck_date 				if !mi(bcheck_f17`month')  & bcheck_f17`month' != add_f17`month'

	replace book_outpatient_source_`month' 	=  1 						if (!mi(bcheck_f17`month') & bcheck_f17`month' != add_f17`month') & bcheck_f30 == 1 // source is MOH717
	replace book_outpatient_source_`month' 	=  3 						if (!mi(bcheck_f17`month') & bcheck_f17`month' != add_f17`month') & bcheck_f32 == 1 // source is own books

	replace	book_outpatient_miss_`month' 	= bcheck_f17_miss_`month' 	if !mi(bcheck_f17`month')  & bcheck_f17`month' != add_f17`month'
}




********* 1.1.2 Construction of MONTHLY outpatient variables using MOH under 5 and MOH over 5  *********

foreach month in a b c d e f g {
	*Generating the date and variables, as complete as possible. 

* Number of outpatients
* Adding outpatient data that were collected later on by supervisors for facilities for which outpatient data was missing
	replace	f18`month' 	= add_f18`month' 				if !mi(add_f18`month') | !mi(add_f19`month') //if any data was collected by supervisor, replace both
	replace f19`month' 	= add_f19`month' 				if !mi(add_f18`month') | !mi(add_f19`month')

	gen 	UO5_`month' = f18`month' + f19`month' // If only have one of the two, it will then be missing
	
* Date of the outpatient data collection
	gen 	UO5_date_`month'= .
	format  UO5_date_`month' %td
	replace UO5_date_`month' = add_date_outpatient  	if !mi(add_f18`month') | !mi(add_f19`month')

*source of outpatient data  (MOH u/o 5)
	gen 	UO5_source_`month' =  2 					if f31 == 1 // source is MOH for o/u 5
	replace UO5_source_`month' =  2 					if (!mi(add_f18`month') | !mi(add_f19`month')) 

*Number of missing days of data in the books for each month
	gen 	UO5_miss_`month' = max(f18_miss_`month',f19_miss_`month') //Taking the maximum of missing days to get a conservative estimate   					
	replace UO5_miss_`month' = max(f18_miss_`month',f19_miss_`month')

* Labelling
	label var UO5_`month' 				"$`month':Monthly outpatients from adding o/u 5 outpatient"
	label var UO5_date_`month'			"Date when data was collected for $`month' for outpatients o/u 5 from any book source"
	label var UO5_source_`month'		"Source o/u 5 outpatient data for $`month'" 
	label var UO5_miss_`month' 			"Number of missing days o/u 5 outpatient for $`month'"

	label value UO5_source_`month' source		
}

* Replacing with the outpatient value collected through backchecks when available 
// No need to do it here as bcheck_f18a, bcheck_f18d, bcheck_f19a, bcheck_f19d are all empty. 



********* 1.1.3 Merging MOH 717 and own books with data from MOH under 5 and MOH over 5 when available *********

foreach month in a b c d e f g {
* Origin of data which should be used, either from books or from UO5
	gen 	data_use`month' = 1
	replace data_use`month' = 2 if  mi(book_outpatient_`month') & !mi(UO5_`month')
	replace data_use`month' = 2 if !mi(book_outpatient_`month') & !mi(UO5_`month') & book_outpatient_source_`month' != 1 //If data are not from MOH 717, then MOH U/O 5 more reliable if non missing  

* Number of outpatients
	gen 	outpatient_`month' = book_outpatient_`month'							  
	replace outpatient_`month' = UO5_`month' 							if data_use`month' == 2 // For now, priority on books over the addition of u/o 5 outpatient calculation

* Date of the outcome collection
	gen 	outpatient_date_`month' = book_outpatient_date_`month'
	replace outpatient_date_`month' = UO5_date_`month'  				if data_use`month' == 2 
	format  outpatient_date_`month' %td

*source of outcome
	gen 	outpatient_source_`month' = book_outpatient_source_`month' 
	replace outpatient_source_`month' = UO5_source_`month' 				if data_use`month' == 2 
	gen 	outpatient_source_other_`month' = book_outpatient_source_other_`month'

*Number of missing days of outcome
	gen 	outpatient_miss_`month' = book_outpatient_miss_`month'
	replace	outpatient_miss_`month' = UO5_miss_`month'					if data_use`month' == 2 

* Labelling
	label var outpatient_`month' 				"$`month':Monthly outpatients"
	label var outpatient_date_`month' 			"Date when data was collected for $`month' for outpatients"
	label var outpatient_source_`month' 		"Source outpatient data for $`month'"
	label var outpatient_source_other_`month' 	"Other Source outpatient data for $`month'"
	label var outpatient_miss_`month' 			"Number of missing days outpatient for $`month'"

	label value outpatient_source_`month' source

	drop data_use`month'  
}


*Checking on the number of missing data for each month variable
foreach month in a b c d e f g {
	disp "`month'"
	count if mi(outpatient_`month') 
	count if mi(outpatient_`month') | (outpatient_miss_`month' >= 0 & !mi(outpatient_miss_`month')) //Counting either missing value for the month or some missing days in the month 
}


*Extracting month and year from the date of the outpatient data collection
foreach month in a b c d e f g {
	gen outpatient_year_`month'  = year(outpatient_date_`month')
	label var outpatient_year_`month' "Year on which outpatient data was collected for $`month'"
	gen outpatient_month_`month' = month(outpatient_date_`month') 
	label var outpatient_month_`month' "Month on which outpatient data  was collected for $`month'"

	label value outpatient_month_`month' month
}


	*---------------------------------------------------------------------------------------------*
	* 1.2 Creating outpatient variables using in-charge estimations (last week and last two days) *
	*---------------------------------------------------------------------------------------------*

********* 1.2.1 Number of outpatients over the last 7 days *********************

*Main outcome
	gen 	outpatient_w	= out_seven  			// outpatients in one week	
	replace outpatient_w 	= add_out_seven 		if !mi(add_out_seven)
	replace outpatient_w 	= bcheck_out_seven 		if !mi(bcheck_out_seven) & bcheck_out_seven != add_out_seven

*Date
	gen 	outpatient_w_date = date
	replace outpatient_w_date = add_date 			if !mi(add_out_seven)
	replace outpatient_w_date = bcheck_date 		if !mi(bcheck_out_seven) & bcheck_out_seven != add_out_seven

*Label
	label var outpatient_w 		"Number of patients over the last seven days"
	label var outpatient_w_date "Date of collection of: number of patients over the last seven days"


*Extracting month and year from the date of the outpatient data collection
	gen outpatient_w_year  = year(outpatient_w_date)
	label var outpatient_w_year "Year on which outpatient data on the last seven days was collected for $`month'"
	gen outpatient_w_month = month(outpatient_w_date) 
	label var outpatient_w_month "Month on which outpatient data on the last seven days was collected for $`month'"

	label value outpatient_w_month month



********* 1.2.2 Number of outpatients yesterday or the day before *********************
*This was only asked when supervisors went to visit again facilities for which outpatients data were missing

	rename add_pat_yesterday  			outpatient_dm1 // dm1 is for day minus 1
	rename add_past_beforeyesterday 	outpatient_dm2 // dm1 is for day minus 2

	label var outpatient_dm1 "Daily outpatient: yesterday"
	label var outpatient_dm2 "Daily outpatient: day before yesterday"

	gen date_dm1  = add_date - 1
	label var date_dm1 "Date for the number of outpatient recorded in outpatient_dm1"
	gen date_dm2  = add_date - 2
	label var date_dm2 "Date for the number of outpatient recorded in outpatient_dm2"

	gen date_dm1_year  = year(date_dm1)
	label var date_dm1_year "Year on which outpatient data was collected in outpatient_dm1"
	gen date_dm1_month = month(date_dm1) 
	label var date_dm1_month "Month on which outpatient data was collected in outpatient_dm1"

	label value date_dm1_month month

	gen date_dm2_year  = year(date_dm2)
	label var date_dm2_year "Year on which outpatient data was collected in outpatient_dm2"
	gen date_dm2_month = month(date_dm2) 
	label var date_dm2_month "Month on which outpatient data was collected in outpatient_dm2"

	label value date_dm2_month month
	


			
			
********************************************************************************
* # Part 2: Indentifying potential issues in the data
********************************************************************************		
			
			
	*---------------------------------------------------------------------------------------------*
	* 2.1 Issue 1 : Indentifying facilities with limited data available on outpatients *
	*---------------------------------------------------------------------------------------------*		
* This variable is currently not used in the analysis but could be used for robustness checks 

*Rule as defined in technical appendice: facilities should be flagged if less than 1 month complete (missing less than 6 days is allowed) if established before 2018 ///
*or 0 month complete if established in 2018.
	gen flag = 0
	label var flag "Facilities with little or no available data"

	gen month_complete_tech = 0
	label var month_complete_tech "Number months complete under technical appendice definition"

	foreach month in a b c d e f g {
		replace month_complete_tech = month_complete_tech + 1 if (outpatient_miss_`month'< 6 | mi(outpatient_miss_`month')) & !mi(outpatient_`month')	
			}

			replace flag = 1 if month_complete_tech < 2  & startyear < 2018 
			replace flag = 1 if month_complete_tech == 0 & startyear == 2018 


	*----------------------------------------------------------------------------------------------------------------*
	* 2.2 Issue 2 : Indentifying months with a suspicious recording of zero outpatients, replacing them with missing *
	*----------------------------------------------------------------------------------------------------------------*		
	
	
*Variable useful to know how many observations were put to missing in each case, which will be used throughout the dofile
foreach month in a b c d e f g {
	gen id_change_`month'= 0 if !mi(outpatient_`month')
	}	

*Creating a variable with all the 0, original variables
foreach month in a b c d e f g {
	gen outpatient_original_`month' = outpatient_`month'
}

global outpatient  outpatient_w outpatient_a outpatient_b outpatient_c outpatient_d outpatient_e outpatient_f outpatient_g	

*We can look at 0 for outpatient variable. 0 can only happen if the facility is of small size. Put to missing when there is a doubt. 

	egen outpatient_max = rowmax($outpatient)
	egen outpatient_min = rowmin($outpatient)

list hfid outpatient_dm1 outpatient_dm2 $outpatient if outpatient_min == 0

*Facilities with only 0 for all months recorded - put to missing for now as not working / closed: 12028, 510110, 514060, 518010, 515060 , 900641
*Facilities with missing for all months and 0 for previous week/previous days: 515010, 515090, 516030, 516070, 519070 (0 for all months), 555571, 900274, 900498, 901428    

*12028 : 25 for weekly, 0 for all months a b c d | 510110 70 for weekly, 0 for a b c d | 514060 40 for weekly, 0 for c d e f | 515060, 30 for weekly and 0 for c d e f
foreach month in a b c d {
	replace outpatient_`month' = .q if hfid == 12028 | hfid == 510110 | hfid == 900641 
	}

foreach month in c d e f {
	replace outpatient_`month' = .q if hfid == 514060 | hfid == 515060 | hfid == 518010
	}

* 510020 : 200 for c, 201 for d and 0 for a and b 
foreach month in a b {
	replace outpatient_`month' = .q if hfid == 510020
	}

*510130 : 33 for weekly, 86 for d, 0 for a b c 
foreach month in a b c {
	replace outpatient_`month' = .q if hfid == 510130
	}

* 510130 : 22 for weekly, 159 for c, 130 for d and 0 for a and b 
foreach month in a b {
	replace outpatient_`month' = .q if hfid == 510130
	}

* 555595 : 70 for weekly, 189 for d,  0 for a b and c 
foreach month in a b c {
	replace outpatient_`month' = .q if hfid == 555595
	}

* 555617 : 93 for weekly, 906 for c and 1096 for d, 0 for a b  
foreach month in a b {
	replace outpatient_`month' = .q if hfid == 555617
	}

* 588112 : 10 for weekly, 93 for c and 102 for d, 0 for a b  
foreach month in a b {
	replace outpatient_`month' = .q if hfid == 588112
	}

* 800007 : 22 for weekly, 104 for d, 0 for a b c 
foreach month in a b c {
	replace outpatient_`month' = .q if hfid == 800007
	}

* 800029 : 14 for weekly, 88 for b, missing for c d, 0 for a
foreach month in a {
	replace outpatient_`month' = .q if hfid == 800029
	}

* 900317 : 20 for weekly, 53 for a, 61 for c d, 0 for b
foreach month in b {
	replace outpatient_`month' = .q if hfid == 900317
	}

* 900860 : 30 for weekly, 242 for c and 183 for d, 0 for a b  
foreach month in a b {
	replace outpatient_`month' = .q if hfid == 900860
	}


	*----------------------------------------------------------------------------------------------------------------*
	* 2.3 Issue 3 : Set all data from 2017 as missing for facilities which started in 2018 = assuming that starting date is correct *
	*----------------------------------------------------------------------------------------------------------------*		

tab outpatient_a if startyear == 2018 
tab outpatient_b if startyear == 2018 
*6 facilities have 0 and three facilities (18728, 510120, 588101) have positive numbers. 

foreach month in a b {
	replace id_change_`month'  = 1  if startyear == 2018 & outpatient_`month' == 0	 & !mi(id_change_`month')
	replace outpatient_`month' = .  if startyear == 2018 & outpatient_`month' == 0

	replace id_change_`month'  = 1  if startyear == 2018 & outpatient_`month' >  0 & !mi(outpatient_`month') & !mi(id_change_`month')
	replace outpatient_`month' = .q if startyear == 2018 & outpatient_`month' >  0 & !mi(outpatient_`month')
}



****************************************************************************************************
*Part 3 - Constructing daily outpatient averages from the different sources (books or in-charge estimations)
****************************************************************************************************

	*------------------------------------------------------------------*
	* 3.1 Constructing daily outpatient averages from monthly books data
	*------------------------------------------------------------------*
	
********* 3.1.1 Using all available monthly data, no replacement (apart from a few extreme outliers)   *********************	
	

	foreach month in a b c d e f g {
		gen 	  outpatient_allsources_`month' 	= outpatient_`month' 
		label var outpatient_allsources_`month' "$`month':Monthly outpatients inputting all missing data"
	}


	* Identifying extreme untrustful observation - no rule for now, just observation *
	*Only for 36 observations with missing days more than 10. When the number is consistent with the others, keep it, otherwise set to missing. 
	replace outpatient_allsources_b = .q if hfid == 12070 // 70 outpatient for the month while the other sources give something closer to 150
	replace outpatient_allsources_c = .q if hfid == 16572 //29 missing days, estimation of 30 000 while outseven gives around 130
	replace outpatient_allsources_a = .q if hfid == 17065
	replace outpatient_allsources_b = .q if hfid == 17065 // estimation 80, other sources give between 170 and 800
	replace outpatient_allsources_f = .q if hfid == 500032 //estimation 50, other sources give 20
	replace outpatient_allsources_a = .q if hfid == 513040 // estimation 20, other sources give 60
	replace outpatient_allsources_b = .q if hfid == 555562 // estimation 6, other sources give 20
	replace outpatient_allsources_a = .q if hfid == 900452 // Estimation 4, other sources give 10
	replace outpatient_allsources_d = .q if hfid == 901236 // Estimation 750, other sources give 100
	replace outpatient_allsources_c = .q if hfid == 901911 // Estimation 100, other sources give between 100 and 200 
	replace outpatient_allsources_d = .q if hfid == 21319 //more missing days than opening days
	replace outpatient_allsources_a = .q if hfid == 555568 //more missing days than opening days
	replace outpatient_allsources_a = .q if hfid == 555587 //more missing days than opening days

	
	*Averaging over each month
	local cut allsources

foreach month in a b c d e f g {
	gen 	miss_day_allsources_`month' = 0
	replace miss_day_allsources_`month' = outpatient_miss_`month' if !mi(outpatient_miss_`month') & !mi(outpatient_allsources_`month')

	gen 	outpatient_`cut'_d_`month' = outpatient_`cut'_`month' / (`days_`month'' - miss_day_`cut'_`month')  	  if daysopen == 7  //taking the number of days where the HF is open minus the number of missing days, corresponding to the number of days for which we have the info
	replace outpatient_`cut'_d_`month' = outpatient_`cut'_`month' / (`days_`month'_6dw'- miss_day_`cut'_`month')  if daysopen == 6 | mi(daysopen)  
	replace outpatient_`cut'_d_`month' = outpatient_`cut'_`month' / (`days_`month'_5dw'- miss_day_`cut'_`month')  if daysopen == 5  
	replace outpatient_`cut'_d_`month' = outpatient_`cut'_`month' / (`days_`month'_4dw'- miss_day_`cut'_`month')  if daysopen <= 4  

	drop miss_day_allsources_`month'
	}
	
********* 3.1.2 Using data only for months with no missing days, replacing the other months as missing  *********************

* Putting as missing all months with missing days 
foreach month in a b c d e f g {
	gen 	  outpatient_complete_`month' 	= outpatient_`month' 
	replace   outpatient_complete_`month' 	= .q   					if !mi(outpatient_miss_`month') & outpatient_miss_`month' > 0 
	replace   id_change_`month'  			= 2 					if !mi(outpatient_miss_`month') & outpatient_miss_`month' > 0  & !mi(id_change_`month')

	label var outpatient_complete_`month'  "$`month':Monthly outpatients without missing data" 
}

*Number of months missing per facilities
	gen month_partial_complete = 0
	gen month_complete = 0

	label var month_partial_complete  	"Number of months with some data"
	label var month_complete 			"Number of months complete"

	foreach month in a b c d e f g {
		replace month_partial_complete 	= month_partial_complete + 1 	if !mi(outpatient_`month') 		
		replace month_complete 			= month_complete + 1 			if !mi(outpatient_complete_`month') 	
			}


	*Averaging over each month
foreach month in a b c d e f g {
	gen 	outpatient_complete_d_`month' = outpatient_complete_`month' / `days_`month'' 	    if daysopen == 7  
	replace outpatient_complete_d_`month' = outpatient_complete_`month' / `days_`month'_6dw'  if daysopen == 6 | mi(daysopen)  
	replace outpatient_complete_d_`month' = outpatient_complete_`month' / `days_`month'_5dw'  if daysopen == 5  
	replace outpatient_complete_d_`month' = outpatient_complete_`month' / `days_`month'_4dw'  if daysopen <= 4  
}


********* 3.1.3 Using data from months with less than 5 or 10 missing days, replacing the other months as missing  *********************	

*Setting locals for later on
local cut_miss_5  = 5
local cut_miss_10 = 10


*  Putting as missing all months where more than 5 (10) days are missing*
foreach cut in `cut_miss_5' `cut_miss_10' {

	foreach month in a b c d e f g {
		gen 	  outpatient_miss`cut'_`month' 	= outpatient_`month' 
		replace   outpatient_miss`cut'_`month' 	= .q   					if !mi(outpatient_miss_`month') & outpatient_miss_`month' > `cut' 

		label var outpatient_miss`cut'_`month'  "$`month':Monthly outpatients with less than `cut' days of missing data" 
	}

*Number of months missing per facilities
		gen month_miss`cut' = 0
		label var month_miss`cut' 				"Number of months with less than `cut' days of missing data"

	foreach month in a b c d e f g {	
		replace month_miss`cut' 			= month_miss`cut' + 1 			if !mi(outpatient_miss`cut'_`month') 	
	}

	
	*Averaging over each month
foreach month in a b c d e f g {
	gen 	miss_day_`cut'_`month' = 0
	replace miss_day_`cut'_`month' = outpatient_miss_`month' if !mi(outpatient_miss_`month') & outpatient_miss_`month' <= `cut'

	gen 	outpatient_miss`cut'_d_`month' = outpatient_miss`cut'_`month' / (`days_`month'' - miss_day_`cut'_`month')  	  if daysopen == 7   
	replace outpatient_miss`cut'_d_`month' = outpatient_miss`cut'_`month' / (`days_`month'_6dw'- miss_day_`cut'_`month')  if daysopen == 6 | mi(daysopen)  
	replace outpatient_miss`cut'_d_`month' = outpatient_miss`cut'_`month' / (`days_`month'_5dw'- miss_day_`cut'_`month')  if daysopen == 5  
	replace outpatient_miss`cut'_d_`month' = outpatient_miss`cut'_`month' / (`days_`month'_4dw'- miss_day_`cut'_`month')  if daysopen <= 4  
	}


}

tab month_miss5
tab month_miss10


	
	*------------------------------------------------------------------*
	* 3.2 Constructing daily outpatient averages from weekly/daily outpatient estimations
	*------------------------------------------------------------------*

*Daily average using the number of patients over the last week divided by the number of days the facility is open
gen 		day_w = outpatient_w / daysopen
label var 	day_w "average daily outpatient from weekly data"


*Daily average using the number of patients over the last two days
gen 		day_d = (outpatient_dm1 + outpatient_dm2) / 2
label var 	day_d "average daily outpatient from daily data"


*Replace daily average from the last week estimation with daily average from the last two days estimation whenever it is missing 
*We trust more the average over the previous week than over the last two days as it is less sensitive to within week variations

replace 	day_w = day_d if mi(day_w) & !mi(day_d)






****************************************************************************************************
*Part 4: Identifying and replacing outliers and missings using all sources of data available 
****************************************************************************************************

	*--------------------------------------------------------------------------------------*
	* 4.1 Indentify outliers using the relative distance to the mean excluding the observation
	*--------------------------------------------------------------------------------------*
	
//Done it first as after that we input the average so it would be an issue
	foreach type in complete miss5 miss10 allsources {
global `type' day_w outpatient_`type'_d_a outpatient_`type'_d_b outpatient_`type'_d_c outpatient_`type'_d_d outpatient_`type'_d_e outpatient_`type'_d_f outpatient_`type'_d_g
	}

	
*Generating all the useful variables: mean, mean without the observation, absolute distance from the min to observation, relative distance from the min to observation
	foreach type in complete miss5 miss10 allsources {

		egen month_data_`type'     = rownonmiss($`type') 
		tab month_data_`type'		

		egen outpatient_`type'_av  = rowmean($`type')

			foreach month in a b c d e f g {
			*Variable useful to know how many observations were put to missing in each case.
			
				gen 	flag_`type'_`month' 		  = 0 if !mi(outpatient_`type'_d_`month')

				gen 	av_minus_data_`type'_`month'  = (outpatient_`type'_av - outpatient_`type'_d_`month'/month_data_`type') * (month_data_`type'/(month_data_`type'-1)) if month_data_`type' > 2
			
				gen 	diff_to_av_`type'_`month'     = (outpatient_`type'_d_`month' - av_minus_data_`type'_`month')  if outpatient_`type'_d_`month' > av_minus_data_`type'_`month'
				replace diff_to_av_`type'_`month'     = -(outpatient_`type'_d_`month' - av_minus_data_`type'_`month') if outpatient_`type'_d_`month' <= av_minus_data_`type'_`month'

				gen	    dist_to_av_`type'_`month'_max = diff_to_av_`type'_`month' / av_minus_data_`type'_`month' if outpatient_`type'_d_`month' > av_minus_data_`type'_`month'  & month_data_`type' > 2 
				gen 	dist_to_av_`type'_`month'_min = diff_to_av_`type'_`month'/ outpatient_`type'_av 		 if outpatient_`type'_d_`month' <= av_minus_data_`type'_`month' & month_data_`type' > 2 
	
		}


*******Identifying outliers and replacing them with the mean without the observation. 3 main rules: 
*1.Replace at most one observation per facility, the furthest one.
*2.If observation is a max, then outliers when the relative distance to the mean without observation is more than 2
*3.If observation is a min, then outliers when the ratio of ditance to the mean without average to the mean is more than 1

global `type'2 diff_to_av_`type'_a diff_to_av_`type'_b diff_to_av_`type'_c diff_to_av_`type'_d diff_to_av_`type'_e diff_to_av_`type'_f diff_to_av_`type'_g
 
		egen outpatient_`type'_max = rowmax($`type'2)

		foreach month in a b c d e f g {
			count 									if dist_to_av_`type'_`month'_max > 2 & !mi(dist_to_av_`type'_`month'_max) //change 63 observations in total, 5% of facilities impacted 
			gen  	outpatient_`type'_noo_d_`month' = outpatient_`type'_d_`month'
			replace outpatient_`type'_noo_d_`month' = av_minus_data_`type'_`month' if dist_to_av_`type'_`month'_max > 2 & !mi(dist_to_av_`type'_`month'_max) & diff_to_av_`type'_`month' == outpatient_`type'_max
			replace outpatient_`type'_noo_d_`month' = av_minus_data_`type'_`month' if dist_to_av_`type'_`month'_min > 1 & !mi(dist_to_av_`type'_`month'_min) & diff_to_av_`type'_`month' == outpatient_`type'_max

			*Flagging observations which have been changed 
			replace flag_`type'_`month' = 1 if dist_to_av_`type'_`month'_max > 2 & !mi(dist_to_av_`type'_`month'_max) & diff_to_av_`type'_`month' == outpatient_`type'_max
			replace flag_`type'_`month' = 1 if dist_to_av_`type'_`month'_min > 1 & !mi(dist_to_av_`type'_`month'_min) & diff_to_av_`type'_`month' == outpatient_`type'_max
			
		}

		gen flag_`type' = 0
		replace flag_`type' = 1 if flag_`type'_a == 1 | flag_`type'_b == 1 | flag_`type'_c == 1 | flag_`type'_d == 1 | flag_`type'_e == 1 | flag_`type'_f == 1 | flag_`type'_g == 1
		
		list hfid $`type' if flag_`type' == 1
		
}

*Generating ratio min max to look for other outliers. The ones which still have high ratio are small facilities or high volatility facilities
foreach type in complete_noo miss5_noo miss10_noo allsources_noo {
global `type' outpatient_`type'_d_a outpatient_`type'_d_b outpatient_`type'_d_c outpatient_`type'_d_d outpatient_`type'_d_e outpatient_`type'_d_f outpatient_`type'_d_g


	egen outpatient_`type'_max = rowmax($`type')
	egen outpatient_`type'_min = rowmin($`type')

	gen ratio_maxmin_`type' = outpatient_`type'_max / outpatient_`type'_min  
	*hist ratio_maxmin_`type', freq
	
}



	*----------------------------------------------------------------------------------------------------------------------------------------------------------*
	* 4.2 Impute all the missing observations in outpatient using the average across all the other available data sources (not corrected for outliers) 
	*----------------------------------------------------------------------------------------------------------------------------------------------------------*
	foreach type in complete miss5 miss10 allsources {

global `type' day_w outpatient_`type'_d_a outpatient_`type'_d_b outpatient_`type'_d_c outpatient_`type'_d_d outpatient_`type'_d_e outpatient_`type'_d_f outpatient_`type'_d_g
	
	egen  outpatient_`type'_d_av   = rowmean($`type')
	egen  obs_missing_`type'_w     = rownonmiss($`type')

		foreach month in a b c d e f g {
			gen 	outpatient_`type'_input_d_`month' = outpatient_`type'_d_`month'
			replace outpatient_`type'_input_d_`month' = outpatient_`type'_d_av if mi(outpatient_`type'_d_`month')
		}

count if obs_missing_`type'_w == 1  & !mi(day_w) //Most of the data come from the weekly anyway, 131 out of 155 or 169 for Januray or February

	}
 


	*----------------------------------------------------------------------------------------------------------------------------------------------------------*
	* 4.3 Create a single outpatient variable as the average of all the month variables WITHOUT outliers and replace the missing observations using outpatient estimations by the in-charge
	*----------------------------------------------------------------------------------------------------------------------------------------------------------*
	foreach type in complete_noo miss5_noo miss10_noo allsources_noo  {

global `type'  outpatient_`type'_d_a outpatient_`type'_d_b outpatient_`type'_d_c outpatient_`type'_d_d outpatient_`type'_d_e outpatient_`type'_d_f outpatient_`type'_d_g
	
	egen    outpatient_`type'_d_av   = rowmean($`type')
	replace outpatient_`type'_d_av   = day_w              if mi(outpatient_`type'_d_av)

	}


****************************************************************************************************
*Part 5: Cleaning final variables 
****************************************************************************************************
*Renamed using the standardisation described in KePSIE_DataDictionary excel file

global a nov
global b dec
global c jan 
global d feb 
global e mar 
global f apr
global g may

global nov November 2017
global dec December 2017
global jan January 2018 
global feb February 2018 
global mar March 2018 
global apr April 2018 
global may May 2018 


foreach month in a b c d e f g {
	rename 		outpatient_complete_d_`month'  			outpatients_complete_${`month'}_d 
	label var 	outpatients_complete_${`month'}_d  	"Daily Outpatients - ${${`month'}}  (Monthly Complete Records)"
	
	
*Final variable to be used in the rest of the analysis, month of January => outpatients_allsources_jan_d later renamed as outp_as_jan		
	rename 		outpatient_allsources_input_d_`month'		outpatients_allsources_${`month'}_d
	label var 	outpatients_allsources_${`month'}_d 	"Daily Outpatients - ${${`month'}} (All Sources)"
}


rename 			outpatient_allsources_noo_d_av				outpatients_allsources_mean_d 
label var 		outpatients_allsources_mean_d 		"Daily Outpatients - Average Available Months (All Sources)"

*Shortening variables name
foreach x in _nov_d _dec_d _jan_d _feb_d _mar_d _apr_d _may_d {

rename outpatients_complete`x' outpatients_cmonth`x'
}


*Adding and putting to 0 outpatients values for facilities which were closed by endline
merge 1:1 hfid using "${profile_clean}", keepusing(inactive)
drop _merge

foreach month in nov dec jan feb mar apr may {
	 	replace	outpatients_cmonth_`month'_d		= 0 if inactive == 0
	 	replace	outpatients_allsources_`month'_d 	= 0 if inactive == 0
}

		replace outpatients_allsources_mean_d = 0 if inactive == 0


********************************************************************************
*Part 6: Save dataset
********************************************************************************	

		save "${outp_av_end_r}", replace
	

************************************************End of do file****************************************************


