/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare patient quality variables for analysis (e.g., satisfaction, waiting times, physical exam index)

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Construct physical examination index
			Part 2: Construct patient satisfaction and provider quality as reported by patients
			Part 3: Export 
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pe_clean 			"${dt_end_clean}/pe_end.dta"
	
	* Output 
	glo pe_quality 			"${dt_end_const}/patient_quality.dta"	

********************************************************************************
** Part 1: Construct physical examination index
********************************************************************************
use "${pe_clean}", clear 
loc pind g1a g1b g2a g3a h1a h1b h1c h1d h1e h1f h1g h2	g5* f1 f2 f3_* e2	
keep hfid `pind' key // keep only key vars
	
	* Physical examination index is estimated through principal components analysis (PCA)
	foreach var of varlist g5a g5b g5c g5d g5e g5f g5h g5i g5j g5k  {  //Enter the list of variables for PCA
	lab var g5a "Checked pulse"
	lab var g5b "Checked blood pressure"
	lab var g5c "Listened (directly or with stethoscope) to front of body"
	lab var g5d "Listened (directly or with stethoscope) to back of body"
	lab var g5e "Performed throat exam"
	lab var g5f "Checked temperature with thermometer"
	lab var g5g "Checked temperature by touch"
	lab var g5h "Conducted other tests (malaria, stool)"
	lab var g5i "Conducted basic check (weight, height)"
	lab var g5j "Conducted other exams (eye exam)"
	lab var g5k "Conducted follow-up check from previous visit"
	gen pca_`var' = `var'
	}
	ds pca_*
	loc pca_exam `r(varlist)'
	* Generate the PCA index
	sum `pca_exam'
	pca `pca_exam', mineigen (1) means
	predict pca_exam, score
	lab var pca_exam "Physical Examination Index"
	
********************************************************************************
** Part 2: Patient satisfaction and provider quality as reported by patients
********************************************************************************
/*******************************************************************************
Notes: Overall satisfaction is a rank-ordered variable where patients rate their 
service satisfaction according to 5 categories: very dissatisfied, dissatisfied, 
neither satisfied nor dissatisfied, satisfied, and very satisfied. Overall 
satisfaction is equal to 1 if ranked satisfied or above, and 0 otherwise. 
Satisfaction according to general metrics of "user" experience including 
consultation time and problems they faced while at the facility were asked 
according to 3 categories: major problems, minor problems, or no problems 
experienced during their visit. These metrics of satisfaction are equal to 1 if
no problems are experienced, 0 otherwise.
********************************************************************************/	
	
	* Satisfaction
	* --------------------
	foreach x in h1a h1b h1c h1d h1e h1f h1g {
	gen `x'_ = 1 if `x'==1
	replace `x'_ = 0 if inlist(`x',2,3)
	}
	gen h2_ = 1 if inlist(h2,1,2)
	replace h2_ = 0 if inlist(h2,3,4,5)
	lab var h1a_ "Patient satisfaction with discussing condition with HCW"
	lab var h1b_ "Patient satisfaction with explanations about treatment"
	lab var h1c_ "Patient satisfaction with quality of exam and treatment"
	lab var h1d_ "Patient satisfaction with availability of medicines/methods"
	lab var h1e_ "Patient satisfaction with cleanliness of HF"
	lab var h1f_ "Patient satisfaction with how staff treated you"
	lab var h1g_ "Patient satisfaction with waiting time"
	lab var h2_ "Overall patient satisfaction with HF"	
	
	* Reasons for choosing this HF
	* ------------------------------ // TO-DO: move relabels to cleaning dofiles
	lab var f3_1 "Better services"
	lab var f3_2 "Wider variety of services"
	lab var f3_3 "Higher quality"
	lab var f3_4 "Shorter waiting time"
	lab var f3_5 "Shorter distance"
	lab var f3_6 "Cheaper"
	lab var f3_7 "My insurance is accepted here"
	lab var f3_8 "Better staff"
	lab var f3_11 "Better results"
	lab var f3_12 "I always come to this health facility"
	lab var f3_13 "The facility I usually go to was closed"
	lab var f3_14 "Recommended by someone"
	lab var f3_15 "Trying this facility for the first time"
	lab var f3_16 "Better availability of essential medicines"
	
	* Waiting time 
	* -------------------- 
	lab var g1a "Minutes waiting before examination"
	lab var g1b "Minutes spend with HCW in examination"
	lab var g2a "Minutes waiting before laboratory"
	lab var g3a "Minutes waiting before pharmacy"
	egen mins_waiting = rowtotal(g1a g2a g3a)
	lab var mins_waiting "Minutes waiting in exam, lab, and pharmacy"
	
	* Other
	* -------------------- 
	gen years = 2018-f1 
	lab var years "Years since started coming to this HF"
	gen travel = 1 if inlist(e2,3,4)
	replace travel = 0 if inlist(e2,1,2)
	lab var travel "Traveled more than 4km to reach HF"
	gen alt = f2 if f2<50
	lab var alt "Number of other HFs could have gone for this condition"	
	
********************************************************************************
** Part 3: Export 
********************************************************************************
save "$pe_quality", replace
	
								
							
