/*******************************************************************************	

Project:  		KePSIE
Created on:  	October 24, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************			

THIS DO FILE: 	 It selects different samples under different assumption (scenarios) to then construct the dataset decomposition_data by running the dofile decomposition_construction which can then be used for the final analysis. 

CONTENT:		Part 0 - Create globals for directories and files 
                Part 1: Flagging the different facilities with which there are issues to then change in the simulation
				Part 2: Running the construction do file on the selected sample 
						S1 Basic scenario : Dropping markets when more than 30% of the outpatients (from the listing) come from facilities that have missings at baseline or endline
						S2 Keeping markets which do not have facilities at baseline and endline and dropping facilities which have some missing because of consent issues
						S3 Imputation with average
						S4 Best Scenario (see S2 for the origin of the values: facilities which gave higher number of entry, within between cross and exit
						S5 Worst Scenario
				
				
INPUTS:     	"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"
					
OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000
	
	*Inputs
		global 	inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
	*Output
		global decomposition_data 	"${dt_end_fin}/decomposition_data_${scenario}.dta"
		
	*Dofiles to run
		global decomposition_construction 	"${do_end_fin}/decomposition_construction.do"			

	*Programs run in the do file
	local single = 1 // single = 0 when running multiple scenarios, single = 1 to get the final table on a simple scenarios
	if `single' == 1 { 		
		global scenario 			S1
		global decomposition_data 	"${dt_end_fin}/decomposition_data_${scenario}.dta"
		}

	*Options for graphs
	global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid noticks)  legend(region(lc(none) fc(none)))

********************************************************************************
** Part 1: Flagging the different facilities with which there are issues to then change in the simulation
********************************************************************************

use "${inputdata}", clear

*Defining the sample: 
keep if !mi(market_all_expanded) //only keep facilities that are part of a market, meaning they have been randomized
keep if active_bl == 1 | active == 1 //Keeping facilities which are either active at baseline and/or active at endline (66 facilities excluded) as we are looking at changes in baseline versus endline so don't care about facilities that entered and exited in between periods

*Generating dummies for continuing, entering and exiting using enter_exit variable  

gen continuing = (enter_exit == 1)
gen entering   = (enter_exit == 2)
gen exiting    = (enter_exit == 3)

*Markets with at least one active facility at endline and one active facility at baseline
bys market_all_expanded  : egen N_bl_consent = sum(bl_consent)
bys market_all_expanded  : egen N_fl_consent = sum(fl_consent)

*Generating flags for facilities with issues
gen 	issue_mkt_change = 0
replace issue_mkt_change = 1 		if N_fl_consent == 0 |  N_bl_consent== 0 //Facilities which belong to a market that either has no facilities at baseline or no facilities at endline
drop if issue_mkt_change == 1 //Need to drop it here, cannot vary it as market has to exist as we compare entry and exit to average quality at the market level at baseline.  

gen 	issue_exithf_ncons_bl = 0
replace issue_exithf_ncons_bl = 1 	if active != 1 & bl_consent !=1  //Facilities which did not give consent at baseline and were not active at endline

gen 	issue_enterhf_ncons_fl = 0
replace issue_enterhf_ncons_fl = 1 	if active_bl != 1 & fl_consent !=1  //Facilities which were not active at baseline and did not give consent at endline

gen 	issue_hf_ncons_fl = 0
replace issue_hf_ncons_fl = 1 		if  active == 1 & bl_consent ==1 & fl_consent !=1   //Facilities which gave consent at baseline but did not give consent at endline (but active)

gen 	issue_hf_ncons_bl = 0
replace issue_hf_ncons_bl = 1 		if  active_bl == 1 & bl_consent !=1 & fl_consent ==1     //Facilities which did not give consent at baseline (but active) but gave consent at endline 

gen     issue_hf_ncons = 0
replace issue_hf_ncons = 1 			if  active_bl == 1 & bl_consent !=1 & fl_consent !=1  & active == 1   //Facilities which did not give consent at baseline (but active) and no consent at endline (but active)

gen 	issue_mi_outp_bl = 0
replace issue_mi_outp_bl = 1 		if  active_bl == 1 & bl_consent ==1 & mi(outp_as_jan_bl)

bysort market_all_expanded : egen tot_fac 		= sum(active) 
bysort market_all_expanded : egen tot_fac_bl 	= sum(active_bl) 

gen issue_fac 		= issue_enterhf_ncons_fl + issue_hf_ncons_fl + issue_hf_ncons_bl + issue_hf_ncons 
gen issue_fac_bl 	= issue_exithf_ncons_bl + issue_hf_ncons_bl + issue_hf_ncons_fl + issue_hf_ncons + issue_mi_outp_bl


bysort market_all_expanded : egen N_fac_mi 		= sum(issue_fac) 
gen per_fac_mi		= N_fac_mi / tot_fac 							//Percentage of facilities at endline in each market that have an issue and should be dropped impacting the whole market

bysort market_all_expanded : egen N_fac_mi_bl 	= sum(issue_fac_bl) 
gen per_fac_mi_bl     = N_fac_mi_bl / tot_fac_bl 					//Percentage of facilities at baseline in each market that have an issue and should be dropped impacting the whole market

*Assumption here
*Three hfs which belong to issue_exithf_ncons_bl have a missing for level. As the 20 other facilities in the same situation are all level 2, we will impute the missing with level 2
replace level = 2 if mi(level) & issue_exithf_ncons_bl == 1

*Variables for imputations: impute by the mean within similar categories : by level, treatment and ownership
bysort t private level : egen jhic_av 		= mean(jhic_all)
bysort t private level : egen jhic_av_bl 	= mean(jhic_all_bl)
bysort t private level : egen outp_av 		= mean(outp_as_jan)
bysort t private level : egen outp_av_bl 	= mean(outp_as_jan_bl)

********************************************************************************
** Part 2: Running the construction do file on the selected sample
********************************************************************************
*Setting up globals for how to run it

*S1 Basic scenario : Dropping markets when more than 30% of the outpatients (from the listing) come from facilities that have missings observations at baseline or endline
*Market 6 actually does not exist at baseline but does at endline, it was already dropped before 
if (`single' == 0) | (`single' == 1 & "${scenario}" == "S1") {
global scenario 			S1
preserve

* Identiying markets when more than 30% of the outpatients (from the listing) come from facilities that have missings observations at baseline or endlin
bysort market_all_expanded : egen patients_day_m   	= sum(patients_day )
gen patients_day_missing = patients_day if (issue_exithf_ncons_bl == 1 | issue_enterhf_ncons_fl == 1 | issue_hf_ncons_fl == 1 | issue_hf_ncons_bl == 1 | issue_hf_ncons == 1 | issue_mi_outp_bl == 1)

bysort market_all_expanded : egen patients_day_missing_m   	= sum(patients_day_missing ) 
gen per_patients_day_missing = patients_day_missing_m / patients_day_m

tab market_all_expanded  if per_patients_day_missing >= 0.3
*droppping markets when more than 30% of the outpatients (from the listing) come from facilities that have missings observations at baseline or endline. Need to check market 273. 
drop if market_all_expanded ==6 | market_all_expanded == 194 | market_all_expanded == 199 | market_all_expanded == 241 | market_all_expanded == 273 

*droppping facilities that have missings observations at baseline or endline
drop if issue_exithf_ncons_bl == 1 | issue_enterhf_ncons_fl == 1 | issue_hf_ncons_fl == 1 | issue_hf_ncons_bl == 1 | issue_hf_ncons == 1 | issue_mi_outp_bl == 1

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
global reg_${scenario}_1_5_2 = _N /*Using all the facilities in the sample to compute the values at the market level and run the regression*/
do "${decomposition_construction}"
restore
}

*S2 Keeping markets which do not have facilities at baseline and endline and dropping facilities which have some missing because of consent issues
if (`single' == 0) | (`single' == 1 & "${scenario}" == "S2") {
global scenario 			S2
preserve
drop if per_fac_mi_bl > 0 | per_fac_mi > 0
*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
*Analyzing best and worst facilities to impute in later best and worst scenario
*Continuing
gen tot_continuing  = tsum_within + tsum_between + tsum_cross
gen delta_outp 		= outp_as_jan - outp_as_jan_bl
gen delta_jhic_all  = jhic_all - jhic_all_bl
sum tot_continuing if t == 0 & tsum_between != 0
list  outp_as_jan jhic_all outp_as_jan_bl jhic_all_bl delta_outp delta_jhic_all tot_continuing if (tot_continuing <= `r(min)'+0.001 | tot_continuing >= `r(max)'-0.001) & !mi(tot_continuing) & t == 0 & tsum_between != 0
/*

     +------------------------------------------------------------------------------+
     | ou~s_jan   jhic_all   outp_a..   jhi~l_bl   delta_~p   delta_j~l   tot_con~g |
     |------------------------------------------------------------------------------|
	 | 55.13044      25.18   49.09091   53.92489   6.039528   -28.74489   -13.55206 |
	 | 36.47826      49.25   19.90909    35.0788   16.56917     14.1712    14.05609 |
     +------------------------------------------------------------------------------+

*/

sum tot_continuing if t == 1  & tsum_between != 0
list  outp_as_jan jhic_all outp_as_jan_bl jhic_all_bl delta_outp delta_jhic_all tot_continuing if (tot_continuing <= `r(min)'+0.001 | tot_continuing >= `r(max)'-0.001) & !mi(tot_continuing) & t == 1 & tsum_between != 0
/*

     +-------------------------------------------------------------------------------+
     | ou~s_jan   jhic_all   outp_a..   jhi~l_bl   delta_o~p   delta_j~l   tot_con~g |
     |-------------------------------------------------------------------------------|
	 | 35.83871      40.71   53.41935   55.63184   -17.58064   -14.92184   -12.54309 |
	 | 40.78261      56.04   5.727273   36.24445    35.05534    19.79556    14.73641 |
     +-------------------------------------------------------------------------------+

*/


*Entry
sum tsum_entry if t == 0 
list  outp_as_jan jhic_all if (tsum_entry <= `r(min)'+0.001 | tsum_entry >= `r(max)'-0.001) & !mi(tsum_entry) & t == 0

/*
     +---------------------+
     | ou~s_jan   jhic_all |
     |---------------------|
	 | 36.47826      46.51 |
	 |    8.375      18.26 |
     +---------------------+*/
sum tsum_entry if t == 1 
list outp_as_jan jhic_all if (tsum_entry <= `r(min)'+0.001 | tsum_entry >= `r(max)' -0.001) & !mi(tsum_entry) & t == 1
/*
     +---------------------+
     | ou~s_jan   jhic_all |
     |---------------------|
	 | 50.21739      28.54 |
	 | 30.90322      38.77 |
     +---------------------+
*/

*Exit
sum tsum_exit if t == 0 
list outp_as_jan_bl jhic_all_bl if (tsum_exit <= `r(min)'+0.001 | tsum_exit >= `r(max)'-0.001) & !mi(tsum_exit) & t == 0
/*
     +---------------------+
     | outp_a..   jhi~l_bl |
     |---------------------|
	 |       10   14.93333 |
	 | 2.592592      43.75 |
     +---------------------+

*/ 
 
sum tsum_exit if t == 1 
list outp_as_jan_bl jhic_all_bl if (tsum_exit <= `r(min)'+0.001 | tsum_exit >= `r(max)'-0.001) & !mi(tsum_exit) & t == 1 
/*
     +---------------------+
     | outp_a..   jhi~l_bl |
     |---------------------|
	 | 21.03704   25.43333 |
	 |       15   29.56944 |
     +---------------------+

*/

restore
}

*S3 Imputation with average
if (`single' == 0) | (`single' == 1 & "${scenario}" == "S3") {
global scenario 			S3
preserve

*Imputation with listing for baseline outpatients first
replace outp_as_jan_bl = patients_day if (issue_mi_outp_bl == 1 | issue_hf_ncons == 1 | issue_hf_ncons_bl | issue_exithf_ncons_bl == 1) & mi(outp_as_jan_bl)

*Imputation with average for similar groups 
replace outp_as_jan_bl  = outp_av_bl if mi(outp_as_jan_bl)  & active_bl == 1 
replace outp_as_jan 	= outp_av    if mi(outp_as_jan) 	& active == 1 
replace jhic_all_bl     = jhic_av_bl if mi(jhic_all_bl)   	& active_bl == 1 
replace jhic_all 		= jhic_av   if mi(jhic_all) 		& active == 1 

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
restore
}

*S4 Best Scenario (see S2 for the origin of the values: facilities which gave higher number of entry, within between cross and exit
if (`single' == 0) | (`single' == 1 & "${scenario}" == "S4") {
global scenario 			S4
preserve

*Continuing facilities
*No data either at baseline or endline
replace outp_as_jan 	=  36.47826     if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		=  49.25  		 if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  =  19.90909  	 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	=  35.0788 	 if t == 0 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

replace outp_as_jan 	= 40.78261   if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		= 56.04   	  if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  = 5.727273   if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	= 36.24445   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

*Data at baseline only
replace outp_as_jan 	=  outp_as_jan_bl 	+ 16.56917	if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl 	+ 14.1712	if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1
replace outp_as_jan 	=  outp_as_jan_bl  + 35.05534 	if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl  	+ 19.79556	if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1

*Data at endline only
replace outp_as_jan_bl  =  outp_as_jan - 16.56917 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all  - 14.1712    if t == 0 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace outp_as_jan_bl  =  outp_as_jan - 35.05534 if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all  - 19.79556   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1 |issue_mi_outp_bl == 1)


*Entering facilities
replace outp_as_jan = 36.47826  if t == 0 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 46.51 	 if t == 0 & mi(jhic_all)    & entering == 1

replace outp_as_jan = 30.90322  if t == 1 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 38.77 	 if t == 1 & mi(jhic_all)    & entering == 1

*Exiting facilities 
replace outp_as_jan_bl  = 10  			 if t == 0 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 14.93333 	 if t == 0 & mi(jhic_all_bl)    & exiting == 1

replace outp_as_jan_bl  = 21.03704  	 if t == 1 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 25.43333 	 if t == 1 & mi(jhic_all_bl)    & exiting == 1


*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
restore
}


*S5 Worst Scenario
if (`single' == 0) | (`single' == 1 & "${scenario}" == "S5") {
global scenario 			S5
preserve

*No data either at baseline or endline
replace outp_as_jan 	=  55.13044    if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		=  25.18  		 if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  =  49.09091  	 if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	=  53.92489 	 if t == 0 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

replace outp_as_jan 	= 35.83871   if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all 		= 40.71   	  if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons == 1
replace outp_as_jan_bl  = 53.41935   if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & issue_hf_ncons == 1
replace jhic_all_bl 	= 55.63184   if t == 1 & mi(jhic_all_bl)    & continuing == 1 & issue_hf_ncons == 1

*Data at baseline only
replace outp_as_jan 	=  outp_as_jan_bl 	+ 6.039528	if t == 0 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl 	- 28.74489	if t == 0 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1
replace outp_as_jan 	=  outp_as_jan_bl  - 17.58064 	if t == 1 & mi(outp_as_jan) & continuing == 1 & issue_hf_ncons_fl == 1
replace jhic_all 		=  jhic_all_bl  	- 14.92184	if t == 1 & mi(jhic_all)    & continuing == 1 & issue_hf_ncons_fl == 1

*Data at endline only
replace outp_as_jan_bl  =  outp_as_jan - 6.039528 		if t == 0 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all    + 28.74489    	if t == 0 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace outp_as_jan_bl  =  outp_as_jan + 17.58064 		if t == 1 & mi(outp_as_jan_bl) & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)
replace jhic_all_bl 	=  jhic_all    + 14.92184   	if t == 1 & mi(jhic_all_bl)    & continuing == 1 & (issue_hf_ncons_bl == 1|issue_mi_outp_bl == 1)

*Entering facilities
replace outp_as_jan = 8.375   	 if t == 0 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 18.26 	 if t == 0 & mi(jhic_all)    & entering == 1

replace outp_as_jan = 50.21739  if t == 1 & mi(outp_as_jan) & entering == 1
replace jhic_all 	= 28.54 	 if t == 1 & mi(jhic_all)    & entering == 1

*Exiting facilities 
replace outp_as_jan_bl  = 2.592592  	 if t == 0 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 43.75  		 if t == 0 & mi(jhic_all_bl)    & exiting == 1

replace outp_as_jan_bl  = 15  			 if t == 1 & mi(outp_as_jan_bl) & exiting == 1
replace jhic_all_bl 	= 29.56944 	 if t == 1 & mi(jhic_all_bl)    & exiting == 1

*Checking there are no missings for outpatients or jhic score
assert !mi(outp_as_jan) 	if active 	 == 1
assert !mi(outp_as_jan_bl)  if active_bl == 1
assert !mi(jhic_all) 		if active    == 1
assert !mi(jhic_all_bl)     if active_bl == 1
*Adding number of markets and HFs
count if !mi(outp_as_jan) 
global reg_${scenario}_1_5_2 = _N

do "${decomposition_construction}"
restore
}

******************************End of do file*********************************
