/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare month of first market inspection and endline survey variables for fadeout analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Construct month of first market inspection
			Part 2: Construct market-level endline survey variables
			Part 3: Export 
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  	Lupe Bedoya (gbedoya@worldbank.org) / Dec 2022	
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo inspect		"${dt_mast}/inspections.dta"
	glo insp_v		"${dt_mast}/inspections_visits.dta"
	glo qps2		"${dt_end_clean}/qps2_end.dta"
	glo qps2_bl		"${dt_bl_clean}/qps2_bl.dta"
	
	* Output 
	glo insp 		"${dt_end_fin}/inspections_fadeout.dta"
		
********************************************************************************
** Part 1: Construct month of first market inspection
********************************************************************************
	
	* Date of facility- and market-level inspections 
	use "${inspect}", clear
	keep if m_insp_num!=. // keep only completed inspections
	ren _hfid hfid	
	bys hfid f_wave_num: egen max_insp_wave=max(m_insp_num)
	bys hfid: egen max_insp_num=max(m_insp_num) 
	sort p_market_id date1 // ** date1 NO LABEL
	bys p_market_id: egen date_first_insp = min(date1) // Date of first market inspection
	format date_first_insp %td
	bys hfid: egen date_i = min(date1) // Date of first facility inspection 
	format date_i %td  
	bys hfid: egen date_i_l = max(date1) // Date of last facility inspection 
	format date_i_l %td 
	bys hfid: gen counter_hf = _n
	keep if counter_hf == 1
	keep hfid max_insp_num date_*
	tempfile i
	save `i'

	* Dummy variables for month of first market inspection
	use "${pro}", clear
	merge 1:1 hfid using `i', keep(1 3) nogen 
	bys market_all_expanded: egen date_first_insp_m = min(date_first_insp) // expand to sample
	format date_first_insp_m %td
	loc i date_first_insp_m
	gen ti1_m = 1 if `i'>td(15nov2016) & `i'<=td(15dec2016)
	gen ti2_m = 1 if `i'>td(15dec2016) & `i'<=td(15jan2017)
	gen ti3_m = 1 if `i'>td(15jan2017) & `i'<=td(15feb2017)
	gen ti4_m = 1 if `i'>td(15feb2017) & `i'<=td(15mar2017)
	gen ti5_m = 1 if `i'>td(15mar2017) & `i'<=td(15apr2017)
	gen ti6_m = 1 if `i'>td(15apr2017) & `i'<=td(15may2017)
	gen ti7_m = 1 if `i'>td(15may2017) & `i'<=td(15jun2017)
	gen ti8_m = 1 if `i'>td(15jun2017) & `i'<=td(15jul2017)
	gen ti9_m = 1 if `i'>td(15jul2017) & `i'<=td(15aug2017)
	gen ti10_m = 1 if `i'>td(15aug2017) & `i'<=td(15sep2017)
	gen ti11_m = 1 if `i'>td(15sep2017) & `i'<=td(15oct2017)
	gen ti12_m = 1 if `i'>td(15oct2017) & `i'<=td(15nov2017)
	gen ti13_m = 1 if `i'>td(15nov2017) & `i'<=td(15dec2017)
	gen ti1_2_m = 1 if `i'>td(15nov2016) & `i'<=td(15jan2017)
	gen ti8plus_m = 1 if `i'>td(15jun2017) & `i'<=td(15dec2017)
	foreach x in 1 2 3 4 5 6 7 8 9 10 11 12 13 1_2 8plus {
	replace ti`x'_m = 0 if mi(ti`x'_m) & t!=.
	lab var ti`x'_m "First Market Inspection in Month `x'"
	}
	gen ti_m = 1 if ti1_m == 1
	foreach x in 2 3 4 5 6 7 8 9 10 11 12 13 {
	replace ti_m = `x' if ti`x'_m == 1	
	}
	lab var ti_m "First Market Inspection by Month"
	
	* Grouped vars
	recode ti_m (1/2=3) (9/13=8), gen(ti_group_m) // Group into 6 periods: group months 1-3 and 8+
	foreach x in ti_m ti_group_m {
	replace `x' = 0 if mi(`x') & t!=.
	}	
	recode ti_group_m (6/8=1) (0/5=0), gen(ti_group_month4to6_m) // Dummy for last 3 periods.  *** RECALL WE HAVE GROUPS NOT PERIODS ANYMORE
	recode ti_group_m (3/5=1) (0/2 6/8=0), gen(ti_group_month1to3_m) // Dummy for first 3 periods	

	* # of all inspection visits
	clonevar inspections=max_insp_num 
	replace inspections = 0 if mi(inspections) & t!=.
	gen inspections2 = inspections*inspections
	gen inspections2_t = inspections2*t
	
********************************************************************************
** Part 3: Construct facility- and market-level endline survey variables
********************************************************************************
	* Import baseline and endline survey dates
	merge 1:1 hfid using "${qps2_bl}", keepus(date) keep(1 3) nogen
	ren date date_bl
	merge 1:1 hfid using "${qps2}", keepus(date) keep(1 3) nogen
	ren date date_end
	
	* Date of first endline survey at the market level	
	* ------------------------------------------------
	sort market_all_expanded date_end
	by market_all_expanded: gen counter_date_m = _n if date_end!=.
	gen date_e_m = date_end if counter_date_m==1
	format date_e_m %td
	preserve
	collapse (mean) date_e_m, by(market_all_expanded)
	ren date_e_m date_e_m_m
	tempfile end
	save `end'
	restore
	merge m:1 market_all_expanded using `end', nogen	
	
	* First Market Endline Survey by Month
	* ------------------------------------------------
	loc i date_e_m_m
	loc dm 30.5 // days per month
	loc es 06mar2018 // start date of endline
	loc bs 31mar2015 // start date of baseline
	gen te_m = 1 if 	`i'>=td(01mar2018) & `i'<td(01apr2018)
	replace te_m = 2 if `i'>=td(01apr2018) & `i'<td(01may2018)
	replace te_m = 3 if `i'>=td(01may2018) & `i'<td(01jun2018)
	replace te_m = 4 if `i'>=td(01jun2018) & `i'<td(01jul2018)
	replace te_m = 5 if `i'>=td(01jul2018) & `i'<td(01aug2018)
	replace te_m = 6 if `i'>=td(01aug2018) & `i'<td(01sep2018)
	replace te_m = . if fl_consent==.
	* Time between start of endline and endline survey
	gen date_end_start = td(`es')
	format date_end_start %td
	gen time_collect_mo = (date_end - date_end_start) / `dm'
	replace time_collect_mo = round(time_collect_mo,1)+1 // start with month 1, not month 0
	* Generate time from last inspection to date of endline survey
	gen time_i_last_mo = (date_end - date_i_l) / `dm'
	replace time_i_last_mo = round(time_i_last_mo,1)+1 
	gen time_i_first_mo = (date_end - date_i) / `dm'
	replace time_i_first_mo = round(time_i_first_mo,1)+1
	* Time between start of baseline and baseline survey
	gen date_bl_start = td(`bs')
	format date_bl_start %td
	gen time_collect_mo_bl = (date_bl - date_bl_start) / `dm'
	replace time_collect_mo_bl = round(time_collect_mo_bl,1)+1
	
	* Grouped vars
	* ----------------
	recode time_collect_mo (5=4) (6=4), gen(time_collect_group_mo) // Group into 4 main months
	recode time_collect_mo_bl (9=6), gen(time_collect_group_mo_bl) // Group into 6 main months
	recode time_collect_group_mo_bl (1/3=0) (4/6=1), gen(time_collect_month4to6_bl) 
	recode time_collect_group_mo_bl (1/3=1) (4/6=0), gen(time_collect_month1to3_bl)
	recode time_collect_group_mo (1/2=0) (3/4=1), gen(time_collect_month3to4)
	recode time_collect_group_mo (1/2=1) (3/4=0), gen(time_collect_month1to2)
	tab time_collect_group_mo, gen(time_collect_month_)  
	* Month of endline survey interaction with month first market inspection
	foreach x in time_collect_month_1 time_collect_month_2 time_collect_month_3 time_collect_month_4 time_collect_month1to2 {
	gen `x'_t1 = `x'*ti_group_month1to3_m
	gen `x'_t2 = `x'*ti_group_month4to6_m
	}
	
********************************************************************************
** Part 4: Export  
********************************************************************************
	* Labels
	lab var ti_group_m "First Market Inspection by Month (Grouped)"
	lab var date_bl "Date of baseline survey"	
	lab var date_end "Date of endline survey"	
	lab var date_e_m_m "Date of first endline survey at the market level"	
	lab var te_m "First Market Endline Survey by Month"
	lab var date_end_start "Start date of endline survey"
	lab var ti_group_month4to6_m "First Inspection by Month (Market) for Last 3 Months" // * rename to be consistent with groups rather than months. Same below 
	lab var ti_group_month1to3_m "First Inspection by Month (Market) for First 3 Months"	
	lab var time_collect_mo "Time between start of endline and endline survey (Months)"
	lab var time_i_last_mo "Time between last inspection and endline survey (Months)"				
	lab var time_i_first_mo "Time between first inspection and endline survey (Months)"		
	lab var time_collect_mo_bl "Time between start of baseline and baseline survey (Months)"
	lab var time_collect_group_mo "Time between start of endline and endline survey (Months) Grouped"		
	lab var time_collect_group_mo_bl "Time between start of baseline and baseline survey (Months) Grouped"		
	lab var time_collect_month4to6_bl "Time between start of baseline and baseline survey is in last 3 months"
	lab var time_collect_month1to3_bl "Time between start of baseline and baseline survey is in first 3 months"
	lab var time_collect_month3to4 "Time between start of endline and endline survey is in last 2 months"
	lab var time_collect_month1to2 "Time between start of endline and endline survey is in first 2 months"
	lab var inspections "Total Inspections (incl full, license checks, and dept-only)"
	lab var inspections2 "Total Inspections^2"
	* Interactions
	foreach x in time_collect_month1to3_bl time_collect_month4to6_bl time_collect_month3to4 time_collect_month1to2 ti_group_month4to6_m ti_group_month1to3_m time_collect_mo time_i_first_mo time_collect_mo_bl {
	gen `x'_t=`x'*t
	loc label : var label `x'
	lab var `x'_t "`label' x T"
	}
	* Save
	save "$insp", replace		

						
							
