/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare IPC sampling weights for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Construct outpatient-based sampling weights for adherence indicators
			Part 2: Construct observation site-based sampling weights for supplies indicators
			Part 3: Construct clinical staff-based sampling weights for knowledge indicators
			Part 4: Export 
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input 
	glo pro			"${dt_mast}/profile_end.dta"
	glo qps1 		"${dt_end_clean}/qps1_end.dta"
	glo qps1_bl		"${dt_bl_clean}/qps1_bl.dta"	
	glo roster_bl 	"${dt_bl_clean}/qps1_roster_bl.dta"
	glo helper_bl 	"${dt_bl_clean}/qps1_helper_bl.dta"
	glo ipc_adh		"${dt_end_clean}/pps_do_adh_end.dta"	
	glo ipc_know	"${dt_end_clean}/pps_hcw_adh_end.dta"
	glo ipc_sup		"${dt_end_clean}/pps_so_adh_end.dta"
	glo outp 		"${dt_end_fin}/outpatients_for_analysis.dta"
	glo staff 		"${dt_end_fin}/staff_for_analysis.dta"
	
	* Output 
	glo adh4a 		"${dt_end_fin}/ipc_adherence.dta"
	glo sup4a 		"${dt_end_fin}/ipc_supplies.dta"
	glo sup4a_ind 	"${dt_end_fin}/ipc_supplies_ind.dta"
	glo know4a 		"${dt_end_fin}/ipc_knowledge.dta"
	glo know4a_ind 	"${dt_end_fin}/ipc_knowledge_ind.dta"
				
********************************************************************************
** Part 1: Outpatient-based sampling weights for adherence indicators
********************************************************************************	
	use "${ipc_adh}", clear
	merge m:1 hfid using "${pro}", keep(1 3) nogen
	merge m:1 hfid using "${outp}", keep(1 3) keepus(weight weight_bl) nogen
	* Number of unique patients
	by hfid patientid, sort: gen counter_hf_p =_n
	preserve
	keep if counter_hf_p == 1
	collapse (count) patientid, by(hfid)
	ren patientid do_p
	lab var do_p "Number of DO Patients per Facility"
	tempfile pps_do_np
	save `pps_do_np'
	restore
	merge m:1 hfid using `pps_do_np', nogen
	* Number of indications
	by hfid patientid, sort: egen do_p_i = max(counter_hf_p)
	* Indication weights using HF-level outpatient data
	by market_all_expanded, sort: gen counter_adh=_n
	lab var counter_adh "Counter by market"
	by market_all_expanded, sort: egen adherence_m=mean(adherence)
	lab var adherence_m "Compliance with IPC Practices (Market)"
	gen weight_do_p =  weight / do_p
	lab var weight_do_p "HF Patient Indication Sampling Weight - Outpatient-based"
	gen weight_do = weight_do_p / do_p_i
	sort market_all_expanded hfid patientid counter_hf_p
	lab var adherence "Compliance with IPC Practices (HCW)"
	tempfile adh4a 
	save `adh4a'
	
********************************************************************************
** Part 2: Observation site-based sampling weights for supplies indicators
********************************************************************************	
	use "${ipc_sup}", clear
	merge m:1 hfid using "${pro}", keep(1 3) nogen
	merge m:1 hfid using "${outp}", keep(1 3) keepus(weight weight_bl) nogen
	preserve
	use "${qps1}", clear
	gen sites = c3
	replace sites = sites + 1 if c5==1
	replace sites = sites + 1 if c6==1
	lab var sites "Number of Sites per HF"	
	tempfile sw
	save `sw'	
	restore
	merge m:1 hfid using `sw', keepus(sites) keep(1 3) nogen
	gen weight_site = sites
	lab var weight_site "HF Weights - Observation site-based" 
	by market_all_expanded, sort: egen weight_site_m=total(sites)
	lab var weight_site_m "Market Weights - Observation site-based" 
	preserve
	use "${qps1_bl}", clear
	gen sites_bl = c3
	replace sites_bl = sites_bl + 1 if c5==1
	replace sites_bl = sites_bl + 1 if c6==1
	lab var sites_bl "Number of Sites per HF at Baseline"	
	tempfile sw_bl
	save `sw_bl'
	restore
	merge m:1 hfid using `sw_bl', keepus(sites_bl) keep(1 3) nogen
	gen weight_site_bl = sites_bl
	lab var weight_site_bl "HF Weights - Observation site-based" 
	by market_all_expanded, sort: egen weight_site_bl_m=total(sites_bl)
	lab var weight_site_bl_m "Market Weights - Observation site-based"	
	* Site weights using HF-level site data
	by hfid, sort: gen counter_site = _n
	by hfid, sort: egen so = max(counter_site)
	gen weight_so = weight_site / so
	lab var weight_so "HF Site Sampling Weight - Observation site-based"
	sort market_all_expanded hfid so counter_site 
	tempfile sup4a
	save `sup4a'
	* Indicaton-level dataset
	clonevar i1 = so_hh_notstr
	clonevar i2 = so_gloves
	clonevar i3 = so_syringe
	clonevar i4 = so_needle
	clonevar i5 = so_disinfectant
	clonevar i6 = so_sharp
	clonevar i7 = so_waste_notstr	
	egen siteid = concat(hfid site)
	duplicates drop siteid, force
	keep hfid site siteid i?
	reshape long i, i(siteid) j(indicator)
	ren i supplies
	keep indicator hfid site supplies siteid
	ren supplies ipc_supplies_all
	tempfile sup4a_ind
	save `sup4a_ind'
		
********************************************************************************
** Part 3: Clinical staff-based sampling weights for knowledge indicators
********************************************************************************	
	use "${roster_bl}", clear
	gen staff_total_bl = h2b
	replace staff_total_bl = h2a if mi(staff_total_bl)
	lab var staff_total_bl "Total Staff at Baseline"		
	tempfile r_bl
	save `r_bl'
	use "${helper_bl}", clear
	loc clinical b2a b2b b2c b2d b2e b2f b2g b2h b2i b2j b2k b2l b2m b2n b2o b2p b2q b2r b2s
	gen staff_total_helper = b2_total
	gen staff_total_h_bl = b2_total
	destring staff_total_h_bl, replace
	egen staff_total_c_h_bl = rowtotal(`clinical')
	keep hfid staff_total_h_bl staff_total_c_h_bl 
	tempfile h_bl
	save `h_bl'
	use `r_bl', clear
	merge m:1 hfid using `h_bl', nogen
	preserve
	collapse (sum) h8_1, by(hfid)
	ren h8_1 staff_total_c_bl_m
	tempfile clinical
	save `clinical'
	restore
	merge m:1 hfid using `clinical', nogen
	gen staff_total_c_bl = staff_total_c_bl_m
	replace staff_total_c_bl = staff_total_c_h_bl if staff_total_c_h_bl!=.
	replace staff_total_bl = 1 if staff_total_c_bl==1 & staff_total_bl==0
	gen staff_hback = 1 if h10 == 1
	replace staff_hback = 0 if mi(staff_hback)
	preserve
	collapse (sum) staff_hback, by(hfid)
	ren staff_hback staff_hback_hf
	tempfile clinic
	save `clinic'
	restore
	merge m:1 hfid using `clinic'
	gen staff_hback_per_bl = staff_hback_hf / staff_total_bl
	gen staff_c_per_bl = staff_total_c_bl / staff_total_bl
	keep hfid staff_total_bl staff_total_c_bl staff_hback_hf staff_hback_per_bl staff_c_per_bl
	duplicates drop hfid, force
	tempfile cl
	save `cl'
	use "${pro}", clear
	merge 1:1 hfid using `cl', keep(1 3) nogen
	merge 1:1 hfid using "${outp}", keep(1 3) keepus(weight weight_bl) nogen
	merge 1:1 hfid using "${staff}", keep(1 3) keepus(qual) nogen
	tempfile kw
	save `kw'
	use "${ipc_know}", clear
	merge m:1 hfid using `kw', keep(1 3) 	
	lab var staff_total_c_bl "Total Clinical Staff at Baseline"
	lab var staff_hback_per_bl "Percentage of Staff with Health Background"
	lab var staff_c_per_bl "Percentage of Staff with Clinical Background"
	gen weight_staff_bl = staff_total_c_bl
	lab var weight_staff_bl "HF Weights - Clinical Staff-based at Baseline" 
	by market_all_expanded, sort: egen weight_staff_bl_m=total(staff_total_c_bl)
	lab var weight_staff_bl_m "Market Weights - Clinical Staff-based at Baseline"	
	ren staff_total_c_bl staff_c_bl
	ren staff_hback_hf staff_hback_bl
	lab var staff_hback_bl "Staff with Health Background"
	lab var private "Private"	
	* Staff weights using HF-level staff data
	by hfid, sort: gen counter_hcw = _n
	by hfid, sort: egen hcw = max(counter_hcw)
	gen weight_staff = qual
	lab var weight_staff "HF Weights - Clinical Staff-based" 
	by market_all_expanded, sort: egen weight_staff_m=total(qual)
	lab var weight_staff_m "Market Weights - Clinical Staff-based"	
	gen weight_hcw = weight_staff / hcw
	lab var weight_hcw "HF Staff Sampling Weight - Clinical Staff-based"
	tempfile know4a
	save `know4a'
	* Indication-level dataset
	clonevar i1 = c5_1
	clonevar i2 = c5_2
	clonevar i3 = c5_3
	clonevar i4 = c5_4
	clonevar i5 = c5_5
	clonevar i6 = gloves
	clonevar i7 = gloves_hh_a
	clonevar i8 = gloves_p
	clonevar i10 = gloves_d
	clonevar i11 = ibd_n
	clonevar i12 = ibd_s
	clonevar i13 = thermo
	clonevar i14 = stetho
	clonevar i15 = waste_n
	clonevar i16 = waste_s
	clonevar i17 = waste_lenient	
	egen hfhcw = concat(hfid hcwid)
	duplicates drop hfhcw, force
	keep hfid hcwid hfhcw i? i??
	reshape long i, i(hfhcw) j(indicator)
	ren i knowledge
	keep hfid hcwid indicator knowledge 
	ren knowledge ipc_know_all
	tempfile know4a_ind
	save `know4a_ind'
		
********************************************************************************
** Part 4: Export
********************************************************************************
foreach x in adh4a sup4a sup4a_ind know4a know4a_ind {
	use ``x'', clear
	save "${`x'}", replace	
	}

