/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare JHIC variables for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Combine JHIC scores across baseline, endline, and inspections
			Part 2: Construct compliance categories 
			Part 3: Construct market-level variables
			Part 4: Construct treatment interactions
			Part 5: Construct variables for heterogeneity analysis
			Part 6: Export
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo jhic_b		"${dt_bl_const}/jhic_bl_scores"
	glo jhic_e 		"${dt_end_const}/jhic_end_scores"
	glo outp 		"${dt_end_fin}/outpatients_for_analysis.dta"
	
	* Output 
	glo jhic 		"${dt_end_fin}/jhic_for_analysis.dta"				

********************************************************************************
** Part 1: Combine JHIC scores across baseline, endline, and inspections
********************************************************************************
	*---------------------------------------------------------------*
	* Baseline
	*---------------------------------------------------------------*				
	use "${jhic_b}", clear
	loc scores total_ps risk_* s2_a_ps s3_a_ps s4_a_ps s5_a_ps
	loc mgmt s3a_a_ps s3b_a_ps s3c_a_ps s3d_a_ps 
	keep hfid `scores' `mgmt'
	ren total_ps jhic_all_bl // TO-DO: move renames and labels to cleaning dofile
	ren s2_a_ps jhic_infrastructure_bl
	ren s3_a_ps jhic_management_bl
	ren s4_a_ps jhic_generalipc_bl
	ren s5_a_ps jhic_consultation_bl
	lab var jhic_all_bl "JHIC Score at baseline (% of max)"
	lab var jhic_infrastructure_bl "JHIC Score at Baseline - Consultation (% of max)"
	lab var jhic_management_bl "JHIC Score at Baseline - Management (% of max)"
	lab var jhic_generalipc_bl "JHIC Score at Baseline - General IPC (% of max)"
	lab var jhic_consultation_bl "JHIC Score at Baseline - Infrastructure (% of max)"
	foreach x in jhic_all_bl jhic_consultation_bl jhic_generalipc_bl jhic_management_bl jhic_infrastructure_bl {
	replace `x' = `x'*100
	}
	tempfile scores_b
	save `scores_b'	
			
	*---------------------------------------------------------------*
	* Endline
	*---------------------------------------------------------------*
	use "${jhic_e}", clear
	ren tot_score_ps total_ps
	* Compliance categories
	gen risk_c = 1 if (total_ps<=10.49)
	replace risk_c = 2 if total_ps>=10.50 & total_ps<=40.49 & total_ps != . 
	replace risk_c = 3 if total_ps>=40.50 & total_ps<=60.49 & total_ps !=. 
	replace risk_c = 4 if total_ps>=60.50 & total_ps<=75.49 & total_ps !=. 
	replace risk_c = 5 if total_ps>75.50 & total_ps !=. 
	lab val risk_c risk_c
	glo scores total_ps risk_c s2_ps s3_ps s4_ps s5_ps
	keep hfid $scores // keep only main vars
	ren total_ps jhic_all
	ren s2_ps jhic_infrastructure
	ren s3_ps jhic_management
	ren s4_ps jhic_generalipc
	ren s5_ps jhic_consultation
	tempfile scores_e
	save `scores_e'	

	*---------------------------------------------------------------*
	* Merge
	*---------------------------------------------------------------*
	use "${pro}", clear
	loc keyvars t t* private market_all_expanded s2
	keep hfid `keyvars'
	merge 1:1 hfid using "${outp}", keep(1 3) keepus(weight weight_bl) nogen
	merge 1:1 hfid using `scores_b', keep(1 3) nogen
	merge 1:1 hfid using `scores_e', keep(1 3) nogen
	
********************************************************************************
** Part 2: Construct compliance categories 
********************************************************************************
	* Baseline
	recode risk_c_bl (2=1) (3 4 5 = 0), gen(minimally_c_bl)
	recode risk_c_bl (3=1) (2 4 5 = 0), gen(partially_c_bl)
	recode risk_c_bl (4=1) (2 3 5 = 0), gen(substantially_c_bl)
	recode risk_c_bl (5=1) (2 3 4 = 0), gen(fully_c_bl)
	* Endline
	recode risk_c (2=1) (3 4 5 = 0), gen(minimally_c)
	recode risk_c (3=1) (2 4 5 = 0), gen(partially_c)
	recode risk_c (4=1) (2 3 5 = 0), gen(substantially_c)
	recode risk_c (5=1) (2 3 4 = 0), gen(fully_c)	
	
********************************************************************************
** Part 3: Construct market-level variables
********************************************************************************
	* Unweighted
	glo outcomes jhic_all jhic_infrastructure jhic_management jhic_generalipc jhic_consultation
	glo outcomes_bl minimally_c_bl jhic_all_bl jhic_infrastructure_bl jhic_management_bl jhic_generalipc_bl jhic_consultation_bl 
	glo $outcomes $outcomes_bl
	foreach x of glo outcomes {
	bys market_all_expanded: egen `x'_m=total(`x'), missing
	}
	* Weighted
	foreach x in jhic_all jhic_infrastructure jhic_management jhic_generalipc jhic_consultation {
	preserve 
	collapse (mean) `x' [aweight=weight], by(market_all_expanded)
	local label : var label `x'
	ren `x' `x'_m				
	lab var `x'_m  "`label' - Market"
	tempfile c_`x' 
	save `c_`x''			
	restore
	merge m:1 market_all_expanded using `c_`x'', nogen	
	}
	foreach x in jhic_all_bl jhic_infrastructure_bl jhic_management_bl jhic_generalipc_bl jhic_consultation_bl minimally_c_bl {
	preserve 
	collapse (mean) `x' [aweight=weight_bl], by(market_all_expanded)
	local label : var label `x'
	ren `x' `x'_m	
	lab var `x'_m  "`label' - Market"
	tempfile c_`x' 
	save `c_`x''			
	restore
	merge m:1 market_all_expanded using `c_`x'', nogen	
	}			

********************************************************************************
** Part 4: Construct treatment interactions
********************************************************************************
	foreach x in jhic_all jhic_all_bl minimally_c_bl {
	gen `x'_t = `x'*t
	local label : var label `x'
	lab var `x'_t "`label' x T"
	}
		
********************************************************************************
** Part 5: Construct heterogeneity vars
********************************************************************************
	*1) Mean at market level including the facility
	* Baseline JHIC Mean at Market Level (Doing it unweighted for now) - continuous
	egen jhic_all_bl_m_mean = mean(jhic_all_bl), by(market_all_expanded) 
	* Dummy above / below median
	gen 	jhic_all_bl_m_mean_dummy = 1 if !mi(jhic_all_bl) & jhic_all_bl >= jhic_all_bl_m_mean	
	replace jhic_all_bl_m_mean_dummy = 0 if !mi(jhic_all_bl) & jhic_all_bl <  jhic_all_bl_m_mean	
		
	*2) Tercile at baseline market level including the facility
	* Baseline JHIC Mean at Market Level (Doing it unweighted for now) - continuous
	egen jhic_all_bl_m_tercile1 = pctile(jhic_all_bl), p(33) by(market_all_expanded) 
	egen jhic_all_bl_m_tercile2 = pctile(jhic_all_bl), p(66) by(market_all_expanded) 
	* Dummy for belonging at each tercile
	gen 	jhic_all_bl_m_tercile_dummy1 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_m_tercile_dummy1 = 1 if !mi(jhic_all_bl) & jhic_all_bl <=  jhic_all_bl_m_tercile1	
	
	gen 	jhic_all_bl_m_tercile_dummy2 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_m_tercile_dummy2 = 1 if !mi(jhic_all_bl) & jhic_all_bl >  jhic_all_bl_m_tercile1	& jhic_all_bl <=  jhic_all_bl_m_tercile2 
	
	gen 	jhic_all_bl_m_tercile_dummy3 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_m_tercile_dummy3 = 1 if !mi(jhic_all_bl) & jhic_all_bl >  jhic_all_bl_m_tercile2	

	*2_b) Tercile at baseline accross all facilities including the facility
	* Baseline JHIC Mean at Market Level (Doing it unweighted for now) - continuous
	egen jhic_all_bl_tercile1 = pctile(jhic_all_bl), p(33) 
	egen jhic_all_bl_tercile2 = pctile(jhic_all_bl), p(66) 
	* Dummy for belonging at each tercile
	gen 	jhic_all_bl_tercile_dummy1 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_tercile_dummy1 = 1 if !mi(jhic_all_bl) & jhic_all_bl <=  jhic_all_bl_tercile1	
	
	gen 	jhic_all_bl_tercile_dummy2 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_tercile_dummy2 = 1 if !mi(jhic_all_bl) & jhic_all_bl >  jhic_all_bl_tercile1	& jhic_all_bl <=  jhic_all_bl_tercile2 
	
	gen 	jhic_all_bl_tercile_dummy3 = 0 if !mi(jhic_all_bl) 
	replace jhic_all_bl_tercile_dummy3 = 1 if !mi(jhic_all_bl) & jhic_all_bl >  jhic_all_bl_tercile2	
			
		
	*3) Mean at market level excluding the facility
	bys market_all_expanded (hfid) : gen count = _n 
	gen jhic_all_bl_m_mean_wo_hf = .

	levelsof market_all_expanded
	*Loop on all markets	
	foreach mkt in `r(levels)' {
	count if  market_all_expanded == `mkt'
	local market_`mkt' = r(N)
	*loop on all facilities in a market
	forvalues i = 1 / `market_`mkt'' {
	sum jhic_all_bl if !mi(jhic_all_bl) & market_all_expanded == `mkt' & count != `i' /*Average excluding the facility*/
	replace jhic_all_bl_m_mean_wo_hf = r(mean) if !mi(jhic_all_bl) & market_all_expanded == `mkt' & count == `i'
	}
	}

	* Dummy above / below median
	gen 	jhic_all_bl_m_mean_wo_hf_d = 1 if !mi(jhic_all_bl) & !mi(jhic_all_bl_m_mean_wo_hf)  & jhic_all_bl >= jhic_all_bl_m_mean_wo_hf	
	replace jhic_all_bl_m_mean_wo_hf_d = 0 if !mi(jhic_all_bl) & !mi(jhic_all_bl_m_mean_wo_hf)  & jhic_all_bl <  jhic_all_bl_m_mean_wo_hf	
		
	*4) Missing Indicator method
	*Replacing 0 for the missings at baseline and adding a dummy for the missings
	gen 	jhic_all_bl_missing_d = 0
	replace jhic_all_bl_missing_d = 1 if mi(jhic_all_bl)
	gen 	jhic_all_bl_missing = jhic_all_bl
	replace jhic_all_bl_missing = 0 if mi(jhic_all_bl)
		
	*Label variables
	label var jhic_all_bl_m_mean 			"JHIC market mean score at baseline including facility"
	label var jhic_all_bl_m_mean_dummy 		"Dummy above baseline market mean score  including facility"
	label var jhic_all_bl_m_tercile_dummy1  "Dummy first tercile baseline market  score  including facility"
	label var jhic_all_bl_m_tercile_dummy2	"Dummy second tercile baseline market  score  including facility"
	label var jhic_all_bl_m_tercile_dummy3  "Dummy third tercile baseline market  score  including facility"
	label var jhic_all_bl_tercile_dummy1  	"Dummy first tercile baseline score including facility"
	label var jhic_all_bl_tercile_dummy2	"Dummy second tercile baseline score including facility"
	label var jhic_all_bl_tercile_dummy3  	"Dummy third tercile baseline score including facility"
	label var jhic_all_bl_m_mean_wo_hf	 	"JHIC market mean score at baseline excluding facility"
	label var jhic_all_bl_m_mean_wo_hf_d 	"Dummy above baseline market mean score  excluding facility"
	label var jhic_all_bl_missing_d		"Dummy for facilites with missing baseline score"
	label var jhic_all_bl_missing	    	"JHIC baseline score with missings imputed as 0"

	*Interaction	
	foreach var in jhic_all_bl_m_mean jhic_all_bl_m_mean_dummy jhic_all_bl_m_tercile_dummy1 jhic_all_bl_m_tercile_dummy2 jhic_all_bl_m_tercile_dummy3 jhic_all_bl_tercile_dummy1 jhic_all_bl_tercile_dummy2 jhic_all_bl_tercile_dummy3  jhic_all_bl_m_mean_wo_hf jhic_all_bl_m_mean_wo_hf_d jhic_all_bl_missing_d jhic_all_bl_missing {
	gen `var'_t = `var' * t
	}	
	*Adding one extra variable with market size at baseline (not randomization) based as the existence of JHIC score at baseline
	gen one = 1 if !mi(jhic_all_bl)
	bys market_all_expanded : egen marketsize_baseline = sum(one)	
	label var marketsize_baseline "Market size at baseline (not randomization) based as the existence of JHIC score at baseline"

	*---------------------------------------------------------------*
	* JHIC quintiles by treatment status
	*---------------------------------------------------------------*			
	xtile jhic_all_c_q = jhic_all if t==0, nq(5)
	xtile jhic_all_t_q = jhic_all if t==1, nq(5)
	lab var jhic_all_c_q "JHIC Quintiles for Control Group"
	lab var jhic_all_t_q "JHIC Quintiles for Treatment Groups"

	xtile jhic_all_bl_c_q_pri = jhic_all_bl if t==0 & private==1, nq(5)
	xtile jhic_all_bl_t_q_pri = jhic_all_bl if t==1 & private==1, nq(5)
	lab var jhic_all_bl_c_q_pri "Quintiles for JHIC at Basline for Control Group (Private HFs)"
	lab var jhic_all_bl_t_q_pri "Quintiles for JHIC at Baseline for Treatment Groups (Private HFs)"	
	
	*---------------------------------------------------------------*
	* JHIC interactions (>=40% of max score)
	*---------------------------------------------------------------*		
	* 40 plus			
	gen jhic_all_bl_40plus = 1 if jhic_all_bl>=40 
	replace jhic_all_bl_40plus = 0 if jhic_all_bl<40 
	replace jhic_all_bl_40plus = . if jhic_all_bl==.
	replace jhic_all_bl_40plus = 0 if jhic_all_bl_missing_d==1 // include if running with dummy
	gen jhic_all_bl_40plus_t=jhic_all_bl_40plus*t
	
	*---------------------------------------------------------------*
	* JHIC management Quantiles
	*---------------------------------------------------------------*		
	* histogram jhic_management_bl, by(private)
	foreach x in jhic_management_bl {
	xtile `x'_q = `x' if private==0, nq(4)
	replace `x'_q = . if `x'==.
	gen `x'_q1 = 1 if `x'_q==1
	replace `x'_q1 = 0 if `x'_q1==. & !mi(`x'_q) & private==0
	gen `x'_q2 = 1 if `x'_q==2
	replace `x'_q2 = 0 if `x'_q2==. & !mi(`x'_q) & private==0
	gen `x'_q3 = 1 if `x'_q==3
	replace `x'_q3 = 0 if `x'_q3==. & !mi(`x'_q) & private==0
	gen `x'_q4 = 1 if `x'_q==4
	replace `x'_q4 = 0 if `x'_q4==. & !mi(`x'_q) & private==0
	foreach x in `x'_q1 `x'_q2 `x'_q3 `x'_q4 {
	gen `x'_t = `x'*t
	}
	}
	lab var jhic_management_bl_q "Quantiles for JHIC Management Section at Baseline (Public HFs)"	
	
	merge 1:1 hfid using "${outp}", keepus(outp_as_jan weight_bl weight_bl_m) nogen	
	
	* market weighted means
	gen weight_bl_m_prop = weight_bl/weight_bl_m	
	
	* JHIC market mean (weighted)
	gen jhic_all_bl_m_w_in = jhic_all_bl*weight_bl_m_prop
	bys market_all_expanded: egen jhic_all_bl_m_w = sum(jhic_all_bl_m_w_in)
	
	*Missing Indicator method
	foreach x in jhic_all_bl_m jhic_all_bl_m_w {
		gen 	`x'_mi_d 	= 0
		replace `x'_mi_d 	= 1 if mi(`x')
		gen 	`x'_mi 		= `x'
		replace `x'_mi 		= 0 if mi(`x')
		}	

	keep hfid jhic_* risk_* minimally_* s3a_a_ps s3b_a_ps s3c_a_ps s3d_a_ps
	
********************************************************************************
** Part 6: Export
********************************************************************************				
save "${jhic}", replace	


	
	
	
	
	
	
