/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare market density and other market type variables for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Construct market size variables for analysis (e.g., singletons)
			Part 2: Construct market characteristics variables (e.g., number of other public HFs in market)
			Part 3: Construct market distance to main towns and economic markets
			Part 4: Export 
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo emarkets 	"${dt_mast}/markets.dta" 
	glo jhic 		"${dt_end_fin}/jhic_for_analysis.dta"
	
	* Output 
	glo market 		"${dt_end_fin}/markets_density.dta"				

********************************************************************************
** Part 1: Construct market size variables for analysis
********************************************************************************
use "${pro}", clear
loc pro hfid marketsize* t s0 s1 s2 county private level_* market_all market_all_expanded latitude longitude
keep `pro' 
merge 1:1 hfid using "${jhic}", keepus(jhic_all_bl minimally_c_bl) nogen

	* Density
	*------------------------
	gen dense_mkt = 0 if marketsize_rand_expanded_group == 1 | marketsize_rand_expanded_group == 2
	replace dense_mkt = 1 if marketsize_rand_expanded_group == 3 | marketsize_rand_expanded_group == 4 | marketsize_rand_expanded_group == 5
	gen dense_mkt_t = dense_mkt*t
	gen density_market = 0 if marketsize_rand_expanded_group == 1 | marketsize_rand_expanded_group == 2
	replace density_market = 1 if marketsize_rand_expanded_group == 3 | marketsize_rand_expanded_group == 4 | marketsize_rand_expanded_group == 5
	gen density_market_t=density_market*t
	gen density_market_private_t=density_market*private*t
	* Market size dummies
	gen ms1 = 1 if marketsize_rand_expanded ==1
	replace ms1 = 0 if mi(ms1) & marketsize_rand_expanded!=.
	gen ms2 = 1 if marketsize_rand_expanded ==2 | marketsize_rand_expanded ==3
	replace ms2 = 0 if mi(ms2) & marketsize_rand_expanded!=.
	gen ms2o = 1 if marketsize_rand_expanded ==2 
	replace ms2o = 0 if mi(ms2o) & marketsize_rand_expanded!=.
	gen ms3o = 1 if marketsize_rand_expanded ==3
	replace ms3o = 0 if mi(ms3o) & marketsize_rand_expanded!=.
	gen ms3 = 1 if marketsize_rand_expanded >=4 & marketsize_rand_expanded <=10
	replace ms3 = 0 if mi(ms3) & marketsize_rand_expanded!=.
	gen ms4 = 1 if marketsize_rand_expanded >=11 & marketsize_rand_expanded!=.
	replace ms4 = 0 if mi(ms4) & marketsize_rand_expanded!=.
	gen ms3to10 = 1 if marketsize_rand_expanded >=3 & marketsize_rand_expanded<=10
	replace ms3to10 = 0 if mi(ms3to10) & marketsize_rand_expanded!=.
	* Interactions
	foreach x in ms1 ms2 ms3 ms4 {
	gen `x'_t=`x'*t
	local label : var label `x'
	lab var  `x'_t "`label' x T"
	gen `x'_pri_t=`x'*private*t
	lab var  `x'_pri_t "`label' x Private x T"
	}		
	foreach x in density_market ms1 ms2 ms3 ms4 {
	gen `x'_jhicbl_t=`x'*jhic_all_bl*t
	local label : var label `x'
	lab var `x'_jhicbl_t "`label' x JHIC at Baseline x T"
	gen `x'_mcbl_t=`x'*minimally_c_bl*t
	lab var `x'_mcbl_t "`label' x Minimally Compliant at Baseline x T"
	}			
	* Singleton market - dummy var
	*---------------------------------
	gen singleton_s0 = 1 if marketsize == 1	
	replace singleton_s0 = 0 if marketsize != 1 & marketsize != . 
	gen singleton_s2 = 1 if marketsize_expanded == 1
	replace singleton_s2 = 0 if marketsize_expanded != 1 & marketsize_expanded != . 
	
********************************************************************************
** Part 2: Construct market size variables for analysis
********************************************************************************	
	* Public market - dummy var
	*---------------------------------
	bys market_all : egen private_tot_s0 = sum(private)
	replace private_tot_s0 = . if market_all==.
	bys market_all : gen  private_p_s0 = private_tot_s0 / _N
	replace private_p_s0 = . if private_p_s0==.
	gen allpublic_s0 = 1 if private_p_s0 == 0	
	replace allpublic_s0 = 0 if private_p_s0 != 0 & private_p_s0 != .
	gen allprivate_s0 = 1 if private_p_s0 == 1
	replace allprivate_s0 = 0 if private_p_s0 != 1 & private_p_s0 != .
	bys market_all_expanded : egen private_tot_s2 = sum(private)
	replace private_tot_s2 = . if market_all_expanded==.
	bys market_all_expanded : gen  private_p_s2 = private_tot_s2 / _N
	replace private_p_s2 = . if market_all_expanded==.
	gen allpublic_s2 = 1 if private_p_s2 == 0	
	replace allpublic_s2 = 0 if private_p_s2 != 0 & private_p_s2 != .
	gen allprivate_s2 = 1 if private_p_s2 == 1	
	replace allprivate_s2 = 0 if private_p_s2 != 1 & private_p_s2 != .
	
	* All private except 1 public market - dummy var
	*-----------------------------------------------------
	gen public = 1 if private == 0
	replace public = 0 if private == 1
	bys market_all : egen public_tot_s0 = sum(public)
	replace public_tot_s0 = . if market_all==.
	bys market_all_expanded : egen public_tot_s2 = sum(public)
	replace public_tot_s2 = . if market_all_expanded==.	
	gen allprivate_w1pub_s0 = 1 if public_tot_s0 == 1 & marketsize>1 & marketsize!=.	
	replace allprivate_w1pub_s0 = 0 if mi(allprivate_w1pub_s0) & marketsize!=.
	gen allprivate_w1pub_s2 = 1 if public_tot_s2 == 1 & marketsize_expanded>1 & marketsize_expanded!=.	
	replace allprivate_w1pub_s2 = 0 if mi(allprivate_w1pub_s2) & marketsize_expanded!=.				
			
	* Markets with 2 or more public HFs
	*-----------------------------------------
	gen public_2plus_s0 = 1 if public_tot_s0 >=2
	replace public_2plus_s0 = 0 if mi(public_2plus_s0) & marketsize!=.
	gen public_2plus_s2 = 1 if public_tot_s2 >=2
	replace public_2plus_s2 = 0 if mi(public_2plus_s2) & marketsize_expanded!=.
	
	* Number of public/private in market (Continuous)
	*----------------------------------------------------
	* Number of public HFs in market (public HFs only)
	gen opu = 0 if public_tot_s0==1 
	replace opu = 1 if public_tot_s0==2
	replace opu = 2 if public_tot_s0==3
	replace opu = 3 if public_tot_s0==4
	replace opu = 4 if public_tot_s0>4
	replace opu = . if public_tot_s0==. | private==1
	lab def opu 0 "No other public HF in market" 1 "1 other public HF" 2 "2 other public HFs" 3 "3 other public HFs" 4 "4-6 other public HFs", modify
	lab val opu opu
	gen opu_t = opu*t // Interaction
	* Number of private HFs in market (public HFs only)		
	gen op = private_tot_s0 if (public_tot_s0>0 & public_tot_s0!=.)
	replace op = . if private==1
	gen op_t = op*t // Interaction
	* Number of other HFs
	gen other_hfs = marketsize - 1
	replace other_hfs = . if public_tot_s0==. | private==1
	gen other_hfs_t = other_hfs * t
	
	* Total and % level per market
	* -------------------------------
	bys market_all_expanded : egen tot_level_2 = sum(level_2)
	bys market_all_expanded : gen  per_level_2 = tot_level_2 / _N
	bys market_all_expanded : egen tot_level_3 = sum(level_3)
	bys market_all_expanded : gen  per_level_3 = tot_level_3 / _N
	bys market_all_expanded : egen tot_level_4_5 = sum(level_4_5)
	bys market_all_expanded : gen  per_level_4_5 = tot_level_4_5 / _N    
	
********************************************************************************
** Part 2: Construct market distance to main towns and economic markets
********************************************************************************	
	* Distance to HQs
	*----------------------------
	* Set distance from office
	loc latitude_1 0.275583
	loc longitude_1 34.73582
	loc latitude_2 -3.63089
	loc longitude_2 39.85255			
	loc latitude_3 0.056599
	loc longitude_3 37.64142
	
	gen maintown_m = .
	forvalues county = 1/3 { 
	geodist latitude longitude `latitude_`county'' `longitude_`county'', gen(maintown_km`county')
	replace maintown_m = (maintown_km`county' * 1000) if county==`county'
	}	
	gen maintown_km = maintown_km1 if county==1
	replace maintown_km = maintown_km2 if county==2
	replace maintown_km = maintown_km3 if county==3
	lab var maintown_m "Distance from HF to Main Town (meters)"
	lab var maintown_km "Distance from HF to Main Town (km)"
	drop maintown_km?			
	gen maintown_km_group = 1 if maintown_km<10
	replace maintown_km_group = 2 if maintown_km>=10 & maintown_km<=30
	replace maintown_km_group = 3 if maintown_km>=30 & maintown_km<=50
	replace maintown_km_group = 4 if maintown_km>=50 
	lab def maintown_km_group 	1 "< 10 km" ///
								2 "Between 10 and 30 km" ///
								3 "Between 30 and 50 km" ///
								4 "> 50 km", modify
	lab val maintown_km_group maintown_km_group
	tempfile mark
	save `mark'
	
	* Distance to economic markets
	*---------------------------------	
	use "${emarkets}", clear
	keep if !mi(lat)
	ren market market_e
	keep market_e lat lon
	tempfile tocross
	save `tocross'		
	use `mark', clear
	cross using `tocross'
	* Distance
	geodist latitude longitude lat lon, gen(market_e_m) 
	ren market_e_m market_e_km
	gen market_e_m=market_e_km*1000
	sort hfid market_e_m
	by hfid: gen serial=_n
	keep if serial==1
	gen market_e_km_group = 1 if market_e_km<0.5
	replace market_e_km_group = 2 if market_e_km>=0.5 & market_e_km<=2
	replace market_e_km_group = 3 if market_e_km>2 & market_e_km<=5
	replace market_e_km_group = 4 if market_e_km>5 & market_e_km<=10
	replace market_e_km_group = 5 if market_e_km>10
	lab def market_e_km_group 	1 "< 500 meters" ///
						2 "Between 500 meters and 2 km" ///
						3 "Between 2 and 5 km" ///
						4 "Between 5 and 10 km" ///
						5 "> 10 km"
						lab val market_e_km_group market_e_km_group
	
	* Labels
	label var dense_mkt "High Density Market"
	label var dense_mkt_t "High Density Market x T"
	lab var density_market "High Density Market"
	lab var density_market_t "High Density Market x T"
	lab var density_market_private_t "High Density Market x Private x T"
	lab var ms1 "Market Size 1"
	lab var ms2 "Market Size 2-3"
	lab var ms2o "Market Size 2"
	lab var ms3o "Market Size 3"
	lab var ms3 "Market Size 4-10"
	lab var ms4 "Market Size 11+"
	lab var ms3to10 "Market Size 3-10"
	lab var singleton_s0 "Singleton Market at Randomization"
	lab var singleton_s2 "Singleton Market at Endline"
	lab var private_tot_s0 "Number of Private HFs in Market at Randomization"
	lab var private_p_s0 "Percentage of Private HFs per Market at Randomization"
	lab var allpublic_s0 "HF in Market with All Public HFs at Randomization"
	lab var allprivate_s0 "HF in Market with All Private HFs at Randomization"			
	lab var private_tot_s2 "Number of Private HFs in Market at Randomization"
	lab var private_p_s2 "Percentage of Private HFs per Market at Endline"	
	lab var allpublic_s2 "HF in Market with All Public HFs at Endline"	
	lab var allprivate_s2 "HF in Market with All Private HFs at Endline"
	lab var public "=1 if Public"
	lab var public_tot_s0 "Number of Public HFs in Market at Randomization"
	lab var public_tot_s2 "Number of Public HFs in Market at Endline"
	lab var allprivate_w1pub_s0 "HF in Market with Private HF(s) and 1 Public HF at Randomization"
	lab var allprivate_w1pub_s2 "HF in Market with Private HF(s) and 1 Public HF at Endline"
	lab var public_2plus_s0 "HF in Market with 2 or More Public HFs at Randomization"
	lab var public_2plus_s2 "HF in Market with 2 or More Public HFs at Endline"	
	lab var opu "Number of Other Public HFs in Market"
	lab var opu_t "Number of Other Public HFs in Market x T"
	lab var op "Number of Other Private HFs in Market"
	lab var op_t "Number of Other Private HFs in Market x T"
	lab var other_hfs "Number of Other HFs in Market"
	lab var other_hfs_t "Number of Other HFs in Market x T"	
	lab var per_level_2 "Percentage of Level 2 per market"
	lab var per_level_3 "Percentage of Level 3 per market"
	lab var per_level_4_5 "Percentage of Level 4 and 5 per market"
	lab var maintown_km_group "Distance from HF to Main Town (km, grouped)"
	lab var market_e_km "Distance from HF to Nearest Economic Market (kilometers)"
	lab var market_e_m "Distance from HF to Nearest Economic Market (meters)"
	lab var market_e_km_group "Distance from HF to Nearest Economic Market (km, grouped)"
	keep hfid ms1 ms2 ms2o ms3o ms3 ms4 ms3to10 ms?_* density_* singleton_* all* opu opu_t op op_t maintown_km maintown_km_group per_level* market_e_km market_e_km_group public_* other* tot* per*
		
********************************************************************************
** Save
********************************************************************************
save "${market}", replace
			

				
			
			
			
			
			
			
			
			
			
