/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare facility distance variables for spillovers analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Prepare pairwise combination of data to estimate distances
			Part 2: Construct number of T HFs within buffer
			Part 3: Construct number of all HFs within buffer
			Part 4: Export 
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	
	* Output 
	glo sat 		"${dt_end_fin}/markets_saturation.dta"				

********************************************************************************
** Part 1: Prepare pairwise combinations to estimate distances
********************************************************************************
use "${pro}", clear
	loc sample s2
	keep if `sample' == 1
	keep hfid county latitude longitude t market_all_expanded marketcenter
	tempfile c 
	save `c'
	* Number of T HFs
	preserve
	keep if t==1 
	keep hfid county latitude longitude t market_all_expanded marketcenter
	tempfile t
	save `t'
	restore
	* Match
	ren latitude lat 
	ren longitude lon		
	cross using `t'
	
********************************************************************************
** Part 2: Construct number of T HFs within buffer
********************************************************************************	
	geodist lat lon latitude longitude, gen(distance_km) 
	lab var distance_km "Distance (in kilometers) to T HFs"
	forvalues i = 4/6 {
	gen distance_km_`i' = 1 if distance_km <= `i'
	replace distance_km_`i' = 0 if distance_km > `i'
	lab var distance_km_`i' "T HFs <= `i' kms"
	}
	tempfile saturation_all2t
	save `saturation_all2t'
	foreach i in 4 5 6 {
	preserve
	keep if distance_km_`i' == 1 
	sort hfid distance_km
	bysort hfid: gen counter = _n
	lab var counter "HF Counter"
	bysort hfid: egen hfs_km_`i' = max(counter)
	lab var hfs_km_`i' "Number of T HFs within `i' kms"
	keep if counter == 1	
	merge 1:1 hfid using `c', nogen
	replace hfs_km_`i' = 0 if mi(hfs_km_`i')									
	tempfile t_`i'
	save `t_`i''
	restore
	}		
	use `t_4', clear
	tempfile saturation_km2t
	save `saturation_km2t'			
	
********************************************************************************
** Part 3: Construct number of all HFs within buffer
********************************************************************************					
	use `c', clear
	ren latitude lat 
	ren longitude lon		
	cross using `c'
	* Distance 
	geodist latitude longitude lat lon, gen(distance_km_all) 
	lab var distance_km_all "Distance (in kilometers) Between HFs"		
	forvalues i = 4/6 {
	gen distance_km_`i'_all = 1 if distance_km_all <= `i'
	replace distance_km_`i'_all = 0 if distance_km_all > `i'
	}
	tempfile saturation_all2all
	save `saturation_all2all'		
	foreach i in 4 5 6 {
	preserve
	keep if distance_km_`i'_all == 1 
	sort hfid distance_km_all
	bysort hfid: gen counter = _n
	lab var counter "HF Counter"
	bysort hfid: egen hfs_km_`i'_all = max(counter)
	lab var hfs_km_`i'_all "Number of HFs within `i' kms (All HFs)"
	keep if counter == 1	
	merge 1:1 hfid using `c', nogen
	replace hfs_km_`i'_all = 0 if mi(hfs_km_`i'_all)									
	tempfile t_`i'
	save `t_`i''
	restore
	}	
	use `t_4', clear
	foreach x in 4 {
	replace hfs_km_`x'_all = hfs_km_`x'_all - 1
		}								
	tempfile saturation_km2all
	save `saturation_km2all'
	merge 1:1 hfid using `saturation_km2t'
	ren hfs_km_4 hfs_km_4_t
	ren hfs_km_4_all hfs_km_4
	keep hfid hfs_km_4 hfs_km_4_t
							
********************************************************************************
** Part 4: Export
********************************************************************************
save "${sat}", replace	

				
		
			


			
			
			
			
			
			
