/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare license variables for anlaysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Construct unlicensed (with and without expired license) variables
			Part 2: Construct formality and other variables for analysis
			Part 3: Construct market-level variables
			Part 4: Construct variables for heterogeneity analysis
			Part 5: Export 
			
DATE: 		Jan 2020
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input 
	glo pro			"${dt_mast}/profile_end.dta"
	glo licdata 	"${dt_adm}/licenses_all.dta"

	* Output 
	glo licenses 	"${dt_end_fin}/new_licenses_for_analysis.dta"
				
********************************************************************************
** Part 1: Construct unlicensed (with and without expired license) variables
********************************************************************************	
use "${licdata}", clear
merge 1:1 hfid using "${pro}", keep(2 3) nogen keepus(t market_all_expanded s0 s1 s2 private bl_consent fl_consent close* f_everclose inactive activ* startyear startyear_m)
	
	* Private only 
	* -----------------
	* Expired license
	gen expired_s0 = 1 if r2016==1 & l2016!=1
	replace expired_s0 = 1 if !mi(lr2015) & lr2016!=1
	replace expired_s0 = 0 if mi(expired_s0)
	lab var expired_s0 "Expired License"			
	
	* License type
	gen unlicensed_type_s0 = 0 if lr2016==1
	replace unlicensed_type_s0 = 2 if mi(unlicensed_type_s0) & expired_s0==1
	replace unlicensed_type_s0 = 1 if mi(unlicensed_type_s0) 
	lab def utype 0 "License" 1 "No License" 2 "Expired License", modify
	lab val unlicensed_type_s0 utype
	lab var unlicensed_type_s0 "License Status in Admin Data at Randomization (end of 2016)"	
	
	* Unlicensed variables
	recode unlicensed_type_s0 (2=1), gen(unlicensed_s0) // Strict definition: unlicensed (incl. expired license)
	recode unlicensed_type_s0 (2=0), gen(unlicensed_noexp_s0) // Lenient definition: unlicensed (not incl. expired license)
	lab var unlicensed_s0 "Unlicensed (with Expired License) (Private Only)"
	lab var unlicensed_noexp_s0 "Unlicensed (without Expired License) (Private Only)"	
	lab def u 1 "No License or Expired License" 0 "License", modify
	lab def u_noexp	1 "No License" 0 "License or Expired License", modify
	lab val unlicensed_s0 u
	lab val unlicensed_noexp_s0 u_noexp	
	
		* Replace all as missing if private, new (open in 2017 or after) or not in s2
		foreach x in unlicensed_type_s0 expired_s0 unlicensed_s0 unlicensed_noexp_s0 {
		replace `x' = 1 if mi(`x')
		replace `x' = . if private==0 | s0==0
		replace `x' = 1 if mi(`x') & active_s0==1 & private==1 
		}			
	
	* All (private + public)
	* ---------------------------	
	foreach x in unlicensed_s0 unlicensed_noexp_s0 {
	clonevar `x'_all = `x'
	replace `x'_all = 0 if private==0 & active_s0==1
	}
	lab var unlicensed_s0_all "Unlicensed (with Expired License) (All HFs)"
	lab var unlicensed_noexp_s0_all "Unlicensed (without Expired License) (All HFs)"
	
	* Interactions
	* ---------------------------	
	foreach x in unlicensed_s0 unlicensed_noexp_s0 unlicensed_s0_all unlicensed_noexp_s0_all {
	gen `x'_t = `x'*t
	}			
	
	* Checks
	*count if mi(unlicensed_s0) & private==1 & s1==1 & new_end==0 & !mi(t)
	*count if mi(unlicensed_s0_all) & private==1 & s1==1 & new_end==0 & !mi(t)
		
********************************************************************************
** Part 2: Construct formality and other variables for analysis
********************************************************************************	

	* Formality
	clonevar formality = lr2018 // in licensing admin data in 2018
	foreach x in formality {
	replace `x' = 0 if mi(`x')
	replace `x' = . if private==0
	replace `x' = . if active==0
	}		
	lab def formality 1 "License" 0 "No License", modify // Lenient definition: unlicensed (not incl. expired license)
	lab val formality formality
	lab var formality "Formality (Licenses) (Private Only)"	
	
	clonevar formality_all = formality
	replace formality_all = 0 if mi(formality_all) & private==0 
	foreach x in formality_all {
	replace `x' = . if active==0
	}		
	lab val formality_all formality
	lab var formality_all "Formality (Licenses) or Public Gazette (All HFs)"	
	
	* Unlicensed at endline
	recode formality (1=0) (0=1), gen(unlicensed_s2)
	lab var unlicensed_s2 "Unlicensed at Endline (Private Only)"
	lab def unlicensed_s2 0 "License" 1 "No License", modify
	lab val unlicensed_s2 unlicensed_s2

	foreach x in unlicensed_s2 {
	gen `x'_t = `x'*t
	local label : var label `x'
	lab var `x'_t "`label' x T"
	}	
	
	* Last available license status
	gen license_last = lr2018
	replace license_last = lrinsp if mi(license_last)
	replace license_last = lr2017 if mi(license_last)
	replace license_last = lr2016 if mi(license_last)
	lab def license_last 1 "Licensed" 0 "Unlicensed", modify
	lab val license_last license_last
	lab var license_last "Last Available License Status"	

	
********************************************************************************
** Part 3: Construct market-level variables
********************************************************************************
	
	* Number of unlicensed in market
	bys market_all_expanded: egen unlicensed_s0_m = sum(unlicensed_s0)	
	gen unlicensed_s0_m_t = unlicensed_s0_m*t
	lab var unlicensed_s0_m "Number of Unlicensed HFs in Market at Randomization"
	lab var unlicensed_s0_m_t "Number of Unlicensed HFs in Market at Randomization x T"	
	
	* At least 1 unlicensed in market
	bys market_all_expanded: gen unlicensed_s0_1_m = 1 if unlicensed_s0_m>=1
	replace unlicensed_s0_1_m = 0 if mi(unlicensed_s0_1_m)
	gen unlicensed_s0_1_m_t = unlicensed_s0_1_m*t
	lab var unlicensed_s0_1_m "At Least 1 Unlicensed HF in Market at Randomization"
	lab var unlicensed_s0_1_m_t "At Least 1 Unlicensed HF in Market at Randomization x T"
	
	foreach x in unlicensed_s0 unlicensed_noexp_s0 unlicensed_s0_all unlicensed_noexp_s0_all {
	local label : var label `x'
	lab var `x'_t "`label' x T"	
	}		
	
********************************************************************************
** Part 4: Construct variables for heterogeneity analysis
********************************************************************************
	
	* Replacing 0 for the missings and adding a dummy for the missings
	gen unlicensed_s0_missing_d = 0 if private==1 & s2==1
	replace unlicensed_s0_missing_d = 1 if mi(unlicensed_s0) & private==1 & s2==1
	
	gen unlicensed_s0_missing = unlicensed_s0 & private==1 & s2==1
	replace unlicensed_s0_missing = 0 if mi(unlicensed_s0) & private==1 & s2==1
	gen unlicensed_s0_missing_t = unlicensed_s0_missing*t
	gen unlicensed_s0_missing_d_t = unlicensed_s0_missing_d*t	
	
	
********************************************************************************
** Part 5: Construct entry (new) and enter-exit variables for analysis
********************************************************************************
/*******************************************************************************
Notes: Entry equals 1 if the facility is listed for the first time at the 
endline and started operations after randomization. We triangulate data to 
verify that the facility was not listed before. Multiple sources of data are 
used to construct to this variable including admin records from licensing, 
listing of different rounds (baseline, randomization, and endline), and manual 
inputs from a field team verification exercise to collect information from 
facility phone calls and web searches on dates of operation.     
********************************************************************************/

* New (Open after Randomization) and Active at Endline
gen new_end = 1 if active_s0==0 & inactive==0
replace new_end = 0 if mi(new_end) & inactive==0
lab var new_end "New (Open after Randomization) and Active at Endline"

* Generate dummy var for new HFs that opened in 2017 or later

	* Step 1. Combine available start year data 
	gen new_year = 1 if startyear>=2017 // facility self-reported data available
	replace new_year = 0 if startyear<=2016 
	replace new_year = . if inlist(startyear,.,.d)
	replace new_year = 1 if mi(startyear) & startyear_m=="2017 and after"  // manual inputs from field team verification exercise if missing data
	replace new_year = 0 if mi(startyear) & startyear_m=="2016 and before" // manual inputs from field team verification exercise if missing data
	lab var new_year "New (Opened in 2017 or After)"
	
	* Step 2. Flag and replace with zero if facility is listed in other study sources before 2017
	gen before2017_studysources = 1 if s0==1 | bl_consent!=. | (lr2016==1 & private==1) // Listed before 2017 in other sources
	replace new_year = 0 if before2017_studysources==1 // set to 0 if was previously listed in other sources
	replace new_year = 1 if mi(new_year) & s2==1 // set new if listed in s1 or s2 and in no previous lists
	
* Grouped var for estimated startyear based on multiple data sources
gen new_year_group = 1 if new_year==1
replace new_year_group = 2 if new_year==0 & startyear>=2015 
replace new_year_group = 3 if mi(new_year_group) & new_year==0 & startyear<2015
lab def new_year_group 1 "2017+" 2 "2015+" 3 "Before 2015", modify
lab val new_year_group new_year_group
lab var new_year_group "Estimated start year (Grouped)"	

ren new_year_group startyear_group
gen startyear_group_det 		= 1 if startyear_group==1
replace startyear_group_det 	= 2 if startyear_group==2
replace startyear_group_det  	= 3 if startyear_group==3 & startyear>=2010 & startyear<=2014
replace startyear_group_det  	= 4 if startyear_group==3 & startyear>=2005 & startyear<=2009
replace startyear_group_det  	= 5 if startyear_group==3 & startyear<2005

lab def startyear_group_det 1 "2017+" 2 "2015-2016" 3 "2010-2014" 4 "2005-2009" 5 "Before 2005", modify
lab val startyear_group_det startyear_group_det

lab def startyear_group 1 "2017+" 2 "2015-2016" 3 "Before 2015"
lab val startyear_group startyear_group

* Enter-exit status from baseline to endline data collection
gen enter_exit = 1 if active_bl==1 & active==1
replace enter_exit = 2 if active_bl!=1 & active==1
replace enter_exit = 3 if active_bl==1 & active!=1
lab def enter_exit 1 "Continuing" 2 "Enter (New)" 3 "Exit (Inactive)", modify
lab val enter_exit enter_exit
lab var enter_exit "HF Baseline-Endline Enter and Exit Status"

* Stable-unstable status (where stable = in operation for 3+ years)
gen stable = 1 if startyear<=2015 & new_end==0
replace stable = 0 if mi(stable) & new_end!=.
replace stable = 2 if private==0
replace stable = . if active!=1
gen stable_bl = 1 if startyear<=2012 & new_end==0
replace stable_bl = 0 if mi(stable_bl) & new_end!=.
replace stable_bl = 2 if private==0
replace stable_bl = . if active_bl!=1
lab def stable 1 "Private stable" 0 "Private unstable" 2 "Public"
lab val stable stable
lab val stable_bl stable	
			
********************************************************************************
** Part 6: Construct market-level variables
********************************************************************************
foreach x in inactive new_end {
by market_all_expanded, sort: egen `x'_m=total(`x'), missing
local label : var label `x'
lab var `x'_m  "`label' - Market"	
} 	

** The 5 singleton markets that disappeared did not registered any HF 5-km around so we are replacing the market-level new with zero
** This was done with the neighbor matching algorithm
replace new_end_m =0 if (market_all_expanded == 31 | market_all_expanded == 138 | market_all_expanded == 167 | market_all_expanded == 205 | market_all_expanded == 216)
	
********************************************************************************
** Part 7: Export
********************************************************************************

	* Order
	order hfid expired_* unlicensed_* formalit* lr* new* startyear_grou* enter_exit stable stable_bl inactive_m new_end_m
	keep hfid expired_* unlicensed_* formalit* lr* new* startyear_grou* enter_exit stable stable_bl inactive_m new_end_m
	
	* Save
	save "${licenses}", replace					

	
		

	
		
		
		

		
		

		
		
