/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare NHIF outpatient claims data for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Import and match claims data to study facilities
			Part 2: Construct outpatient reimbursement variables for analysis
			Part 3: Export 		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo nhifdata 	"${dt_adm}/nhif_claims.xlsx"
	
	* Output 
	glo nhif		"${dt_end_fin}/nhif_claims.dta"

********************************************************************************
** Part 1: Import and match claims data to study facilities
********************************************************************************
use "${pro}", clear

	* Tempfile by county
	forval i=1/3 {
	preserve
	keep if county==`i' & s2==1
	replace hfname = upper(hfname)
	keep hfid hfname county private bl_consent fl_consent
	* Soundex 	
	gen soundex = soundex(hfname)
	tempfile nhif_`i'
	save `nhif_`i''
	restore		
	}
			
	* NHIF data
	*--------------
	import excel using "${nhifdata}", first clear 
	drop if hfname_nhif==""
	drop if flag==1 // specialized services or another county
	foreach x in 16 17 18 19 20 all {
	gen fy`x'=1 if nhif_outp_fy`x'!=.
	lab var fy`x' "FY`x'"
	}
	lab var fyall "Any FY"
	fsum fy16 fy17 fy18 fy19 fy20 fyall, u
	tempfile nhif
	save `nhif'
	* Kakamega
		keep if county==1
		* Soundex 	
		gen soundex = soundex(hfname_nhif)
		* Merge
		merge m:m soundex using `nhif_1', keep(1 3) nogen
		* Keep the match with lowest Levenshtein distance
		strdist hfname_nhif hfname, gen(dist)
		sort id soundex dist
		bys id soundex: gen n = _n
		* Manual matches
		drop if id==15 & hfid!=15961
		drop if id==36 & hfid!=16762
		replace hfid=15820 if id==7
		replace hfid=500018 if id==25
		replace hfid=18161 if id==31
		replace hfid=16027 if id==85
		replace hfid=15888 if id==89
		replace hfid=20077 if id==92
		replace hfid=16030 if id==99
		replace hfid=15915 if id==93
		replace hfid=500004 if id==16
		replace hfid=900914 if id==32
		replace hfid=15844 if id==95
		replace hfid=16037 if id==22
		replace hfid=16010 if id==11
		replace hfid=555595 if id==71
		replace hfid=15914 if id==49
		replace hfid=16115 if id==60
		replace hfid=17409 if id==17409
		* Match
		duplicates drop id, force	
		tempfile match_1
		save `match_1'
	* Kilifi
		use `nhif', clear
		keep if county==2
		* Soundex 	
		gen soundex = soundex(hfname_nhif)
		* Merge
		merge m:m soundex using `nhif_2', keep(1 3) nogen
		* Keep the match with lowest Levenshtein distance
		strdist hfname_nhif hfname, gen(dist)
		sort id soundex dist
		bys id soundex: gen n = _n
		* Manual matches
		replace hfid=. if id==293
		replace hfid=11897 if id==405
		replace hfid=11845 if id==274
		replace hfid=11293 if id==278
		replace hfid=900946 if id==328
		replace hfid=11891 if id==366
		replace hfid=11912 if id==373
		replace hfid=800055 if id==378
		replace hfid=17689 if id==400
		replace hfid=20342 if id==330
		replace hfid=21787 if id==361
		replace hfid=19019 if id==343
		replace hfid=901286 if id==365
		replace hfid=11244 if id==265
		* Match
		duplicates drop id, force
		tempfile match_2
		save `match_2'
	* Meru
		use `nhif', clear
		keep if county==3
		* Soundex 	
		gen soundex = soundex(hfname_nhif)
		* Merge
		merge m:m soundex using `nhif_3', keep(1 3) nogen
		* Keep the match with lowest Levenshtein distance
		strdist hfname_nhif hfname, gen(dist)
		sort id soundex dist
		bys id soundex: gen n = _n
		* Manual matches
		replace hfid=555586 if id==110
		replace hfid=. if inlist(id,158,159,160,176,181)
		replace hfid=12266 if id==145
		replace hfid=19192 if id==166
		replace hfid=12666 if id==207
		replace hfid=12816 if id==251
		replace hfid=901068 if id==249
		replace hfid=12743 if id==241
		* Match
		duplicates drop id, force
		tempfile match_3
		save `match_3'		
		
		* Append
		*--------------		
		use `match_1', clear
		append using `match_2'
		append using `match_3'
		* Check issues
		duplicates tag hfid, gen(tag)
		* br county id hfname_nhif hfid hfname if hfid==. 
		* Expand to s2
		keep if hfid!=.
		tempfile all
		save `all'
		use "${pro}", clear
		keep hfid hfname county private s2 bl_consent fl_consent
		merge 1:1 hfid using `all', keep(1 3) nogen	
		
********************************************************************************
** Part 2: Construct variables for analysis
********************************************************************************
	* NHIF outpatient claims
	gen nhif_outp = 1 if nhif_outp_fy19!=. // FY19 if endline
	replace nhif_outp = 0 if mi(nhif_outp) & fl_consent==1
	lab var nhif_outp "NHIF Outpatient Reimbursements (2018-2019)"
	gen nhif_outp_bl = 1 if nhif_outp_fy16!=. // FY16 if baseline
	replace nhif_outp_bl = 0 if mi(nhif_outp_bl) & bl_consent==1
	lab var nhif_outp_bl "NHIF Outpatient Reimbursements (2015-2016)"
	* NHIF outpatient claims per month
	gen nhif_outp_mo = nhif_outp_fy19/12
	lab var nhif_outp_mo "NHIF Outpatient Reimbursements per Month (2018-2019) (KES)"
	gen nhif_outp_mo_bl = nhif_outp_fy16/12
	lab var nhif_outp_mo_bl "NHIF Outpatient Reimbursements per Month (2015-2016) (KES)"
	foreach x in nhif_outp nhif_outp_mo nhif_outp_fy16 nhif_outp_fy17 nhif_outp_fy18 nhif_outp_fy19 nhif_outp_fy20 nhif_outp_fyall  {
	replace `x'=0 if mi(`x') & s2==1 & fl_consent==1
	replace `x'=. if fl_consent!=1
	}	
	foreach x in nhif_outp_bl nhif_outp_mo_bl {
	replace `x'=0 if mi(`x') & bl_consent==1
	replace `x'=. if bl_consent!=1
	}			
		
	* Order and label
	*-------------------		
	order hfid hfname county private nhif_outp nhif_outp_bl nhif_outp_mo nhif_outp_mo_bl nhif_* id n hfname_nhif dist soundex
	keep hfid hfname county private nhif_outp nhif_outp_bl nhif_outp_mo nhif_outp_mo_bl nhif_* id n hfname_nhif dist soundex
	lab var county "County"
	lab var hfname_nhif "Facility Name in NHIF List"
	lab var nhif_outp_fy16 "NHIF Outpatient Reimbursements (2015-2016) (KES)"
	lab var nhif_outp_fy17 "NHIF Outpatient Reimbursements (2016-2017) (KES)"
	lab var nhif_outp_fy18 "NHIF Outpatient Reimbursements (2017-2018) (KES)"
	lab var nhif_outp_fy19 "NHIF Outpatient Reimbursements (2018-2019) (KES)"
	lab var nhif_outp_fy20 "NHIF Outpatient Reimbursements (2019-2020) (KES)"
	lab var nhif_outp_fyall "NHIF Outpatient Reimbursements (All Years 2015-2020) (KES)"
	lab var id "NHIF ID (generated)"
	lab var n "NHIF Match Counter"
	lab var dist "NHIF Match Levenshtein Distance"
	lab var soundex "NHIF Soundex"
	
********************************************************************************
** Part 3: Export
********************************************************************************
save "${nhif}", replace

	

	
	
	
	
