/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare OOP variables and sampling weights for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Combine baseline and endline OOP vars at patient level
			Part 2: Correct outliers
			Part 3: Construct patient sampling weights 
			Part 4: Construct facility- and market-level variables
			Part 5: Construct variables for heterogeneity analysis
			Part 6: Export
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo pro			"${dt_mast}/profile_end.dta"
glo pe_bl 		"${dt_bl_clean}/pe_bl.dta"
glo pe_end 		"${dt_end_clean}/pe_end.dta"
glo outp 		"${dt_end_fin}/outpatients_for_analysis.dta"
glo lic 		"${dt_end_fin}/new_licenses_for_analysis.dta"			

* Output 
glo oop_p 		"${dt_end_fin}/oop_for_analysis.dta"	
glo oop_hf 		"${dt_end_fin}/oop_hf_for_analysis.dta"	

********************************************************************************
** Part 1: Combine baseline and endline vars for analysis
********************************************************************************

* Baseline 
use "${pe_bl}", clear
ren i1 oop_all_bl 
ren i2 oop_exam_bl
gen bl_end=1
keep hfid key oop_* bl_end 
tempfile pe_b
save `pe_b'

* Endline
use "${pe_end}", clear
ren i1 oop_all 
ren i2 oop_exam
gen bl_end=2
keep hfid key oop_* bl_end 

* Combine
append using `pe_b'
loc pro level private t market_all_expanded strata_expanded bl_consent fl_consent s0 s1 s2 level*
merge m:1 hfid using "${pro}", keepus(`pro') keep(1 3) nogen
merge m:1 hfid using "${outp}", keepus(weight weight_m weight_bl weight_bl_m) keep(1 3) nogen
	
********************************************************************************
** Part 2: Outliers
********************************************************************************

* IQR // outlier = 1 if IQR >= 1000 & not more than 1 obs > 3x the min
foreach x in oop_all oop_all_bl {
bys hfid: egen `x'_iqr = iqr(`x')
bys hfid: egen `x'_min = min(`x')
bys hfid: egen `x'_max = max(`x')
bys hfid: egen `x'_mode = mode(`x')
}
foreach x in oop_all oop_all_bl {
gen `x'_iqr_flag = `x'_max/`x'_iqr
}
* Lower bound 
foreach x in oop_all oop_all_bl {
replace `x' = .o if `x' < 5 & `x'!=. & `x'!=.d & `x'!=0 
}
* Outlier = 1 if IQR >= 1000 & not more than 1 obs > 3x the min	
foreach x in oop_all {
replace `x' = .o if hfid == 18700 & oop_exam == 5000 // 
replace `x' = .o if hfid == 510140 & oop_exam == 1700	
}				
foreach x in oop_all_bl {
replace `x' = .o if hfid == 11829 & oop_all_bl == 5000 
replace `x' = .o if hfid == 16607 & oop_all_bl == 12000
replace `x' = .o if hfid == 17887 & oop_all_bl == 9400
}	
foreach x in oop_all_bl {
replace `x' = .o if hfid == 15844 & oop_exam_bl == 12500
replace `x' = .o if hfid == 11402 & oop_exam_bl == 1500
replace `x' = .o if hfid == 18937 & oop_exam_bl == 1400
}	
	
********************************************************************************
** Part 3: Construct patient sampling weights 
********************************************************************************

* Number of surveys per facility
bys hfid bl_end: gen counter_pe=_n
bys hfid bl_end: egen counter_pe_max=max(counter_pe)
gen pe = counter_pe_max if bl_end==2
gen pe_bl = counter_pe_max if bl_end==1
lab var pe "Total number of PEs completed per HF at Endline" 
lab var pe_bl "Total number of PEs completed per HF at Baseline"
	
* Weights	
* Sampling weights
gen weight_p = weight / pe
lab var weight_p "HF Patient Sampling Weight - Outpatient-based"
gen weight_p_bl = weight_bl / pe_bl
lab var weight_p_bl "HF Patient Sampling Weight at Baseline - Outpatient-based"	
* Market-level
gen weight_prop_m = weight / weight_m 
gen weight_prop_m_bl = weight_bl / weight_bl_m
	
********************************************************************************
** Part 4: Construct facility- and market-level variables
********************************************************************************
	
* Market-level means
winsor2 oop_all, suffix(_win) cuts(0 99) by(level private) // winsorize		
* Unweighted
foreach x in oop_all_bl oop_all oop_all_win {
bysort market_all_expanded: egen `x'_m = mean(`x')
local label : var label `x'
lab var `x'_m  "`label' - Market"
}
* Weighted		
bysort market_all_expanded: gen counter_m = _n
foreach x in oop_all oop_all_bl {
by hfid, sort: egen `x'_hf=mean(`x')
}	
gen weight1 = weight_m/weight
preserve
collapse (mean) oop_all_hf [aweight=weight1], by(market_all_expanded)
ren oop_all_hf oop_all_m_w
lab var oop_all_m_w "Out-of-pocket Expenses (KES) with Weights at the Market Level"
tempfile oop_all_m_w
save `oop_all_m_w'
restore
merge m:1 market_all_expanded using `oop_all_m_w', nogen
keep hfid key oop* weight_p weight_p_bl bl_end 

* Facility level vars
preserve
keep hfid oop_all_hf oop_all_bl_hf oop_all_m oop_all_bl_m weight_p weight_p*
bys hfid: gen counter_hf = _n
keep if counter_hf==1
foreach x in oop_all oop_all_bl {
ren `x'_hf `x'
}
lab var oop_all "Out-of-pocket Expenses (USD PPP)"
lab var oop_all_bl "Out-of-pocket Expenses (USD PPP) at Baseline"

merge 1:1 hfid using "${pro}", keepus(t private level fl_consent market_all_expanded) nogen
merge 1:1 hfid using "${lic}", keepus(unlicensed_s0) nogen
merge 1:1 hfid using "${outp}", keepus(outp_as_jan weight_bl weight_bl_m) nogen
 
********************************************************************************
** Part 5: Construct variables for analysis
********************************************************************************	

* Replacing 0 for the missings at baseline and adding a dummy for the missings
gen 	oop_all_bl_missing_d 	= 0
replace oop_all_bl_missing_d 	= 1 if mi(oop_all_bl)
gen 	oop_all_bl_missing 		= oop_all_bl
replace oop_all_bl_missing 		= 0 if mi(oop_all_bl)	
lab var oop_all_bl_missing_d 	"Dummy for facilites with missing baseline score"
lab var oop_all_bl_missing 		"OOP at baseline with missings imputed as 0"

foreach x in oop_all oop_all_bl {
	clonevar `x'_kes=`x'
	}
	replace oop_all 		= oop_all/50.963
	replace oop_all_bl 		= oop_all_bl/43.926
	lab var oop_all 		"Out-of-pocket Expenses (USD PPP)"
	lab var oop_all_bl 		"Out-of-pocket Expenses (USD PPP) at Baseline"	
	lab var oop_all_kes 	"Out-of-pocket Expenses (KES)"
	lab var oop_all_bl_kes 	"Out-of-pocket Expenses (KES) at Baseline"	
	
* Generate oupatient groups for imputation
gen 	outp_group = 1 if outp_as_jan <1
replace outp_group = 2 if outp_as_jan >=1 & outp_as_jan<2
replace outp_group = 3 if outp_as_jan >=2 & outp_as_jan<4
replace outp_group = 4 if outp_as_jan >=4
replace outp_group = . if outp_as_jan ==.
lab var outp_group "Daily outpatients (grouped)"

* Variables for imputations: impute by the mean within similar categories: by level, ownership, treatment, outpatient groups, and unlicensed at randomization
bysort 	t private level unlicensed_s0 outp_group : egen oop_av = mean(oop_all)
gen 	oop_all_imp = oop_all
replace oop_all_imp = oop_av if mi(oop_all_imp) & fl_consent==1
lab var oop_av 		"Mean OOP by treatment, ownership, level, unlicensed, and outpatients group"
lab var oop_all_imp "OOP (with imputation by oop_av)"		

* market weighted means
gen weight_bl_m_prop = weight_bl/weight_bl_m	

* OOP market mean (weighted)
gen oop_all_bl_m_w_in = oop_all_bl*weight_bl_m_prop
bys market_all_expanded: egen oop_all_bl_m_w = sum(oop_all_bl_m_w_in)

* Missing Indicator method for market level
foreach x in oop_all_bl_m oop_all_bl_m_w {
	gen 	`x'_mi_d 	= 0
	replace `x'_mi_d 	= 1 if mi(`x')
	gen 	`x'_mi 		= `x'
	replace `x'_mi 		= 0 if mi(`x')
	}

drop level fl_consent private t unlicensed_s0 outp_as_jan
tempfile hf
save `hf'
restore	
lab var oop_all_bl "Out-of-pocket Expenses (KES) at Baseline"
lab var oop_exam_bl "Out-of-pocket Expenses - Exam Services (KES) at Baseline"
lab var oop_all_bl "Out-of-pocket Expenses (KES) at Baseline"
lab var oop_exam_bl "Out-of-pocket Expenses - Exam Services (KES) at Baseline"

foreach x in oop_all oop_all_bl {
	clonevar `x'_kes=`x'
	}
	replace oop_all 		= oop_all/50.963
	replace oop_all_bl 		= oop_all_bl/43.926	
	lab var oop_all 		"Out-of-pocket Expenses (USD PPP)"
	lab var oop_all_bl 		"Out-of-pocket Expenses (USD PPP) at Baseline"	
	lab var oop_all_kes 	"Out-of-pocket Expenses (KES)"
	lab var oop_all_bl_kes 	"Out-of-pocket Expenses (KES) at Baseline"	
	
********************************************************************************
** Part 6: Export 
********************************************************************************
save "$oop_p", replace // patient level
use `hf', clear 
save "$oop_hf", replace	// facility level		
							
								
							
