/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare outpatient variables and outpatient-based weights for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Combine demand variables across rounds
			Part 2: Construct market-level variables
			Part 3: Construct outpatient-based weights for analysis
			Part 4: Construct variables for heterogeneity analysis
			Part 5: Export
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo demand		"${dt_end_const}/outp_av_end.dta"		
	glo demand_bl   "${dt_bl_const}/outp_av_bl.dta"

	* Output 
	glo outp 		"${dt_end_fin}/outpatients_for_analysis.dta"

********************************************************************************
** Part 1: Combine demand variables across rounds
********************************************************************************
	use "${pro}", clear
	loc pro hfid level private market_all_expanded inactiv*
	keep `pro'
	merge 1:1 hfid using "${demand}", keepus(outp_as_jan) nogen keep(1 3)
	merge 1:1 hfid using "${demand_bl}", keepus(outp_as_jan_bl) nogen keep(1 3)
		
********************************************************************************
** Part 2: Construct market-level variables
********************************************************************************	
	winsor2 outp_as_jan, suffix(_win) cuts(0 99) by(level private) // Winsorize
	glo outcomes outp_as_jan outp_as_jan_bl outp_as_jan_win
	foreach x of global outcomes  {
	by market_all_expanded, sort: egen `x'_m=total(`x'), missing
	local label : var label `x'
	lab var `x'_m  "`label' - Market"	
	} 

********************************************************************************
** Part 3: Construct outpatient-based weights for analysis
********************************************************************************	
	* Probability weights based on the average daily outpatients 
	gen weight = outp_as_jan
	replace weight = 0.2 if weight==0 & inactive==0 // Replace the weight by 0.2 when missing. We assume this way that they may have 3-4 patients a month but the week we collected data they didn't have any as they reported.		
	lab var weight "HF Weights - Outpatient-based" 
	by market_all_expanded, sort: egen outpatients_market=total(outp_as_jan)
	* Baseline
	gen weight_bl = outp_as_jan_bl 
	replace weight_bl = 0.2 if weight_bl==0 & inactive_bl==0		
	lab var weight_bl "HF Weights at Baseline - Outpatient-based" 
	* Market-level 
	gen weight_m = outpatients_market 
	lab var weight_m "Market Weights - Outpatient-based"
	drop outpatients_market
	by market_all_expanded, sort: egen outpatients_market_bl=total(outp_as_jan_bl)
	gen weight_bl_m = outpatients_market_bl
	lab var weight_bl_m "Market Weights at Baseline - Outpatient-based"	
	drop outpatients_market_bl
	keep hfid outp_as_jan outp_as_jan_bl outp_as_jan_m outp_as_jan_bl_m outp_as_jan_win outp_as_jan_win_m weight weight_m weight_bl weight_bl_m	
	
********************************************************************************
** Part 4: Construct variables for heterogeneity analysis
********************************************************************************	
	* Replacing 0 for the missings at baseline and adding a dummy for the missings
	gen 	outp_as_jan_bl_missing_d = 0
	replace outp_as_jan_bl_missing_d = 1 if mi(outp_as_jan_bl)
	gen 	outp_as_jan_bl_missing = outp_as_jan_bl
	replace outp_as_jan_bl_missing = 0 if mi(outp_as_jan_bl)	
	lab var outp_as_jan_bl_missing_d "Dummy for facilites with missing baseline score"
	lab var outp_as_jan_bl_missing "Daily outpatients at baseline with missings imputed as 0"
	
	*Missing Indicator method for markets
	foreach x in outp_as_jan_bl_m {
		gen 	`x'_mi_d 	= 0
		replace `x'_mi_d 	= 1 if mi(`x')
		gen 	`x'_mi 		= `x'
		replace `x'_mi 		= 0 if mi(`x')
		}
	
********************************************************************************
** Part 5: Export 
********************************************************************************				
save "$outp", replace


	
	
	
	
	
	
