/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare staff variables for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Combine all sources of staff data
			Part 2: Construct total and clinical staff ratio variables
			Part 3: Construct monthly take-home pay as proxy for staff costs
			Part 4: Export
			
DATE: 		May 2019
UPDATED: 	May 2021		
AUTHOR(S):	Amy Dolinger (adolinger@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	glo pro			"${dt_mast}/profile_end.dta"
	glo roster 		"${dt_end_const}/staff_roster_end.dta"
	glo qps1 		"${dt_end_clean}/qps1_end.dta"
	glo helper		"${dt_end_clean}/qps1_helper_end.dta"
	glo outp 		"${dt_end_fin}/outpatients_for_analysis.dta"
	glo oop_hf 		"${dt_end_fin}/oop_hf_for_analysis.dta"	
	glo nhif 		"${dt_end_fin}/nhif_claims.dta"				
		
	* Output 
	glo staff 		"${dt_end_fin}/profits_staff_for_analysis.dta"				

********************************************************************************
** Part 1: Combine all sources of staff data
********************************************************************************
	use "${roster}", clear
	keep hfid staff_total_roster qual_r noqual_r cost_staff_avg_q cost_staff_avg_nq
	duplicates drop hfid, force
	tempfile roster
	save `roster'
	use "${helper}"
	ren a5 hfid
	tempfile helper
	save `helper'
	use "${qps1}", clear
	lab var hfid "Facility ID"
	merge 1:1 hfid using `helper', nogen	
	merge 1:1 hfid using `roster', nogen

********************************************************************************
** Part 2: Prepare days per month
********************************************************************************
merge 1:1 hfid using "${outp}", keepus(outp_as_j* weigh*) nogen
merge 1:1 hfid using "${oop_hf}", keepus(oop_a*) nogen
merge 1:1 hfid using "${nhif}", keepus(nhif*) nogen
merge 1:1 hfid using "${pro}", keepus(daysopen s2 fl_consent bl_consent) nogen

	* January days per month
	local days_c	     = 31
	local days_c_6dw     = 27 //assuming not working on sundays
	local days_c_5dw     = 23 //assuming not working on saturdays and sundays
	local days_c_4dw     = 19 //assuming not working on Mondays, saturdays and sundays	
	local days_c_3dw	 = 15
	local days_c_2dw	 = 10
	local days_c_1dw	 = 5
	
	gen daysopen_jan = `days_c' if daysopen == 7
	forvalues i = 1/6 {
	replace daysopen_jan = `days_c_`i'dw' if daysopen == `i'
	}
	replace daysopen_jan = 24 if daysopen == . & outp_as_jan!=.
	lab var daysopen_jan "Days Open in January"
	*keep hfid s2 daysopen* outp_as_jan* oop_all* cost* nhif* fl_consent bl_consent
			
********************************************************************************
** Part 3: Construct revenues from outpatients
********************************************************************************
* In order to estimate revenues from outpatients we need: (average outpatients per month) x (average oop_all per outpatient)
* Final variable is an estimate per HF, per month of revenues, you can call it rev_outpat_month						
	* Per month
	gen rev_outp_mo = outp_as_jan * daysopen_jan * oop_all
	gen rev_outp_mo_bl = outp_as_jan_bl * daysopen_jan * oop_all_bl	
	* Checks
	gen revenues = outp_as_jan*24*oop_all
	gen revenues2 = outp_as_jan*(daysopen*4)*oop_all
	* Total incl. NHIF
	gen rev_outp_mo_total = rev_outp_mo+nhif_outp_mo
	gen rev_outp_mo_total_bl = rev_outp_mo_bl+nhif_outp_mo_bl
	* Patients per month
	gen outp_mo = outp_as_jan * daysopen_jan
	gen outp_mo_bl = outp_as_jan_bl * daysopen_jan
	* Total per patient
	gen rev_outp_pp = rev_outp_mo_total/outp_mo
	gen rev_outp_pp_bl = rev_outp_mo_total_bl/outp_mo_bl
	* Restrict to baseline/follow-up consent only
	foreach x in rev_outp_mo rev_outp_mo_total outp_mo rev_outp_pp {
	replace `x' = . if fl_consent!=1
	}
	foreach x in rev_outp_mo_bl rev_outp_mo_total_bl outp_mo_bl rev_outp_pp_bl {
	replace `x' = . if bl_consent!=1
	}			
	* Labels
	lab var rev_outp_mo "Revenue from Outpatients per Month (KES)"
	lab var rev_outp_mo_bl "Revenue from Outpatients per Month at Baseline (KES)"	
	lab var revenues "Revenue check 1"
	lab var revenues2 "Revenue check 2"	
	lab var rev_outp_mo_total "Revenue from Outpatients per Month (2018-2019) (KES)"
	lab var rev_outp_mo_total_bl "Revenue from Outpatients per Month (2015-2016) (KES)"
	lab var outp_mo "Outpatients per Month"
	lab var outp_mo_bl "Outpatients per Month at Baseline"	
	lab var rev_outp_pp "Revenue from Outpatients per Patient (2018-2019) (KES)"
	lab var rev_outp_pp_bl "Revenue from Outpatients per Patient (2015-2016) (KES)"
	
********************************************************************************
** Part 4: Construct total and clinical staff ratio variables
********************************************************************************
	* Total staff
	gen staff_total = c3_s // first priority values are totals from QPS1 helper, which has verification by cadre
	destring staff_total, replace
	replace staff_total = staff_total_roster if mi(staff_total) // next priority is roster
	destring staff_total, replace
	* Qualified staff (healthcare workers)
	egen qual_qps1 = rowtotal(c3_1 c3_2 c3_20 c3_6 c3_5 c3_7 c3_16 c3_17 c3_18 c3_8 c3_9 c3_10 c3_11 c3_12 c3_13 c3_14 c3_21)
	egen noqual_qps1 = rowtotal(c3_3 c3_4 c3_15 c3_19)	
	gen qual = qual_qps1
	replace qual = qual_r if mi(qual) | qual==0
	gen noqual = noqual_qps1
	replace noqual = noqual_r if (mi(noqual) | noqual==0) & hfid!=510890
	gen sum = qual+noqual
	* ISSUE: 25 HFs (~2%) don't have staff roster info equal to total staff reported (all <18 staff, so roster should be total staff)
	* For now, in these cases, keep reported staff total and use % qual/no qual to estimate
	gen qual_perc = qual/sum
	gen noqual_perc = noqual/sum
	gen qual_total = staff_total*qual_perc
	gen noqual_total = staff_total*noqual_perc
	gen sum_total = qual_total+noqual_total
	replace sum_total = round(sum_total,1)
	assert sum_total==staff_total // assert that estimated qual+noqual = staff total
	* Ratio of healthcare workers to total staff
	gen qual_per = qual_total/staff_total
	* Healthcare workers per outpatient
	gen qual_p = qual_total/outp_mo
	* Labels
	lab var staff_total "Total Staff"
	lab var qual "Number of qualified staff"
	lab var noqual "Number of non-qualified staff"
	lab var qual_per "Ratio of healthcare workers to total staff"	
	lab var qual_p "Healthcare workers per patient"
	
********************************************************************************
** Part 5: Construct monthly take-home pay as proxy for staff costs
********************************************************************************	
	* Monthly staff cost
	gen cost_staff_total_q = (cost_staff_avg_q*qual_total) 
	gen cost_staff_total_nq = (cost_staff_avg_nq*noqual_total)
	gen cost_staff_total_mo = cost_staff_total_q+cost_staff_total_nq
	* Monthly staff cost per outpatient
	gen cost_staff_mo_p = cost_staff_total_mo/outp_mo
	* Monthly staff cost per staff
	gen cost_staff_mo_staff = cost_staff_total_mo/staff_total
	* Labels
	lab var cost_staff_total_mo "Monthly staff cost (KES)"	
	lab var cost_staff_mo_p "Staff cost per outpatient (KES)" 
	lab var cost_staff_mo_staff "Monthly staff cost per staff (KES)"
	loc main staff_total cost_staff_total_mo cost_staff_mo_staff cost_staff_mo_p qual qual_per qual_p	
	order hfid `main'	
	
********************************************************************************
** Part 6: Construct profit variables 
********************************************************************************
	gen  profits_proxy_mo = rev_outp_mo - cost_staff_total_mo
	label var profits_proxy_mo "Profits Proxy per Month (KES)"	
	
	loc main staff_total cost_staff_total_mo cost_staff_mo_staff cost_staff_mo_p qual qual_per qual_p	
	keep hfid `main' outp_mo* rev_* profits_* nhif_outp*
	
********************************************************************************
** Part 7: Export
********************************************************************************
save "${staff}", replace	


		

	
	
	
