/*******************************************************************************	

Project:  		KePSIE - Kenya
Created on:  	September 11, 2019

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 *This do file constructs the dataset ML_cpredict.dta to be used as input dataset for the R prediction algorithm which tries to predict which facilities in the control group might have closed if they had been in the treatment group
				  The dataset only includes variables that are not exogenous to treatment, ie which are the same at baseline and endline.

CONTENT:		Part 0 - Create globals for directories and files
				Part 1 - Merge all inputs dataset keeping only variables of which can be used for the prediction 
				Part 2 - Imputing variables with missing to increase sample size as much as possible
				Part 3: Replacing missings by zero for level, jhic score and outpatient and adding a dummy for whether the facility has a missing observation
INPUTS:     	*

OUTPUTS:		*  

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	*Inputs
	glo input			"${dt_mast}/profile_end.dta"
	glo licenses 		"${dt_end_fin}/new_licenses_for_analysis.dta"
	glo insp 			"${dt_end_fin}/inspections_fadeout.dta"
	glo closures 		"${dt_end_fin}/closures_for_analysis.dta"
	glo market_e 		"${dt_end_fin}/markets_density.dta"
	glo ngofbo 			"${dt_end_fin}/profile_add.dta"
	glo outp 			"${dt_end_fin}/outpatients_for_analysis.dta"
	glo jhic			"${dt_end_fin}/jhic_for_analysis.dta"
	
	* Outputs
	glo ML_data 		"${dt_end_fin}/ml_cpredict_vf.dta"
	
********************************************************************************
	** Part 1: Merge all inputs dataset keeping only variables of which can be used for the prediction 
********************************************************************************

use "$input", clear

*Adding the other required variables
merge 1:1 hfid using "$outp", assert(3) nogen keepusing(outp_as_jan outp_as_jan_bl)
merge 1:1 hfid using "$jhic", assert(3) nogen keepusing(jhic_all jhic_all_bl)
merge 1:1 hfid using "$licenses", assert(3) nogen  
merge 1:1 hfid using "${insp}"	, keepusing(inspections) keep(1 3) nogen
merge 1:1 hfid using "$closures", keep(1 3) nogen keepusing(close_enforce) 
merge 1:1 hfid using "${market_e}", keepus(maintown_km market_e_km) keep(1 3) nogen
merge 1:1 hfid using "${ngofbo}", keep(1 3) nogen	

****************Keep only private facilities open at randomization on which we are going to run the prediction 	
keep if !mi(t)

*Keep only private facilities
keep if private == 1 

*Keep facilities that were active at randomization
keep if active_s0 == 1

*Construct a variable for HFs with expired licenses
gen unlicensed_exp = (unlicensed_s0 != unlicensed_noexp_s0) if !mi(unlicensed_s0) & !mi(unlicensed_noexp_s0)

*********************************************************************************************
	** Part 2: Imputing variables with missing to increase sample size as much as possible
*********************************************************************************************

*Separate treatment facilities which received treatment from treatment facilities which did not, ie at least one visit
*We will train the algo only on facilities that received the treatment but predict on control and treatment facilities which did not receive the treatment
replace t = 0 if (t == 1 & inspections == 0) | (t == 1 & mi(inspections))

*Replace private type with others as otherwise if it was NGO or FBO we would have the info
replace private_type = 3 if mi(private_type) //25 observations changed, 3% of HFs

*Keeping only the variables we need for the models
local var_list hfid t close_enforce unlicensed_noexp_s0 unlicensed_s0 private_type level_2 level_3 market_e_km maintown_km startyear_group_det county marketsize_rand_expanded_group outp_as_jan_bl unlicensed_exp

foreach var of varlist `var_list' {
disp "`var'"
count if mi(`var') 
}

*For now, 0 missing as everything has been imputed
drop if mi(startyear_group_det) //0
drop if mi(private_type) //0


*********************************************************************************************
	** Part 3: Replacing missings by zero for level, jhic score and outpatient and adding a dummy for whether the facility has a missing observation
*********************************************************************************************

*To deal with the missings in level (facilities which were active only at randomization, not baseline and not endline), we replace levels with 0 and create a dummy for wheter level value is missing. 
gen missing_level = 0 
replace missing_level = 1 if mi(level_2) | mi(level_3)
replace level_2 = 0 if mi(level_2)
replace level_3 = 0 if mi(level_3) 

*Do the same to deal with the missings in jhic score at baseline 
gen missing_jhic_bl = 0 
replace missing_jhic_bl = 1 if mi(jhic_all_bl)  
gen jhic_all_bl_nomissings = jhic_all_bl
replace jhic_all_bl_nomissings = 0 if mi(jhic_all_bl)

*Do the same to deal with the missings in outpatients at baseline 
gen missing_outp_as_jan_bl = 0 
replace missing_outp_as_jan_bl = 1 if mi(outp_as_jan_bl)  
gen outp_as_jan_bl_nomissings = outp_as_jan_bl
replace outp_as_jan_bl_nomissings = 0 if mi(outp_as_jan_bl)

foreach var of varlist `var_list' {
disp "`var'"
count if mi(`var')
}

keep `var_list' missing_level jhic_all_bl_nomissings missing_jhic_bl missing_outp_as_jan_bl outp_as_jan_bl_nomissings


save "$ML_data", replace

******************************************End of do file********************************************
