/*******************************************************************************	
Project:  			KePSIE	
********************************************************************************			

THIS DO FILE: 	Constructs variables for analysis of the Staff Roster data

CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Construct 
						 1.1 - Staff vars	
						 1.2 - Take-home pay vars		
						 1.3 - Days worked vars
						 1.4 - Final pay vars
				Part 2 - Save outputs
						 2.1 - Order
						 2.2 - Save

INPUTS: 		* Clean data
				"${KePSIE_DB}/Endline/DataSets/Intermediate/QPS1_HCWroster_clean_pii_end.dta"
				* Job groups
				"${KePSIE_DB}/Endline/DataSets/Other_inputs/JobGroups_Salaries.dta"

OUTPUTS:     	* Dropbox files: Latest versions created by person in charge
					* Staff Roster
					"${KePSIE_DB}/Endline/DataSets/Intermediate/Staff_Roster_end.dta"
				
				* Local files: Produced when running this code and saved in your local GitHub folder
					* Staff Roster
					"${end_dt}/Endline/DataSets/Intermediate/Staff_Roster_end.dta"
					
		
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
	glo roster_clean 	"${dt_end_clean}/qps1_roster_end.dta"
	glo jobgroups 		"${dt_adm}/jobgroups_salaries.dta"
	
	* Output files
	glo staffroster 	"${dt_end_const}/staff_roster_end.dta"
	 
********************************************************************************
	** Part 1: Construct
********************************************************************************
	use "${roster_clean}", clear
	
	*For levels, merging 4 and 5 which are similar
	gen level4_5 = level
	replace level4_5 = 4 if level == 5	
	
	*---------------------------------------------------------------*
	* 1.1 Staff vars
	*---------------------------------------------------------------*
	* Total staff in roster
		
		* Staff including owner
		gen staff_total_roster = h3a
		replace staff_total_roster = h2b if mi(staff_total_roster)
		lab var staff_total_roster "Total Staff in Roster"
		
		* Staff not including owner
		gen staff_total_roster_no_owner = h2a
		replace staff_total_roster_no_owner = h2b if mi(staff_total_roster_no_owner)
		lab var staff_total_roster_no_owner "Total Staff Not Including Owner in Roster"	

	* Owner details			
					
		* Owner works in HF
		gen owner_works = h1
		lab def owner_works 1 "Yes" 0 "No"
		lab val owner_works owner_works
		lab var owner_works "Owner Works in HF"						
			
		* HFs with only owner
		gen owner_run = 1 if staff_total_roster == 1
		replace owner_run = 0 if staff_total_roster!=1
		lab var owner_run "Only Owner/In-Charge Works at HF"
					
		* Assign staff member as owner (first staff entry in survey)		
		gen owner = 1 if owner_works == 1 & staffid == 1 
		replace owner = 0 if (owner_works!=1 & owner_works!=.) & staffid!=1
		lab var owner "Staff is Owner of the HF"

	* Staff details	
		
		* Cadre var
		gen cadre = 1 if h5_1 == 1
		forvalues i = 2/21 {
		replace cadre = `i' if h5_`i' == 1
			}
			label def cadre 1 "Clinical officer" ///
							2 "Community health worker" ///
							3 "Dentist" ///
							4 "Doctor or medical officer" ///
							5 "Hospital administrator/executive director/superintendent" ///
							6 "Intern/Student" ///
							7 "Lab technologist/lab technician" ///
							8 "Laboratory scientist" ///
							9 "Midwife" ///
							10 "Nurse (BSc)" ///
							11 "Nurse (Registered Community Health Nurses (KRHCN))" ///
							12 "Nurse (Enrolled Community Health Nurses (EHCN))" ///
							13 "Nurse Aides" ///
							14 "Nutritionist" ///
							15 "Pharmacist/pharmacy technologist/dispenser" ///
							16 "Public health officer (PHO)" ///
							17 "Specialists (e.g., haemotologists, radiographers)" ///
							18 "Therapist/counselor" ///
							19 "Other clinical staff" ///
							20 "Other administrative staff" ///
							21 "Other support staff" ///	
									
							lab val cadre cadre
							lab var cadre "Staff Job Title"
										
		* Cadre var2: limit the number of categories to have bigger brackets for winsorization
		gen 	 cadre2 = 1 if inlist(cadre,1,3,4,8,14,16,17,18)
		replace  cadre2 = 2 if inlist(cadre,2,6,7,9,10,11,12,13,15,19)
		replace  cadre2 = 3 if inlist(cadre,5)
		replace  cadre2 = 4 if inlist(cadre,20)
		replace  cadre2 = 5 if inlist(cadre,21)
		
		* Qualified staff 
		gen qual_roster = 1 if h8_1==1
		replace qual_roster = 0 if h8_1==0
		lab var qual_roster "Qualified Staff"
		gen noqual_roster = 1 if h8_1==0
		replace noqual_roster = 0 if h8_1==1
		lab var noqual_roster "Non-qualified Staff"
		bys hfid: egen qual_r = sum(qual_roster)
		bys hfid: egen noqual_r = sum(noqual_roster)
		lab var qual_r "Number of qualified staff per HF (Staff roster)"
		lab var noqual_r "Number of non-qualified staff per HF (Staff roster)"
						
	*---------------------------------------------------------------*
	* 1.2 Take-home pay vars
	*---------------------------------------------------------------*
		* Job group data for public HFs 
		gen jobgroup = h14b					
		lab val jobgroup jobgroup
		merge m:1 jobgroup using "${jobgroups}"
		drop if _merge==2
		drop jobgroup_vallab _merge
		gen bs_m = (bs_l + bs_u)/2 if jobgroup!=.
		lab var jobgroup "Staff Job Group"
		lab var bs_l "Basic Salary (Lower Bound)"
		lab var bs_u "Basic Salary (Upper Bound)"
		lab var bs_m "Basic Salary (Midpoint)"											
													
		* Pay range midpoints (when staff gives KES pay range)
		gen midpoint = (h14_min + h14_max)/2
		lab var midpoint "Pay Range Midpoint"
			
		* Combine pay data available		
		gen pay = h14a
		*If given a range, take middle of range
		replace pay = midpoint if mi(pay) & h13 == 3
		*If given a pay group, take middle of pay group
		replace pay = bs_m if mi(pay) & h13 == 2
		lab var pay "Take-home Pay Reported (Monthly)"
		replace pay = . if pay==0 & midpoint==.		
			
		gen pay_type = 1 if h14a!=. | h14_min!=.
		replace pay_type = 2 if h14b!=. & mi(pay_type)
		replace pay_type = . if mi(pay_type)
		lab def pay_type 1 "Kenyan shillings" 2 "Job Group" 3 "Not available"
		lab val pay_type pay_type
		lab var pay_type "Take-home Pay Data Type"	
				
		gen pay_c = 1 if pay!=.
		replace pay_c = 2 if pay==. & pay_type==2
		replace pay_c = . if pay==. & pay_type==3
		lab var pay_c "Salary Data Available (Point or Range)"						

	*---------------------------------------------------------------*
	* 1.3 Days worked vars
	*---------------------------------------------------------------*						
		* Days per month
		gen days_per_month = h12
		lab var days_per_month "Number of Days Worked per Month"
		
		* Days per week
		gen days_per_week = h12*52.18/12
		lab var days_per_week "Number of Days Worked per Week"
			
		* Avg days per week
		egen days_per_week_avg = mean(days_per_week)
		lab var days_per_week_avg "Avg Number of Days Worked per Week"
					
	*---------------------------------------------------------------*
	* 1.4 Final pay vars
	*---------------------------------------------------------------*	
		* Average take-home pay by cadre, public/private, and level
		gen pay_day = pay / h12
		egen plc = concat(private level4_5 cadre2)			
		
		preserve
			collapse (mean) pay pay_day, by(private level4_5 cadre2)
			ren pay pay_plc
			lab var pay_plc "Average Pay by Cadre, Private, and Level (Monthly)"
			ren pay_day pay_day_plc
			lab var pay_day_plc "Average Pay by Cadre, Private, and Level (Daily)"
			egen plc = concat(private level4_5 cadre2)
				tempfile c
				save `c'
				restore			
			
				merge m:1 plc using `c', nogen
				replace pay_plc 	= . if cadre2==.	
				replace pay_day_plc = . if cadre2==.	
		
		* Complete pay vars with imputations based on means		
				
			* All pay data including imputed
			gen pay_i = pay	
			replace pay_i = pay_day_plc * h12 if mi(pay)
			lab var pay_i "Take-home Monthly Pay with Imputed Values based on Private/Level/Cadre Means"
			tab cadre level4_5 if private==1, sum(pay)	

			*Winsorized pay at 95 within each plc bracket
			winsor2 pay_i, s(win) by(plc) cuts(5 95)
			
			* Average take-home pay by qualified vs. non-qualified staff
			bys hfid: egen cost_staff_avg_q_in = mean(pay_i) if qual_roster==1
			bys hfid: egen cost_staff_avg_nq_in = mean(pay_i) if qual_roster==0
			bys hfid: egen cost_staff_avg_q = mean(cost_staff_avg_q_in)
			bys hfid: egen cost_staff_avg_nq = mean(cost_staff_avg_nq_in)
			replace cost_staff_avg_nq = 0 if mi(cost_staff_avg_nq) & qual_roster!=.
			replace cost_staff_avg_q = 0 if mi(cost_staff_avg_q) & qual_roster!=.
			lab var cost_staff_avg_q "Average monthly take-home pay for qualified staff"
			lab var cost_staff_avg_nq "Average monthly take-home pay for non-qualified staff"
											
********************************************************************************
	** Part 2: Order and Save
********************************************************************************
	*---------------------------------------------------------------*
	* 2.1 Order
	*---------------------------------------------------------------*
	global profile 	hfid hfname county subcounty private level level4_5 latitude longitude 
	global survey 	h1 h2* h3a h3* staffid h4 h5* h6 h7 h8* h9 h10* h11 h12* h13 h14* h16 key
	global staff 	cadre staff_total_roster staff_total_roster_no_owner staff_c owner* 
	global pay		days_* pay pay_i pay_type pay_c pay_plc midpoint jobgroup bs_m bs_l bs_u qual_* noqual_* cost_staff_avg_q cost_staff_avg_nq
		
		order $profile $survey $staff $pay
		keep $profile $survey $staff $pay
		
	*---------------------------------------------------------------*
	* 2.2 Save
	*---------------------------------------------------------------*
	if	c(stata_version)>=14 {
		saveold	"${staffroster}", v(13) replace
			}
			else {
			save "${staffroster}", replace
					}

						

									

	
