/*******************************************************************************	
*		Project:
*		KePSIE IE
		Author : Thomas Escande (tescande@worldbank.org)
*		Created on:		2019-06-24
********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file creates the wealth Index (using PCA) for patient exit at endline. We first compute the wealth index for our sample only following the Kenya Demographics and Health Survey (DHS) methodology.
				It gives us the most variation within our sample. Then we compute the wealth index in our sample using the coefficients used from the DHS sample that is representative at the national and county levels.
				This allows us to compare people in our sample to the representative sample of the population in the country.
				
				
** INPUTS:     	DHS 2014 dataset
**# Bookmark #1
				Patient exit dataset (Endline/DataSets/Intermediate/PE_clean_nopii.dta) where patient are asked these assets questions


** OUTLINE: 	Part 0: Initiate and import the database
				Part 1: Create Wealth Index for patient exit survey using our KEPSIE patient exit sample
				Part 2: Create Wealth Index for patient using PCA coefficient from DHS sample on same variables
				Part 3: Saving dataset
				
** OUTPUTS:    Dataset with the different wealth indices (Endline/DataSets/Intermediate/PE_wealth_index.dta)
				
*******************************************************************************/



********************************************************************************

*** # Part 0: Initiate and import the database

********************************************************************************
	clear all
	set more off

	*Setting up the globals 
	*Input
	glo pe_clean 			"${dt_end_clean}/pe_end.dta"
	global dhs 				"${dt_adm}/dhs_svy.dta"

	*Output
	glo wealth_end 			"${dt_end_const}/wealth_index_end.dta"
	
********************************************************************************

*** # Part 1: Create Wealth Index for patient exit

********************************************************************************
	use "${pe_clean}", clear

	gen electric 		= j3a
	gen water 			= j3b
	gen clock 			= j3c
	gen radio 			= j3d
	gen television 		= j3e
	gen mobile 			= j3f
	gen landline 		= j3g
	gen fridge 			= j3h
	gen solar 			= j3i
	gen cycle 			= j3j
	gen boat 			= j3k
	gen car 			= j3l
	gen cart 			= j3n
	gen bike 			= j3m
	gen farm_animals 	= j3r
	gen memsleep 		= j1/j3x 	if j3x>0           //Numbers of members in household / Number of rooms used for sleeping 
		replace memsleep	 = j1 	if j3x==0 
	gen num_cows 		= j3s
	gen num_horse 		= j3t
	gen num_goat 		= j3u
	gen num_sheep 		= j3v
	gen num_chicken 	= j3w

	gen toil_shared 	= 0
		replace toil_shared 	= 1 if j3z == 1 | j3z == 2
			
	gen kitchen_separate = j3y //Has a lot of missing in the equivalent DHS table 

*Replacing by 0 for the number of animals when household does not have any animal
	foreach var in num_cows num_horse num_goat num_sheep num_chicken {
		replace `var' = 0 if farm_animals == 0 
	}

	foreach var of varlist electric water clock radio television mobile landline fridge solar cycle boat car cart bike farm_animals memsleep num_cows num_horse num_goat num_sheep num_chicken toil_shared  { 
		gen wealth_`var'=`var'  
		gen dhs_`var'=`var'
	}

	ds wealth_*	
	loc wealth_assets `r(varlist)'

	*Generate the index using PCA : maximum variation across the sample
	sum `wealth_assets'

	pca `wealth_assets', mineigen (1) means
	predict kepsie_wealth, score   
	lab var kepsie_wealth "Wealth Index for KePSIE"

	*Put in quintiles
	pctile cutoff_kepsie = kepsie_wealth, nq(5)
	xtile  wealth_ranking_kepsie = kepsie_wealth, nq(5)
	label define ranking 1 "Lowest" 2 "Second" 3 "Third" 4 "Fourth" 5 "Highest"
	label values wealth_ranking_kepsie ranking
	
	*Save temporarily
	tempfile kepsie_wealth_index
	save `kepsie_wealth_index', replace 

	
********************************************************************************

*** # Part 2: Create Wealth Index for patient using PCA coefficient from DHS sample on same variables

********************************************************************************
	
	use "${dhs}", clear
	label define ranking 1 "Lowest" 2 "Second" 3 "Third" 4 "Fourth" 5 "Highest"

	*Variable Constructions:

	gen electric = hv206
	gen water = hv201_t
	gen clock = hv243b
	gen radio = hv207
	gen television = hv208
	gen mobile = hv243a
	gen landline = hv221
	gen fridge = hv209
	gen solar = sh110g
	gen cycle = hv210
	gen boat = hv243d
	gen car = hv212
	gen cart = hv243c
	gen bike = hv211 
	gen farm_animals = hv246
	gen num_cows = hv246b
	gen num_horse = hv246c
	gen num_goat = hv246d
	gen num_sheep = hv246e
	gen num_chicken = hv246f

 *Generating memsleep, the number of household members per rooms used for sleeping (or how many people sleep in each room on average) 
 * We use here the "de jure" members, i.e. usual residents.  
	gen memsleep 			= hv012/hv216 if hv216>0
		replace memsleep	= hv012 if hv216 == 0 //Only 27 cases, assume that they have one room where they sleep so that we don't have missing. 

	gen toil_shared = hv225 /*Not taking it into account as 16% of missing and small correlation with the rest*/


 //Enter the list of variables for PCA
	foreach var of varlist electric water clock radio television mobile landline fridge solar cycle boat car cart bike farm_animals memsleep num_cows num_horse num_goat num_sheep num_chicken  {     //Enter the list of variables for PCA
		gen dhs_`var' = `var'
	}

	ds dhs_*
	loc dhs_assets `r(varlist)'

	*Generate the index
	sum `dhs_assets'
	
	pca `dhs_assets', mineigen (1) means
	predict dhs_wealth, score
	lab var dhs_wealth "Wealth Index for DHS"


	*Checking correlation with the variables we have (hv271 is the wealth Index part of DHS with all available variables
	reg hv271_s dhs_wealth
	reg hv271_s `dhs_assets'
	

	pctile cutoff_dhs_origin = hv271_s, nq(5)
	global dhs1_origin = cutoff_dhs_origin[1]
	global dhs2_origin = cutoff_dhs_origin[2]
	global dhs3_origin = cutoff_dhs_origin[3]
	global dhs4_origin = cutoff_dhs_origin[4]
	
	xtile  wealth_ranking_dhs_origin = hv271_s, nq(5)
	label values wealth_ranking_dhs_origin ranking
	label var wealth_ranking_dhs_origin "Wealth Quintiles (DHS all variables)"

	pctile cutoff_dhs = dhs_wealth, nq(5)
	global dhs1 = cutoff_dhs[1]
	global dhs2 = cutoff_dhs[2]
	global dhs3 = cutoff_dhs[3]
	global dhs4 = cutoff_dhs[4]
	xtile  wealth_ranking_dhs = dhs_wealth, nq(5)
	label values wealth_ranking_dhs ranking
	label var wealth_ranking_dhs     "Wealth Quintiles (DHS subset variables)"
	
	
	*Comparing ranking obtained 
	tab  wealth_ranking_dhs_origin wealth_ranking_dhs, col

	*At the county level, for Kakamega (shcounty == 71), Kilifi (shcounty == 13) and Meru (shcounty == 33) - the three counties we have in our study: 
	*Looking at average patient wealth in each of our county
	foreach county in 71 13 33 {
		pctile cutoff_dhs_`county' = dhs_wealth if shcounty == `county', nq(5)
		global dhs1_`county' = cutoff_dhs_`county'[1]
		global dhs2_`county' = cutoff_dhs_`county'[2]
		global dhs3_`county' = cutoff_dhs_`county'[3]
		global dhs4_`county' = cutoff_dhs_`county'[4]
	}
	

	*Getting the DHS coefficients to then use on the patient exit sample
	pca `dhs_assets', mineigen (1) means //To be able to use the correct predict right after

	tempfile dhs_wealth_index
	save `dhs_wealth_index', replace 

*Applying the model to data from KePSIE
	use `kepsie_wealth_index'
	
	predict dhs_wealth_kepsie, score //Wealth score for KePSIE using model created with DHS
	lab var dhs_wealth_kepsie "Wealth Index for KePSIE based on DHS classification"

	gen 	county_dhs = 71 	if county == 1
		replace county_dhs = 13 if county == 2
		replace county_dhs = 33 if county == 3
		
*Getting the number of patients in our sample who are in each of the national wealth quintiles computed previously.
*This is possible because we compute the index the same way with the same coefficients so they are actually comparable
	gen 	wealth_ranking_kepsie_dhs = 1 if  dhs_wealth_kepsie < $dhs1 & !mi(dhs_wealth_kepsie)
		replace wealth_ranking_kepsie_dhs = 2 if  dhs_wealth_kepsie >= $dhs1 & dhs_wealth_kepsie < $dhs2 & !mi(dhs_wealth_kepsie)
		replace wealth_ranking_kepsie_dhs = 3 if  dhs_wealth_kepsie >= $dhs2 & dhs_wealth_kepsie < $dhs3 & !mi(dhs_wealth_kepsie)
		replace wealth_ranking_kepsie_dhs = 4 if  dhs_wealth_kepsie >= $dhs3 & dhs_wealth_kepsie < $dhs4 & !mi(dhs_wealth_kepsie)
		replace wealth_ranking_kepsie_dhs = 5 if  dhs_wealth_kepsie >= $dhs4  & !mi(dhs_wealth_kepsie)
	label 	values wealth_ranking_kepsie_dhs ranking
	label var wealth_ranking_kepsie_dhs "Ranking of KePSIE sample in DHS Quintiles"

	foreach county in 71 13 33 {
		gen 	wealth_r_kepsie_dhs_`county' = 1 if  dhs_wealth_kepsie < ${dhs1_`county'}  & !mi(dhs_wealth_kepsie) & county_dhs == `county'
			replace wealth_r_kepsie_dhs_`county' = 2 if  dhs_wealth_kepsie >= ${dhs1_`county'} & dhs_wealth_kepsie < ${dhs2_`county'} & !mi(dhs_wealth_kepsie) & county_dhs == `county'
			replace wealth_r_kepsie_dhs_`county' = 3 if  dhs_wealth_kepsie >= ${dhs2_`county'} & dhs_wealth_kepsie < ${dhs3_`county'} & !mi(dhs_wealth_kepsie) & county_dhs == `county'
			replace wealth_r_kepsie_dhs_`county' = 4 if  dhs_wealth_kepsie >= ${dhs3_`county'} & dhs_wealth_kepsie < ${dhs4_`county'} & !mi(dhs_wealth_kepsie) & county_dhs == `county'
			replace wealth_r_kepsie_dhs_`county' = 5 if  dhs_wealth_kepsie >= ${dhs4_`county'} & !mi(dhs_wealth_kepsie) & county_dhs == `county'
		label 	values wealth_r_kepsie_dhs_`county' ranking
		label var wealth_r_kepsie_dhs_`county' "Ranking of KePSIE sample in DHS Quintiles for county `county'"
	}

********************************************************************************

*** # Part 3: Saving dataset

********************************************************************************	

keep hfid key wealth* county_dhs cutoff* dhs* kepsie*


		save "${wealth_end}", replace

******************************End of do file***********************************

