/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Prepare sample variables for analysis

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Prepare randomization vars
			Part 2: Prepare sample vars (e.g., s0, s1, s2)
			Part 3: Prepare market vars (e.g., market_size, market_all_expanded)
			Part 4: Prepare treatment vars (e.g., t, t1_t2)
			Part 5: Keep sample for analysis only
			Part 6: Export 
			
DATE: 		Jan 2019
UPDATED: 	May 2021	
AUTHOR(S):	Rebecca De Guttry, Amy Dolinger (adolinger@worldbank.org),
			and Guadalupe Bedoya (gbedoya@worldbank.org)	
REVISION:  		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input 
glo rand_r0		"${dt_mast}/randomization.dta"
glo rand_r1		"${dt_mast}/treatment_expanded.dta"
glo markets_r0	"${dt_mast}/markets_implementation.dta"
glo pro_end 	"${dt_mast}/listing_end.dta"
		
* Output 
glo pro_sample	"${dt_mast}/profile_end.dta"				
				
********************************************************************************
** Part 1: Randomization vars
********************************************************************************
	
* Randomization (r0)
use "${rand_r0}", clear	// randomization HFs
encode county, gen(county_r0) // standardize main vars  
lab val county_r0 county_r0
ren market_all market_all_r0 
ren marketsize_2 marketsize_group
lab var market_all_r0 "Market ID (unique across all counties, from r0)"
lab var marketsize "Market Size at Randomization"
lab var marketsize_group "Market Size Group at Randomization"	
lab var strata "Market Strata (county marketsize_group)" 
lab var county_r0 "County (from r0)"
keep hfid market_all_r0 marketsize marketsize_group strata county_r0 // keep only main vars
tempfile r_r0
save `r_r0'	
use "${markets_r0}", clear // randomization markets			
keep hfid marketcenter // keep only main vars
tempfile m_r0
save `m_r0'
			
* Randomization expanded (r1)
use "${rand_r1}", clear
keep hfid market_all_expanded // keep only main vars
replace hfid = 555000+hfid if hfid<1000 // AD: update from Shivang's IDs to final study IDs	(see technical notes)
tempfile r_r1
save `r_r1'		
				
********************************************************************************
** Part 2: Prepare sample vars
********************************************************************************
use "${pro_end}", clear // start with profile inventory from endline 
merge 1:1 hfid using `r_r0', keep(1 3) nogen	
merge 1:1 hfid using `m_r0', keep(1 3) nogen
merge 1:1 hfid using `r_r1', keep(1 3) nogen	

* Sample vars (s0, s1, and s2)
* Generate in_r2 (using v2 randomization allocation method)
gen in_r2 = in_r2_v2 if in_r2_v2 == 1
replace in_r2 = in_r2_v1 if mi(in_r2)
lab def in_r2 1 "Yes" 0 "No"
lab val in_r2 in_r2
lab var in_r2 "In extended randomization with market imputation (version 2) for new HFs"

* Check closed permanently for ever active
gen closed_perm = 1 if in_r0==1 & f_status_det==2 // denominator
gen closed_perm_inactive = 1 if closed_perm!=. & (f_status_bl!=1 & f_status_imp!=1 & f_status_fl!=1) // numerator
replace closed_perm_inactive = 0 if mi(closed_perm_inactive) & closed_perm!=.

* Manual revision to final status for HFs that were active and became specialized services
replace f_status_det = 8 if inlist(hfid, 16622, 800058, 16618, 11347, 900009, 18298, 16598, 901602, 500082, 901206, 900575, 900940) // manual data correction - active then specialized services
lab drop f_status_det
lab define f_status_det 1 "Active" 2 "Permanently closed" 3 "Duplicate" ///
						4 "Specialized services" 5 "Relocated" 6 "Closed medium-term" ///
						7 "Cannot be located" 8 "Active then specialized services"
						lab val f_status_det f_status_det
						replace f_status_det_bl = 3 if hfid==901138 // recode duplicate ID to match with endline
						replace f_status_bl = 0 if hfid==901138 // same as above
						replace bl_consent = . if hfid==901138 
						replace f_status_bl = 1 if hfid==500119
						replace f_status_det_bl = 1 if hfid==500119
						replace bl_consent = 1 if hfid==500119 
						
* In randomization (r0) clean var (no duplicates and specialized services)
drop in_r0_clean
clonevar in_r0_clean = in_r0
replace in_r0_clean = 0 if inlist(f_status_det,3,4)
lab var in_r0_clean "In market randomization (no duplicates and specialized services)"
lab val in_r0_clean yesno	

		
* Final sample vars and labels	
clonevar s0 = in_r0_clean
clonevar s1 = in_r1
clonevar s2 = in_r2
lab var s0 "Sample as per Randomization"
lab var s1 "Sample as per Randomization extended in July 2017 for Implementation"
lab var s2 "Sample as per Endline"
lab var f_status "Active as of endline HF status"		
lab var f_status_bl "Active as of baseline HF status"

********************************************************************************
** Part 3: Prepare market and strata IDs
********************************************************************************
		
	* Market ID 
	*-----------------------------
	* Market ID expanded
	replace market_all_expanded = market_all_imp_v2 if km_to_nid_v2!=.	
	lab var market_all_expanded "Market ID (unique across all counties, with imputation v2)"

	* Expanded
	by market_all_expanded, sort: egen strata_expanded=max(strata)
	lab var strata_expanded "Market Strata as per Randomization - Expanded"
		
********************************************************************************
** Part 4: Prepare treatment vars
********************************************************************************
	* Treatment vars
	*----------------------------	
	clonevar treatment_expanded = treatment_imp_v2 // treatment expanded
	lab var treatment_expanded "Imputed treatment (based on r2_v2 assignment to markets)"
	gen t=1 if (treatment_expanded==1 | treatment_expanded==2)
	replace t=0 if treatment_expanded==0
	lab var t "All Inspections"
	gen t1=1 if treatment_expanded==1
	replace t1=0 if treatment_expanded==0
	lab var t1 "Intensive Inspections (T1)"
	gen t2=1 if treatment_expanded==2
	replace t2=0 if treatment_expanded==0
	lab var t2 "Inspections with Scorecards (T2)"
	gen t1_2=1 if treatment_expanded==1
	replace t1_2=0 if treatment_expanded==0 | treatment_expanded==2
	lab var t1_2 "Inspections (T1)"
	gen t2_2=1 if treatment_expanded==2
	replace t2_2=0 if treatment_expanded==0 | treatment_expanded==1
	lab var t2_2 "Inspections with Scorecards (T2)"
	gen t2_t1=1 if treatment_expanded==2
	replace t2_t1=0 if treatment_expanded==1
	lab var t2_t1 "Inspections with Scorecards vs. Inspections"
	tempfile all
	save `all'	
	
********************************************************************************
** Part 5: Keep sample only
********************************************************************************
	* Keep only the 1,555 in our KePSIE sample that we are interested in for analysis
	keep if in_r2_v1 == 1 | bl_consent==1			
	* These should not be in any of the samples (specialized services, etc)
	drop if inlist(f_status_det, 3, 4)
	* Exclude and replace treatment_imp_v2 var = . for HFs that are beyond 5-6 km from nearest market center		
	gen exclude = 1 if hfid == 516020 | hfid == 516030 | hfid == 516050
	lab def exclude 1 "Excluded from analysis: in allocation but not within 5-6 km of a randomized market"
	lab val exclude exclude	
	drop if exclude == 1
	* Replace treatment to missing 
	replace treatment_expanded = . if exclude==1	
	foreach x in s0 s1 s2 {
	replace `x' = 0 if `x'!=1
	}		
	keep if s2==1 // keep only final sample
	
********************************************************************************
** Part 6: Prepare market size variables
********************************************************************************
	* Market size expanded
	by market_all_expanded f_status, sort: gen counter_endline=_n 
	replace counter_endline=. if f_status==0
	lab var counter_endline "HF Counter per Market at Endline (Only Active)"		
	by market_all_expanded, sort: egen marketsize_s2 = max(counter_endline) 
	lab var marketsize_s2 "Market Size at Endline (Only Active)"
	gen marketsize_s2_2 = marketsize_s2
	replace marketsize_s2_2 = 0 if (market_all_expanded == 31 | market_all_expanded == 138 | market_all_expanded == 167 | market_all_expanded == 205 | market_all_expanded == 216)
	lab var marketsize_s2_2 "Market Size at Endline (Including 5 Dissapeared Singleton Markets)"
	drop marketsize_s2
	ren marketsize_s2_2 marketsize_expanded
	lab var marketsize_expanded "Market Size at Endline"
	
	bys market_all_expanded: egen marketsize_clean = count(hfid) if s0==1
	ren marketsize marketsize_r0 
	ren marketsize_clean marketsize
	
	* Market size var with value for endline HFs		
	preserve
	keep if market_all_expanded!=. & marketsize!=.
	bys market_all_expanded: gen counter_m=_n
	lab var counter_m "Market Counter"	
	keep if counter_m == 1
	ren marketsize marketsize_rand_expanded
	keep market_all_expanded marketsize_rand_expanded
	tempfile temp
	save `temp'
	restore
	merge m:1 market_all_expanded using `temp', keepusing(marketsize_rand_expanded) nogen
	label var marketsize_rand_expanded "Market Size (Continuous)"
	
	* Market size grouped
	foreach x in marketsize_expanded marketsize_rand_expanded {
	gen `x'_group=1 if `x'==1
	replace `x'_group=2 if `x'==2
	replace `x'_group=3 if `x'==3
	replace `x'_group=4 if `x'>=4 & `x'<=10
	replace `x'_group=5 if `x'>=11 & `x'!=.
	lab def `x'_group 1 "1 HF" 2 "2 HFs" 3 "3 HFs" 4 "4-10 HFs" 5 "11+ HFs", modify
	lab val `x'_group `x'_group
	}
	lab var marketsize_expanded_group "Market Size at Randomization (Grouped)"
	lab var marketsize_rand_expanded_group "Market Size (Grouped)"	
	
********************************************************************************
** Part 7: Interactions
********************************************************************************
	gen marketsize_rand_exp_t = marketsize_rand_expanded * t
	label var marketsize_rand_exp_t "Market Size * T"
	global marketsize_inter  marketsize_rand_expanded  marketsize_rand_exp_t 
	gen marketsize_t_private = marketsize_rand_expanded * t * private
	label var marketsize_t_private "Market Size * Private * T"
	glo treatments t t1 t2 t1_2 t2_2
	foreach t of global treatments {
	gen private_`t'=private*`t'
	lab var  private_`t' "Private HF x `t'"
	}	
	foreach t of global treatments {
	gen marketsize_group_`t'=marketsize_group*`t'
	lab var  marketsize_group_`t' "Market Size Group at Randomization x `t'"
	}	
	foreach t of global treatments {
	gen marketsize_`t'=marketsize*`t'
	lab var  marketsize_`t' "Market Size at Randomization x `t'"
	}					
	label var t "All Inspections (T)"
	lab var  private_t "Private HF x T"
	lab var  private_t1 "Private HF x T1"	
	lab var  private_t2 "Private HF x T2"		
	lab var  private_t1_2 "Private HF x T1"
	lab var  private_t2_2 "Private HF x T2"
	label var marketsize_group_t "Market Size Group at Randomization x T"
	label var marketsize_group_t1 "Market Size Group at Randomization x T1"
	label var marketsize_group_t2 "Market Size Group at Randomization x T2"
	label var marketsize_group_t1_2 "Market Size Group at Randomization x T1_2"
	label var marketsize_group_t2_2 "Market Size Group at Randomization x T2_2"
	label var marketsize_t "Market Size at Randomization x T"
	label var marketsize_t1 "Market Size at Randomization x T1"
	label var marketsize_t2 "Market Size at Randomization x T2"
	label var marketsize_t1_2 "Market Size at Randomization x T1_2"
	label var marketsize_t2_2 "Market Size at Randomization x T2_2"	
	
********************************************************************************
** Part 1: Construct inactivity
********************************************************************************
/*******************************************************************************
Notes: Inactive equals 1 if the facility is listed as permanently closed
(out of business), that is, was not found operating in the last round of 
data collection, or has changed their operations from full health facility 
services and only offer specialized services (e.g., standalone laboratories 
or pharmacies) and no longer provide general outpatient services.	
********************************************************************************/

* Active facilities
clonevar active=f_status // f_status is latest facility status at endline. See MasterData/Dofiles/Construct/profile.do for more details of f_status construction
clonevar active_bl=f_status_bl
lab var active "Active at Endline"
lab var active_bl "Active at Baseline"

* Inactive facilities
clonevar inactive=f_status
clonevar inactive_bl=f_status_bl 
recode inactive (1=0) (0=1)
recode inactive_bl (1=0) (0=1)
lab def inactive 1 "Inactive" 0 "Active", modify
lab val inactive inactive
lab val inactive_bl inactive
lab var inactive "Inactive at Endline"
lab var inactive_bl "Inactive at Baseline"

* Active at randomization
gen active_s0 = 1 if s0==1
replace active_s0 = 1 if mi(active_s0) & startyear <= 2016 & startyear!=.
replace active_s0 = 0 if mi(active_s0)
replace active_s0 = 1 if !mi(bl_consent)
lab var active_s0 "Active at Randomization"	
			
********************************************************************************
** Part 6: Save
********************************************************************************
save "$pro_sample", replace // sample only
	

		
		
		
